#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1 
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {} 
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; } 
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; } 
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr; 
  size_t sz0, sz1; 
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {} 
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T> 
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a < r && b < r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow; 
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && (((a ^ b) >= 0 && a > std::numeric_limits<T>::max() / b) || ((a ^ b) < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow; 
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _154,    std::shared_ptr< monty::ndarray< long long,1 > > _155,    int _156,    int _157,    int _158,    std::shared_ptr< monty::ndarray< long long,1 > > _159) { mosek::fusion::p_Sort::argTransposeSort(_154,_155,_156,_157,_158,_159); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _154,std::shared_ptr< monty::ndarray< long long,1 > > _155,int _156,int _157,int _158,std::shared_ptr< monty::ndarray< long long,1 > > _159){
  _checked_ptr_1<long long> _ptr__154(_154 ? _154->raw() : nullptr, _154 ? _154->size(0) : 0);
  _checked_ptr_1<long long> _ptr__155(_155 ? _155->raw() : nullptr, _155 ? _155->size(0) : 0);
  _checked_ptr_1<long long> _ptr__159(_159 ? _159->raw() : nullptr, _159 ? _159->size(0) : 0);
  int _6748 = (int)0;
  int _6749 = safe_add( safe_mul( _156,_158 ),(int)1 );
  for (int _160 = _6748; _160 < _6749; ++_160)
  {
    {
      _ptr__155[_160] = (int)0;
    }
  }
  int _6750 = (int)0;
  int _6751 = (int)((_159)->size(0));
  for (int _161 = _6750; _161 < _6751; ++_161)
  {
    {
      ++ _ptr__155[safe_add( safe_add( safe_mul( (_ptr__159[_ptr__154[_161]] / safe_mul( _157,_158 )),_158 ),(_ptr__159[_ptr__154[_161]] % _158) ),(int)1 )];
    }
  }
  int _6752 = (int)0;
  int _6753 = safe_mul( _156,_158 );
  for (int _162 = _6752; _162 < _6753; ++_162)
  {
    {
      _ptr__155[safe_add( _162,(int)1 )] = safe_add( _ptr__155[safe_add( _162,(int)1 )],_ptr__155[_162] );
    }
  }
  std::vector<long long> _6754;
  for (int _164 = (int)0, _6755 = (int)((_154)->size(0)); _164 < _6755 ; ++_164)
  {
    _6754.push_back(_ptr__154[_164]);
  }
  auto _6756 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6754.size()),_6754.begin(),_6754.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _163 = _6756;
  _checked_ptr_1<long long> _ptr__163(_163 ? _163->raw() : nullptr,_163 ? _163->size(0) : 0);
  long long _6757 = (long long)0;
  long long _6758 = (long long)((_159)->size(0));
  for (long long _165 = _6757; _165 < _6758; ++_165)
  {
    {
      long long _166 = safe_add( safe_mul( (_ptr__159[_ptr__163[_165]] / safe_mul( _157,_158 )),_158 ),(_ptr__159[_ptr__163[_165]] % _158) );
      _ptr__154[_ptr__155[_166]] = _ptr__163[_165];
      ++ _ptr__155[_166];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _167,    std::shared_ptr< monty::ndarray< long long,1 > > _168) { mosek::fusion::p_Sort::argsort(_167,_168); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _167,std::shared_ptr< monty::ndarray< long long,1 > > _168){
  _checked_ptr_1<long long> _ptr__167(_167 ? _167->raw() : nullptr, _167 ? _167->size(0) : 0);
  _checked_ptr_1<long long> _ptr__168(_168 ? _168->raw() : nullptr, _168 ? _168->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_167,_168,(long long)((int)0),(long long)((int)((_167)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _169,    std::shared_ptr< monty::ndarray< int,1 > > _170) { mosek::fusion::p_Sort::argsort(_169,_170); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< int,1 > > _170){
  _checked_ptr_1<long long> _ptr__169(_169 ? _169->raw() : nullptr, _169 ? _169->size(0) : 0);
  _checked_ptr_1<int> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_169,_170,(long long)((int)0),(long long)((int)((_169)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _171,    std::shared_ptr< monty::ndarray< long long,1 > > _172,    std::shared_ptr< monty::ndarray< long long,1 > > _173) { mosek::fusion::p_Sort::argsort(_171,_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< long long,1 > > _172,std::shared_ptr< monty::ndarray< long long,1 > > _173){
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  _checked_ptr_1<long long> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<long long> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_171,_172,_173,(long long)((int)0),(long long)((int)((_171)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< int,1 > > _175,    std::shared_ptr< monty::ndarray< int,1 > > _176) { mosek::fusion::p_Sort::argsort(_174,_175,_176); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< int,1 > > _175,std::shared_ptr< monty::ndarray< int,1 > > _176){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<int> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  _checked_ptr_1<int> _ptr__176(_176 ? _176->raw() : nullptr, _176 ? _176->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,(long long)((int)0),(long long)((int)((_174)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _177,    std::shared_ptr< monty::ndarray< long long,1 > > _178,    long long _179,    long long _180) { mosek::fusion::p_Sort::argsort(_177,_178,_179,_180); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _177,std::shared_ptr< monty::ndarray< long long,1 > > _178,long long _179,long long _180){
  _checked_ptr_1<long long> _ptr__177(_177 ? _177->raw() : nullptr, _177 ? _177->size(0) : 0);
  _checked_ptr_1<long long> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_177,_178,_179,_180,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _181,    std::shared_ptr< monty::ndarray< int,1 > > _182,    long long _183,    long long _184) { mosek::fusion::p_Sort::argsort(_181,_182,_183,_184); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _181,std::shared_ptr< monty::ndarray< int,1 > > _182,long long _183,long long _184){
  _checked_ptr_1<long long> _ptr__181(_181 ? _181->raw() : nullptr, _181 ? _181->size(0) : 0);
  _checked_ptr_1<int> _ptr__182(_182 ? _182->raw() : nullptr, _182 ? _182->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_181,_182,_183,_184,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _185,    std::shared_ptr< monty::ndarray< long long,1 > > _186,    std::shared_ptr< monty::ndarray< long long,1 > > _187,    long long _188,    long long _189) { mosek::fusion::p_Sort::argsort(_185,_186,_187,_188,_189); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _185,std::shared_ptr< monty::ndarray< long long,1 > > _186,std::shared_ptr< monty::ndarray< long long,1 > > _187,long long _188,long long _189){
  _checked_ptr_1<long long> _ptr__185(_185 ? _185->raw() : nullptr, _185 ? _185->size(0) : 0);
  _checked_ptr_1<long long> _ptr__186(_186 ? _186->raw() : nullptr, _186 ? _186->size(0) : 0);
  _checked_ptr_1<long long> _ptr__187(_187 ? _187->raw() : nullptr, _187 ? _187->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_185,_186,_187,_188,_189,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _190,    std::shared_ptr< monty::ndarray< int,1 > > _191,    std::shared_ptr< monty::ndarray< int,1 > > _192,    long long _193,    long long _194) { mosek::fusion::p_Sort::argsort(_190,_191,_192,_193,_194); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _190,std::shared_ptr< monty::ndarray< int,1 > > _191,std::shared_ptr< monty::ndarray< int,1 > > _192,long long _193,long long _194){
  _checked_ptr_1<long long> _ptr__190(_190 ? _190->raw() : nullptr, _190 ? _190->size(0) : 0);
  _checked_ptr_1<int> _ptr__191(_191 ? _191->raw() : nullptr, _191 ? _191->size(0) : 0);
  _checked_ptr_1<int> _ptr__192(_192 ? _192->raw() : nullptr, _192 ? _192->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_190,_191,_192,_193,_194,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _195,    std::shared_ptr< monty::ndarray< long long,1 > > _196,    long long _197,    long long _198,    bool _199) { mosek::fusion::p_Sort::argsort(_195,_196,_197,_198,_199); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _195,std::shared_ptr< monty::ndarray< long long,1 > > _196,long long _197,long long _198,bool _199){
  _checked_ptr_1<long long> _ptr__195(_195 ? _195->raw() : nullptr, _195 ? _195->size(0) : 0);
  _checked_ptr_1<long long> _ptr__196(_196 ? _196->raw() : nullptr, _196 ? _196->size(0) : 0);
  if (((!_199) || ((_198 - _197) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_195,_196,_197,_198);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_195,_196,_197,_198,_199)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _200 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__200(_200 ? _200->raw() : nullptr,_200 ? _200->size(0) : 0);
      int _201 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_195,_196,nullptr,_197,_198,_200);
      if (((_ptr__200[(int)1] - _ptr__200[(int)0]) < safe_mul( _201,(_198 - _197) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_195,_196,_197,_198,_ptr__200[(int)0],_ptr__200[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_195,_196,_197,_198);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _202,    std::shared_ptr< monty::ndarray< int,1 > > _203,    long long _204,    long long _205,    bool _206) { mosek::fusion::p_Sort::argsort(_202,_203,_204,_205,_206); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _202,std::shared_ptr< monty::ndarray< int,1 > > _203,long long _204,long long _205,bool _206){
  _checked_ptr_1<long long> _ptr__202(_202 ? _202->raw() : nullptr, _202 ? _202->size(0) : 0);
  _checked_ptr_1<int> _ptr__203(_203 ? _203->raw() : nullptr, _203 ? _203->size(0) : 0);
  if (((!_206) || ((_205 - _204) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_202,_203,_204,_205);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_202,_203,_204,_205,_206)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _207 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__207(_207 ? _207->raw() : nullptr,_207 ? _207->size(0) : 0);
      int _208 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_202,_203,nullptr,_204,_205,_207);
      if (((_ptr__207[(int)1] - _ptr__207[(int)0]) < safe_mul( _208,(_205 - _204) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_202,_203,_204,_205,_ptr__207[(int)0],_ptr__207[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_202,_203,_204,_205);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _209,    std::shared_ptr< monty::ndarray< long long,1 > > _210,    std::shared_ptr< monty::ndarray< long long,1 > > _211,    long long _212,    long long _213,    bool _214) { mosek::fusion::p_Sort::argsort(_209,_210,_211,_212,_213,_214); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _209,std::shared_ptr< monty::ndarray< long long,1 > > _210,std::shared_ptr< monty::ndarray< long long,1 > > _211,long long _212,long long _213,bool _214){
  _checked_ptr_1<long long> _ptr__209(_209 ? _209->raw() : nullptr, _209 ? _209->size(0) : 0);
  _checked_ptr_1<long long> _ptr__210(_210 ? _210->raw() : nullptr, _210 ? _210->size(0) : 0);
  _checked_ptr_1<long long> _ptr__211(_211 ? _211->raw() : nullptr, _211 ? _211->size(0) : 0);
  if (((!_214) || ((_213 - _212) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_209,_210,_211,_212,_213);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_209,_210,_211,_212,_213,_214)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _215 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__215(_215 ? _215->raw() : nullptr,_215 ? _215->size(0) : 0);
      int _216 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_209,_210,_211,_212,_213,_215);
      if ((((_ptr__215[(int)1] - _ptr__215[(int)0]) < safe_mul( _216,(_213 - _212) )) && ((_ptr__215[(int)3] - _ptr__215[(int)2]) < safe_mul( _216,(_213 - _212) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_209,_211,_212,_213,_ptr__215[(int)2],_ptr__215[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_209,_210,_212,_213,_ptr__215[(int)0],_ptr__215[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_209,_210,_211,_212,_213);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _217,    std::shared_ptr< monty::ndarray< int,1 > > _218,    std::shared_ptr< monty::ndarray< int,1 > > _219,    long long _220,    long long _221,    bool _222) { mosek::fusion::p_Sort::argsort(_217,_218,_219,_220,_221,_222); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _217,std::shared_ptr< monty::ndarray< int,1 > > _218,std::shared_ptr< monty::ndarray< int,1 > > _219,long long _220,long long _221,bool _222){
  _checked_ptr_1<long long> _ptr__217(_217 ? _217->raw() : nullptr, _217 ? _217->size(0) : 0);
  _checked_ptr_1<int> _ptr__218(_218 ? _218->raw() : nullptr, _218 ? _218->size(0) : 0);
  _checked_ptr_1<int> _ptr__219(_219 ? _219->raw() : nullptr, _219 ? _219->size(0) : 0);
  if (((!_222) || ((_221 - _220) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_217,_218,_219,_220,_221);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_217,_218,_219,_220,_221,_222)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _223 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__223(_223 ? _223->raw() : nullptr,_223 ? _223->size(0) : 0);
      int _224 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_217,_218,_219,_220,_221,_223);
      if ((((_ptr__223[(int)1] - _ptr__223[(int)0]) < safe_mul( _224,(_221 - _220) )) && ((_ptr__223[(int)3] - _ptr__223[(int)2]) < safe_mul( _224,(_221 - _220) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_217,_219,_220,_221,_ptr__223[(int)2],_ptr__223[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_217,_218,_220,_221,_ptr__223[(int)0],_ptr__223[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_217,_218,_219,_220,_221);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _225,    std::shared_ptr< monty::ndarray< long long,1 > > _226,    long long _227,    long long _228,    long long _229,    long long _230) { mosek::fusion::p_Sort::argbucketsort(_225,_226,_227,_228,_229,_230); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _225,std::shared_ptr< monty::ndarray< long long,1 > > _226,long long _227,long long _228,long long _229,long long _230){
  _checked_ptr_1<long long> _ptr__225(_225 ? _225->raw() : nullptr, _225 ? _225->size(0) : 0);
  _checked_ptr_1<long long> _ptr__226(_226 ? _226->raw() : nullptr, _226 ? _226->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_225,_227,_228,_226,_229,_230);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _231,    std::shared_ptr< monty::ndarray< int,1 > > _232,    long long _233,    long long _234,    int _235,    int _236) { mosek::fusion::p_Sort::argbucketsort(_231,_232,_233,_234,_235,_236); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _231,std::shared_ptr< monty::ndarray< int,1 > > _232,long long _233,long long _234,int _235,int _236){
  _checked_ptr_1<long long> _ptr__231(_231 ? _231->raw() : nullptr, _231 ? _231->size(0) : 0);
  _checked_ptr_1<int> _ptr__232(_232 ? _232->raw() : nullptr, _232 ? _232->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_231,_233,_234,_232,_235,_236);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _237,    std::shared_ptr< monty::ndarray< long long,1 > > _238,    std::shared_ptr< monty::ndarray< long long,1 > > _239,    long long _240,    long long _241,    std::shared_ptr< monty::ndarray< long long,1 > > _242) { mosek::fusion::p_Sort::getminmax(_237,_238,_239,_240,_241,_242); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _237,std::shared_ptr< monty::ndarray< long long,1 > > _238,std::shared_ptr< monty::ndarray< long long,1 > > _239,long long _240,long long _241,std::shared_ptr< monty::ndarray< long long,1 > > _242){
  _checked_ptr_1<long long> _ptr__237(_237 ? _237->raw() : nullptr, _237 ? _237->size(0) : 0);
  _checked_ptr_1<long long> _ptr__238(_238 ? _238->raw() : nullptr, _238 ? _238->size(0) : 0);
  _checked_ptr_1<long long> _ptr__239(_239 ? _239->raw() : nullptr, _239 ? _239->size(0) : 0);
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _ptr__242[(int)0] = _ptr__238[_ptr__237[_240]];
  _ptr__242[(int)1] = _ptr__238[_ptr__237[_240]];
  long long _6759 = safe_add( _240,(int)1 );
  long long _6760 = _241;
  for (long long _243 = _6759; _243 < _6760; ++_243)
  {
    {
      if ((_ptr__242[(int)0] > _ptr__238[_ptr__237[_243]]))
      {
        {
          _ptr__242[(int)0] = _ptr__238[_ptr__237[_243]];
        }
      }
      {}
      if ((_ptr__242[(int)1] < _ptr__238[_ptr__237[_243]]))
      {
        {
          _ptr__242[(int)1] = _ptr__238[_ptr__237[_243]];
        }
      }
      {}
    }
  }
  if ((NULL != _239.get()))
  {
    {
      _ptr__242[(int)2] = _ptr__239[_ptr__237[_240]];
      _ptr__242[(int)3] = _ptr__239[_ptr__237[_240]];
      long long _6761 = safe_add( _240,(int)1 );
      long long _6762 = _241;
      for (long long _244 = _6761; _244 < _6762; ++_244)
      {
        {
          if ((_ptr__242[(int)2] > _ptr__239[_ptr__237[_244]]))
          {
            {
              _ptr__242[(int)2] = _ptr__239[_ptr__237[_244]];
            }
          }
          {}
          if ((_ptr__242[(int)3] < _ptr__239[_ptr__237[_244]]))
          {
            {
              _ptr__242[(int)3] = _ptr__239[_ptr__237[_244]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _245,    std::shared_ptr< monty::ndarray< int,1 > > _246,    std::shared_ptr< monty::ndarray< int,1 > > _247,    long long _248,    long long _249,    std::shared_ptr< monty::ndarray< int,1 > > _250) { mosek::fusion::p_Sort::getminmax(_245,_246,_247,_248,_249,_250); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _245,std::shared_ptr< monty::ndarray< int,1 > > _246,std::shared_ptr< monty::ndarray< int,1 > > _247,long long _248,long long _249,std::shared_ptr< monty::ndarray< int,1 > > _250){
  _checked_ptr_1<long long> _ptr__245(_245 ? _245->raw() : nullptr, _245 ? _245->size(0) : 0);
  _checked_ptr_1<int> _ptr__246(_246 ? _246->raw() : nullptr, _246 ? _246->size(0) : 0);
  _checked_ptr_1<int> _ptr__247(_247 ? _247->raw() : nullptr, _247 ? _247->size(0) : 0);
  _checked_ptr_1<int> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _ptr__250[(int)0] = _ptr__246[_ptr__245[_248]];
  _ptr__250[(int)1] = _ptr__246[_ptr__245[_248]];
  long long _6763 = safe_add( _248,(int)1 );
  long long _6764 = _249;
  for (long long _251 = _6763; _251 < _6764; ++_251)
  {
    {
      if ((_ptr__250[(int)0] > _ptr__246[_ptr__245[_251]]))
      {
        {
          _ptr__250[(int)0] = _ptr__246[_ptr__245[_251]];
        }
      }
      {}
      if ((_ptr__250[(int)1] < _ptr__246[_ptr__245[_251]]))
      {
        {
          _ptr__250[(int)1] = _ptr__246[_ptr__245[_251]];
        }
      }
      {}
    }
  }
  if ((NULL != _247.get()))
  {
    {
      _ptr__250[(int)2] = _ptr__247[_ptr__245[_248]];
      _ptr__250[(int)3] = _ptr__247[_ptr__245[_248]];
      long long _6765 = safe_add( _248,(int)1 );
      long long _6766 = _249;
      for (long long _252 = _6765; _252 < _6766; ++_252)
      {
        {
          if ((_ptr__250[(int)2] > _ptr__247[_ptr__245[_252]]))
          {
            {
              _ptr__250[(int)2] = _ptr__247[_ptr__245[_252]];
            }
          }
          {}
          if ((_ptr__250[(int)3] < _ptr__247[_ptr__245[_252]]))
          {
            {
              _ptr__250[(int)3] = _ptr__247[_ptr__245[_252]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _253,    std::shared_ptr< monty::ndarray< long long,1 > > _254,    long long _255,    long long _256,    bool _257) { return mosek::fusion::p_Sort::issorted(_253,_254,_255,_256,_257); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _253,std::shared_ptr< monty::ndarray< long long,1 > > _254,long long _255,long long _256,bool _257){
  _checked_ptr_1<long long> _ptr__253(_253 ? _253->raw() : nullptr, _253 ? _253->size(0) : 0);
  _checked_ptr_1<long long> _ptr__254(_254 ? _254->raw() : nullptr, _254 ? _254->size(0) : 0);
  long long _6767 = _255;
  long long _6768 = (_256 - (int)1);
  for (long long _258 = _6767; _258 < _6768; ++_258)
  {
    {
      if ((_ptr__254[_ptr__253[_258]] > _ptr__254[_ptr__253[safe_add( _258,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _259,    std::shared_ptr< monty::ndarray< int,1 > > _260,    long long _261,    long long _262,    bool _263) { return mosek::fusion::p_Sort::issorted(_259,_260,_261,_262,_263); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _259,std::shared_ptr< monty::ndarray< int,1 > > _260,long long _261,long long _262,bool _263){
  _checked_ptr_1<long long> _ptr__259(_259 ? _259->raw() : nullptr, _259 ? _259->size(0) : 0);
  _checked_ptr_1<int> _ptr__260(_260 ? _260->raw() : nullptr, _260 ? _260->size(0) : 0);
  long long _6769 = _261;
  long long _6770 = (_262 - (int)1);
  for (long long _264 = _6769; _264 < _6770; ++_264)
  {
    {
      if ((_ptr__260[_ptr__259[_264]] > _ptr__260[_ptr__259[safe_add( _264,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _265,    std::shared_ptr< monty::ndarray< long long,1 > > _266,    std::shared_ptr< monty::ndarray< long long,1 > > _267,    long long _268,    long long _269,    bool _270) { return mosek::fusion::p_Sort::issorted(_265,_266,_267,_268,_269,_270); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _265,std::shared_ptr< monty::ndarray< long long,1 > > _266,std::shared_ptr< monty::ndarray< long long,1 > > _267,long long _268,long long _269,bool _270){
  _checked_ptr_1<long long> _ptr__265(_265 ? _265->raw() : nullptr, _265 ? _265->size(0) : 0);
  _checked_ptr_1<long long> _ptr__266(_266 ? _266->raw() : nullptr, _266 ? _266->size(0) : 0);
  _checked_ptr_1<long long> _ptr__267(_267 ? _267->raw() : nullptr, _267 ? _267->size(0) : 0);
  long long _6771 = _268;
  long long _6772 = (_269 - (int)1);
  for (long long _271 = _6771; _271 < _6772; ++_271)
  {
    {
      if (((_ptr__266[_ptr__265[_271]] > _ptr__266[_ptr__265[safe_add( _271,(int)1 )]]) || ((_ptr__266[_ptr__265[safe_add( _271,(int)1 )]] == _ptr__266[_ptr__265[_271]]) && (_ptr__267[_ptr__265[_271]] > _ptr__267[_ptr__265[safe_add( _271,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _272,    std::shared_ptr< monty::ndarray< int,1 > > _273,    std::shared_ptr< monty::ndarray< int,1 > > _274,    long long _275,    long long _276,    bool _277) { return mosek::fusion::p_Sort::issorted(_272,_273,_274,_275,_276,_277); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _272,std::shared_ptr< monty::ndarray< int,1 > > _273,std::shared_ptr< monty::ndarray< int,1 > > _274,long long _275,long long _276,bool _277){
  _checked_ptr_1<long long> _ptr__272(_272 ? _272->raw() : nullptr, _272 ? _272->size(0) : 0);
  _checked_ptr_1<int> _ptr__273(_273 ? _273->raw() : nullptr, _273 ? _273->size(0) : 0);
  _checked_ptr_1<int> _ptr__274(_274 ? _274->raw() : nullptr, _274 ? _274->size(0) : 0);
  long long _6773 = _275;
  long long _6774 = (_276 - (int)1);
  for (long long _278 = _6773; _278 < _6774; ++_278)
  {
    {
      if (((_ptr__273[_ptr__272[_278]] > _ptr__273[_ptr__272[safe_add( _278,(int)1 )]]) || ((_ptr__273[_ptr__272[_278]] == _ptr__273[_ptr__272[safe_add( _278,(int)1 )]]) && (_ptr__274[_ptr__272[_278]] > _ptr__274[_ptr__272[safe_add( _278,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _279){ return new mosek::fusion::IndexCounter(_279); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _279) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_279); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _279){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__279(_279 ? _279->raw() : nullptr, _279 ? _279->size(0) : 0);
    n = (int)((_279)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_279);
    std::vector<int> _6775;
    for (int _280 = (int)0, _6776 = (int)((_279)->size(0)); _280 < _6776 ; ++_280)
    {
      _6775.push_back(_ptr__279[_280]);
    }
    auto _6777 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6775.size()),_6775.begin(),_6775.end()));
    dims = _6777;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _281,    std::shared_ptr< monty::ndarray< int,1 > > _282,    std::shared_ptr< monty::ndarray< int,1 > > _283){ return new mosek::fusion::IndexCounter(_281,_282,_283); }mosek::fusion::IndexCounter::IndexCounter  (long long _281,    std::shared_ptr< monty::ndarray< int,1 > > _282,    std::shared_ptr< monty::ndarray< int,1 > > _283) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_281,_282,_283); }void mosek::fusion::p_IndexCounter::_initialize  (long long _281,    std::shared_ptr< monty::ndarray< int,1 > > _282,    std::shared_ptr< monty::ndarray< int,1 > > _283){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__282(_282 ? _282->raw() : nullptr, _282 ? _282->size(0) : 0);
    _checked_ptr_1<int> _ptr__283(_283 ? _283->raw() : nullptr, _283 ? _283->size(0) : 0);
    int _284 = (int)((_283)->size(0));
    n = (int)((_282)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6778 = (int)0;
    int _6779 = n;
    for (int _285 = _6778; _285 < _6779; ++_285)
    {
      {
        ((*st)(_285)) = _281;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_283);
    dims = _282;
    start = _281;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _286,    std::shared_ptr< monty::ndarray< int,1 > > _287,    std::shared_ptr< monty::ndarray< long long,1 > > _288){ return new mosek::fusion::IndexCounter(_286,_287,_288); }mosek::fusion::IndexCounter::IndexCounter  (long long _286,    std::shared_ptr< monty::ndarray< int,1 > > _287,    std::shared_ptr< monty::ndarray< long long,1 > > _288) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_286,_287,_288); }void mosek::fusion::p_IndexCounter::_initialize  (long long _286,    std::shared_ptr< monty::ndarray< int,1 > > _287,    std::shared_ptr< monty::ndarray< long long,1 > > _288){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__287(_287 ? _287->raw() : nullptr, _287 ? _287->size(0) : 0);
    _checked_ptr_1<long long> _ptr__288(_288 ? _288->raw() : nullptr, _288 ? _288->size(0) : 0);
    n = (int)((_287)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6780 = (int)0;
    int _6781 = n;
    for (int _289 = _6780; _289 < _6781; ++_289)
    {
      {
        ((*st)(_289)) = _286;
      }
    }
    strides = _288;
    dims = _287;
    start = _286;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _290 = _pubthis->get();
  _pubthis->inc();
  return _290;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _291;
  {
    _291 = (int)0;
    for(;((_291 < (n - (int)1)) && (((*ii)(_291)) == ((*dims)(((n - _291) - (int)1)))));++ _291)
    {
      {
        ((*ii)(_291)) = (int)0;
        ++ ((*ii)(safe_add( _291,(int)1 )));
        ((*st)(safe_add( _291,(int)1 ))) = safe_add( ((*st)(safe_add( _291,(int)1 ))),((*strides)(((n - _291) - (int)2))) );
      }
    }
  }
  int _6782 = (int)0;
  int _6783 = _291;
  for (int _292 = _6782; _292 < _6783; ++_292)
  {
    {
      ((*st)(_292)) = ((*st)(_291));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _6784 = (int)0;
  int _6785 = n;
  for (int _293 = _6784; _293 < _6785; ++_293)
  {
    {
      ((*st)(_293)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _294,    int _295) { return mosek::fusion::p_CommonTools::resize(_294,_295); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _294,int _295){
  _checked_ptr_1<long long> _ptr__294(_294 ? _294->raw() : nullptr, _294 ? _294->size(0) : 0);
  if ((_295 == (int)((_294)->size(0))))
  {
    {
      return _294;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _296 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_295)));
      _checked_ptr_1<long long> _ptr__296(_296 ? _296->raw() : nullptr,_296 ? _296->size(0) : 0);
      if ((_295 > (int)((_294)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,(int)((_294)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,_295);
        }
      }
      return _296;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _297,int _298){
  _checked_ptr_1<int> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _299 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_298)));
      _checked_ptr_1<int> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::resize(_300,_301); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _300,int _301){
  _checked_ptr_1<double> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  if ((_301 == (int)((_300)->size(0))))
  {
    {
      return _300;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _302 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_301)));
      _checked_ptr_1<double> _ptr__302(_302 ? _302->raw() : nullptr,_302 ? _302->size(0) : 0);
      if ((_301 > (int)((_300)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_300,(int)0,_302,(int)0,(int)((_300)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_300,(int)0,_302,(int)0,_301);
        }
      }
      return _302;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _303,    int _304) { return mosek::fusion::p_CommonTools::binarySearch(_303,_304); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _303,int _304){
  _checked_ptr_1<int> _ptr__303(_303 ? _303->raw() : nullptr, _303 ? _303->size(0) : 0);
  int _305 = (int)0;
  int _306 = (int)((_303)->size(0));
  if ((_ptr__303[_305] == _304))
  {
    {
      return _305;
    }
  }
  else if((_ptr__303[(_306 - (int)1)] == _304))
  {
    {
      return (_306 - (int)1);
    }
  }
  {}
  while ( (_305 < (_306 - (int)1)) )
  {
    {
      int _307 = ((_306 - _305) / (int)2);
      if ((_304 < _ptr__303[_307]))
      {
        {
          _305 = safe_add( _307,(int)1 );
        }
      }
      else if((_304 > _ptr__303[_307]))
      {
        {
          _306 = _307;
        }
      }
      else
      {
        {
          return _307;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _308,    long long _309) { return mosek::fusion::p_CommonTools::binarySearch(_308,_309); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309){
  _checked_ptr_1<long long> _ptr__308(_308 ? _308->raw() : nullptr, _308 ? _308->size(0) : 0);
  int _310 = ::mosek::fusion::p_CommonTools::binarySearchL(_308,_309);
  if (((_310 < (int)((_308)->size(0))) && (_ptr__308[_310] == _309)))
  {
    {
      return _310;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _311,    long long _312) { return mosek::fusion::p_CommonTools::binarySearchR(_311,_312); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _311,long long _312){
  _checked_ptr_1<long long> _ptr__311(_311 ? _311->raw() : nullptr, _311 ? _311->size(0) : 0);
  int _313 = (int)0;
  int _314 = (int)((_311)->size(0));
  if ((_ptr__311[_313] > _312))
  {
    {
      return _313;
    }
  }
  {}
  while ( (_313 < (_314 - (int)1)) )
  {
    {
      int _315 = (safe_add( _314,_313 ) / (int)2);
      if ((_312 >= _ptr__311[_315]))
      {
        {
          _313 = _315;
        }
      }
      else
      {
        {
          _314 = _315;
        }
      }
    }
  }
  return _314;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _316,    long long _317) { return mosek::fusion::p_CommonTools::binarySearchL(_316,_317); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _316,long long _317){
  _checked_ptr_1<long long> _ptr__316(_316 ? _316->raw() : nullptr, _316 ? _316->size(0) : 0);
  int _318 = (int)0;
  int _319 = (int)((_316)->size(0));
  if ((_317 <= _ptr__316[_318]))
  {
    {
      return _318;
    }
  }
  {}
  while ( (_318 < (_319 - (int)1)) )
  {
    {
      int _320 = (safe_add( _319,_318 ) / (int)2);
      if ((_ptr__316[_320] < _317))
      {
        {
          _318 = _320;
        }
      }
      else
      {
        {
          _319 = _320;
        }
      }
    }
  }
  return _319;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _321,    std::shared_ptr< monty::ndarray< int,1 > > _322,    std::shared_ptr< monty::ndarray< int,1 > > _323) { mosek::fusion::p_CommonTools::ndIncr(_321,_322,_323); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _321,std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323){
  _checked_ptr_1<int> _ptr__321(_321 ? _321->raw() : nullptr, _321 ? _321->size(0) : 0);
  _checked_ptr_1<int> _ptr__322(_322 ? _322->raw() : nullptr, _322 ? _322->size(0) : 0);
  _checked_ptr_1<int> _ptr__323(_323 ? _323->raw() : nullptr, _323 ? _323->size(0) : 0);
  int _324 = ((int)((_321)->size(0)) - (int)1);
  ++ _ptr__321[_324];
  while ( ((_324 > (int)0) && (_ptr__321[_324] >= _ptr__323[_324])) )
  {
    {
      _ptr__321[_324] = _ptr__322[_324];
      ++ _ptr__321[(_324 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _325,    std::shared_ptr< monty::ndarray< int,1 > > _326,    std::shared_ptr< monty::ndarray< double,1 > > _327,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _328,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _329,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _330,    long long _331,    int _332,    int _333) { mosek::fusion::p_CommonTools::transposeTriplets(_325,_326,_327,_328,_329,_330,_331,_332,_333); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _325,std::shared_ptr< monty::ndarray< int,1 > > _326,std::shared_ptr< monty::ndarray< double,1 > > _327,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _328,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _329,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _330,long long _331,int _332,int _333){
  _checked_ptr_1<int> _ptr__325(_325 ? _325->raw() : nullptr, _325 ? _325->size(0) : 0);
  _checked_ptr_1<int> _ptr__326(_326 ? _326->raw() : nullptr, _326 ? _326->size(0) : 0);
  _checked_ptr_1<double> _ptr__327(_327 ? _327->raw() : nullptr, _327 ? _327->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _334 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _332,(int)2 ))));
  _checked_ptr_1<long long> _ptr__334(_334 ? _334->raw() : nullptr,_334 ? _334->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _335 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _333,(int)2 ))));
  _checked_ptr_1<long long> _ptr__335(_335 ? _335->raw() : nullptr,_335 ? _335->size(0) : 0);
  {
    long long _336 = (long long)0;
    for(;(_336 < _331);++ _336)
    {
      {
        _ptr__335[safe_add( _ptr__326[_336],(int)2 )] = safe_add( _ptr__335[safe_add( _ptr__326[_336],(int)2 )],(int)1 );
        _ptr__334[safe_add( _ptr__325[_336],(int)2 )] = safe_add( _ptr__334[safe_add( _ptr__325[_336],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _337 = (int)1;
    for(;(_337 < _332);++ _337)
    {
      {
        _ptr__334[safe_add( _337,(int)1 )] = safe_add( _ptr__334[safe_add( _337,(int)1 )],_ptr__334[_337] );
      }
    }
  }
  {
    int _338 = (int)1;
    for(;(_338 < _333);++ _338)
    {
      {
        _ptr__335[safe_add( _338,(int)1 )] = safe_add( _ptr__335[safe_add( _338,(int)1 )],_ptr__335[_338] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _339 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_331)));
  _checked_ptr_1<long long> _ptr__339(_339 ? _339->raw() : nullptr,_339 ? _339->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _340 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_331)));
  _checked_ptr_1<long long> _ptr__340(_340 ? _340->raw() : nullptr,_340 ? _340->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _341 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_331)));
  _checked_ptr_1<double> _ptr__341(_341 ? _341->raw() : nullptr,_341 ? _341->size(0) : 0);
  int _6786 = (int)0;
  int _6787 = _332;
  for (int _342 = _6786; _342 < _6787; ++_342)
  {
    {
      {
        long long _343 = _ptr__334[_342];
        for(;(_343 < _ptr__334[safe_add( _342,(int)1 )]);++ _343)
        {
          {
            int _344 = _ptr__326[_343];
            long long _345 = _ptr__335[_344];
            _ptr__339[_345] = _342;
            _ptr__340[_345] = _344;
            _ptr__341[_345] = _ptr__327[_343];
            _ptr__335[_344] = safe_add( _345,(int)1 );
          }
        }
      }
    }
  }
  ((*_328)((int)0)) = _340;
  ((*_329)((int)0)) = _339;
  ((*_330)((int)0)) = _341;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _346,    std::shared_ptr< monty::ndarray< int,1 > > _347,    std::shared_ptr< monty::ndarray< double,1 > > _348,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _349,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _350,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _351,    long long _352,    int _353,    int _354) { mosek::fusion::p_CommonTools::transposeTriplets(_346,_347,_348,_349,_350,_351,_352,_353,_354); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _346,std::shared_ptr< monty::ndarray< int,1 > > _347,std::shared_ptr< monty::ndarray< double,1 > > _348,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _349,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _350,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _351,long long _352,int _353,int _354){
  _checked_ptr_1<int> _ptr__346(_346 ? _346->raw() : nullptr, _346 ? _346->size(0) : 0);
  _checked_ptr_1<int> _ptr__347(_347 ? _347->raw() : nullptr, _347 ? _347->size(0) : 0);
  _checked_ptr_1<double> _ptr__348(_348 ? _348->raw() : nullptr, _348 ? _348->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _355 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _353,(int)2 ))));
  _checked_ptr_1<long long> _ptr__355(_355 ? _355->raw() : nullptr,_355 ? _355->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _356 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _354,(int)2 ))));
  _checked_ptr_1<long long> _ptr__356(_356 ? _356->raw() : nullptr,_356 ? _356->size(0) : 0);
  {
    long long _357 = (long long)0;
    for(;(_357 < _352);++ _357)
    {
      {
        _ptr__356[safe_add( _ptr__347[_357],(int)2 )] = safe_add( _ptr__356[safe_add( _ptr__347[_357],(int)2 )],(int)1 );
        _ptr__355[safe_add( _ptr__346[_357],(int)2 )] = safe_add( _ptr__355[safe_add( _ptr__346[_357],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _358 = (int)1;
    for(;(_358 < _353);++ _358)
    {
      {
        _ptr__355[safe_add( _358,(int)1 )] = safe_add( _ptr__355[safe_add( _358,(int)1 )],_ptr__355[_358] );
      }
    }
  }
  {
    int _359 = (int)1;
    for(;(_359 < _354);++ _359)
    {
      {
        _ptr__356[safe_add( _359,(int)1 )] = safe_add( _ptr__356[safe_add( _359,(int)1 )],_ptr__356[_359] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _360 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_352)));
  _checked_ptr_1<int> _ptr__360(_360 ? _360->raw() : nullptr,_360 ? _360->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _361 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_352)));
  _checked_ptr_1<int> _ptr__361(_361 ? _361->raw() : nullptr,_361 ? _361->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _362 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_352)));
  _checked_ptr_1<double> _ptr__362(_362 ? _362->raw() : nullptr,_362 ? _362->size(0) : 0);
  {
    int _363 = (int)0;
    for(;(_363 < _353);++ _363)
    {
      {
        long long _6788 = _ptr__355[_363];
        long long _6789 = _ptr__355[safe_add( _363,(int)1 )];
        for (long long _364 = _6788; _364 < _6789; ++_364)
        {
          {
            int _365 = _ptr__347[_364];
            long long _366 = _ptr__356[_365];
            _ptr__360[_366] = _363;
            _ptr__361[_366] = _365;
            _ptr__362[_366] = _ptr__348[_364];
            _ptr__356[_365] = safe_add( _366,(int)1 );
          }
        }
      }
    }
  }
  ((*_349)((int)0)) = _361;
  ((*_350)((int)0)) = _360;
  ((*_351)((int)0)) = _362;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _367,    std::shared_ptr< monty::ndarray< int,1 > > _368,    std::shared_ptr< monty::ndarray< double,1 > > _369,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _370,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _371,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _372,    long long _373,    int _374,    int _375) { mosek::fusion::p_CommonTools::tripletSort(_367,_368,_369,_370,_371,_372,_373,_374,_375); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _367,std::shared_ptr< monty::ndarray< int,1 > > _368,std::shared_ptr< monty::ndarray< double,1 > > _369,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _370,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _371,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _372,long long _373,int _374,int _375){
  _checked_ptr_1<int> _ptr__367(_367 ? _367->raw() : nullptr, _367 ? _367->size(0) : 0);
  _checked_ptr_1<int> _ptr__368(_368 ? _368->raw() : nullptr, _368 ? _368->size(0) : 0);
  _checked_ptr_1<double> _ptr__369(_369 ? _369->raw() : nullptr, _369 ? _369->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _376 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_373)));
  _checked_ptr_1<int> _ptr__376(_376 ? _376->raw() : nullptr,_376 ? _376->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _377 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _375,(int)2 ))));
  _checked_ptr_1<long long> _ptr__377(_377 ? _377->raw() : nullptr,_377 ? _377->size(0) : 0);
  long long _6790 = (long long)0;
  long long _6791 = _373;
  for (long long _378 = _6790; _378 < _6791; ++_378)
  {
    {
      _ptr__377[safe_add( _ptr__368[_378],(int)2 )] = safe_add( _ptr__377[safe_add( _ptr__368[_378],(int)2 )],(int)1 );
    }
  }
  int _6792 = (int)1;
  int _6793 = _375;
  for (int _379 = _6792; _379 < _6793; ++_379)
  {
    {
      _ptr__377[safe_add( _379,(int)1 )] = safe_add( _ptr__377[safe_add( _379,(int)1 )],_ptr__377[_379] );
    }
  }
  int _6794 = (int)0;
  int _6795 = (int)_373;
  for (int _380 = _6794; _380 < _6795; ++_380)
  {
    {
      int _381 = _ptr__368[_380];
      _ptr__376[_ptr__377[safe_add( _381,(int)1 )]] = _380;
      _ptr__377[safe_add( _381,(int)1 )] = safe_add( _ptr__377[safe_add( _381,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _382 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _374,(int)2 ))));
  _checked_ptr_1<long long> _ptr__382(_382 ? _382->raw() : nullptr,_382 ? _382->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _383 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_373)));
  _checked_ptr_1<int> _ptr__383(_383 ? _383->raw() : nullptr,_383 ? _383->size(0) : 0);
  {
    int _384 = (int)0;
    for(;(_384 < _373);++ _384)
    {
      {
        _ptr__382[safe_add( _ptr__367[_384],(int)2 )] = safe_add( _ptr__382[safe_add( _ptr__367[_384],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _385 = (int)1;
    for(;(_385 < _374);++ _385)
    {
      {
        _ptr__382[safe_add( _385,(int)1 )] = safe_add( _ptr__382[safe_add( _385,(int)1 )],_ptr__382[_385] );
      }
    }
  }
  {
    int _386 = (int)0;
    for(;(_386 < _375);++ _386)
    {
      {
        {
          long long _387 = _ptr__377[_386];
          for(;(_387 < _ptr__377[safe_add( _386,(int)1 )]);++ _387)
          {
            {
              int _388 = _ptr__367[_ptr__376[_387]];
              _ptr__383[_ptr__382[safe_add( _388,(int)1 )]] = _ptr__376[_387];
              _ptr__382[safe_add( _388,(int)1 )] = safe_add( _ptr__382[safe_add( _388,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _389 = (int)1;
  {
    int _390 = _ptr__367[_ptr__383[(int)0]];
    int _391 = _ptr__368[_ptr__383[(int)0]];
    {
      int _392 = (int)1;
      for(;(_392 < _373);++ _392)
      {
        {
          int _393 = _ptr__383[_392];
          if (((_390 != _ptr__367[_393]) || (_391 != _ptr__368[_393])))
          {
            {
              _390 = _ptr__367[_393];
              _391 = _ptr__368[_393];
              ++ _389;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _394 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_389)));
  _checked_ptr_1<int> _ptr__394(_394 ? _394->raw() : nullptr,_394 ? _394->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _395 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_389)));
  _checked_ptr_1<int> _ptr__395(_395 ? _395->raw() : nullptr,_395 ? _395->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _396 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_389)));
  _checked_ptr_1<double> _ptr__396(_396 ? _396->raw() : nullptr,_396 ? _396->size(0) : 0);
  {
    int _397 = _ptr__383[(int)0];
    _ptr__394[(int)0] = _ptr__367[_397];
    _ptr__395[(int)0] = _ptr__368[_397];
    _ptr__396[(int)0] = _ptr__369[_397];
  }
  int _398 = (int)1;
  int _6796 = (int)1;
  long long _6797 = _373;
  for (long long _399 = _6796; _399 < _6797; ++_399)
  {
    {
      int _400 = _ptr__383[_399];
      if (((_ptr__394[(_398 - (int)1)] == _ptr__367[_400]) && (_ptr__395[(_398 - (int)1)] == _ptr__368[_400])))
      {
        {
          _ptr__396[(_398 - (int)1)] = (_ptr__396[(_398 - (int)1)] + _ptr__369[_400]);
        }
      }
      else
      {
        {
          _ptr__394[_398] = _ptr__367[_400];
          _ptr__395[_398] = _ptr__368[_400];
          _ptr__396[_398] = _ptr__369[_400];
          ++ _398;
        }
      }
    }
  }
  ((*_370)((int)0)) = _394;
  ((*_371)((int)0)) = _395;
  ((*_372)((int)0)) = _396;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _401,    std::shared_ptr< monty::ndarray< int,1 > > _402) { mosek::fusion::p_CommonTools::argMSort(_401,_402); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _401,std::shared_ptr< monty::ndarray< int,1 > > _402){
  _checked_ptr_1<int> _ptr__401(_401 ? _401->raw() : nullptr, _401 ? _401->size(0) : 0);
  _checked_ptr_1<int> _ptr__402(_402 ? _402->raw() : nullptr, _402 ? _402->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _403 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_401)->size(0)))));
  _checked_ptr_1<int> _ptr__403(_403 ? _403->raw() : nullptr,_403 ? _403->size(0) : 0);
  bool _404 = false;
  {
    int _405 = (int)1;
    for(;(_405 < (int)((_401)->size(0)));_405 *= (int)2)
    {
      {
        _404 = (!_404);
        int _6798 = (int)0;
        int _6799 = (int)((_401)->size(0));
        int _6800 = safe_mul( _405,(int)2 );
        for (int _406 = _6798; _406 < _6799; _406 += _6800)
        {
          {
            if (_404)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_401,_403,_402,_406,safe_add( _406,_405 ),safe_add( _406,safe_mul( (int)2,_405 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_403,_401,_402,_406,safe_add( _406,_405 ),safe_add( _406,safe_mul( (int)2,_405 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_404)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_403,(int)0,_401,(int)0,(int)((_401)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _407,std::shared_ptr< monty::ndarray< int,1 > > _408,std::shared_ptr< monty::ndarray< int,1 > > _409,int _410,int _411,int _412){
  _checked_ptr_1<int> _ptr__407(_407 ? _407->raw() : nullptr, _407 ? _407->size(0) : 0);
  _checked_ptr_1<int> _ptr__408(_408 ? _408->raw() : nullptr, _408 ? _408->size(0) : 0);
  _checked_ptr_1<int> _ptr__409(_409 ? _409->raw() : nullptr, _409 ? _409->size(0) : 0);
  int _6801;
  bool _6802 = (_412 > (int)((_407)->size(0)));
  if (_6802)
  {
    _6801 = (int)((_407)->size(0));
  }
  else
  {
    _6801 = _412;
  }
  int _413 = _6801;
  int _6803;
  bool _6804 = (_411 > _413);
  if (_6804)
  {
    _6803 = _413;
  }
  else
  {
    _6803 = _411;
  }
  int _414 = _6803;
  if ((_414 == _413))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_407,_410,_408,_410,(_414 - _410));
    }
  }
  else
  {
    {
      int _415 = _410;
      int _416 = _414;
      int _417;
      {
        _417 = _410;
        for(;((_415 < _414) && (_416 < _413));++ _417)
        {
          {
            if ((_ptr__409[_ptr__407[_415]] < _ptr__409[_ptr__407[_416]]))
            {
              {
                _ptr__408[_417] = _ptr__407[_415];
                ++ _415;
              }
            }
            else
            {
              {
                _ptr__408[_417] = _ptr__407[_416];
                ++ _416;
              }
            }
          }
        }
      }
      while ( (_415 < _414) )
      {
        {
          _ptr__408[_417] = _ptr__407[_415];
          ++ _415;
          ++ _417;
        }
      }
      while ( (_416 < _413) )
      {
        {
          _ptr__408[_417] = _ptr__407[_416];
          ++ _416;
          ++ _417;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _418,    std::shared_ptr< monty::ndarray< long long,1 > > _419,    std::shared_ptr< monty::ndarray< long long,1 > > _420,    long long _421,    long long _422) { mosek::fusion::p_CommonTools::argQsort(_418,_419,_420,_421,_422); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _418,std::shared_ptr< monty::ndarray< long long,1 > > _419,std::shared_ptr< monty::ndarray< long long,1 > > _420,long long _421,long long _422){
  _checked_ptr_1<long long> _ptr__418(_418 ? _418->raw() : nullptr, _418 ? _418->size(0) : 0);
  _checked_ptr_1<long long> _ptr__419(_419 ? _419->raw() : nullptr, _419 ? _419->size(0) : 0);
  _checked_ptr_1<long long> _ptr__420(_420 ? _420->raw() : nullptr, _420 ? _420->size(0) : 0);
  if ((NULL == _420.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_418,_419,_421,_422);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_418,_419,_420,_421,_422);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _423,    std::shared_ptr< monty::ndarray< int,1 > > _424,    std::shared_ptr< monty::ndarray< int,1 > > _425,    long long _426,    long long _427) { mosek::fusion::p_CommonTools::argQsort(_423,_424,_425,_426,_427); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _423,std::shared_ptr< monty::ndarray< int,1 > > _424,std::shared_ptr< monty::ndarray< int,1 > > _425,long long _426,long long _427){
  _checked_ptr_1<long long> _ptr__423(_423 ? _423->raw() : nullptr, _423 ? _423->size(0) : 0);
  _checked_ptr_1<int> _ptr__424(_424 ? _424->raw() : nullptr, _424 ? _424->size(0) : 0);
  _checked_ptr_1<int> _ptr__425(_425 ? _425->raw() : nullptr, _425 ? _425->size(0) : 0);
  if ((NULL == _425.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_423,_424,_426,_427);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_423,_424,_425,_426,_427);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _428,    int _429,    int _430,    int _431){ return new mosek::fusion::SolutionStruct(_428,_429,_430,_431); }mosek::fusion::SolutionStruct::SolutionStruct  (int _428,    int _429,    int _430,    int _431) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_428,_429,_430,_431); }void mosek::fusion::p_SolutionStruct::_initialize  (int _428,    int _429,    int _430,    int _431){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _428;
    sol_numcon = _429;
    sol_numcone = _430;
    sol_numbarvar = _431;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_428 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
    if ((_431 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
      }
    }
    {}
    if ((_429 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_429)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_429)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_429)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_429)));
      }
    }
    {}
    if ((_430 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _432){ return new mosek::fusion::SolutionStruct(_432); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _432) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_432); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _432){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_432)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_432)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_432)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_432)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_432)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_432)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_432)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_432)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_432)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _6805;
    bool _6806 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->xc.get());
    if (_6806)
    {
      _6805 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->xc);
    }
    else
    {
      _6805 = nullptr;
    }
    xc = _6805;
    std::shared_ptr< monty::ndarray< double,1 > > _6807;
    bool _6808 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->xx.get());
    if (_6808)
    {
      _6807 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->xx);
    }
    else
    {
      _6807 = nullptr;
    }
    xx = _6807;
    std::shared_ptr< monty::ndarray< double,1 > > _6809;
    bool _6810 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->yx.get());
    if (_6810)
    {
      _6809 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->yx);
    }
    else
    {
      _6809 = nullptr;
    }
    yx = _6809;
    std::shared_ptr< monty::ndarray< double,1 > > _6811;
    bool _6812 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->slc.get());
    if (_6812)
    {
      _6811 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->slx);
    }
    else
    {
      _6811 = nullptr;
    }
    slc = _6811;
    std::shared_ptr< monty::ndarray< double,1 > > _6813;
    bool _6814 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->suc.get());
    if (_6814)
    {
      _6813 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->sux);
    }
    else
    {
      _6813 = nullptr;
    }
    suc = _6813;
    std::shared_ptr< monty::ndarray< double,1 > > _6815;
    bool _6816 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->y.get());
    if (_6816)
    {
      _6815 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->y);
    }
    else
    {
      _6815 = nullptr;
    }
    y = _6815;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _6817;
    bool _6818 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->slx.get());
    if (_6818)
    {
      _6817 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->slx);
    }
    else
    {
      _6817 = nullptr;
    }
    slx = _6817;
    std::shared_ptr< monty::ndarray< double,1 > > _6819;
    bool _6820 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->sux.get());
    if (_6820)
    {
      _6819 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->sux);
    }
    else
    {
      _6819 = nullptr;
    }
    sux = _6819;
    std::shared_ptr< monty::ndarray< double,1 > > _6821;
    bool _6822 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_432)->snx.get());
    if (_6822)
    {
      _6821 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_432)->snx);
    }
    else
    {
      _6821 = nullptr;
    }
    snx = _6821;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _433,int _434,int _435,int _436) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_433,_434,_435,_436); }void mosek::fusion::p_SolutionStruct::resize(int _433,int _434,int _435,int _436){
  if ((_436 < (int)0))
  {
    {
    }
  }
  else if((_436 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _436;
    }
  }
  else if((_436 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _437;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _436,(int)100 )))
      {
        {
          _437 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _437 = safe_add( _436,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_437);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_437);
      sol_numbarvar = _437;
    }
  }
  if ((_433 < (int)0))
  {
    {
    }
  }
  else if((_433 <= sol_numvar))
  {
    {
      sol_numvar = _433;
    }
  }
  else if((_433 <= (int)((xx)->size(0))))
  {
    {
      int _6823 = sol_numvar;
      int _6824 = _433;
      for (int _438 = _6823; _438 < _6824; ++_438)
      {
        {
          ((*slx)(_438)) = 0.0;
          ((*sux)(_438)) = 0.0;
          ((*xx)(_438)) = 0.0;
          ((*yx)(_438)) = 0.0;
        }
      }
      sol_numvar = _433;
    }
  }
  else
  {
    {
      int _439;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _433,(int)100 )))
      {
        {
          _439 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _439 = safe_add( _433,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _440 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_439)));
      _checked_ptr_1<double> _ptr__440(_440 ? _440->raw() : nullptr,_440 ? _440->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_440,(int)0,(int)((slx)->size(0)));
      slx = _440;
      std::shared_ptr< monty::ndarray< double,1 > > _441 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_439)));
      _checked_ptr_1<double> _ptr__441(_441 ? _441->raw() : nullptr,_441 ? _441->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_441,(int)0,(int)((sux)->size(0)));
      sux = _441;
      std::shared_ptr< monty::ndarray< double,1 > > _442 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_439)));
      _checked_ptr_1<double> _ptr__442(_442 ? _442->raw() : nullptr,_442 ? _442->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_442,(int)0,(int)((xx)->size(0)));
      xx = _442;
      std::shared_ptr< monty::ndarray< double,1 > > _443 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_439)));
      _checked_ptr_1<double> _ptr__443(_443 ? _443->raw() : nullptr,_443 ? _443->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_443,(int)0,(int)((yx)->size(0)));
      yx = _443;
      {
        int _444 = sol_numvar;
        for(;(_444 < _433);++ _444)
        {
          {
            ((*slx)(_444)) = 0.0;
            ((*sux)(_444)) = 0.0;
            ((*xx)(_444)) = 0.0;
          }
        }
      }
      sol_numvar = _433;
    }
  }
  if ((_434 < (int)0))
  {
    {
    }
  }
  else if((_434 <= sol_numcon))
  {
    {
      sol_numcon = _434;
    }
  }
  else if((_434 <= (int)((xx)->size(0))))
  {
    {
      int _6825 = sol_numcon;
      int _6826 = _434;
      for (int _445 = _6825; _445 < _6826; ++_445)
      {
        {
          ((*slc)(_445)) = 0.0;
          ((*suc)(_445)) = 0.0;
          ((*xc)(_445)) = 0.0;
          ((*y)(_445)) = 0.0;
        }
      }
      sol_numcon = _434;
    }
  }
  else
  {
    {
      int _446;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _434,(int)100 )))
      {
        {
          _446 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _446 = safe_add( _434,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_446)));
      _checked_ptr_1<double> _ptr__447(_447 ? _447->raw() : nullptr,_447 ? _447->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_447,(int)0,(int)((slc)->size(0)));
      slc = _447;
      std::shared_ptr< monty::ndarray< double,1 > > _448 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_446)));
      _checked_ptr_1<double> _ptr__448(_448 ? _448->raw() : nullptr,_448 ? _448->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_448,(int)0,(int)((suc)->size(0)));
      suc = _448;
      std::shared_ptr< monty::ndarray< double,1 > > _449 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_446)));
      _checked_ptr_1<double> _ptr__449(_449 ? _449->raw() : nullptr,_449 ? _449->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_449,(int)0,(int)((xc)->size(0)));
      xc = _449;
      std::shared_ptr< monty::ndarray< double,1 > > _450 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_446)));
      _checked_ptr_1<double> _ptr__450(_450 ? _450->raw() : nullptr,_450 ? _450->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_450,(int)0,(int)((y)->size(0)));
      y = _450;
      int _6827 = sol_numcon;
      int _6828 = _434;
      for (int _451 = _6827; _451 < _6828; ++_451)
      {
        {
          ((*slc)(_451)) = 0.0;
          ((*suc)(_451)) = 0.0;
          ((*xc)(_451)) = 0.0;
          ((*y)(_451)) = 0.0;
        }
      }
      sol_numcon = _434;
    }
  }
  if ((_435 < (int)0))
  {
    {
    }
  }
  else if((_435 <= sol_numcone))
  {
    {
      sol_numcone = _435;
    }
  }
  else if((_435 <= (int)((xx)->size(0))))
  {
    {
      int _6829 = sol_numcone;
      int _6830 = _435;
      for (int _452 = _6829; _452 < _6830; ++_452)
      {
        {
          ((*snx)(_452)) = 0.0;
        }
      }
      sol_numcone = _435;
    }
  }
  else
  {
    {
      int _453;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _435,(int)100 )))
      {
        {
          _453 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _453 = safe_add( _435,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _454 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_453)));
      _checked_ptr_1<double> _ptr__454(_454 ? _454->raw() : nullptr,_454 ? _454->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_454,(int)0,(int)((snx)->size(0)));
      snx = _454;
      {
        int _455 = sol_numcone;
        for(;(_455 < _435);++ _455)
        {
          {
            ((*snx)(_455)) = 0.0;
          }
        }
      }
      sol_numcone = _435;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _456) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_456); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _456){
  return isAcceptable(dstatus,_456);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _457) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_457); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _457){
  return isAcceptable(pstatus,_457);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _458,mosek::fusion::AccSolutionStatus _459){
  if ((_459 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_459 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_458 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_459 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_458 == ::mosek::fusion::SolutionStatus::Optimal) || (_458 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_459 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_458 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< double,1 > > _462,    std::shared_ptr< monty::ndarray< double,1 > > _463,    std::shared_ptr< monty::ndarray< int,1 > > _464,    std::shared_ptr< monty::ndarray< int,1 > > _465,    std::shared_ptr< monty::ndarray< int,1 > > _466){ return new mosek::fusion::ConNZStruct(_460,_461,_462,_463,_464,_465,_466); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< double,1 > > _462,    std::shared_ptr< monty::ndarray< double,1 > > _463,    std::shared_ptr< monty::ndarray< int,1 > > _464,    std::shared_ptr< monty::ndarray< int,1 > > _465,    std::shared_ptr< monty::ndarray< int,1 > > _466) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_460,_461,_462,_463,_464,_465,_466); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< double,1 > > _462,    std::shared_ptr< monty::ndarray< double,1 > > _463,    std::shared_ptr< monty::ndarray< int,1 > > _464,    std::shared_ptr< monty::ndarray< int,1 > > _465,    std::shared_ptr< monty::ndarray< int,1 > > _466){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__460(_460 ? _460->raw() : nullptr, _460 ? _460->size(0) : 0);
    _checked_ptr_1<int> _ptr__461(_461 ? _461->raw() : nullptr, _461 ? _461->size(0) : 0);
    _checked_ptr_1<double> _ptr__462(_462 ? _462->raw() : nullptr, _462 ? _462->size(0) : 0);
    _checked_ptr_1<double> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    _checked_ptr_1<int> _ptr__464(_464 ? _464->raw() : nullptr, _464 ? _464->size(0) : 0);
    _checked_ptr_1<int> _ptr__465(_465 ? _465->raw() : nullptr, _465 ? _465->size(0) : 0);
    _checked_ptr_1<int> _ptr__466(_466 ? _466->raw() : nullptr, _466 ? _466->size(0) : 0);
    ptrb = _460;
    subj = _461;
    cof = _462;
    bfix = _463;
    barsubi = _464;
    barsubj = _465;
    barmidx = _466;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _467){ return new mosek::fusion::Model(_467); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _467) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_467); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _467){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_467);
    monty::rc_ptr< ::mosek::fusion::Model > _468 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_467)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_467)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_467)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_467)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6831;
    for (int _469 = (int)0, _6832 = (int)((mosek::fusion::p_Model::_get_impl(_467)->vars)->size(0)); _469 < _6832 ; ++_469)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6833;
      bool _6834 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_467)->vars)(_469)).get());
      if (_6834)
      {
        _6833 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_467)->vars)(_469)).get())->__mosek_2fusion_2ModelVariable__clone(_468);
      }
      else
      {
        _6833 = nullptr;
      }
      _6831.push_back(_6833);
    }
    auto _6835 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6831.size()),_6831.begin(),_6831.end()));
    vars = _6835;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_467)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_467)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_467)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6836;
    for (int _470 = (int)0, _6837 = (int)((mosek::fusion::p_Model::_get_impl(_467)->barvars)->size(0)); _470 < _6837 ; ++_470)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6838;
      bool _6839 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_467)->barvars)(_470)).get());
      if (_6839)
      {
        _6838 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_467)->barvars)(_470)).get())->__mosek_2fusion_2ModelVariable__clone(_468);
      }
      else
      {
        _6838 = nullptr;
      }
      _6836.push_back(_6838);
    }
    auto _6840 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6836.size()),_6836.begin(),_6836.end()));
    barvars = _6840;
    var_map = mosek::fusion::p_Model::_get_impl(_467)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_type);
    natconmap_efix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_efix);
    natconmap_lb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_lb);
    natconmap_ub = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_467)->natconmap_ub);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_467)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6841;
    for (int _471 = (int)0, _6842 = (int)((mosek::fusion::p_Model::_get_impl(_467)->cons)->size(0)); _471 < _6842 ; ++_471)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _6843;
      bool _6844 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_467)->cons)(_471)).get());
      if (_6844)
      {
        _6843 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_467)->cons)(_471)).get())->__mosek_2fusion_2ModelConstraint__clone(_468);
      }
      else
      {
        _6843 = nullptr;
      }
      _6841.push_back(_6843);
    }
    auto _6845 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6841.size()),_6841.begin(),_6841.end()));
    cons = _6845;
    con_map = mosek::fusion::p_Model::_get_impl(_467)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    bfixidx = mosek::fusion::p_Model::_get_impl(_467)->bfixidx;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _472){ return new mosek::fusion::Model(_472); }mosek::fusion::Model::Model  (const std::string &  _472) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_472); }void mosek::fusion::p_Model::_initialize  (const std::string &  _472){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_472,std::string (""));
    model_name = _472;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6846;
    for (int _473 = (int)0, _6847 = (int)1024; _473 < _6847 ; ++_473)
    {
      _6846.push_back(nullptr);
    }
    auto _6848 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6846.size()),_6846.begin(),_6846.end()));
    vars = _6848;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_efix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_lb = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_ub = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6849;
    for (int _474 = (int)0, _6850 = (int)1024; _474 < _6850 ; ++_474)
    {
      _6849.push_back(nullptr);
    }
    auto _6851 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6849.size()),_6849.begin(),_6849.end()));
    cons = _6851;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    bfixidx = natvarmap_alloc((int)1);
    task_var_putboundlist_fx(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(bfixidx)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}));
    task_var_name(bfixidx,std::string ("1.0"));
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _475,std::shared_ptr< monty::ndarray< int,1 > > _476,std::shared_ptr< monty::ndarray< int,1 > > _477){
  _checked_ptr_1<int> _ptr__476(_476 ? _476->raw() : nullptr, _476 ? _476->size(0) : 0);
  _checked_ptr_1<int> _ptr__477(_477 ? _477->raw() : nullptr, _477 ? _477->size(0) : 0);
  return _475;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _478,const std::string & _479,std::shared_ptr< monty::ndarray< int,1 > > _480,std::shared_ptr< monty::ndarray< long long,1 > > _481){
  _checked_ptr_1<int> _ptr__478(_478 ? _478->raw() : nullptr, _478 ? _478->size(0) : 0);
  _checked_ptr_1<int> _ptr__480(_480 ? _480->raw() : nullptr, _480 ? _480->size(0) : 0);
  _checked_ptr_1<long long> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  task_format_con_names(_478,_479,_480,_481);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _482,const std::string & _483,std::shared_ptr< monty::ndarray< int,1 > > _484,std::shared_ptr< monty::ndarray< long long,1 > > _485){
  _checked_ptr_1<int> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  _checked_ptr_1<int> _ptr__484(_484 ? _484->raw() : nullptr, _484 ? _484->size(0) : 0);
  _checked_ptr_1<long long> _ptr__485(_485 ? _485->raw() : nullptr, _485 ? _485->size(0) : 0);
  task_format_var_names(_482,_483,_484,_485);
}
void mosek::fusion::p_Model::varname(int _486,const std::string & _487){
  task_var_name(_486,_487);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _488,std::shared_ptr< monty::ndarray< int,1 > > _489){
  _checked_ptr_1<int> _ptr__489(_489 ? _489->raw() : nullptr, _489 ? _489->size(0) : 0);
  int _490 = ((*natbarvarmap_ptr)(_488));
  int _491 = ((*natbarvarmap_num)(_488));
  int _6852 = (int)0;
  int _6853 = _491;
  for (int _492 = _6852; _492 < _6853; ++_492)
  {
    {
      _ptr__489[_492] = safe_add( _490,_492 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _493,std::shared_ptr< monty::ndarray< long long,1 > > _494){
  _checked_ptr_1<long long> _ptr__494(_494 ? _494->raw() : nullptr, _494 ? _494->size(0) : 0);
  int _495 = ((*natbarvarmap_ptr)(_493));
  int _496 = ((*natbarvarmap_num)(_493));
  int _497 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_493))));
  int _498 = (safe_mul( safe_mul( _496,_497 ),safe_add( _497,(int)1 ) ) / (int)2);
  long long _499 = ((*natbarvar_ptr)(_495));
  int _6854 = (int)0;
  int _6855 = _498;
  for (int _500 = _6854; _500 < _6855; ++_500)
  {
    {
      _ptr__494[_500] = safe_add( _499,_500 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _501,int _502){
  int _503 = (int)((natbarvar_idx)->size(0));
  int _504 = task_numbarvar();
  int _505 = (safe_mul( _502,safe_add( _502,(int)1 ) ) / (int)2);
  int _506 = safe_mul( _501,_505 );
  if ((safe_add( natbarvar_numbarvarelm,_506 ) >= _503))
  {
    {
      if ((_506 < _503))
      {
        {
          _506 = _503;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _503,_506 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _503,_506 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _503,_506 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _6856;
      bool _6857 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_6857)
      {
        _6856 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _6856 = (int)32;
      }
      int _507 = _6856;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_507);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _507,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _508 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_507)));
      int _6858 = (int)0;
      int _6859 = (int)((barvars)->size(0));
      for (int _509 = _6858; _509 < _6859; ++_509)
      {
        {
          ((*_508)(_509)) = ((*barvars)(_509));
        }
      }
      barvars = _508;
    }
  }
  {}
  if ((safe_add( _504,_501 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _6860;
      bool _6861 = (safe_add( _504,_501 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_6861)
      {
        _6860 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _6860 = safe_add( _504,_501 );
      }
      int _510 = _6860;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_510);
    }
  }
  {}
  if ((safe_add( _504,_501 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _6862;
      bool _6863 = (_501 > (int)((natbarvar_ptr)->size(0)));
      if (_6863)
      {
        _6862 = _501;
      }
      else
      {
        _6862 = (int)((natbarvar_ptr)->size(0));
      }
      int _511 = _6862;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_511 ),(int)1 ));
    }
  }
  {}
  int _6864 = (int)0;
  int _6865 = _501;
  for (int _512 = _6864; _512 < _6865; ++_512)
  {
    {
      ((*natbarvar_dim)(safe_add( _504,_512 ))) = _502;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _501;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_501 );
  int _513 = task_append_barvar(_502,_501);
  int _514 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _515 = ((*natbarvar_ptr)(_504));
    int _6866 = (int)0;
    int _6867 = _502;
    for (int _516 = _6866; _516 < _6867; ++_516)
    {
      {
        int _6868 = _516;
        int _6869 = _502;
        for (int _517 = _6868; _517 < _6869; ++_517)
        {
          {
            int _6870 = (int)0;
            int _6871 = _501;
            for (int _518 = _6870; _518 < _6871; ++_518)
            {
              {
                ((*natbarvar_idx)(safe_add( _515,safe_mul( _518,_505 ) ))) = safe_add( _514,_518 );
                ((*natbarvar_i)(safe_add( _515,safe_mul( _518,_505 ) ))) = _517;
                ((*natbarvar_j)(safe_add( _515,safe_mul( _518,_505 ) ))) = _516;
              }
            }
            ++ _515;
          }
        }
      }
    }
    int _6872 = (int)0;
    int _6873 = _501;
    for (int _519 = _6872; _519 < _6873; ++_519)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _514,_519 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _514,_519 ))),_505 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _501,_505 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _520){
  int _521 = natvarmap->alloc(_520);
  int _522 = safe_add( natvarmap->maxidx(_521),(int)1 );
  int _523 = natvarmap->capacity();
  int _524 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _523))
  {
    {
      int _525 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_523);
      int _6874 = _525;
      int _6875 = _523;
      for (int _526 = _6874; _526 < _6875; ++_526)
      {
        {
          ((*natvarmap_idx)(_526)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_523);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _524))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_524);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _527 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_524)));
      int _6876 = (int)0;
      int _6877 = (int)((vars)->size(0));
      for (int _528 = _6876; _528 < _6877; ++_528)
      {
        {
          ((*_527)(_528)) = ((*vars)(_528));
        }
      }
      int _6878 = (int)((vars)->size(0));
      int _6879 = (int)((_527)->size(0));
      for (int _529 = _6878; _529 < _6879; ++_529)
      {
        {
          ((*_527)(_529)) = nullptr;
        }
      }
      vars = _527;
    }
  }
  {}
  if ((task_numvar() < _522))
  {
    {
      task_append_var((_522 - task_numvar()));
    }
  }
  {}
  return _521;
}
int mosek::fusion::p_Model::natconmap_alloc(int _530){
  int _531 = natconmap->alloc(_530);
  int _532 = safe_add( natconmap->maxidx(_531),(int)1 );
  int _533 = natconmap->capacity();
  int _534 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _533))
  {
    {
      int _535 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_533);
      int _6880 = _535;
      int _6881 = _533;
      for (int _536 = _6880; _536 < _6881; ++_536)
      {
        {
          ((*natconmap_idx)(_536)) = (-(int)1);
        }
      }
      natconmap_efix = ::mosek::fusion::p_CommonTools::resize(natconmap_efix,_533);
      natconmap_lb = ::mosek::fusion::p_CommonTools::resize(natconmap_lb,_533);
      natconmap_ub = ::mosek::fusion::p_CommonTools::resize(natconmap_ub,_533);
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_533);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_533);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _534))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_534);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _537 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_534)));
      int _6882 = (int)0;
      int _6883 = (int)((cons)->size(0));
      for (int _538 = _6882; _538 < _6883; ++_538)
      {
        {
          ((*_537)(_538)) = ((*cons)(_538));
        }
      }
      int _6884 = (int)((cons)->size(0));
      int _6885 = _534;
      for (int _539 = _6884; _539 < _6885; ++_539)
      {
        {
          ((*_537)(_539)) = nullptr;
        }
      }
      cons = _537;
    }
  }
  {}
  if ((_532 > task_numcon()))
  {
    {
      task_append_con((_532 - task_numcon()));
    }
  }
  {}
  return _531;
}
int mosek::fusion::p_Model::natconemap_alloc(int _540){
  int _541 = natconemap->alloc(_540);
  int _542 = safe_add( natconemap->maxidx(_541),(int)1 );
  if ((_542 > task_numcone()))
  {
    {
      task_append_zerocones((_542 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _541;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _543){
  _checked_ptr_1<long long> _ptr__543(_543 ? _543->raw() : nullptr, _543 ? _543->size(0) : 0);
  int _544 = (int)0;
  int _6886 = (int)0;
  int _6887 = (int)((_543)->size(0));
  for (int _545 = _6886; _545 < _6887; ++_545)
  {
    {
      if ((_ptr__543[_545] > (int)0))
      {
        {
          ++ _544;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _546 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_544)));
  _checked_ptr_1<int> _ptr__546(_546 ? _546->raw() : nullptr,_546 ? _546->size(0) : 0);
  int _547 = (int)0;
  int _6888 = (int)0;
  int _6889 = (int)((_543)->size(0));
  for (int _548 = _6888; _548 < _6889; ++_548)
  {
    {
      if ((_ptr__543[_548] > (int)0))
      {
        {
          _ptr__546[_547] = (int)(_ptr__543[_548] - (int)1);
          ++ _547;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_546);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _549){
  _checked_ptr_1<long long> _ptr__549(_549 ? _549->raw() : nullptr, _549 ? _549->size(0) : 0);
  int _550 = (int)0;
  int _6890 = (int)0;
  int _6891 = (int)((_549)->size(0));
  for (int _551 = _6890; _551 < _6891; ++_551)
  {
    {
      if ((_ptr__549[_551] > (int)0))
      {
        {
          ++ _550;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _552 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_550)));
  _checked_ptr_1<int> _ptr__552(_552 ? _552->raw() : nullptr,_552 ? _552->size(0) : 0);
  int _553 = (int)0;
  int _6892 = (int)0;
  int _6893 = (int)((_549)->size(0));
  for (int _554 = _6892; _554 < _6893; ++_554)
  {
    {
      if ((_ptr__549[_554] > (int)0))
      {
        {
          _ptr__552[_553] = (int)(_ptr__549[_554] - (int)1);
          ++ _553;
        }
      }
      {}
    }
  }
  task_var_putintlist(_552);
}
void mosek::fusion::Model::putlicensewait  ( bool _555) { mosek::fusion::p_Model::putlicensewait(_555); }void mosek::fusion::p_Model::putlicensewait(bool _555){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_555);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _556) { mosek::fusion::p_Model::putlicensepath(_556); }void mosek::fusion::p_Model::putlicensepath(const std::string & _556){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_556);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _557) { mosek::fusion::p_Model::putlicensecode(_557); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _557){
  _checked_ptr_1<int> _ptr__557(_557 ? _557->raw() : nullptr, _557 ? _557->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_557);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _6894 = (int)0;
  int _6895 = (int)((vars)->size(0));
  for (int _558 = _6894; _558 < _6895; ++_558)
  {
    {
      ((*vars)(_558)) = nullptr;
    }
  }
  int _6896 = (int)0;
  int _6897 = (int)((cons)->size(0));
  for (int _559 = _6896; _559 < _6897; ++_559)
  {
    {
      ((*cons)(_559)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _560,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _561){
  if (((_560 < (int)0) || ((_560 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_560)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_560))))->elementName((long long)(((*natvarmap_idx)(_560))),_561);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintValues(bool _562,std::shared_ptr< monty::ndarray< int,1 > > _563,std::shared_ptr< monty::ndarray< double,1 > > _564,int _565) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_562,_563,_564,_565); }void mosek::fusion::p_Model::getConstraintValues(bool _562,std::shared_ptr< monty::ndarray< int,1 > > _563,std::shared_ptr< monty::ndarray< double,1 > > _564,int _565){
  _checked_ptr_1<int> _ptr__563(_563 ? _563->raw() : nullptr, _563 ? _563->size(0) : 0);
  _checked_ptr_1<double> _ptr__564(_564 ? _564->raw() : nullptr, _564 ? _564->size(0) : 0);
  int _566 = (int)((_563)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6898;
  bool _6899 = _562;
  if (_6899)
  {
    _6898 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6898 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _567 = _6898;
  _checked_ptr_1<double> _ptr__567(_567 ? _567->raw() : nullptr,_567 ? _567->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6900;
  bool _6901 = _562;
  if (_6901)
  {
    _6900 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6900 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _568 = _6900;
  _checked_ptr_1<double> _ptr__568(_568 ? _568->raw() : nullptr,_568 ? _568->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6902;
  bool _6903 = _562;
  if (_6903)
  {
    _6902 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6902 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _569 = _6902;
  _checked_ptr_1<double> _ptr__569(_569 ? _569->raw() : nullptr,_569 ? _569->size(0) : 0);
  int _6904 = (int)0;
  int _6905 = _566;
  for (int _570 = _6904; _570 < _6905; ++_570)
  {
    {
      long long _571 = ((*natconmap_slackidx)(_ptr__563[_570]));
      if ((_571 < (int)0))
      {
        {
          long long _572 = (-safe_add( _571,(int)1 ));
          _ptr__564[safe_add( _565,_570 )] = _ptr__568[_572];
        }
      }
      else if((_571 > (int)0))
      {
        {
          _ptr__564[safe_add( _565,_570 )] = _ptr__567[(_571 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__564[safe_add( _565,_570 )] = _ptr__569[_ptr__563[_570]];
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableDuals(bool _573,std::shared_ptr< monty::ndarray< long long,1 > > _574,std::shared_ptr< monty::ndarray< double,1 > > _575,int _576) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_573,_574,_575,_576); }void mosek::fusion::p_Model::getVariableDuals(bool _573,std::shared_ptr< monty::ndarray< long long,1 > > _574,std::shared_ptr< monty::ndarray< double,1 > > _575,int _576){
  _checked_ptr_1<long long> _ptr__574(_574 ? _574->raw() : nullptr, _574 ? _574->size(0) : 0);
  _checked_ptr_1<double> _ptr__575(_575 ? _575->raw() : nullptr, _575 ? _575->size(0) : 0);
  int _577 = (int)((_574)->size(0));
  if (_573)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _578 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__578(_578 ? _578->raw() : nullptr,_578 ? _578->size(0) : 0);
      int _6906 = (int)0;
      int _6907 = _577;
      for (int _579 = _6906; _579 < _6907; ++_579)
      {
        {
          if ((_ptr__574[_579] > (int)0))
          {
            {
              _ptr__575[safe_add( _576,_579 )] = _ptr__578[(_ptr__574[_579] - (int)1)];
            }
          }
          else
          {
            {
              _ptr__575[safe_add( _576,_579 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _580 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__580(_580 ? _580->raw() : nullptr,_580 ? _580->size(0) : 0);
      int _6908 = (int)0;
      int _6909 = _577;
      for (int _581 = _6908; _581 < _6909; ++_581)
      {
        {
          if ((_ptr__574[_581] > (int)0))
          {
            {
              _ptr__575[safe_add( _576,_581 )] = (-_ptr__580[(_ptr__574[_581] - (int)1)]);
            }
          }
          else
          {
            {
              _ptr__575[safe_add( _576,_581 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _582,std::shared_ptr< monty::ndarray< long long,1 > > _583,std::shared_ptr< monty::ndarray< double,1 > > _584,int _585) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_582,_583,_584,_585); }void mosek::fusion::p_Model::getVariableValues(bool _582,std::shared_ptr< monty::ndarray< long long,1 > > _583,std::shared_ptr< monty::ndarray< double,1 > > _584,int _585){
  _checked_ptr_1<long long> _ptr__583(_583 ? _583->raw() : nullptr, _583 ? _583->size(0) : 0);
  _checked_ptr_1<double> _ptr__584(_584 ? _584->raw() : nullptr, _584 ? _584->size(0) : 0);
  int _586 = (int)((_583)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6910;
  bool _6911 = _582;
  if (_6911)
  {
    _6910 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6910 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _587 = _6910;
  _checked_ptr_1<double> _ptr__587(_587 ? _587->raw() : nullptr,_587 ? _587->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6912;
  bool _6913 = (natbarvar_numbarvarelm > (int)0);
  if (_6913)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _6914;
    bool _6915 = _582;
    if (_6915)
    {
      _6914 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _6914 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _6912 = _6914;
  }
  else
  {
    _6912 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _588 = _6912;
  _checked_ptr_1<double> _ptr__588(_588 ? _588->raw() : nullptr,_588 ? _588->size(0) : 0);
  int _6916 = (int)0;
  int _6917 = _586;
  for (int _589 = _6916; _589 < _6917; ++_589)
  {
    {
      if ((_ptr__583[_589] > (int)0))
      {
        {
          _ptr__584[safe_add( _585,_589 )] = _ptr__587[(_ptr__583[_589] - (int)1)];
        }
      }
      else if((_ptr__583[_589] < (int)0))
      {
        {
          long long _590 = (-safe_add( _ptr__583[_589],(int)1 ));
          _ptr__584[safe_add( _585,_589 )] = _ptr__588[_590];
        }
      }
      else
      {
        {
          _ptr__584[safe_add( _585,_589 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _591,std::shared_ptr< monty::ndarray< long long,1 > > _592,std::shared_ptr< monty::ndarray< double,1 > > _593) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_591,_592,_593); }void mosek::fusion::p_Model::setVariableValues(bool _591,std::shared_ptr< monty::ndarray< long long,1 > > _592,std::shared_ptr< monty::ndarray< double,1 > > _593){
  _checked_ptr_1<long long> _ptr__592(_592 ? _592->raw() : nullptr, _592 ? _592->size(0) : 0);
  _checked_ptr_1<double> _ptr__593(_593 ? _593->raw() : nullptr, _593 ? _593->size(0) : 0);
  if (_591)
  {
    {
      int _594 = (int)0;
      int _6918 = (int)0;
      int _6919 = (int)((_592)->size(0));
      for (int _595 = _6918; _595 < _6919; ++_595)
      {
        {
          if ((_ptr__592[_595] >= (int)0))
          {
            {
              ++ _594;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _596 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_594)));
      _checked_ptr_1<int> _ptr__596(_596 ? _596->raw() : nullptr,_596 ? _596->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6920;
      bool _6921 = (_594 == (int)((_592)->size(0)));
      if (_6921)
      {
        _6920 = _593;
      }
      else
      {
        _6920 = _593;
      }
      std::shared_ptr< monty::ndarray< double,1 > > _597 = _6920;
      _checked_ptr_1<double> _ptr__597(_597 ? _597->raw() : nullptr,_597 ? _597->size(0) : 0);
      int _598 = (int)0;
      int _6922 = (int)0;
      int _6923 = (int)((_592)->size(0));
      for (int _599 = _6922; _599 < _6923; ++_599)
      {
        {
          if ((_ptr__592[_599] > (int)0))
          {
            {
              _ptr__596[_598] = (int)(_ptr__592[_599] - (int)1);
              ++ _598;
            }
          }
          {}
        }
      }
      setSolution_xx(_596,_597);
    }
  }
  else
  {
    {
    }
  }
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _6924 = (int)0;
  int _6925 = (int)((vars)->size(0));
  for (int _600 = _6924; _600 < _6925; ++_600)
  {
    {
      if ((NULL != ((*vars)(_600)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_600)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6926 = (int)0;
  int _6927 = (int)((barvars)->size(0));
  for (int _601 = _6926; _601 < _6927; ++_601)
  {
    {
      if ((NULL != ((*barvars)(_601)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_601)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6928 = (int)0;
  int _6929 = (int)((cons)->size(0));
  for (int _602 = _6928; _602 < _6929; ++_602)
  {
    {
      if ((NULL != ((*cons)(_602)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_602)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTask(const std::string & _603) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_603); }void mosek::fusion::p_Model::writeTask(const std::string & _603){
  _pubthis->flushNames();
  task_write(_603);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _604) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_604); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _604){
  return task_get_liinf(_604);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _605) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_605); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _605){
  return task_get_iinf(_605);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _606) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_606); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _606){
  return task_get_dinf(_606);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _607) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_607); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _607){
  task_setCallbackHandler(_607);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _608) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_608); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _608){
  task_setDataCallbackHandler(_608);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _609) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_609); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _609){
  task_setLogHandler(_609);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _610,double _611) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_610,_611); }void mosek::fusion::p_Model::setSolverParam(const std::string & _610,double _611){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_610,_611);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _612,int _613) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_612,_613); }void mosek::fusion::p_Model::setSolverParam(const std::string & _612,int _613){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_612,_613);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _614,const std::string & _615) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_614,_615); }void mosek::fusion::p_Model::setSolverParam(const std::string & _614,const std::string & _615){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_614,_615);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: solve(const std::string & _616,const std::string & _617) { mosek::fusion::p_Model::_get_impl(this)->solve(_616,_617); }void mosek::fusion::p_Model::solve(const std::string & _616,const std::string & _617){
  _pubthis->flushSolutions();
  task_solve(true,_616,_617);
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  _pubthis->flushSolutions();
  task_solve(false,std::string (""),std::string (""));
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _618){
  if ((NULL != initsol_xx.get()))
  {
    {
      int _619 = task_numvar();
      std::shared_ptr< monty::ndarray< double,1 > > _620 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_619)));
      _checked_ptr_1<double> _ptr__620(_620 ? _620->raw() : nullptr,_620 ? _620->size(0) : 0);
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _622 = __mosek_2fusion_2Model__get_sol_cache(_618,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_622)->xx.get()))
          {
            {
              int _6930;
              bool _6931 = ((int)((mosek::fusion::p_SolutionStruct::_get_impl(_622)->xx)->size(0)) <= _619);
              if (_6931)
              {
                _6930 = (int)((mosek::fusion::p_SolutionStruct::_get_impl(_622)->xx)->size(0));
              }
              else
              {
                _6930 = _619;
              }
              ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_622)->xx,(int)0,_620,(int)0,_6930);
            }
          }
          {}
        }
      }
      catch (mosek::fusion::SolutionError _621)
      {
        {
        }
      }
      int _6932;
      bool _6933 = ((int)((initsol_xx)->size(0)) <= _619);
      if (_6933)
      {
        _6932 = (int)((initsol_xx)->size(0));
      }
      else
      {
        _6932 = _619;
      }
      int _623 = _6932;
      int _6934 = (int)0;
      int _6935 = _623;
      for (int _624 = _6934; _624 < _6935; ++_624)
      {
        {
          if (((*initsol_xx_flag)(_624)))
          {
            {
              _ptr__620[_624] = ((*initsol_xx)(_624));
            }
          }
          {}
        }
      }
      task_putxx_slice(_618,(int)0,_619,_620);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _625,bool _626,bool _627){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _628 = nullptr;
  mosek::fusion::SolutionType _629 = _625;
  if ((_629 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _629 = solutionptr;
    }
  }
  {}
  if ((_629 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _628 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _628 = sol_bas;
        }
      }
      else
      {
        {
          _628 = sol_itr;
        }
      }
    }
  }
  else if((_629 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _628 = sol_itr;
    }
  }
  else if((_629 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _628 = sol_bas;
    }
  }
  else if((_629 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _628 = sol_itg;
    }
  }
  {}
  if ((NULL == _628.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_627 || ((_626 && _628->isPrimalAcceptable(acceptable_sol)) || ((!_626) && _628->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _628;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _630 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _631 = mosek::fusion::p_SolutionStruct::_get_impl(_628)->pstatus;
          mosek::fusion::ProblemStatus _632 = mosek::fusion::p_SolutionStruct::_get_impl(_628)->probstatus;
          if ((!_626))
          {
            {
              _631 = mosek::fusion::p_SolutionStruct::_get_impl(_628)->dstatus;
            }
          }
          {}
          _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_631 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_631 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_631 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_631 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_631 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          else if((_631 == ::mosek::fusion::SolutionStatus::IllposedCert))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("IllposedCert"));
            }
          }
          {}
          _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but at least "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected. Reason: Accessing "));
          if ((_628 == sol_itr))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("interior-point solution"));
            }
          }
          else if((_628 == sol_bas))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("basic solution"));
            }
          }
          else if((_628 == sol_itg))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("integer solution"));
            }
          }
          {}
          _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" whose problem status is "));
          if ((_632 == ::mosek::fusion::ProblemStatus::Unknown))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::PrimalAndDualFeasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalAndDualFeasible"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::PrimalFeasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalFeasible"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::DualFeasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DualFeasible"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::PrimalInfeasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalInfeasible"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::DualInfeasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DualInfeasible"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::PrimalAndDualInfeasible))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalAndDualInfeasible"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::IllPosed))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("IllPosed"));
            }
          }
          else if((_632 == ::mosek::fusion::ProblemStatus::PrimalInfeasibleOrUnbounded))
          {
            {
              _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalInfeasibleOrUnbounded"));
            }
          }
          {}
          _630->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("."));
          throw ::mosek::fusion::SolutionError(_630->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _633,bool _634){
  return __mosek_2fusion_2Model__get_sol_cache(_633,_634,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _635,std::shared_ptr< monty::ndarray< double,1 > > _636){
  _checked_ptr_1<int> _ptr__635(_635 ? _635->raw() : nullptr, _635 ? _635->size(0) : 0);
  _checked_ptr_1<double> _ptr__636(_636 ? _636->raw() : nullptr, _636 ? _636->size(0) : 0);
  ensure_initsol_xx();
  int _6936 = (int)0;
  int _6937 = (int)((_635)->size(0));
  for (int _637 = _6936; _637 < _6937; ++_637)
  {
    {
      ((*initsol_xx)(_ptr__635[_637])) = _ptr__636[_637];
      ((*initsol_xx_flag)(_ptr__635[_637])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _638 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_638)));
      std::vector<bool> _6938;
      for (int _639 = (int)0, _6939 = _638; _639 < _6939 ; ++_639)
      {
        _6938.push_back(false);
      }
      auto _6940 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6938.size()),_6938.begin(),_6938.end()));
      initsol_xx_flag = _6940;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _638))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _640 = initsol_xx;
      _checked_ptr_1<double> _ptr__640(_640 ? _640->raw() : nullptr,_640 ? _640->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _641 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_638)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_638)));
      ::mosek::fusion::Utils::Tools::arraycopy(_640,(int)0,initsol_xx,(int)0,_638);
      int _6941 = (int)0;
      int _6942 = _638;
      for (int _642 = _6941; _642 < _6942; ++_642)
      {
        {
          ((*initsol_xx_flag)(_642)) = ((*_641)(_642));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _643){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_643,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _644){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_644,true))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _645){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_645,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _646){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_646,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _647){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_647,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _648){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_648,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _649){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_649,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _650){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_650,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _651){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_651,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _652){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_652,false))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _653){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_653,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _654) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_654); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _654){
  solutionptr = _654;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _655) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_655); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _655){
  acceptable_sol = _655;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _656) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_656); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _656){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _657 = nullptr;
  if ((_656 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _657 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _657 = sol_bas;
        }
      }
      else
      {
        {
          _657 = sol_itr;
        }
      }
    }
  }
  else if((_656 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _657 = sol_itr;
    }
  }
  else if((_656 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _657 = sol_bas;
    }
  }
  else if((_656 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _657 = sol_itg;
    }
  }
  {}
  if ((NULL == _657.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_657)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _658) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_658); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _658){
  return getSolutionStatus(_658,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _659) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_659); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _659){
  return getSolutionStatus(_659,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _660,bool _661){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _663 = __mosek_2fusion_2Model__get_sol_cache(_660,_661,true);
      if (_661)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_663)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_663)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _662)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _664,monty::rc_ptr< ::mosek::fusion::Expression > _665){
  _checked_ptr_1<int> _ptr__664(_664 ? _664->raw() : nullptr, _664 ? _664->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_665)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _666 = ws->popi32();
  int _667 = ws->popi32(_666);
  int _668 = ws->popi32();
  int _669 = ws->popi32();
  bool _670 = ((int)0 != ws->popi32());
  int _671 = ws->popi32(safe_add( _668,(int)1 ));
  int _6943;
  bool _6944 = _670;
  if (_6944)
  {
    _6943 = ws->popi64(_668);
  }
  else
  {
    _6943 = (int)0;
  }
  int _672 = _6943;
  int _673 = ws->popi64(_669);
  int _674 = ws->popf64(_668);
  int _675 = ws->popf64(_669);
  std::shared_ptr< monty::ndarray< int,1 > > _676 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__676(_676 ? _676->raw() : nullptr,_676 ? _676->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _677 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__677(_677 ? _677->raw() : nullptr,_677 ? _677->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _678 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__678(_678 ? _678->raw() : nullptr,_678 ? _678->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _679 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _668,(int)1 ))));
  _checked_ptr_1<long long> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
  int _6945 = (int)0;
  int _6946 = _668;
  for (int _680 = _6945; _680 < _6946; ++_680)
  {
    {
      int _6947 = _ptr__676[safe_add( _671,_680 )];
      int _6948 = _ptr__676[safe_add( safe_add( _671,_680 ),(int)1 )];
      for (int _681 = _6947; _681 < _6948; ++_681)
      {
        {
          if ((_ptr__677[safe_add( _673,_681 )] > (int)0))
          {
            {
              ++ _ptr__679[safe_add( _680,(int)1 )];
            }
          }
          {}
        }
      }
    }
  }
  int _6949 = (int)0;
  int _6950 = _668;
  for (int _682 = _6949; _682 < _6950; ++_682)
  {
    {
      _ptr__679[safe_add( _682,(int)1 )] += _ptr__679[_682];
    }
  }
  long long _683 = _ptr__679[_668];
  std::shared_ptr< monty::ndarray< int,1 > > _684 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_683)));
  _checked_ptr_1<int> _ptr__684(_684 ? _684->raw() : nullptr,_684 ? _684->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _685 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_683)));
  _checked_ptr_1<double> _ptr__685(_685 ? _685->raw() : nullptr,_685 ? _685->size(0) : 0);
  int _686 = (int)0;
  int _6951 = (int)0;
  int _6952 = _668;
  for (int _687 = _6951; _687 < _6952; ++_687)
  {
    {
      int _6953 = _ptr__676[safe_add( _671,_687 )];
      int _6954 = _ptr__676[safe_add( safe_add( _671,_687 ),(int)1 )];
      for (int _688 = _6953; _688 < _6954; ++_688)
      {
        {
          if ((_ptr__677[safe_add( _673,_688 )] > (int)0))
          {
            {
              _ptr__684[_686] = (int)(_ptr__677[safe_add( _673,_688 )] - (int)1);
              _ptr__685[_686] = _ptr__678[safe_add( _675,_688 )];
              ++ _686;
            }
          }
          {}
        }
      }
    }
  }
  task_putarowlist(_664,_679,_684,_685);
  std::vector<int> _6955;
  for (int _689 = (int)0, _6956 = _668; _689 < _6956 ; ++_689)
  {
    _6955.push_back(bfixidx);
  }
  auto _6957 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6955.size()),_6955.begin(),_6955.end()));
  std::vector<double> _6958;
  for (int _690 = (int)0, _6959 = _668; _690 < _6959 ; ++_690)
  {
    _6958.push_back(_ptr__678[safe_add( _674,_690 )]);
  }
  auto _6960 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6958.size()),_6958.begin(),_6958.end()));
  task_putaijlist(_664,_6957,_6960,(long long)(_668));
  int _691 = (int)0;
  int _6961 = (int)0;
  int _6962 = _668;
  for (int _692 = _6961; _692 < _6962; ++_692)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__664[_692])) > (int)0))
      {
        {
          ++ _691;
        }
      }
      {}
    }
  }
  if ((_691 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _693 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_691)));
      _checked_ptr_1<int> _ptr__693(_693 ? _693->raw() : nullptr,_693 ? _693->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _694 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_691)));
      _checked_ptr_1<int> _ptr__694(_694 ? _694->raw() : nullptr,_694 ? _694->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _695 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_691)));
      _checked_ptr_1<double> _ptr__695(_695 ? _695->raw() : nullptr,_695 ? _695->size(0) : 0);
      int _696 = (int)0;
      int _6963 = (int)0;
      int _6964 = _668;
      for (int _697 = _6963; _697 < _6964; ++_697)
      {
        {
          if ((((*natconmap_slackidx)(_ptr__664[_697])) > (int)0))
          {
            {
              _ptr__693[_696] = _ptr__664[_697];
              _ptr__694[_696] = (int)(((*natconmap_slackidx)(_ptr__664[_697])) - (int)1);
              _ptr__695[_696] = (-1.0);
              ++ _696;
            }
          }
          {}
        }
      }
      task_putaijlist(_693,_694,_695,(long long)(_691));
    }
  }
  {}
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _698,monty::rc_ptr< ::mosek::fusion::Expression > _699,std::shared_ptr< monty::ndarray< int,1 > > _700,bool _701){
  _checked_ptr_1<int> _ptr__698(_698 ? _698->raw() : nullptr, _698 ? _698->size(0) : 0);
  _checked_ptr_1<int> _ptr__700(_700 ? _700->raw() : nullptr, _700 ? _700->size(0) : 0);
  int _702 = safe_mul( (int)((_698)->size(0)),(int)((_700)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _703 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_702)));
  _checked_ptr_1<double> _ptr__703(_703 ? _703->raw() : nullptr,_703 ? _703->size(0) : 0);
  std::vector<int> _6965;
  for (int _705 = (int)0, _6966 = (int)((_698)->size(0)); _705 < _6966 ; ++_705)
  {
    for (int _706 = (int)0, _6967 = (int)((_700)->size(0)); _706 < _6967 ; ++_706)
    {
      _6965.push_back(_ptr__698[_705]);
    }
  }
  auto _6968 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6965.size()),_6965.begin(),_6965.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _704 = _6968;
  _checked_ptr_1<int> _ptr__704(_704 ? _704->raw() : nullptr,_704 ? _704->size(0) : 0);
  std::vector<int> _6969;
  for (int _708 = (int)0, _6970 = (int)((_698)->size(0)); _708 < _6970 ; ++_708)
  {
    for (int _709 = (int)0, _6971 = (int)((_700)->size(0)); _709 < _6971 ; ++_709)
    {
      _6969.push_back(_ptr__700[_709]);
    }
  }
  auto _6972 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6969.size()),_6969.begin(),_6969.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _707 = _6972;
  _checked_ptr_1<int> _ptr__707(_707 ? _707->raw() : nullptr,_707 ? _707->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_699)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _710 = ws->popi32();
  int _711 = ws->popi32(_710);
  int _712 = ws->popi32();
  int _713 = ws->popi32();
  bool _714 = ((int)0 != ws->popi32());
  int _715 = ws->popi32(safe_add( _712,(int)1 ));
  int _6973;
  bool _6974 = _714;
  if (_6974)
  {
    _6973 = ws->popi64(_712);
  }
  else
  {
    _6973 = (int)0;
  }
  int _716 = _6973;
  int _717 = ws->popi64(_713);
  int _718 = ws->popf64(_712);
  int _719 = ws->popf64(_713);
  std::shared_ptr< monty::ndarray< int,1 > > _720 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__720(_720 ? _720->raw() : nullptr,_720 ? _720->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _721 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__721(_721 ? _721->raw() : nullptr,_721 ? _721->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _722 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__722(_722 ? _722->raw() : nullptr,_722 ? _722->size(0) : 0);
  int _723 = (int)0;
  int _6975 = (int)0;
  int _6976 = _712;
  for (int _724 = _6975; _724 < _6976; ++_724)
  {
    {
      int _725 = _ptr__720[safe_add( _715,_724 )];
      int _726 = _ptr__720[safe_add( safe_add( _715,_724 ),(int)1 )];
      int _727 = _725;
      int _728 = (int)0;
      while ( ((_728 < (int)((_700)->size(0))) && (_727 < _726)) )
      {
        {
          if ((_ptr__700[_728] < (_ptr__721[safe_add( _717,_727 )] - (int)1)))
          {
            {
              ++ _728;
            }
          }
          else if((_ptr__700[_728] > (_ptr__721[safe_add( _717,_727 )] - (int)1)))
          {
            {
              ++ _727;
            }
          }
          else
          {
            {
              _ptr__703[safe_add( _723,_728 )] = _ptr__722[safe_add( _719,_727 )];
              ++ _728;
              ++ _727;
            }
          }
        }
      }
      _723 += (int)((_700)->size(0));
    }
  }
  task_putaijlist(_704,_707,_703,(long long)(_702));
  if (_701)
  {
    {
      std::vector<int> _6977;
      for (int _729 = (int)0, _6978 = _712; _729 < _6978 ; ++_729)
      {
        _6977.push_back(bfixidx);
      }
      auto _6979 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6977.size()),_6977.begin(),_6977.end()));
      std::vector<double> _6980;
      for (int _730 = (int)0, _6981 = _712; _730 < _6981 ; ++_730)
      {
        _6980.push_back(_ptr__722[safe_add( _718,_730 )]);
      }
      auto _6982 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6980.size()),_6980.begin(),_6980.end()));
      task_putaijlist(_698,_6979,_6982,(long long)(_712));
    }
  }
  {}
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _731,monty::rc_ptr< ::mosek::fusion::Variable > _732) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_731,_732); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _731,monty::rc_ptr< ::mosek::fusion::Variable > _732){
  if ((_731->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _733 = _732->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _734 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_733)));
  _checked_ptr_1<long long> _ptr__734(_734 ? _734->raw() : nullptr,_734 ? _734->size(0) : 0);
  if ((_733 < _732->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _735 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_733)));
      _checked_ptr_1<long long> _ptr__735(_735 ? _735->raw() : nullptr,_735 ? _735->size(0) : 0);
      _732->inst((int)0,_735,(int)0,_734);
    }
  }
  else
  {
    {
      _732->inst((int)0,_734);
    }
  }
  int _6983 = (int)0;
  int _6984 = _733;
  for (int _736 = _6983; _736 < _6984; ++_736)
  {
    {
      if ((_ptr__734[_736] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _737 = true;
  int _6985 = (int)0;
  int _6986 = (_733 - (int)1);
  for (int _738 = _6985; _738 < _6986; ++_738)
  {
    {
      _737 = (_737 && (_ptr__734[_738] < _ptr__734[(_738 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _739 = nullptr;
  _checked_ptr_1<int> _ptr__739(_739 ? _739->raw() : nullptr,_739 ? _739->size(0) : 0);
  if (_737)
  {
    {
      std::vector<int> _6987;
      for (int _740 = (int)0, _6988 = _733; _740 < _6988 ; ++_740)
      {
        _6987.push_back((int)(_ptr__734[_740] - (int)1));
      }
      auto _6989 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6987.size()),_6987.begin(),_6987.end()));
      _739 = _6989;
      _ptr__739.update(_739 ? _739->raw() : nullptr, _739 ? _739->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _6990;
      for (int _742 = (-(int)1), _6991 = _733; _742 < _6991 ; ++_742)
      {
        _6990.push_back(_742);
      }
      auto _6992 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6990.size()),_6990.begin(),_6990.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _741 = _6992;
      _checked_ptr_1<long long> _ptr__741(_741 ? _741->raw() : nullptr,_741 ? _741->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_741,_734,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_733));
      std::vector<int> _6993;
      for (int _743 = (int)0, _6994 = _733; _743 < _6994 ; ++_743)
      {
        _6993.push_back((int)(_ptr__734[_ptr__741[_743]] - (int)1));
      }
      auto _6995 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6993.size()),_6993.begin(),_6993.end()));
      _739 = _6995;
      _ptr__739.update(_739 ? _739->raw() : nullptr, _739 ? _739->size(0) : 0);
    }
  }
  int _744 = (int)((_739)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _745 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_744)));
  _checked_ptr_1<double> _ptr__745(_745 ? _745->raw() : nullptr,_745 ? _745->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _746 = _739;
  _checked_ptr_1<int> _ptr__746(_746 ? _746->raw() : nullptr,_746 ? _746->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_731)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _747 = ws->popi32();
  int _748 = ws->popi32(_747);
  int _749 = ws->popi32();
  int _750 = ws->popi32();
  bool _751 = ((int)0 != ws->popi32());
  int _752 = ws->popi32(safe_add( _749,(int)1 ));
  int _6996;
  bool _6997 = _751;
  if (_6997)
  {
    _6996 = ws->popi64(_749);
  }
  else
  {
    _6996 = (int)0;
  }
  int _753 = _6996;
  int _754 = ws->popi64(_750);
  int _755 = ws->popf64(_749);
  int _756 = ws->popf64(_750);
  std::shared_ptr< monty::ndarray< int,1 > > _757 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__757(_757 ? _757->raw() : nullptr,_757 ? _757->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _758 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__758(_758 ? _758->raw() : nullptr,_758 ? _758->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _759 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__759(_759 ? _759->raw() : nullptr,_759 ? _759->size(0) : 0);
  int _760 = (int)0;
  int _6998 = (int)0;
  int _6999 = _749;
  for (int _761 = _6998; _761 < _6999; ++_761)
  {
    {
      int _762 = _ptr__757[safe_add( _752,_761 )];
      int _763 = _ptr__757[safe_add( safe_add( _752,_761 ),(int)1 )];
      int _764 = _762;
      int _765 = (int)0;
      while ( ((_765 < (int)((_739)->size(0))) && (_764 < _763)) )
      {
        {
          if ((_ptr__739[_765] < (_ptr__758[safe_add( _754,_764 )] - (int)1)))
          {
            {
              ++ _765;
            }
          }
          else if((_ptr__739[_765] > (_ptr__758[safe_add( _754,_764 )] - (int)1)))
          {
            {
              ++ _764;
            }
          }
          else
          {
            {
              _ptr__745[safe_add( _760,_765 )] = _ptr__759[safe_add( _756,_764 )];
              ++ _765;
              ++ _764;
            }
          }
        }
      }
      _760 += (int)((_739)->size(0));
    }
  }
  task_putclist(_746,_745);
}
void mosek::fusion::p_Model::objective_(const std::string & _766,mosek::fusion::ObjectiveSense _767,monty::rc_ptr< ::mosek::fusion::Expression > _768){
  task_putobjectivename(_766);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _769 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _770 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_768)).as<::mosek::fusion::Expression>())->eval(_769,_770,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _771 = mosek::fusion::p_WorkStack::_get_impl(_769)->i32;
  _checked_ptr_1<int> _ptr__771(_771 ? _771->raw() : nullptr,_771 ? _771->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _772 = mosek::fusion::p_WorkStack::_get_impl(_769)->i64;
  _checked_ptr_1<long long> _ptr__772(_772 ? _772->raw() : nullptr,_772 ? _772->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _773 = mosek::fusion::p_WorkStack::_get_impl(_769)->f64;
  _checked_ptr_1<double> _ptr__773(_773 ? _773->raw() : nullptr,_773 ? _773->size(0) : 0);
  int _774 = _769->popi32();
  int _775 = (int)1;
  int _7000 = (int)0;
  int _7001 = _774;
  for (int _776 = _7000; _776 < _7001; ++_776)
  {
    {
      _774 *= _769->popi32();
    }
  }
  if ((_775 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _777 = _769->popi32();
  if ((_777 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _778 = _769->popi32();
  bool _779 = (_769->popi32() != (int)0);
  int _780 = _769->popi32(safe_add( _777,(int)1 ));
  int _781 = _769->popi64(_778);
  int _782 = _769->popf64(_777);
  int _783 = _769->popf64(_778);
  int _784 = (int)0;
  int _785 = (int)0;
  int _7002 = (int)0;
  int _7003 = _778;
  for (int _786 = _7002; _786 < _7003; ++_786)
  {
    {
      if ((_ptr__772[safe_add( _781,_786 )] < (int)0))
      {
        {
          ++ _785;
        }
      }
      else if((_ptr__772[safe_add( _781,_786 )] > (int)0))
      {
        {
          ++ _784;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _787 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_784)));
  _checked_ptr_1<int> _ptr__787(_787 ? _787->raw() : nullptr,_787 ? _787->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _788 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_784)));
  _checked_ptr_1<double> _ptr__788(_788 ? _788->raw() : nullptr,_788 ? _788->size(0) : 0);
  {
    int _789 = (int)0;
    int _7004 = (int)0;
    int _7005 = _778;
    for (int _790 = _7004; _790 < _7005; ++_790)
    {
      {
        if ((_ptr__772[safe_add( _781,_790 )] > (int)0))
        {
          {
            _ptr__787[_789] = (int)(_ptr__772[safe_add( _781,_790 )] - (int)1);
            _ptr__788[_789] = _ptr__773[safe_add( _783,_790 )];
            ++ _789;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_767 == ::mosek::fusion::ObjectiveSense::Maximize),_787,_788,_ptr__773[_782]);
  if ((_785 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _791 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_785)));
      _checked_ptr_1<int> _ptr__791(_791 ? _791->raw() : nullptr,_791 ? _791->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _792 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_785)));
      _checked_ptr_1<int> _ptr__792(_792 ? _792->raw() : nullptr,_792 ? _792->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _793 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_785)));
      _checked_ptr_1<int> _ptr__793(_793 ? _793->raw() : nullptr,_793 ? _793->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _794 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_785)));
      _checked_ptr_1<double> _ptr__794(_794 ? _794->raw() : nullptr,_794 ? _794->size(0) : 0);
      int _7006 = (int)0;
      int _7007 = _785;
      for (int _795 = _7006; _795 < _7007; ++_795)
      {
        {
          long long _796 = (-safe_add( _ptr__772[safe_add( _781,_795 )],(int)1 ));
          _ptr__791[_795] = ((*natbarvar_idx)(_796));
          _ptr__792[_795] = ((*natbarvar_i)(_796));
          _ptr__793[_795] = ((*natbarvar_j)(_796));
          double _7008;
          bool _7009 = (_ptr__792[_795] == _ptr__793[_795]);
          if (_7009)
          {
            _7008 = _ptr__773[safe_add( _783,_795 )];
          }
          else
          {
            _7008 = (0.5 * _ptr__773[safe_add( _783,_795 )]);
          }
          _ptr__794[_795] = _7008;
        }
      }
      task_putbarc(_791,_792,_793,_794);
    }
  }
  {}
}
void mosek::fusion::Model :: objective(double _797) { mosek::fusion::p_Model::_get_impl(this)->objective(_797); }void mosek::fusion::p_Model::objective(double _797){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_797));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _798,double _799) { mosek::fusion::p_Model::_get_impl(this)->objective(_798,_799); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _798,double _799){
  objective_(std::string (""),_798,::mosek::fusion::p_Expr::constTerm(_799));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _800,monty::rc_ptr< ::mosek::fusion::Expression > _801) { mosek::fusion::p_Model::_get_impl(this)->objective(_800,_801); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _800,monty::rc_ptr< ::mosek::fusion::Expression > _801){
  objective_(std::string (""),_800,_801);
}
void mosek::fusion::Model :: objective(const std::string & _802,double _803) { mosek::fusion::p_Model::_get_impl(this)->objective(_802,_803); }void mosek::fusion::p_Model::objective(const std::string & _802,double _803){
  objective_(_802,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_803));
}
void mosek::fusion::Model :: objective(const std::string & _804,mosek::fusion::ObjectiveSense _805,double _806) { mosek::fusion::p_Model::_get_impl(this)->objective(_804,_805,_806); }void mosek::fusion::p_Model::objective(const std::string & _804,mosek::fusion::ObjectiveSense _805,double _806){
  objective_(_804,_805,::mosek::fusion::p_Expr::constTerm(_806));
}
void mosek::fusion::Model :: objective(const std::string & _807,mosek::fusion::ObjectiveSense _808,monty::rc_ptr< ::mosek::fusion::Expression > _809) { mosek::fusion::p_Model::_get_impl(this)->objective(_807,_808,_809); }void mosek::fusion::p_Model::objective(const std::string & _807,mosek::fusion::ObjectiveSense _808,monty::rc_ptr< ::mosek::fusion::Expression > _809){
  objective_(_807,_808,_809);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::ConeDomain > _811) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_810,_811); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::ConeDomain > _811) { return __mosek_2fusion_2Model__constraint(_810,_811); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _810,monty::rc_ptr< ::mosek::fusion::ConeDomain > _811){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_810,_811);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::ConeDomain > _814) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_812,_813,_814); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::ConeDomain > _814) { return __mosek_2fusion_2Model__constraint(_812,_813,_814); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _812,monty::rc_ptr< ::mosek::fusion::Expression > _813,monty::rc_ptr< ::mosek::fusion::ConeDomain > _814){
  return __mosek_2fusion_2Model__constraint_(_812,_813,_814);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::RangeDomain > _816) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_815,_816); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::RangeDomain > _816) { return __mosek_2fusion_2Model__constraint(_815,_816); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::RangeDomain > _816){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_815,_816);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::RangeDomain > _819) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_817,_818,_819); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::RangeDomain > _819) { return __mosek_2fusion_2Model__constraint(_817,_818,_819); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _817,monty::rc_ptr< ::mosek::fusion::Expression > _818,monty::rc_ptr< ::mosek::fusion::RangeDomain > _819){
  return __mosek_2fusion_2Model__constraint_(_817,_818,_819);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinearDomain > _821) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_820,_821); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinearDomain > _821) { return __mosek_2fusion_2Model__constraint(_820,_821); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _820,monty::rc_ptr< ::mosek::fusion::LinearDomain > _821){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_820,_821);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinearDomain > _824) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_822,_823,_824); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinearDomain > _824) { return __mosek_2fusion_2Model__constraint(_822,_823,_824); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _822,monty::rc_ptr< ::mosek::fusion::Expression > _823,monty::rc_ptr< ::mosek::fusion::LinearDomain > _824){
  return __mosek_2fusion_2Model__constraint_(_822,_823,_824);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _826) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_825,_826); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _826) { return __mosek_2fusion_2Model__constraint(_825,_826); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _825,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _826){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_825,_826);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_827,_828,_829); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return __mosek_2fusion_2Model__constraint(_827,_828,_829); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _827,monty::rc_ptr< ::mosek::fusion::Expression > _828,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829){
  return __mosek_2fusion_2Model__constraint_(_827,_828,_829);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _830,monty::rc_ptr< ::mosek::fusion::PSDDomain > _831) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_830,_831); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _830,monty::rc_ptr< ::mosek::fusion::PSDDomain > _831) { return __mosek_2fusion_2Model__constraint(_830,_831); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _830,monty::rc_ptr< ::mosek::fusion::PSDDomain > _831){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_830,_831);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _832,monty::rc_ptr< ::mosek::fusion::Expression > _833,monty::rc_ptr< ::mosek::fusion::PSDDomain > _834) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_832,_833,_834); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _832,monty::rc_ptr< ::mosek::fusion::Expression > _833,monty::rc_ptr< ::mosek::fusion::PSDDomain > _834) { return __mosek_2fusion_2Model__constraint(_832,_833,_834); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _832,monty::rc_ptr< ::mosek::fusion::Expression > _833,monty::rc_ptr< ::mosek::fusion::PSDDomain > _834){
  return __mosek_2fusion_2Model__constraint_(_832,_833,_834);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_835); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835) { return __mosek_2fusion_2Model__variable(_835); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _835){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_835)->shape,_835);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _836,int _837,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _838) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_836,_837,_838); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _836,int _837,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _838) { return __mosek_2fusion_2Model__variable(_836,_837,_838); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _836,int _837,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _838){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_836),(int)(_836),(int)(_837)}),_838);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_839,_840); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) { return __mosek_2fusion_2Model__variable(_839,_840); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_839),(int)(_839)}),_840);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _841,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _842) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_841,_842); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _841,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _842) { return __mosek_2fusion_2Model__variable(_841,_842); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _841,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _842){
  return __mosek_2fusion_2Model__variable_(_841,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_842);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _843,int _844,int _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_843,_844,_845,_846); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _843,int _844,int _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) { return __mosek_2fusion_2Model__variable(_843,_844,_845,_846); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _843,int _844,int _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846){
  return __mosek_2fusion_2Model__variable_(_843,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_844),(int)(_844),(int)(_845)}),_846);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _847,int _848,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _849) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_847,_848,_849); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _847,int _848,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _849) { return __mosek_2fusion_2Model__variable(_847,_848,_849); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _847,int _848,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _849){
  return __mosek_2fusion_2Model__variable_(_847,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_848),(int)(_848)}),_849);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _850,std::shared_ptr< monty::ndarray< int,1 > > _851,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _852) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_850,_851,_852); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _850,std::shared_ptr< monty::ndarray< int,1 > > _851,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _852) { return __mosek_2fusion_2Model__variable(_850,_851,_852); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _850,std::shared_ptr< monty::ndarray< int,1 > > _851,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _852){
  _checked_ptr_1<int> _ptr__851(_851 ? _851->raw() : nullptr, _851 ? _851->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_850,_851,_852);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_853); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _853) { return __mosek_2fusion_2Model__variable(_853); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _853){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_853)->shape,_853)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _854,int _855,monty::rc_ptr< ::mosek::fusion::PSDDomain > _856) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_854,_855,_856); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _854,int _855,monty::rc_ptr< ::mosek::fusion::PSDDomain > _856) { return __mosek_2fusion_2Model__variable(_854,_855,_856); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _854,int _855,monty::rc_ptr< ::mosek::fusion::PSDDomain > _856){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_854),(int)(_854),(int)(_855)}),_856)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_857,_858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) { return __mosek_2fusion_2Model__variable(_857,_858); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_857),(int)(_857)}),_858)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _859,monty::rc_ptr< ::mosek::fusion::PSDDomain > _860) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_859,_860); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _859,monty::rc_ptr< ::mosek::fusion::PSDDomain > _860) { return __mosek_2fusion_2Model__variable(_859,_860); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _859,monty::rc_ptr< ::mosek::fusion::PSDDomain > _860){
  return (__mosek_2fusion_2Model__variable_(_859,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_860)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _861,int _862,int _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_861,_862,_863,_864); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _861,int _862,int _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) { return __mosek_2fusion_2Model__variable(_861,_862,_863,_864); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _861,int _862,int _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864){
  return (__mosek_2fusion_2Model__variable_(_861,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_862),(int)(_862),(int)(_863)}),_864)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _865,int _866,monty::rc_ptr< ::mosek::fusion::PSDDomain > _867) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_865,_866,_867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _865,int _866,monty::rc_ptr< ::mosek::fusion::PSDDomain > _867) { return __mosek_2fusion_2Model__variable(_865,_866,_867); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _865,int _866,monty::rc_ptr< ::mosek::fusion::PSDDomain > _867){
  return (__mosek_2fusion_2Model__variable_(_865,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_866),(int)(_866)}),_867)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _868,std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::PSDDomain > _870) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_868,_869,_870); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _868,std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::PSDDomain > _870) { return __mosek_2fusion_2Model__variable(_868,_869,_870); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _868,std::shared_ptr< monty::ndarray< int,1 > > _869,monty::rc_ptr< ::mosek::fusion::PSDDomain > _870){
  _checked_ptr_1<int> _ptr__869(_869 ? _869->raw() : nullptr, _869 ? _869->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_868,_869,_870)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _871) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_871); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _871) { return __mosek_2fusion_2Model__variable(_871); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _871){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_871);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _872) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_872); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _872) { return __mosek_2fusion_2Model__variable(_872); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _872){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_872);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_873); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) { return __mosek_2fusion_2Model__variable(_873); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _873){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_873);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874,monty::rc_ptr< ::mosek::fusion::ConeDomain > _875) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_874,_875); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _874,monty::rc_ptr< ::mosek::fusion::ConeDomain > _875) { return __mosek_2fusion_2Model__variable(_874,_875); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874,monty::rc_ptr< ::mosek::fusion::ConeDomain > _875){
  _checked_ptr_1<int> _ptr__874(_874 ? _874->raw() : nullptr, _874 ? _874->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_874,_875);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _876,monty::rc_ptr< ::mosek::fusion::RangeDomain > _877) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_876,_877); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _876,monty::rc_ptr< ::mosek::fusion::RangeDomain > _877) { return __mosek_2fusion_2Model__variable(_876,_877); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _876,monty::rc_ptr< ::mosek::fusion::RangeDomain > _877){
  _checked_ptr_1<int> _ptr__876(_876 ? _876->raw() : nullptr, _876 ? _876->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_876,_877);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::LinearDomain > _879) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_878,_879); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::LinearDomain > _879) { return __mosek_2fusion_2Model__variable(_878,_879); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _878,monty::rc_ptr< ::mosek::fusion::LinearDomain > _879){
  _checked_ptr_1<int> _ptr__878(_878 ? _878->raw() : nullptr, _878 ? _878->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_878,_879);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _880) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_880); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _880) { return __mosek_2fusion_2Model__variable(_880); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _880){
  _checked_ptr_1<int> _ptr__880(_880 ? _880->raw() : nullptr, _880 ? _880->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_880,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _881,monty::rc_ptr< ::mosek::fusion::ConeDomain > _882) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_881,_882); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _881,monty::rc_ptr< ::mosek::fusion::ConeDomain > _882) { return __mosek_2fusion_2Model__variable(_881,_882); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _881,monty::rc_ptr< ::mosek::fusion::ConeDomain > _882){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_881)}),_882);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _883,monty::rc_ptr< ::mosek::fusion::RangeDomain > _884) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_883,_884); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _883,monty::rc_ptr< ::mosek::fusion::RangeDomain > _884) { return __mosek_2fusion_2Model__variable(_883,_884); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _883,monty::rc_ptr< ::mosek::fusion::RangeDomain > _884){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_883)}),_884);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _885,monty::rc_ptr< ::mosek::fusion::LinearDomain > _886) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_885,_886); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _885,monty::rc_ptr< ::mosek::fusion::LinearDomain > _886) { return __mosek_2fusion_2Model__variable(_885,_886); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _885,monty::rc_ptr< ::mosek::fusion::LinearDomain > _886){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_885)}),_886);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _887) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_887); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _887) { return __mosek_2fusion_2Model__variable(_887); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _887){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_887)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _888,monty::rc_ptr< ::mosek::fusion::ConeDomain > _889) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_888,_889); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _888,monty::rc_ptr< ::mosek::fusion::ConeDomain > _889) { return __mosek_2fusion_2Model__variable(_888,_889); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _888,monty::rc_ptr< ::mosek::fusion::ConeDomain > _889){
  return __mosek_2fusion_2Model__variable_(_888,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_889);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _890,monty::rc_ptr< ::mosek::fusion::RangeDomain > _891) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_890,_891); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _890,monty::rc_ptr< ::mosek::fusion::RangeDomain > _891) { return __mosek_2fusion_2Model__variable(_890,_891); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _890,monty::rc_ptr< ::mosek::fusion::RangeDomain > _891){
  return __mosek_2fusion_2Model__ranged_variable(_890,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_891);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _892,monty::rc_ptr< ::mosek::fusion::LinearDomain > _893) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_892,_893); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _892,monty::rc_ptr< ::mosek::fusion::LinearDomain > _893) { return __mosek_2fusion_2Model__variable(_892,_893); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _892,monty::rc_ptr< ::mosek::fusion::LinearDomain > _893){
  return __mosek_2fusion_2Model__variable_(_892,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_893);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::ConeDomain > _896) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_894,_895,_896); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::ConeDomain > _896) { return __mosek_2fusion_2Model__variable(_894,_895,_896); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::ConeDomain > _896){
  _checked_ptr_1<int> _ptr__895(_895 ? _895->raw() : nullptr, _895 ? _895->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_894,_895,_896);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _897,std::shared_ptr< monty::ndarray< int,1 > > _898,monty::rc_ptr< ::mosek::fusion::RangeDomain > _899) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_897,_898,_899); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _897,std::shared_ptr< monty::ndarray< int,1 > > _898,monty::rc_ptr< ::mosek::fusion::RangeDomain > _899) { return __mosek_2fusion_2Model__variable(_897,_898,_899); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _897,std::shared_ptr< monty::ndarray< int,1 > > _898,monty::rc_ptr< ::mosek::fusion::RangeDomain > _899){
  _checked_ptr_1<int> _ptr__898(_898 ? _898->raw() : nullptr, _898 ? _898->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_897,_898,_899);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _900,std::shared_ptr< monty::ndarray< int,1 > > _901,monty::rc_ptr< ::mosek::fusion::LinearDomain > _902) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_900,_901,_902); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _900,std::shared_ptr< monty::ndarray< int,1 > > _901,monty::rc_ptr< ::mosek::fusion::LinearDomain > _902) { return __mosek_2fusion_2Model__variable(_900,_901,_902); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _900,std::shared_ptr< monty::ndarray< int,1 > > _901,monty::rc_ptr< ::mosek::fusion::LinearDomain > _902){
  _checked_ptr_1<int> _ptr__901(_901 ? _901->raw() : nullptr, _901 ? _901->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_900,_901,_902);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _903,std::shared_ptr< monty::ndarray< int,1 > > _904) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_903,_904); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _903,std::shared_ptr< monty::ndarray< int,1 > > _904) { return __mosek_2fusion_2Model__variable(_903,_904); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _903,std::shared_ptr< monty::ndarray< int,1 > > _904){
  _checked_ptr_1<int> _ptr__904(_904 ? _904->raw() : nullptr, _904 ? _904->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_903,_904,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _905,int _906,monty::rc_ptr< ::mosek::fusion::ConeDomain > _907) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_905,_906,_907); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _905,int _906,monty::rc_ptr< ::mosek::fusion::ConeDomain > _907) { return __mosek_2fusion_2Model__variable(_905,_906,_907); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _905,int _906,monty::rc_ptr< ::mosek::fusion::ConeDomain > _907){
  return __mosek_2fusion_2Model__variable_(_905,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_906)}),_907);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _908,int _909,monty::rc_ptr< ::mosek::fusion::RangeDomain > _910) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_908,_909,_910); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _908,int _909,monty::rc_ptr< ::mosek::fusion::RangeDomain > _910) { return __mosek_2fusion_2Model__variable(_908,_909,_910); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _908,int _909,monty::rc_ptr< ::mosek::fusion::RangeDomain > _910){
  return __mosek_2fusion_2Model__ranged_variable(_908,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_909)}),_910);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _911,int _912,monty::rc_ptr< ::mosek::fusion::LinearDomain > _913) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_911,_912,_913); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _911,int _912,monty::rc_ptr< ::mosek::fusion::LinearDomain > _913) { return __mosek_2fusion_2Model__variable(_911,_912,_913); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _911,int _912,monty::rc_ptr< ::mosek::fusion::LinearDomain > _913){
  return __mosek_2fusion_2Model__variable_(_911,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_912)}),_913);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _914,int _915) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_914,_915); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _914,int _915) { return __mosek_2fusion_2Model__variable(_914,_915); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _914,int _915){
  return __mosek_2fusion_2Model__variable_(_914,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_915)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _916) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_916); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _916) { return __mosek_2fusion_2Model__variable(_916); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _916){
  return __mosek_2fusion_2Model__variable_(_916,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _917,std::shared_ptr< monty::ndarray< int,1 > > _918,monty::rc_ptr< ::mosek::fusion::RangeDomain > _919){
  _checked_ptr_1<int> _ptr__918(_918 ? _918->raw() : nullptr, _918 ? _918->size(0) : 0);
  if ((((int)((_917).size()) > (int)0) && hasVariable(_917)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_917)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7010;
  bool _7011 = (NULL != _918.get());
  if (_7011)
  {
    _7010 = _918;
  }
  else
  {
    _7010 = mosek::fusion::p_RangeDomain::_get_impl(_919)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _920 = _7010;
  _checked_ptr_1<int> _ptr__920(_920 ? _920->raw() : nullptr,_920 ? _920->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_919)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_919)->shape,_920))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _920.get()))
  {
    {
      _920 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__920.update(_920 ? _920->raw() : nullptr, _920 ? _920->size(0) : 0);
    }
  }
  {}
  int _921 = (int)((_920)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _922 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_921)));
  _checked_ptr_1<int> _ptr__922(_922 ? _922->raw() : nullptr,_922 ? _922->size(0) : 0);
  if ((_921 > (int)0))
  {
    {
      _ptr__922[(_921 - (int)1)] = (int)1;
      int _7012 = (int)1;
      int _7013 = _921;
      for (int _923 = _7012; _923 < _7013; ++_923)
      {
        {
          _ptr__922[((_921 - _923) - (int)1)] = safe_mul( _ptr__922[(_921 - _923)],_ptr__920[(_921 - _923)] );
        }
      }
    }
  }
  {}
  int _924 = (int)1;
  int _7014 = (int)0;
  int _7015 = (int)((_920)->size(0));
  for (int _925 = _7014; _925 < _7015; ++_925)
  {
    {
      _924 *= _ptr__920[_925];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _926 = nullptr;
  _checked_ptr_1<long long> _ptr__926(_926 ? _926->raw() : nullptr,_926 ? _926->size(0) : 0);
  if ((NULL != _926.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)->size(1)) != _921))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _926 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)->size(0)))));
      _ptr__926.update(_926 ? _926->raw() : nullptr, _926 ? _926->size(0) : 0);
      int _7016 = (int)0;
      int _7017 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)->size(0));
      for (int _927 = _7016; _927 < _7017; ++_927)
      {
        {
          int _7018 = (int)0;
          int _7019 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)->size(1));
          for (int _928 = _7018; _928 < _7019; ++_928)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)(_927,_928)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)(_927,_928)) >= _ptr__920[_928])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _929 = (int)0;
          int _7020 = (int)0;
          int _7021 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)->size(1));
          for (int _930 = _7020; _930 < _7021; ++_930)
          {
            {
              _929 += safe_mul( _ptr__922[_930],((*mosek::fusion::p_RangeDomain::_get_impl(_919)->sparsity)(_927,_930)) );
            }
          }
          _ptr__926[_927] = _929;
        }
      }
    }
  }
  {}
  int _7022;
  bool _7023 = (NULL != _926.get());
  if (_7023)
  {
    _7022 = (int)((_926)->size(0));
  }
  else
  {
    _7022 = _924;
  }
  int _931 = _7022;
  std::shared_ptr< monty::ndarray< double,1 > > _932;
  _checked_ptr_1<double> _ptr__932(_932 ? _932->raw() : nullptr,_932 ? _932->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _933;
  _checked_ptr_1<double> _ptr__933(_933 ? _933->raw() : nullptr,_933 ? _933->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_919)->scalable)
  {
    {
      std::vector<double> _7024;
      for (int _934 = (int)0, _7025 = _931; _934 < _7025 ; ++_934)
      {
        _7024.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_919)->lb)((int)0)));
      }
      auto _7026 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7024.size()),_7024.begin(),_7024.end()));
      _932 = _7026;
      _ptr__932.update(_932 ? _932->raw() : nullptr, _932 ? _932->size(0) : 0);
      std::vector<double> _7027;
      for (int _935 = (int)0, _7028 = _931; _935 < _7028 ; ++_935)
      {
        _7027.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_919)->ub)((int)0)));
      }
      auto _7029 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7027.size()),_7027.begin(),_7027.end()));
      _933 = _7029;
      _ptr__933.update(_933 ? _933->raw() : nullptr, _933 ? _933->size(0) : 0);
    }
  }
  else
  {
    {
      _932 = mosek::fusion::p_RangeDomain::_get_impl(_919)->lb;
      _ptr__932.update(_932 ? _932->raw() : nullptr, _932 ? _932->size(0) : 0);
      _933 = mosek::fusion::p_RangeDomain::_get_impl(_919)->ub;
      _ptr__933.update(_933 ? _933->raw() : nullptr, _933 ? _933->size(0) : 0);
    }
  }
  int _936 = natvarmap_alloc(_931);
  std::shared_ptr< monty::ndarray< int,1 > > _937 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_936))));
  _checked_ptr_1<int> _ptr__937(_937 ? _937->raw() : nullptr,_937 ? _937->size(0) : 0);
  natvarmap->get(_936,_937,(int)0);
  int _7030 = (int)0;
  int _7031 = _931;
  for (int _938 = _7030; _938 < _7031; ++_938)
  {
    {
      ((*natvarmap_idx)(_ptr__937[_938])) = _936;
    }
  }
  task_var_putboundlist_ra(_937,_932,_933);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _939 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_917,(long long)(_936),_920,_926,_937);
  if (mosek::fusion::p_RangeDomain::_get_impl(_919)->cardinal_flag)
  {
    {
      task_var_putintlist(_937);
    }
  }
  {}
  ((*vars)(_936)) = (_939).as<::mosek::fusion::ModelVariable>();
  if (((int)((_917).size()) > (int)0))
  {
    {
      var_map->setItem(_917,_936);
    }
  }
  {}
  return (_939).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _940,std::shared_ptr< monty::ndarray< int,1 > > _941,monty::rc_ptr< ::mosek::fusion::ConeDomain > _942){
  _checked_ptr_1<int> _ptr__941(_941 ? _941->raw() : nullptr, _941 ? _941->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7032;
  bool _7033 = (NULL != _941.get());
  if (_7033)
  {
    _7032 = _941;
  }
  else
  {
    _7032 = mosek::fusion::p_ConeDomain::_get_impl(_942)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _943 = _7032;
  _checked_ptr_1<int> _ptr__943(_943 ? _943->raw() : nullptr,_943 ? _943->size(0) : 0);
  if ((((int)((_940).size()) > (int)0) && hasVariable(_940)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_940)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _943.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_942)->shape.get()) && (!::mosek::fusion::p_Set::match(_943,mosek::fusion::p_ConeDomain::_get_impl(_942)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_942->getAxis() >= (int)((_943)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _7034;
  bool _7035 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_942)->shape.get());
  if (_7035)
  {
    _7034 = _942->getAxis();
  }
  else
  {
    _7034 = ((int)((_943)->size(0)) - (int)1);
  }
  int _944 = _7034;
  int _945 = _ptr__943[_944];
  int _946 = (int)((_943)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _947 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_946)));
  _checked_ptr_1<int> _ptr__947(_947 ? _947->raw() : nullptr,_947 ? _947->size(0) : 0);
  _ptr__947[(_946 - (int)1)] = (int)1;
  int _7036 = (int)1;
  int _7037 = _946;
  for (int _948 = _7036; _948 < _7037; ++_948)
  {
    {
      _ptr__947[((_946 - _948) - (int)1)] = safe_mul( _ptr__947[(_946 - _948)],_ptr__943[(_946 - _948)] );
    }
  }
  int _949 = _ptr__943[(int)0];
  int _7038 = (int)1;
  int _7039 = (int)((_943)->size(0));
  for (int _950 = _7038; _950 < _7039; ++_950)
  {
    {
      _949 *= _ptr__943[_950];
    }
  }
  int _951 = (int)1;
  int _7040 = (int)0;
  int _7041 = _944;
  for (int _952 = _7040; _952 < _7041; ++_952)
  {
    {
      _951 *= _ptr__943[_952];
    }
  }
  int _953 = (int)1;
  int _7042 = safe_add( _944,(int)1 );
  int _7043 = _946;
  for (int _954 = _7042; _954 < _7043; ++_954)
  {
    {
      _953 *= _ptr__943[_954];
    }
  }
  int _955 = safe_mul( _951,_953 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InQCone) && (_945 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_945 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_945 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_945 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_945 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_945 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _956 = natvarmap_alloc(_949);
  int _957 = natconemap_alloc(_955);
  ((*natvarmap_type)(_956)) = safe_add( _957,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _958 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_956))));
  _checked_ptr_1<int> _ptr__958(_958 ? _958->raw() : nullptr,_958 ? _958->size(0) : 0);
  natvarmap->get(_956,_958,(int)0);
  int _7044 = (int)0;
  int _7045 = _949;
  for (int _959 = _7044; _959 < _7045; ++_959)
  {
    {
      ((*natvarmap_idx)(_ptr__958[_959])) = _956;
    }
  }
  task_var_putboundlist_fr(_958);
  if (mosek::fusion::p_ConeDomain::_get_impl(_942)->int_flag)
  {
    {
      task_var_putintlist(_958);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _960 = _958;
  _checked_ptr_1<int> _ptr__960(_960 ? _960->raw() : nullptr,_960 ? _960->size(0) : 0);
  if ((_944 < ((int)((_943)->size(0)) - (int)1)))
  {
    {
      _960 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_958)->size(0)))));
      _ptr__960.update(_960 ? _960->raw() : nullptr, _960 ? _960->size(0) : 0);
      int _961 = (int)0;
      int _7046 = (int)0;
      int _7047 = _951;
      for (int _962 = _7046; _962 < _7047; ++_962)
      {
        {
          int _7048 = (int)0;
          int _7049 = _953;
          for (int _963 = _7048; _963 < _7049; ++_963)
          {
            {
              int _7050 = (int)0;
              int _7051 = _945;
              for (int _964 = _7050; _964 < _7051; ++_964)
              {
                {
                  _ptr__960[_961] = _ptr__958[safe_add( safe_mul( safe_add( safe_mul( _962,_945 ),_964 ),_953 ),_963 )];
                  ++ _961;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _965 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_955)));
  _checked_ptr_1<int> _ptr__965(_965 ? _965->raw() : nullptr,_965 ? _965->size(0) : 0);
  natconemap->get(_957,_965,(int)0);
  ((*natconemap_dim)(_957)) = _945;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_965,_945,_955,_960);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_965,_945,_955,_960);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_965,_945,_955,_960);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _7052;
                  for (int _966 = (int)0, _7053 = _955; _966 < _7053 ; ++_966)
                  {
                    _7052.push_back(mosek::fusion::p_ConeDomain::_get_impl(_942)->alpha);
                  }
                  auto _7054 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7052.size()),_7052.begin(),_7052.end()));
                  task_put_ppowcones(_965,_945,_955,_960,_7054);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_965,_945,_955,_960);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_942)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _7055;
                          for (int _967 = (int)0, _7056 = _955; _967 < _7056 ; ++_967)
                          {
                            _7055.push_back(mosek::fusion::p_ConeDomain::_get_impl(_942)->alpha);
                          }
                          auto _7057 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7055.size()),_7055.begin(),_7055.end()));
                          task_put_dpowcones(_965,_945,_955,_960,_7057);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _7058 = (int)0;
  int _7059 = (int)((_965)->size(0));
  for (int _968 = _7058; _968 < _7059; ++_968)
  {
    {
      task_cone_name(_ptr__965[_968],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__965[_968])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _969 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_940,_956,_943,_958);
  ((*vars)(_956)) = (_969).as<::mosek::fusion::ModelVariable>();
  if (((int)((_940).size()) > (int)0))
  {
    {
      var_map->setItem(_940,_956);
    }
  }
  {}
  return (_969).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _970,std::shared_ptr< monty::ndarray< int,1 > > _971,monty::rc_ptr< ::mosek::fusion::LinearDomain > _972){
  _checked_ptr_1<int> _ptr__971(_971 ? _971->raw() : nullptr, _971 ? _971->size(0) : 0);
  if ((((int)((_970).size()) > (int)0) && hasVariable(_970)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_970)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7060;
  bool _7061 = (NULL != _971.get());
  if (_7061)
  {
    _7060 = _971;
  }
  else
  {
    _7060 = mosek::fusion::p_LinearDomain::_get_impl(_972)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _973 = _7060;
  _checked_ptr_1<int> _ptr__973(_973 ? _973->raw() : nullptr,_973 ? _973->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_972)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_972)->shape,_973))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _973.get()))
  {
    {
      _973 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__973.update(_973 ? _973->raw() : nullptr, _973 ? _973->size(0) : 0);
    }
  }
  {}
  int _974 = (int)((_973)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _975 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_974)));
  _checked_ptr_1<int> _ptr__975(_975 ? _975->raw() : nullptr,_975 ? _975->size(0) : 0);
  if ((_974 > (int)0))
  {
    {
      _ptr__975[(_974 - (int)1)] = (int)1;
      int _7062 = (int)1;
      int _7063 = _974;
      for (int _976 = _7062; _976 < _7063; ++_976)
      {
        {
          _ptr__975[((_974 - _976) - (int)1)] = safe_mul( _ptr__975[(_974 - _976)],_ptr__973[(_974 - _976)] );
        }
      }
    }
  }
  {}
  int _977 = (int)1;
  int _7064 = (int)0;
  int _7065 = (int)((_973)->size(0));
  for (int _978 = _7064; _978 < _7065; ++_978)
  {
    {
      _977 *= _ptr__973[_978];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _979 = nullptr;
  _checked_ptr_1<long long> _ptr__979(_979 ? _979->raw() : nullptr,_979 ? _979->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _980 = nullptr;
  _checked_ptr_1<int> _ptr__980(_980 ? _980->raw() : nullptr,_980 ? _980->size(0) : 0);
  if (mosek::fusion::p_LinearDomain::_get_impl(_972)->empty)
  {
    {
      _979 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
      _ptr__979.update(_979 ? _979->raw() : nullptr, _979 ? _979->size(0) : 0);
    }
  }
  else if((NULL != mosek::fusion::p_LinearDomain::_get_impl(_972)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_972)->sparsity)->size(1)) != _974))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _981 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_972)->sparsity)->size(0));
      _979 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_981)));
      _ptr__979.update(_979 ? _979->raw() : nullptr, _979 ? _979->size(0) : 0);
      {
        bool _982 = false;
        std::shared_ptr< monty::ndarray< int,2 > > _983 = mosek::fusion::p_LinearDomain::_get_impl(_972)->sparsity;
        int _7066 = (int)0;
        int _7067 = _981;
        for (int _984 = _7066; _984 < _7067; ++_984)
        {
          {
            int _7068 = (int)0;
            int _7069 = (int)((_983)->size(1));
            for (int _985 = _7068; _985 < _7069; ++_985)
            {
              {
                _982 = (_982 || ((((*_983)(_984,_985)) < (int)0) || (((*_983)(_984,_985)) >= _ptr__973[_985])));
              }
            }
            if ((!_982))
            {
              {
                long long _986 = (int)0;
                int _7070 = (int)0;
                int _7071 = (int)((_983)->size(1));
                for (int _987 = _7070; _987 < _7071; ++_987)
                {
                  {
                    _986 += safe_mul( _ptr__975[_987],((*_983)(_984,_987)) );
                  }
                }
                _ptr__979[_984] = _986;
              }
            }
            {}
          }
        }
        if (_982)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is out of bounds"));
          }
        }
        {}
      }
      std::shared_ptr< monty::ndarray< int,2 > > _988 = mosek::fusion::p_LinearDomain::_get_impl(_972)->sparsity;
      int _989 = (int)0;
      int _7072 = (int)0;
      int _7073 = _974;
      for (int _990 = _7072; _990 < _7073; ++_990)
      {
        {
          if ((_989 < _ptr__973[_990]))
          {
            {
              _989 = _ptr__973[_990];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _991 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_981)));
      _checked_ptr_1<int> _ptr__991(_991 ? _991->raw() : nullptr,_991 ? _991->size(0) : 0);
      int _7074 = (int)0;
      int _7075 = _981;
      for (int _992 = _7074; _992 < _7075; ++_992)
      {
        {
          _ptr__991[_992] = _992;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _993 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_981)));
      _checked_ptr_1<int> _ptr__993(_993 ? _993->raw() : nullptr,_993 ? _993->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _994 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _989,(int)1 ))));
      _checked_ptr_1<int> _ptr__994(_994 ? _994->raw() : nullptr,_994 ? _994->size(0) : 0);
      int _7076 = (int)0;
      int _7077 = _974;
      for (int _995 = _7076; _995 < _7077; ++_995)
      {
        {
          {
            int _996 = ((_974 - _995) - (int)1);
            int _7078 = (int)0;
            int _7079 = safe_add( _ptr__973[_996],(int)1 );
            for (int _997 = _7078; _997 < _7079; ++_997)
            {
              {
                _ptr__994[_997] = (int)0;
              }
            }
            int _7080 = (int)0;
            int _7081 = _981;
            for (int _998 = _7080; _998 < _7081; ++_998)
            {
              {
                ++ _ptr__994[safe_add( ((*_988)(_998,_996)),(int)1 )];
              }
            }
            int _7082 = (int)0;
            int _7083 = _ptr__973[_996];
            for (int _999 = _7082; _999 < _7083; ++_999)
            {
              {
                _ptr__994[safe_add( _999,(int)1 )] += _ptr__994[_999];
              }
            }
            int _7084 = (int)0;
            int _7085 = _981;
            for (int _1000 = _7084; _1000 < _7085; ++_1000)
            {
              {
                int _1001 = _ptr__991[_1000];
                _ptr__993[_ptr__994[((*_988)(_1001,_996))]] = _1001;
                ++ _ptr__994[((*_988)(_1001,_996))];
              }
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _1002 = _991;
          _checked_ptr_1<int> _ptr__1002(_1002 ? _1002->raw() : nullptr,_1002 ? _1002->size(0) : 0);
          _991 = _993;
          _ptr__991.update(_991 ? _991->raw() : nullptr, _991 ? _991->size(0) : 0);
          _993 = _1002;
          _ptr__993.update(_993 ? _993->raw() : nullptr, _993 ? _993->size(0) : 0);
        }
      }
      int _7086 = (int)0;
      int _7087 = _981;
      for (int _1003 = _7086; _1003 < _7087; ++_1003)
      {
        {
          int _1004 = _ptr__991[_1003];
          long long _1005 = (int)0;
          int _7088 = (int)0;
          int _7089 = _974;
          for (int _1006 = _7088; _1006 < _7089; ++_1006)
          {
            {
              _1005 += safe_mul( _ptr__975[_1006],((*_988)(_1004,_1006)) );
            }
          }
          _ptr__979[_1003] = _1005;
        }
      }
    }
  }
  {}
  int _7090;
  bool _7091 = (NULL != _979.get());
  if (_7091)
  {
    _7090 = (int)((_979)->size(0));
  }
  else
  {
    _7090 = _977;
  }
  int _1007 = _7090;
  std::shared_ptr< monty::ndarray< double,1 > > _1008 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1007)));
  _checked_ptr_1<double> _ptr__1008(_1008 ? _1008->raw() : nullptr,_1008 ? _1008->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_972)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_972)->bnd)->size(0)) == (int)1))
      {
        {
          int _7092 = (int)0;
          int _7093 = _1007;
          for (int _1009 = _7092; _1009 < _7093; ++_1009)
          {
            {
              _ptr__1008[_1009] = ((*mosek::fusion::p_LinearDomain::_get_impl(_972)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_972)->bnd)->size(0)) == _1007))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_972)->bnd,(int)0,_1008,(int)0,_1007);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _1010 = natvarmap_alloc(_1007);
  std::shared_ptr< monty::ndarray< int,1 > > _1011 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1010))));
  _checked_ptr_1<int> _ptr__1011(_1011 ? _1011->raw() : nullptr,_1011 ? _1011->size(0) : 0);
  natvarmap->get(_1010,_1011,(int)0);
  int _7094 = (int)0;
  int _7095 = _1007;
  for (int _1012 = _7094; _1012 < _7095; ++_1012)
  {
    {
      ((*natvarmap_idx)(_ptr__1011[_1012])) = _1010;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_972)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_1011);
      ((*natvarmap_type)(_1010)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_972)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_1011,_1008);
      ((*natvarmap_type)(_1010)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_972)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_1011,_1008);
      ((*natvarmap_type)(_1010)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_972)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_1011,_1008);
      ((*natvarmap_type)(_1010)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _1013 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_970,(long long)(_1010),_973,_979,_1011);
  if (mosek::fusion::p_LinearDomain::_get_impl(_972)->cardinal_flag)
  {
    {
      task_var_putintlist(_1011);
    }
  }
  {}
  ((*vars)(_1010)) = (_1013).as<::mosek::fusion::ModelVariable>();
  if (((int)((_970).size()) > (int)0))
  {
    {
      var_map->setItem(_970,_1010);
    }
  }
  {}
  return (_1013).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1014,std::shared_ptr< monty::ndarray< int,1 > > _1015,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1016){
  _checked_ptr_1<int> _ptr__1015(_1015 ? _1015->raw() : nullptr, _1015 ? _1015->size(0) : 0);
  if ((((int)((_1014).size()) > (int)0) && hasVariable(_1014)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1014)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7096;
  bool _7097 = (NULL != _1015.get());
  if (_7097)
  {
    _7096 = _1015;
  }
  else
  {
    _7096 = mosek::fusion::p_LinPSDDomain::_get_impl(_1016)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1017 = _7096;
  _checked_ptr_1<int> _ptr__1017(_1017 ? _1017->raw() : nullptr,_1017 ? _1017->size(0) : 0);
  if ((NULL == _1017.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if((!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_1016)->shape,_1017)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _1018 = (int)((_1017)->size(0));
  int _1019 = mosek::fusion::p_LinPSDDomain::_get_impl(_1016)->conedim;
  if (((_1019 < (int)0) || (_1019 >= _1018)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1020 = _ptr__1017[_1019];
  int _1021 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1020 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1021,safe_add( _1021,(int)1 ) ) / (int)2) != _1020))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1022 = (int)1;
  int _1023 = _ptr__1017[_1019];
  int _1024 = (int)1;
  int _7098 = (int)0;
  int _7099 = _1019;
  for (int _1025 = _7098; _1025 < _7099; ++_1025)
  {
    {
      _1024 *= _ptr__1017[_1025];
    }
  }
  int _7100 = safe_add( _1019,(int)1 );
  int _7101 = _1018;
  for (int _1026 = _7100; _1026 < _7101; ++_1026)
  {
    {
      _1022 *= _ptr__1017[_1026];
    }
  }
  int _1027 = safe_mul( _1024,_1022 );
  int _1028 = safe_mul( _1027,_1020 );
  int _1029 = natbarvarmap_alloc(_1027,_1021);
  std::shared_ptr< monty::ndarray< int,1 > > _1030 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1028)));
  _checked_ptr_1<int> _ptr__1030(_1030 ? _1030->raw() : nullptr,_1030 ? _1030->size(0) : 0);
  natbarvarmap_get(_1029,_1030);
  std::shared_ptr< monty::ndarray< long long,1 > > _1031 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1027,_1023 ))));
  _checked_ptr_1<long long> _ptr__1031(_1031 ? _1031->raw() : nullptr,_1031 ? _1031->size(0) : 0);
  {
    int _1032 = (int)0;
    int _7102 = (int)0;
    int _7103 = _1024;
    for (int _1033 = _7102; _1033 < _7103; ++_1033)
    {
      {
        int _7104 = (int)0;
        int _7105 = _1023;
        for (int _1034 = _7104; _1034 < _7105; ++_1034)
        {
          {
            int _7106 = (int)0;
            int _7107 = safe_add( _1034,(int)1 );
            for (int _1035 = _7106; _1035 < _7107; ++_1035)
            {
              {
                int _7108 = (int)0;
                int _7109 = _1022;
                for (int _1036 = _7108; _1036 < _7109; ++_1036)
                {
                  {
                    _ptr__1031[_1032] = safe_add( ((*natbarvar_ptr)(safe_add( safe_mul( _1033,_1022 ),_1036 ))),safe_add( (safe_mul( _1034,((safe_mul( (int)2,_1021 ) - _1034) - (int)1) ) / (int)2),_1035 ) );
                    ++ _1032;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1037 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_1014,_1029,_1017,_1019,_1031);
  ((*barvars)(_1029)) = (_1037).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1014).size()) > (int)0))
  {
    {
      var_map->setItem(_1014,(-safe_add( _1029,(int)1 )));
    }
  }
  {}
  return (_1037).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1038,std::shared_ptr< monty::ndarray< int,1 > > _1039,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1040){
  _checked_ptr_1<int> _ptr__1039(_1039 ? _1039->raw() : nullptr, _1039 ? _1039->size(0) : 0);
  if ((((int)((_1038).size()) > (int)0) && hasVariable(_1038)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1038)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1041 = _1039;
  _checked_ptr_1<int> _ptr__1041(_1041 ? _1041->raw() : nullptr,_1041 ? _1041->size(0) : 0);
  if ((NULL == _1041.get()))
  {
    {
      _1041 = mosek::fusion::p_PSDDomain::_get_impl(_1040)->shape;
      _ptr__1041.update(_1041 ? _1041->raw() : nullptr, _1041 ? _1041->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1041.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1042 = mosek::fusion::p_PSDDomain::_get_impl(_1040)->conedim1;
  int _1043 = mosek::fusion::p_PSDDomain::_get_impl(_1040)->conedim2;
  int _1044 = (int)((_1041)->size(0));
  int _1045 = _ptr__1041[_1042];
  if ((_1042 > _1043))
  {
    {
      int _1046 = _1042;
      _1042 = _1043;
      _1043 = _1046;
    }
  }
  {}
  if (((_1042 == _1043) || ((_1042 < (int)0) || (_1043 >= _1044))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1041[_1042] != _ptr__1041[_1043]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1047 = (int)1;
  int _7110 = (int)0;
  int _7111 = _1042;
  for (int _1048 = _7110; _1048 < _7111; ++_1048)
  {
    {
      _1047 *= _ptr__1041[_1048];
    }
  }
  int _7112 = safe_add( _1042,(int)1 );
  int _7113 = _1043;
  for (int _1049 = _7112; _1049 < _7113; ++_1049)
  {
    {
      _1047 *= _ptr__1041[_1049];
    }
  }
  int _7114 = safe_add( _1043,(int)1 );
  int _7115 = _1044;
  for (int _1050 = _7114; _1050 < _7115; ++_1050)
  {
    {
      _1047 *= _ptr__1041[_1050];
    }
  }
  int _1051 = (safe_mul( safe_mul( _1047,_1045 ),safe_add( _1045,(int)1 ) ) / (int)2);
  int _1052 = natbarvarmap_alloc(_1047,_1045);
  std::shared_ptr< monty::ndarray< long long,1 > > _1053 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1051)));
  _checked_ptr_1<long long> _ptr__1053(_1053 ? _1053->raw() : nullptr,_1053 ? _1053->size(0) : 0);
  natbarvar_get(_1052,_1053);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1054 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1038,_1052,_1041,mosek::fusion::p_PSDDomain::_get_impl(_1040)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1040)->conedim2,_1053);
  ((*barvars)(_1052)) = (_1054).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1038).size()) > (int)0))
  {
    {
      var_map->setItem(_1038,(-safe_add( _1052,(int)1 )));
    }
  }
  {}
  return (_1054).as<::mosek::fusion::SymmetricVariable>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1055,monty::rc_ptr< ::mosek::fusion::Expression > _1056,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1057){
  if ((((int)((_1055).size()) > (int)0) && hasConstraint(_1055)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1055)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_RangeDomain::_get_impl(_1057)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1058 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1056)).as<::mosek::fusion::Expression>());
  _1058->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1059 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1059(_1059 ? _1059->raw() : nullptr,_1059 ? _1059->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1060 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1060(_1060 ? _1060->raw() : nullptr,_1060 ? _1060->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1061 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1061(_1061 ? _1061->raw() : nullptr,_1061 ? _1061->size(0) : 0);
  int _1062 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1063 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1064 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1065 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1066 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1067 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1068 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1069 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1070 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1057)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1057)->shape)->size(0)) != _1062))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _7116 = (int)0;
          int _7117 = _1062;
          for (int _1071 = _7116; _1071 < _7117; ++_1071)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1057)->shape)(_1071)) != _ptr__1059[safe_add( _1063,_1071 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1072 = (int)1;
  int _7118 = (int)0;
  int _7119 = _1062;
  for (int _1073 = _7118; _1073 < _7119; ++_1073)
  {
    {
      _1072 *= _ptr__1059[safe_add( _1063,_1073 )];
    }
  }
  int _1074 = natconmap_alloc(_1072);
  std::shared_ptr< monty::ndarray< int,1 > > _1075 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1072)));
  _checked_ptr_1<int> _ptr__1075(_1075 ? _1075->raw() : nullptr,_1075 ? _1075->size(0) : 0);
  natconmap->get(_1074,_1075,(int)0);
  int _7120 = (int)0;
  int _7121 = _1072;
  for (int _1076 = _7120; _1076 < _7121; ++_1076)
  {
    {
      ((*natconmap_idx)(_ptr__1075[_1076])) = _1074;
      ((*natconmap_slackidx)(_ptr__1075[_1076])) = (int)0;
    }
  }
  ((*natconmap_type)(_1074)) = (int)4;
  putarows(_1075,rs,_1064,_1065,_1067,_1068,_1070,_1069,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  xs->clear();
  std::shared_ptr< monty::ndarray< double,1 > > _1077 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1072)));
  _checked_ptr_1<double> _ptr__1077(_1077 ? _1077->raw() : nullptr,_1077 ? _1077->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1078 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1072)));
  _checked_ptr_1<double> _ptr__1078(_1078 ? _1078->raw() : nullptr,_1078 ? _1078->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1079 = natconmap_efix;
  _checked_ptr_1<double> _ptr__1079(_1079 ? _1079->raw() : nullptr,_1079 ? _1079->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1080 = mosek::fusion::p_RangeDomain::_get_impl(_1057)->lb;
  _checked_ptr_1<double> _ptr__1080(_1080 ? _1080->raw() : nullptr,_1080 ? _1080->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1081 = mosek::fusion::p_RangeDomain::_get_impl(_1057)->ub;
  _checked_ptr_1<double> _ptr__1081(_1081 ? _1081->raw() : nullptr,_1081 ? _1081->size(0) : 0);
  bool _1082 = mosek::fusion::p_RangeDomain::_get_impl(_1057)->empty;
  bool _1083 = mosek::fusion::p_RangeDomain::_get_impl(_1057)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1084 = mosek::fusion::p_RangeDomain::_get_impl(_1057)->sparsity;
  {
    int _7122 = (int)0;
    int _7123 = _1064;
    for (int _1085 = _7122; _1085 < _7123; ++_1085)
    {
      {
        _ptr__1079[_ptr__1075[_1085]] = _ptr__1061[safe_add( _1069,_1085 )];
      }
    }
    if (_1083)
    {
      {
        int _7124 = (int)0;
        int _7125 = _1072;
        for (int _1086 = _7124; _1086 < _7125; ++_1086)
        {
          {
            _ptr__1077[_1086] = _ptr__1080[(int)0];
            _ptr__1078[_1086] = _ptr__1081[(int)0];
          }
        }
      }
    }
    else if(_1082)
    {
      {
      }
    }
    else if((NULL != _1084.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1087 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1062)));
        _checked_ptr_1<int> _ptr__1087(_1087 ? _1087->raw() : nullptr,_1087 ? _1087->size(0) : 0);
        _ptr__1087[(_1062 - (int)1)] = (int)1;
        int _7126 = (int)1;
        int _7127 = _1062;
        for (int _1088 = _7126; _1088 < _7127; ++_1088)
        {
          {
            _ptr__1087[((_1062 - _1088) - (int)1)] = safe_mul( _ptr__1087[(_1062 - _1088)],_ptr__1059[(safe_add( _1063,_1062 ) - _1088)] );
          }
        }
        int _7128 = (int)0;
        int _7129 = (int)((_1080)->size(0));
        for (int _1089 = _7128; _1089 < _7129; ++_1089)
        {
          {
            int _1090 = (int)0;
            int _7130 = (int)0;
            int _7131 = _1062;
            for (int _1091 = _7130; _1091 < _7131; ++_1091)
            {
              {
                _1090 += safe_mul( _ptr__1087[_1091],((*_1084)(_1089,_1091)) );
              }
            }
            _ptr__1077[_1090] = _ptr__1080[_1089];
            _ptr__1078[_1090] = _ptr__1081[_1089];
          }
        }
      }
    }
    else
    {
      {
        int _7132 = (int)0;
        int _7133 = _1072;
        for (int _1092 = _7132; _1092 < _7133; ++_1092)
        {
          {
            _ptr__1077[_1092] = _ptr__1080[_1092];
            _ptr__1078[_1092] = _ptr__1081[_1092];
          }
        }
      }
    }
  }
  task_con_putboundlist_ra(_1075,_1077,_1078);
  std::vector<int> _7134;
  for (int _1094 = (int)0, _7135 = _1062; _1094 < _7135 ; ++_1094)
  {
    _7134.push_back(_ptr__1059[safe_add( _1063,_1094 )]);
  }
  auto _7136 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7134.size()),_7134.begin(),_7134.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1093 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1055,_7136,_1075);
  ((*cons)(_1074)) = (_1093).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1055).size()) > (int)0))
  {
    {
      con_map->setItem(_1055,_1074);
    }
  }
  {}
  return (_1093).as<::mosek::fusion::Constraint>();
}
void mosek::fusion::p_Model::update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1095,std::shared_ptr< monty::ndarray< double,1 > > _1096){
  _checked_ptr_1<int> _ptr__1095(_1095 ? _1095->raw() : nullptr, _1095 ? _1095->size(0) : 0);
  _checked_ptr_1<double> _ptr__1096(_1096 ? _1096->raw() : nullptr, _1096 ? _1096->size(0) : 0);
  std::vector<int> _7137;
  for (int _1097 = (int)0, _7138 = (int)((_1095)->size(0)); _1097 < _7138 ; ++_1097)
  {
    _7137.push_back((int)0);
  }
  auto _7139 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7137.size()),_7137.begin(),_7137.end()));
  task_putaijlist(_1095,_7139,_1096,(long long)((int)((_1095)->size(0))));
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1098,monty::rc_ptr< ::mosek::fusion::WorkStack > _1099,int _1100,int _1101,int _1102,int _1103,int _1104,int _1105,std::shared_ptr< monty::ndarray< int,1 > > _1106){
  _checked_ptr_1<int> _ptr__1098(_1098 ? _1098->raw() : nullptr, _1098 ? _1098->size(0) : 0);
  _checked_ptr_1<int> _ptr__1106(_1106 ? _1106->raw() : nullptr, _1106 ? _1106->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1107 = mosek::fusion::p_WorkStack::_get_impl(_1099)->i32;
  _checked_ptr_1<int> _ptr__1107(_1107 ? _1107->raw() : nullptr,_1107 ? _1107->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1108 = mosek::fusion::p_WorkStack::_get_impl(_1099)->i64;
  _checked_ptr_1<long long> _ptr__1108(_1108 ? _1108->raw() : nullptr,_1108 ? _1108->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1109 = mosek::fusion::p_WorkStack::_get_impl(_1099)->f64;
  _checked_ptr_1<double> _ptr__1109(_1109 ? _1109->raw() : nullptr,_1109 ? _1109->size(0) : 0);
  int _1110 = (int)0;
  int _1111 = (int)0;
  int _1112 = (int)0;
  int _7140 = (int)0;
  int _7141 = _1100;
  for (int _1113 = _7140; _1113 < _7141; ++_1113)
  {
    {
      int _1114 = _ptr__1107[safe_add( _1102,_1113 )];
      int _1115 = _ptr__1107[safe_add( safe_add( _1102,_1113 ),(int)1 )];
      int _1116 = _1114;
      while ( ((_1116 < _1115) && (_ptr__1108[safe_add( _1103,_1116 )] < (int)0)) )
      {
        {
          int _1117 = ((*natbarvar_idx)((-safe_add( _ptr__1108[safe_add( _1103,_1116 )],(int)1 ))));
          int _1118 = _1116;
          ++ _1116;
          while ( ((_1116 < _1115) && ((_ptr__1108[safe_add( _1103,_1116 )] < (int)0) && (_1117 == ((*natbarvar_idx)((-safe_add( _ptr__1108[safe_add( _1103,_1116 )],(int)1 ))))))) )
          {
            {
              ++ _1116;
            }
          }
          ++ _1111;
        }
      }
      _1112 += (_1116 - _1114);
      _1110 += (_1115 - _1116);
    }
  }
  _1110 += _1100;
  if ((NULL != _1106.get()))
  {
    {
      _1110 += _1100;
    }
  }
  {}
  int _1119 = (int)((_1098)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1120 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1119,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1120(_1120 ? _1120->raw() : nullptr,_1120 ? _1120->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1121 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1110)));
  _checked_ptr_1<int> _ptr__1121(_1121 ? _1121->raw() : nullptr,_1121 ? _1121->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1122 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1110)));
  _checked_ptr_1<double> _ptr__1122(_1122 ? _1122->raw() : nullptr,_1122 ? _1122->size(0) : 0);
  if ((NULL != _1106.get()))
  {
    {
      int _1123 = (int)0;
      int _7142 = (int)0;
      int _7143 = _1100;
      for (int _1124 = _7142; _1124 < _7143; ++_1124)
      {
        {
          int _1125 = (int)0;
          _ptr__1121[safe_add( _1123,_1125 )] = bfixidx;
          _ptr__1122[safe_add( _1123,_1125 )] = _ptr__1109[safe_add( _1105,_1124 )];
          ++ _1125;
          int _7144 = _ptr__1107[safe_add( _1102,_1124 )];
          int _7145 = _ptr__1107[safe_add( safe_add( _1102,_1124 ),(int)1 )];
          for (int _1126 = _7144; _1126 < _7145; ++_1126)
          {
            {
              if ((_ptr__1108[safe_add( _1103,_1126 )] > (int)0))
              {
                {
                  _ptr__1121[safe_add( _1123,_1125 )] = (int)(_ptr__1108[safe_add( _1103,_1126 )] - (int)1);
                  _ptr__1122[safe_add( _1123,_1125 )] = _ptr__1109[safe_add( _1104,_1126 )];
                  ++ _1125;
                }
              }
              {}
            }
          }
          _ptr__1121[safe_add( _1123,_1125 )] = _ptr__1106[_1124];
          _ptr__1122[safe_add( _1123,_1125 )] = (-1.0);
          ++ _1125;
          _ptr__1120[safe_add( _1124,(int)1 )] = safe_add( _ptr__1120[_1124],_1125 );
          _1123 += _1125;
        }
      }
    }
  }
  else
  {
    {
      int _1127 = (int)0;
      int _7146 = (int)0;
      int _7147 = _1100;
      for (int _1128 = _7146; _1128 < _7147; ++_1128)
      {
        {
          int _1129 = (int)0;
          _ptr__1121[safe_add( _1127,_1129 )] = bfixidx;
          _ptr__1122[safe_add( _1127,_1129 )] = _ptr__1109[safe_add( _1105,_1128 )];
          ++ _1129;
          int _7148 = _ptr__1107[safe_add( _1102,_1128 )];
          int _7149 = _ptr__1107[safe_add( safe_add( _1102,_1128 ),(int)1 )];
          for (int _1130 = _7148; _1130 < _7149; ++_1130)
          {
            {
              if ((_ptr__1108[safe_add( _1103,_1130 )] > (int)0))
              {
                {
                  _ptr__1121[safe_add( _1127,_1129 )] = (int)(_ptr__1108[safe_add( _1103,_1130 )] - (int)1);
                  _ptr__1122[safe_add( _1127,_1129 )] = _ptr__1109[safe_add( _1104,_1130 )];
                  ++ _1129;
                }
              }
              {}
            }
          }
          _ptr__1120[safe_add( _1128,(int)1 )] = safe_add( _ptr__1120[_1128],_1129 );
          _1127 += _1129;
        }
      }
    }
  }
  task_putarowlist(_1098,_1120,_1121,_1122);
  if ((_1111 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1131 = _1098;
      _checked_ptr_1<int> _ptr__1131(_1131 ? _1131->raw() : nullptr,_1131 ? _1131->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1132 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1119,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1132(_1132 ? _1132->raw() : nullptr,_1132 ? _1132->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1133 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1111)));
      _checked_ptr_1<int> _ptr__1133(_1133 ? _1133->raw() : nullptr,_1133 ? _1133->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1134 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1111)));
      _checked_ptr_1<int> _ptr__1134(_1134 ? _1134->raw() : nullptr,_1134 ? _1134->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1135 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1111)));
      _checked_ptr_1<long long> _ptr__1135(_1135 ? _1135->raw() : nullptr,_1135 ? _1135->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1136 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1112)));
      _checked_ptr_1<int> _ptr__1136(_1136 ? _1136->raw() : nullptr,_1136 ? _1136->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1137 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1112)));
      _checked_ptr_1<int> _ptr__1137(_1137 ? _1137->raw() : nullptr,_1137 ? _1137->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1138 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1112)));
      _checked_ptr_1<double> _ptr__1138(_1138 ? _1138->raw() : nullptr,_1138 ? _1138->size(0) : 0);
      int _1139 = (int)0;
      int _1140 = (int)0;
      int _7150 = (int)0;
      int _7151 = _1119;
      for (int _1141 = _7150; _1141 < _7151; ++_1141)
      {
        {
          int _1142 = _ptr__1107[safe_add( _1102,_1141 )];
          int _1143 = _ptr__1107[safe_add( safe_add( _1102,_1141 ),(int)1 )];
          while ( ((_1142 < _1143) && (_ptr__1108[safe_add( _1103,_1142 )] < (int)0)) )
          {
            {
              int _1144 = _1142;
              int _1145 = ((*natbarvar_idx)((-safe_add( _ptr__1108[safe_add( _1103,_1142 )],(int)1 ))));
              while ( ((_1142 < _1143) && ((_ptr__1108[safe_add( _1103,_1142 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1108[safe_add( _1103,_1142 )],(int)1 )))) == _1145))) )
              {
                {
                  _ptr__1136[_1140] = ((*natbarvar_i)((-safe_add( _ptr__1108[safe_add( _1103,_1142 )],(int)1 ))));
                  _ptr__1137[_1140] = ((*natbarvar_j)((-safe_add( _ptr__1108[safe_add( _1103,_1142 )],(int)1 ))));
                  if ((_ptr__1136[_1140] == _ptr__1137[_1140]))
                  {
                    {
                      _ptr__1138[_1140] = _ptr__1109[safe_add( _1104,_1142 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1138[_1140] = (0.5 * _ptr__1109[safe_add( _1104,_1142 )]);
                    }
                  }
                  ++ _1140;
                  ++ _1142;
                }
              }
              _ptr__1133[_1139] = _1145;
              _ptr__1134[_1139] = ((*natbarvar_dim)(_1145));
              _ptr__1135[_1139] = (_1142 - _1144);
              ++ _1139;
            }
          }
          _1142 = _1143;
          _ptr__1132[safe_add( _1141,(int)1 )] = _1139;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1146 = task_appendsymmatlist(_1134,_1135,_1136,_1137,_1138);
      _checked_ptr_1<long long> _ptr__1146(_1146 ? _1146->raw() : nullptr,_1146 ? _1146->size(0) : 0);
      task_putbararowlist(_1131,_1132,_1133,_1146);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1147,monty::rc_ptr< ::mosek::fusion::Expression > _1148,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1149){
  std::shared_ptr< monty::ndarray< int,1 > > _1150 = _1148->getShape();
  _checked_ptr_1<int> _ptr__1150(_1150 ? _1150->raw() : nullptr,_1150 ? _1150->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1149)->shape.get()) && (!::mosek::fusion::p_Set::match(_1150,mosek::fusion::p_PSDDomain::_get_impl(_1149)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1151;
  int _1152;
  int _1153;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1149)->axisIsSet)
  {
    {
      _1151 = (mosek::fusion::p_PSDDomain::_get_impl(_1149)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1149)->conedim2);
      int _7152;
      bool _7153 = _1151;
      if (_7153)
      {
        _7152 = mosek::fusion::p_PSDDomain::_get_impl(_1149)->conedim1;
      }
      else
      {
        _7152 = mosek::fusion::p_PSDDomain::_get_impl(_1149)->conedim2;
      }
      _1153 = _7152;
      int _7154;
      bool _7155 = _1151;
      if (_7155)
      {
        _7154 = mosek::fusion::p_PSDDomain::_get_impl(_1149)->conedim2;
      }
      else
      {
        _7154 = mosek::fusion::p_PSDDomain::_get_impl(_1149)->conedim1;
      }
      _1152 = _7154;
    }
  }
  else
  {
    {
      _1151 = true;
      _1153 = ((int)((_1150)->size(0)) - (int)2);
      _1152 = ((int)((_1150)->size(0)) - (int)1);
    }
  }
  if (((_1152 >= (int)((_1150)->size(0))) || (_ptr__1150[_1153] != _ptr__1150[_1152])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _7156;
  bool _7157 = (mosek::fusion::p_PSDDomain::_get_impl(_1149)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_7157)
  {
    _7156 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1153,_1152,_1148).as<::mosek::fusion::Expression>();
  }
  else
  {
    _7156 = _1148;
  }
  monty::rc_ptr< ::mosek::fusion::ExprCompress > _1154 = ::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1153,_1152,_7156)).as<::mosek::fusion::Expression>());
  _1154->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1155 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1155(_1155 ? _1155->raw() : nullptr,_1155 ? _1155->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1156 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1156(_1156 ? _1156->raw() : nullptr,_1156 ? _1156->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1157 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1157(_1157 ? _1157->raw() : nullptr,_1157 ? _1157->size(0) : 0);
  int _1158 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1159 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1158)));
  _checked_ptr_1<int> _ptr__1159(_1159 ? _1159->raw() : nullptr,_1159 ? _1159->size(0) : 0);
  rs->popi32(_1158,_1159,(int)0);
  int _1160 = rs->popi32();
  int _1161 = rs->popi32();
  bool _1162 = (rs->popi32() != (int)0);
  int _1163 = rs->popi32(safe_add( _1160,(int)1 ));
  int _7158;
  bool _7159 = _1162;
  if (_7159)
  {
    _7158 = rs->popi64(_1160);
  }
  else
  {
    _7158 = (-(int)99999);
  }
  int _1164 = _7158;
  int _1165 = rs->popi64(_1161);
  int _1166 = rs->popf64(_1160);
  int _1167 = rs->popf64(_1161);
  int _1168 = _ptr__1159[_1152];
  int _1169 = (safe_mul( _1168,safe_add( _1168,(int)1 ) ) / (int)2);
  int _7160 = (int)0;
  int _7161 = _1158;
  for (int _1170 = _7160; _1170 < _7161; ++_1170)
  {
    {
      if (((_1170 != _1153) && (_1170 != _1152)))
      {
        {
          _1169 *= _ptr__1159[_1170];
        }
      }
      {}
    }
  }
  int _1171 = natconmap_alloc(_1169);
  std::shared_ptr< monty::ndarray< int,1 > > _1172 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1169)));
  _checked_ptr_1<int> _ptr__1172(_1172 ? _1172->raw() : nullptr,_1172 ? _1172->size(0) : 0);
  natconmap->get(_1171,_1172,(int)0);
  putarows(_1172,rs,_1160,_1161,_1163,_1165,_1167,_1166,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  xs->clear();
  std::shared_ptr< monty::ndarray< int,1 > > _1173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1173(_1173 ? _1173->raw() : nullptr,_1173 ? _1173->size(0) : 0);
  int _7162 = (int)0;
  int _7163 = _1153;
  for (int _1174 = _7162; _1174 < _7163; ++_1174)
  {
    {
      _ptr__1173[(int)0] *= _ptr__1159[_1174];
    }
  }
  _ptr__1173[(int)1] = _ptr__1159[_1153];
  int _7164 = safe_add( _1153,(int)1 );
  int _7165 = _1152;
  for (int _1175 = _7164; _1175 < _7165; ++_1175)
  {
    {
      _ptr__1173[(int)2] *= _ptr__1159[_1175];
    }
  }
  _ptr__1173[(int)3] = _ptr__1159[_1152];
  int _7166 = safe_add( _1152,(int)1 );
  int _7167 = _1158;
  for (int _1176 = _7166; _1176 < _7167; ++_1176)
  {
    {
      _ptr__1173[(int)4] *= _ptr__1159[_1176];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1177 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
  _ptr__1177[(int)4] = (int)1;
  int _7168 = (int)1;
  int _7169 = (int)5;
  for (int _1178 = _7168; _1178 < _7169; ++_1178)
  {
    {
      _ptr__1177[(((int)5 - _1178) - (int)1)] = safe_mul( _ptr__1177[((int)5 - _1178)],_ptr__1173[((int)5 - _1178)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1179 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1169)));
  _checked_ptr_1<double> _ptr__1179(_1179 ? _1179->raw() : nullptr,_1179 ? _1179->size(0) : 0);
  if ((_1164 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _7170 = (int)0;
      int _7171 = _1160;
      for (int _1180 = _7170; _1180 < _7171; ++_1180)
      {
        {
          ((*natconmap_efix)(_ptr__1172[_1180])) = _ptr__1157[safe_add( _1166,_1180 )];
          ((*natconmap_lb)(_ptr__1172[_1180])) = (int)0;
          ((*natconmap_ub)(_ptr__1172[_1180])) = (int)0;
          _ptr__1179[_1180] = 0.0;
        }
      }
    }
  }
  task_con_putboundlist_fx(_1172,_1179);
  int _1181 = safe_mul( safe_mul( _ptr__1173[(int)0],_ptr__1173[(int)2] ),_ptr__1173[(int)4] );
  int _1182 = _ptr__1173[(int)1];
  int _1183 = natbarvarmap_alloc(_1181,_1182);
  std::shared_ptr< monty::ndarray< int,1 > > _1184 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1181)));
  _checked_ptr_1<int> _ptr__1184(_1184 ? _1184->raw() : nullptr,_1184 ? _1184->size(0) : 0);
  natbarvarmap_get(_1183,_1184);
  std::vector<int> _7172;
  for (int _1186 = (int)0, _7173 = (safe_mul( _1182,safe_add( _1182,(int)1 ) ) / (int)2); _1186 < _7173 ; ++_1186)
  {
    _7172.push_back(_1182);
  }
  auto _7174 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7172.size()),_7172.begin(),_7172.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1185 = _7174;
  _checked_ptr_1<int> _ptr__1185(_1185 ? _1185->raw() : nullptr,_1185 ? _1185->size(0) : 0);
  std::vector<long long> _7175;
  for (int _1188 = (int)0, _7176 = (safe_mul( _1182,safe_add( _1182,(int)1 ) ) / (int)2); _1188 < _7176 ; ++_1188)
  {
    _7175.push_back((int)1);
  }
  auto _7177 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7175.size()),_7175.begin(),_7175.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1187 = _7177;
  _checked_ptr_1<long long> _ptr__1187(_1187 ? _1187->raw() : nullptr,_1187 ? _1187->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1189 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1182,safe_add( _1182,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1189(_1189 ? _1189->raw() : nullptr,_1189 ? _1189->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1190 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1182,safe_add( _1182,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1190(_1190 ? _1190->raw() : nullptr,_1190 ? _1190->size(0) : 0);
  std::vector<double> _7178;
  for (int _1192 = (int)0, _7179 = (safe_mul( _1182,safe_add( _1182,(int)1 ) ) / (int)2); _1192 < _7179 ; ++_1192)
  {
    _7178.push_back((-0.5));
  }
  auto _7180 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7178.size()),_7178.begin(),_7178.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1191 = _7180;
  _checked_ptr_1<double> _ptr__1191(_1191 ? _1191->raw() : nullptr,_1191 ? _1191->size(0) : 0);
  int _7181 = (int)1;
  int _7182 = safe_add( _1182,(int)1 );
  for (int _1193 = _7181; _1193 < _7182; ++_1193)
  {
    {
      _ptr__1191[((safe_mul( _1193,safe_add( _1193,(int)1 ) ) / (int)2) - (int)1)] = (-1.0);
    }
  }
  {
    int _1194 = (int)0;
    int _7183 = (int)0;
    int _7184 = _1182;
    for (int _1195 = _7183; _1195 < _7184; ++_1195)
    {
      {
        int _7185 = (int)0;
        int _7186 = safe_add( _1195,(int)1 );
        for (int _1196 = _7185; _1196 < _7186; ++_1196)
        {
          {
            _ptr__1189[_1194] = _1195;
            _ptr__1190[_1194] = _1196;
            ++ _1194;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1197 = task_appendsymmatlist(_1185,_1187,_1189,_1190,_1191);
  _checked_ptr_1<long long> _ptr__1197(_1197 ? _1197->raw() : nullptr,_1197 ? _1197->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1198 = _1172;
  _checked_ptr_1<int> _ptr__1198(_1198 ? _1198->raw() : nullptr,_1198 ? _1198->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1199 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1169)));
  _checked_ptr_1<int> _ptr__1199(_1199 ? _1199->raw() : nullptr,_1199 ? _1199->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1200 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1169)));
  _checked_ptr_1<long long> _ptr__1200(_1200 ? _1200->raw() : nullptr,_1200 ? _1200->size(0) : 0);
  {
    int _1201 = (int)0;
    if (_1151)
    {
      {
        int _7187 = (int)0;
        int _7188 = _ptr__1173[(int)0];
        for (int _1202 = _7187; _1202 < _7188; ++_1202)
        {
          {
            int _7189 = (int)0;
            int _7190 = _ptr__1173[(int)1];
            for (int _1203 = _7189; _1203 < _7190; ++_1203)
            {
              {
                int _7191 = (int)0;
                int _7192 = _ptr__1173[(int)2];
                for (int _1204 = _7191; _1204 < _7192; ++_1204)
                {
                  {
                    int _7193 = (int)0;
                    int _7194 = safe_add( _1203,(int)1 );
                    for (int _1205 = _7193; _1205 < _7194; ++_1205)
                    {
                      {
                        int _7195 = (int)0;
                        int _7196 = _ptr__1173[(int)4];
                        for (int _1206 = _7195; _1206 < _7196; ++_1206)
                        {
                          {
                            _ptr__1200[_1201] = _ptr__1197[safe_add( (safe_mul( _1203,safe_add( _1203,(int)1 ) ) / (int)2),_1205 )];
                            _ptr__1199[_1201] = _ptr__1184[safe_add( safe_mul( safe_add( safe_mul( _1202,_ptr__1173[(int)2] ),_1204 ),_ptr__1173[(int)4] ),_1206 )];
                            ((*natconmap_slackidx)(_ptr__1172[_1201])) = ((-safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1199[_1201])),(safe_mul( _1203,safe_add( _1203,(int)1 ) ) / (int)2) ),_1205 )) - (int)1);
                            ++ _1201;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _7197 = (int)0;
        int _7198 = _ptr__1173[(int)0];
        for (int _1207 = _7197; _1207 < _7198; ++_1207)
        {
          {
            int _7199 = (int)0;
            int _7200 = _ptr__1173[(int)1];
            for (int _1208 = _7199; _1208 < _7200; ++_1208)
            {
              {
                int _7201 = (int)0;
                int _7202 = _ptr__1173[(int)2];
                for (int _1209 = _7201; _1209 < _7202; ++_1209)
                {
                  {
                    int _7203 = _1208;
                    int _7204 = _ptr__1173[(int)1];
                    for (int _1210 = _7203; _1210 < _7204; ++_1210)
                    {
                      {
                        int _7205 = (int)0;
                        int _7206 = _ptr__1173[(int)4];
                        for (int _1211 = _7205; _1211 < _7206; ++_1211)
                        {
                          {
                            _ptr__1200[_1201] = _ptr__1197[safe_add( (safe_mul( _1210,safe_add( _1210,(int)1 ) ) / (int)2),_1208 )];
                            _ptr__1199[_1201] = _ptr__1184[safe_add( safe_mul( safe_add( safe_mul( _1207,_ptr__1173[(int)2] ),_1209 ),_ptr__1173[(int)4] ),_1211 )];
                            ((*natconmap_slackidx)(_ptr__1172[_1201])) = ((-safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1199[_1201])),(safe_mul( _1210,safe_add( _1210,(int)1 ) ) / (int)2) ),_1208 )) - (int)1);
                            ++ _1201;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1198,_1199,_1200);
  ((*natconmap_type)(_1171)) = (-safe_add( _1183,(int)1 ));
  std::vector<long long> _7207;
  for (int _1213 = (int)0, _7208 = _1169; _1213 < _7208 ; ++_1213)
  {
    _7207.push_back(((*natconmap_slackidx)(_ptr__1172[_1213])));
  }
  auto _7209 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7207.size()),_7207.begin(),_7207.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1212 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1147,_1171,_1159,_1153,_1152,_7209,_1172);
  ((*cons)(_1171)) = (_1212).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1147).size()) > (int)0))
  {
    {
      con_map->setItem(_1147,_1171);
    }
  }
  {}
  return (_1212).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1214,monty::rc_ptr< ::mosek::fusion::Expression > _1215,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1216){
  if ((((int)((_1214).size()) > (int)0) && hasConstraint(_1214)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1214)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1214).size()) > (int)0) && hasConstraint(_1214)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1214)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1217 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1215)).as<::mosek::fusion::Expression>());
  _1217->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1218 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1218(_1218 ? _1218->raw() : nullptr,_1218 ? _1218->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1219 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1219(_1219 ? _1219->raw() : nullptr,_1219 ? _1219->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1220 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1220(_1220 ? _1220->raw() : nullptr,_1220 ? _1220->size(0) : 0);
  int _1221 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1222 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1221)));
  _checked_ptr_1<int> _ptr__1222(_1222 ? _1222->raw() : nullptr,_1222 ? _1222->size(0) : 0);
  rs->popi32(_1221,_1222,(int)0);
  int _1223 = rs->popi32();
  int _1224 = rs->popi32();
  bool _1225 = (rs->popi32() != (int)0);
  int _1226 = rs->popi32(safe_add( _1223,(int)1 ));
  int _1227 = rs->popi64(_1224);
  int _1228 = rs->popf64(_1223);
  int _1229 = rs->popf64(_1224);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1216)->shape.get()) && (!::mosek::fusion::p_Set::match(_1222,mosek::fusion::p_LinPSDDomain::_get_impl(_1216)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1230 = (int)1;
  int _7210 = (int)0;
  int _7211 = _1221;
  for (int _1231 = _7210; _1231 < _7211; ++_1231)
  {
    {
      _1230 *= _ptr__1222[_1231];
    }
  }
  int _1232 = mosek::fusion::p_LinPSDDomain::_get_impl(_1216)->conedim;
  int _1233 = _ptr__1222[_1232];
  int _1234 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1233 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1234,safe_add( _1234,(int)1 ) ) / (int)2) != _1233))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1235 = (int)1;
  int _7212 = (int)0;
  int _7213 = _1232;
  for (int _1236 = _7212; _1236 < _7213; ++_1236)
  {
    {
      _1235 *= _ptr__1222[_1236];
    }
  }
  int _1237 = (int)1;
  int _7214 = safe_add( _1232,(int)1 );
  int _7215 = _1221;
  for (int _1238 = _7214; _1238 < _7215; ++_1238)
  {
    {
      _1237 *= _ptr__1222[_1238];
    }
  }
  int _1239 = safe_mul( _1235,_1237 );
  int _1240 = natconmap_alloc(_1230);
  std::shared_ptr< monty::ndarray< int,1 > > _1241 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1230)));
  _checked_ptr_1<int> _ptr__1241(_1241 ? _1241->raw() : nullptr,_1241 ? _1241->size(0) : 0);
  natconmap->get(_1240,_1241,(int)0);
  putarows(_1241,rs,_1223,_1224,_1226,_1227,_1229,_1228,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  int _1242 = natbarvarmap_alloc(_1239,_1234);
  std::shared_ptr< monty::ndarray< int,1 > > _1243 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1239)));
  _checked_ptr_1<int> _ptr__1243(_1243 ? _1243->raw() : nullptr,_1243 ? _1243->size(0) : 0);
  natbarvarmap_get(_1242,_1243);
  ((*barvars)(_1242)) = nullptr;
  int _1244 = safe_mul( safe_mul( _1233,_1235 ),_1237 );
  std::vector<int> _7216;
  for (int _1246 = (int)0, _7217 = _1233; _1246 < _7217 ; ++_1246)
  {
    _7216.push_back(_1246);
  }
  auto _7218 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7216.size()),_7216.begin(),_7216.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1245 = _7218;
  _checked_ptr_1<int> _ptr__1245(_1245 ? _1245->raw() : nullptr,_1245 ? _1245->size(0) : 0);
  std::vector<long long> _7219;
  for (int _1248 = (int)0, _7220 = _1233; _1248 < _7220 ; ++_1248)
  {
    _7219.push_back((int)1);
  }
  auto _7221 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7219.size()),_7219.begin(),_7219.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1247 = _7221;
  _checked_ptr_1<long long> _ptr__1247(_1247 ? _1247->raw() : nullptr,_1247 ? _1247->size(0) : 0);
  std::vector<double> _7222;
  for (int _1250 = (int)0, _7223 = _1233; _1250 < _7223 ; ++_1250)
  {
    _7222.push_back((-0.5));
  }
  auto _7224 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7222.size()),_7222.begin(),_7222.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1249 = _7224;
  _checked_ptr_1<double> _ptr__1249(_1249 ? _1249->raw() : nullptr,_1249 ? _1249->size(0) : 0);
  int _7225 = (int)1;
  int _7226 = safe_add( _1233,(int)1 );
  for (int _1251 = _7225; _1251 < _7226; ++_1251)
  {
    {
      _ptr__1249[((safe_mul( _1251,safe_add( _1251,(int)1 ) ) / (int)2) - (int)1)] = (-1.0);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1252 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1233)));
  _checked_ptr_1<int> _ptr__1252(_1252 ? _1252->raw() : nullptr,_1252 ? _1252->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1253 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1233)));
  _checked_ptr_1<int> _ptr__1253(_1253 ? _1253->raw() : nullptr,_1253 ? _1253->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1254 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1244)));
  _checked_ptr_1<int> _ptr__1254(_1254 ? _1254->raw() : nullptr,_1254 ? _1254->size(0) : 0);
  {
    int _1255 = (int)0;
    int _7227 = (int)0;
    int _7228 = _1235;
    for (int _1256 = _7227; _1256 < _7228; ++_1256)
    {
      {
        int _7229 = (int)0;
        int _7230 = _1234;
        for (int _1257 = _7229; _1257 < _7230; ++_1257)
        {
          {
            int _7231 = (int)0;
            int _7232 = safe_add( _1257,(int)1 );
            for (int _1258 = _7231; _1258 < _7232; ++_1258)
            {
              {
                int _7233 = (int)0;
                int _7234 = _1237;
                for (int _1259 = _7233; _1259 < _7234; ++_1259)
                {
                  {
                    _ptr__1254[_1255] = safe_add( safe_mul( _1256,_1237 ),_1259 );
                    _ptr__1252[_1255] = _1257;
                    _ptr__1253[_1255] = _1258;
                    ++ _1255;
                  }
                }
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1240)) = (-safe_add( _1242,(int)1 ));
    int _7235 = (int)0;
    int _7236 = _1230;
    for (int _1260 = _7235; _1260 < _7236; ++_1260)
    {
      {
        ((*natconmap_blockid)(_ptr__1241[_1260])) = _1240;
        ((*natconmap_idx)(_ptr__1241[_1260])) = _1260;
        ((*natconmap_efix)(_ptr__1241[_1260])) = _ptr__1220[safe_add( _1228,_1260 )];
        ((*natconmap_lb)(_ptr__1241[_1260])) = (int)0;
        ((*natconmap_ub)(_ptr__1241[_1260])) = (int)0;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1261 = task_appendsymmatlist(_1245,_1247,_1252,_1253,_1249);
  _checked_ptr_1<long long> _ptr__1261(_1261 ? _1261->raw() : nullptr,_1261 ? _1261->size(0) : 0);
  task_putbaraijlist(_1241,_1254,_1261);
  std::vector<double> _7237;
  for (int _1263 = (int)0, _7238 = _1230; _1263 < _7238 ; ++_1263)
  {
    _7237.push_back(0.0);
  }
  auto _7239 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7237.size()),_7237.begin(),_7237.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1262 = _7239;
  _checked_ptr_1<double> _ptr__1262(_1262 ? _1262->raw() : nullptr,_1262 ? _1262->size(0) : 0);
  task_con_putboundlist_fx(_1241,_1262);
  std::vector<long long> _7240;
  for (int _1265 = (int)0, _7241 = _1230; _1265 < _7241 ; ++_1265)
  {
    _7240.push_back(((*natconmap_slackidx)(_ptr__1241[_1265])));
  }
  auto _7242 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7240.size()),_7240.begin(),_7240.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1264 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1214,_1240,_1222,_1232,_1241,_7242);
  ((*cons)(_1240)) = (_1264).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1214).size()) > (int)0))
  {
    {
      con_map->setItem(_1214,_1240);
    }
  }
  {}
  return (_1264).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1266,monty::rc_ptr< ::mosek::fusion::Expression > _1267,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1268){
  if ((((int)((_1266).size()) > (int)0) && hasConstraint(_1266)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1266)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1266).size()) > (int)0) && hasConstraint(_1266)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1266)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_ConeDomain::_get_impl(_1268)->int_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1269 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1267)).as<::mosek::fusion::Expression>());
  _1269->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1270 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1270(_1270 ? _1270->raw() : nullptr,_1270 ? _1270->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1271 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1271(_1271 ? _1271->raw() : nullptr,_1271 ? _1271->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1272 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1272(_1272 ? _1272->raw() : nullptr,_1272 ? _1272->size(0) : 0);
  int _1273 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1274 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1275 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1276 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1277 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1278 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1279 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1280 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1281 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7243;
  for (int _1283 = (int)0, _7244 = _1273; _1283 < _7244 ; ++_1283)
  {
    _7243.push_back(_ptr__1270[safe_add( _1274,_1283 )]);
  }
  auto _7245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7243.size()),_7243.begin(),_7243.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1282 = _7245;
  _checked_ptr_1<int> _ptr__1282(_1282 ? _1282->raw() : nullptr,_1282 ? _1282->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1268)->shape.get()) && (!::mosek::fusion::p_Set::match(_1282,mosek::fusion::p_ConeDomain::_get_impl(_1268)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _7246;
  bool _7247 = _1268->axisIsSet();
  if (_7247)
  {
    _7246 = _1268->getAxis();
  }
  else
  {
    _7246 = (_1273 - (int)1);
  }
  int _1284 = _7246;
  int _1285 = _ptr__1282[_1284];
  int _1286 = (int)1;
  int _1287 = (int)1;
  int _1288 = (int)1;
  {
    int _7248 = (int)0;
    int _7249 = _1273;
    for (int _1289 = _7248; _1289 < _7249; ++_1289)
    {
      {
        _1288 *= _ptr__1282[_1289];
      }
    }
    int _7250 = (int)0;
    int _7251 = _1284;
    for (int _1290 = _7250; _1290 < _7251; ++_1290)
    {
      {
        _1287 *= _ptr__1282[_1290];
      }
    }
    int _7252 = safe_add( _1284,(int)1 );
    int _7253 = _1273;
    for (int _1291 = _7252; _1291 < _7253; ++_1291)
    {
      {
        _1286 *= _ptr__1282[_1291];
      }
    }
  }
  int _1292 = safe_mul( _1287,_1286 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InQCone) && (_1285 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1285 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1285 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1285 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1285 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1285 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1285)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1293 = natvarmap_alloc(_1288);
  std::shared_ptr< monty::ndarray< int,1 > > _1294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1288)));
  _checked_ptr_1<int> _ptr__1294(_1294 ? _1294->raw() : nullptr,_1294 ? _1294->size(0) : 0);
  natvarmap->get(_1293,_1294,(int)0);
  int _1295 = natconemap_alloc(_1292);
  int _7254 = (int)0;
  int _7255 = _1288;
  for (int _1296 = _7254; _1296 < _7255; ++_1296)
  {
    {
      ((*natvarmap_idx)(_ptr__1294[_1296])) = _1293;
    }
  }
  task_var_putboundlist_fr(_1294);
  std::shared_ptr< monty::ndarray< int,1 > > _7256;
  bool _7257 = (_1284 < ((int)((_1282)->size(0)) - (int)1));
  if (_7257)
  {
    _7256 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1294)->size(0)))));
  }
  else
  {
    _7256 = _1294;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1297 = _7256;
  _checked_ptr_1<int> _ptr__1297(_1297 ? _1297->raw() : nullptr,_1297 ? _1297->size(0) : 0);
  if ((_1284 < ((int)((_1282)->size(0)) - (int)1)))
  {
    {
      int _1298 = (int)0;
      int _7258 = (int)0;
      int _7259 = _1287;
      for (int _1299 = _7258; _1299 < _7259; ++_1299)
      {
        {
          int _7260 = (int)0;
          int _7261 = _1286;
          for (int _1300 = _7260; _1300 < _7261; ++_1300)
          {
            {
              int _7262 = (int)0;
              int _7263 = _1285;
              for (int _1301 = _7262; _1301 < _7263; ++_1301)
              {
                {
                  _ptr__1297[_1298] = _ptr__1294[safe_add( safe_mul( safe_add( safe_mul( _1299,_1285 ),_1301 ),_1286 ),_1300 )];
                  ++ _1298;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1302 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1292)));
  _checked_ptr_1<int> _ptr__1302(_1302 ? _1302->raw() : nullptr,_1302 ? _1302->size(0) : 0);
  natconemap->get(_1295,_1302,(int)0);
  ((*natconemap_dim)(_1295)) = _1285;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1302,_1285,_1292,_1297);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1302,_1285,_1292,_1297);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1302,_1285,_1292,_1297);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _7264;
      for (int _1303 = (int)0, _7265 = _1292; _1303 < _7265 ; ++_1303)
      {
        _7264.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1268)->alpha);
      }
      auto _7266 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7264.size()),_7264.begin(),_7264.end()));
      task_put_ppowcones(_1302,_1285,_1292,_1297,_7266);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1302,_1285,_1292,_1297);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1268)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _7267;
      for (int _1304 = (int)0, _7268 = _1292; _1304 < _7268 ; ++_1304)
      {
        _7267.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1268)->alpha);
      }
      auto _7269 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7267.size()),_7267.begin(),_7267.end()));
      task_put_dpowcones(_1302,_1285,_1292,_1297,_7269);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1293)) = nullptr;
  std::shared_ptr< monty::ndarray< double,1 > > _1305 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1288)));
  _checked_ptr_1<double> _ptr__1305(_1305 ? _1305->raw() : nullptr,_1305 ? _1305->size(0) : 0);
  int _1306 = natconmap_alloc(_1288);
  std::shared_ptr< monty::ndarray< int,1 > > _1307 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1288)));
  _checked_ptr_1<int> _ptr__1307(_1307 ? _1307->raw() : nullptr,_1307 ? _1307->size(0) : 0);
  natconmap->get(_1306,_1307,(int)0);
  ((*natconmap_type)(_1306)) = safe_add( _1293,(int)6 );
  {
    int _7270 = (int)0;
    int _7271 = _1288;
    for (int _1308 = _7270; _1308 < _7271; ++_1308)
    {
      {
        ((*natconmap_efix)(_ptr__1307[_1308])) = _ptr__1272[safe_add( _1280,_1308 )];
      }
    }
    int _7272 = (int)0;
    int _7273 = _1288;
    for (int _1309 = _7272; _1309 < _7273; ++_1309)
    {
      {
        ((*natconmap_lb)(_ptr__1307[_1309])) = (int)0;
      }
    }
    int _7274 = (int)0;
    int _7275 = _1288;
    for (int _1310 = _7274; _1310 < _7275; ++_1310)
    {
      {
        ((*natconmap_ub)(_ptr__1307[_1310])) = (int)0;
      }
    }
    int _7276 = (int)0;
    int _7277 = _1288;
    for (int _1311 = _7276; _1311 < _7277; ++_1311)
    {
      {
        ((*natconmap_slackidx)(_ptr__1307[_1311])) = safe_add( _ptr__1294[_1311],(int)1 );
      }
    }
    int _7278 = (int)0;
    int _7279 = _1288;
    for (int _1312 = _7278; _1312 < _7279; ++_1312)
    {
      {
        ((*natconmap_blockid)(_ptr__1307[_1312])) = _1306;
      }
    }
    int _7280 = (int)0;
    int _7281 = _1288;
    for (int _1313 = _7280; _1313 < _7281; ++_1313)
    {
      {
        ((*natconmap_idx)(_ptr__1307[_1313])) = _1313;
      }
    }
  }
  task_con_putboundlist_fx(_1307,_1305);
  putarows(_1307,rs,_1275,_1276,_1278,_1279,_1281,_1280,_1294);
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1314 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1266,_1268,_1282,_1306,_1307,_1294);
  ((*cons)(_1306)) = (_1314).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1266).size()) > (int)0))
  {
    {
      con_map->setItem(_1266,_1306);
    }
  }
  {}
  return (_1314).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1315,monty::rc_ptr< ::mosek::fusion::Expression > _1316,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1317){
  if ((((int)((_1315).size()) > (int)0) && hasConstraint(_1315)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1315)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_LinearDomain::_get_impl(_1317)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1318 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1316)).as<::mosek::fusion::Expression>());
  _1318->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1319 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1319(_1319 ? _1319->raw() : nullptr,_1319 ? _1319->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1320 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1320(_1320 ? _1320->raw() : nullptr,_1320 ? _1320->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1321 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1321(_1321 ? _1321->raw() : nullptr,_1321 ? _1321->size(0) : 0);
  int _1322 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1323 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1324 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1325 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1326 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1327 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1328 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1329 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1330 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7282;
  for (int _1332 = (int)0, _7283 = _1322; _1332 < _7283 ; ++_1332)
  {
    _7282.push_back(_ptr__1319[safe_add( _1323,_1332 )]);
  }
  auto _7284 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7282.size()),_7282.begin(),_7282.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1331 = _7284;
  _checked_ptr_1<int> _ptr__1331(_1331 ? _1331->raw() : nullptr,_1331 ? _1331->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1317)->shape.get()) && (!::mosek::fusion::p_Set::match(_1331,mosek::fusion::p_LinearDomain::_get_impl(_1317)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1333 = (int)1;
  int _7285 = (int)0;
  int _7286 = _1322;
  for (int _1334 = _7285; _1334 < _7286; ++_1334)
  {
    {
      _1333 *= _ptr__1331[_1334];
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1335;
  _checked_ptr_1<double> _ptr__1335(_1335 ? _1335->raw() : nullptr,_1335 ? _1335->size(0) : 0);
  int _1336 = natconmap_alloc(_1333);
  std::shared_ptr< monty::ndarray< int,1 > > _1337 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1333)));
  _checked_ptr_1<int> _ptr__1337(_1337 ? _1337->raw() : nullptr,_1337 ? _1337->size(0) : 0);
  natconmap->get(_1336,_1337,(int)0);
  putarows(_1337,rs,_1324,_1325,_1327,_1328,_1330,_1329,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1338 = mosek::fusion::p_LinearDomain::_get_impl(_1317)->sparsity;
    bool _1339 = mosek::fusion::p_LinearDomain::_get_impl(_1317)->empty;
    std::shared_ptr< monty::ndarray< double,1 > > _1340 = mosek::fusion::p_LinearDomain::_get_impl(_1317)->bnd;
    _checked_ptr_1<double> _ptr__1340(_1340 ? _1340->raw() : nullptr,_1340 ? _1340->size(0) : 0);
    bool _1341 = mosek::fusion::p_LinearDomain::_get_impl(_1317)->scalable;
    std::shared_ptr< monty::ndarray< double,1 > > _1342 = natconmap_efix;
    _checked_ptr_1<double> _ptr__1342(_1342 ? _1342->raw() : nullptr,_1342 ? _1342->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1343 = natconmap_lb;
    _checked_ptr_1<double> _ptr__1343(_1343 ? _1343->raw() : nullptr,_1343 ? _1343->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1344 = natconmap_ub;
    _checked_ptr_1<double> _ptr__1344(_1344 ? _1344->raw() : nullptr,_1344 ? _1344->size(0) : 0);
    {
      int _7287 = (int)0;
      int _7288 = _1324;
      for (int _1345 = _7287; _1345 < _7288; ++_1345)
      {
        {
          _ptr__1342[_ptr__1337[_1345]] = _ptr__1321[safe_add( _1329,_1345 )];
        }
      }
      if ((NULL == _1340.get()))
      {
        {
          int _7289 = (int)0;
          int _7290 = _1324;
          for (int _1346 = _7289; _1346 < _7290; ++_1346)
          {
            {
              _ptr__1343[_ptr__1337[_1346]] = (int)0;
              _ptr__1344[_ptr__1337[_1346]] = (int)0;
            }
          }
        }
      }
      else if(_1341)
      {
        {
          int _7291 = (int)0;
          int _7292 = _1324;
          for (int _1347 = _7291; _1347 < _7292; ++_1347)
          {
            {
              _ptr__1343[_ptr__1337[_1347]] = _ptr__1340[(int)0];
              _ptr__1344[_ptr__1337[_1347]] = _ptr__1340[(int)0];
            }
          }
        }
      }
      else if((NULL != _1338.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1348 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1322)));
          _checked_ptr_1<int> _ptr__1348(_1348 ? _1348->raw() : nullptr,_1348 ? _1348->size(0) : 0);
          _ptr__1348[(_1322 - (int)1)] = (int)1;
          int _7293 = (int)1;
          int _7294 = _1322;
          for (int _1349 = _7293; _1349 < _7294; ++_1349)
          {
            {
              _ptr__1348[((_1322 - _1349) - (int)1)] = safe_mul( _ptr__1348[(_1322 - _1349)],_ptr__1331[(_1322 - _1349)] );
            }
          }
          int _7295 = (int)0;
          int _7296 = (int)((_1338)->size(0));
          for (int _1350 = _7295; _1350 < _7296; ++_1350)
          {
            {
              int _1351 = (int)0;
              int _7297 = (int)0;
              int _7298 = _1322;
              for (int _1352 = _7297; _1352 < _7298; ++_1352)
              {
                {
                  _1351 += safe_mul( _ptr__1348[_1352],((*_1338)(_1350,_1352)) );
                }
              }
              _ptr__1343[_ptr__1337[_1351]] = _ptr__1340[_1350];
              _ptr__1344[_ptr__1337[_1351]] = _ptr__1340[_1350];
            }
          }
        }
      }
      else if(_1339)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1353 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1322)));
          _checked_ptr_1<int> _ptr__1353(_1353 ? _1353->raw() : nullptr,_1353 ? _1353->size(0) : 0);
          _ptr__1353[(_1322 - (int)1)] = (int)1;
          int _7299 = (int)1;
          int _7300 = _1322;
          for (int _1354 = _7299; _1354 < _7300; ++_1354)
          {
            {
              _ptr__1353[((_1322 - _1354) - (int)1)] = safe_mul( _ptr__1353[(_1322 - _1354)],_ptr__1331[(_1322 - _1354)] );
            }
          }
          int _7301 = (int)0;
          int _7302 = (int)((_1338)->size(0));
          for (int _1355 = _7301; _1355 < _7302; ++_1355)
          {
            {
              int _1356 = (int)0;
              int _7303 = (int)0;
              int _7304 = _1322;
              for (int _1357 = _7303; _1357 < _7304; ++_1357)
              {
                {
                  _1356 += safe_mul( _ptr__1353[_1357],((*_1338)(_1355,_1357)) );
                }
              }
              _ptr__1343[_ptr__1337[_1356]] = (int)0;
              _ptr__1344[_ptr__1337[_1356]] = (int)0;
            }
          }
        }
      }
      else
      {
        {
          int _7305 = (int)0;
          int _7306 = _1324;
          for (int _1358 = _7305; _1358 < _7306; ++_1358)
          {
            {
              _ptr__1343[_ptr__1337[_1358]] = _ptr__1340[_1358];
              _ptr__1344[_ptr__1337[_1358]] = _ptr__1340[_1358];
            }
          }
        }
      }
    }
    std::vector<double> _7307;
    for (int _1359 = (int)0, _7308 = (int)((_1337)->size(0)); _1359 < _7308 ; ++_1359)
    {
      _7307.push_back(_ptr__1343[_ptr__1337[_1359]]);
    }
    auto _7309 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7307.size()),_7307.begin(),_7307.end()));
    _1335 = _7309;
    _ptr__1335.update(_1335 ? _1335->raw() : nullptr, _1335 ? _1335->size(0) : 0);
  }
  int _7310 = (int)0;
  int _7311 = _1333;
  for (int _1360 = _7310; _1360 < _7311; ++_1360)
  {
    {
      ((*natconmap_idx)(_ptr__1337[_1360])) = _1336;
      ((*natconmap_slackidx)(_ptr__1337[_1360])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1317)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1336)) = (int)1;
      task_con_putboundlist_fr(_1337);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1317)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1336)) = (int)3;
      task_con_putboundlist_up(_1337,_1335);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1317)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1336)) = (int)2;
      task_con_putboundlist_lo(_1337,_1335);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1317)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1336)) = (int)5;
      task_con_putboundlist_fx(_1337,_1335);
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1361 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1315,_1336,_1331,_1337);
  ((*cons)(_1336)) = (_1361).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1315).size()) > (int)0))
  {
    {
      con_map->setItem(_1315,_1336);
    }
  }
  {}
  return (_1361).as<::mosek::fusion::Constraint>();
}
std::string mosek::fusion::Model::getVersion  ( ) { return mosek::fusion::p_Model::getVersion(); }std::string mosek::fusion::p_Model::getVersion(){
  return ::mosek::fusion::p_BaseModel::env_getversion();
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1362) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1362); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1362){
  return con_map->hasItem(_1362);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1363) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1363); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1363){
  return var_map->hasItem(_1363);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1364) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1364); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1364) { return __mosek_2fusion_2Model__getConstraint(_1364); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1364){
  return (((*cons)(_1364))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1365) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1365); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1365) { return __mosek_2fusion_2Model__getConstraint(_1365); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1365){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _7312;
  bool _7313 = con_map->hasItem(_1365);
  if (_7313)
  {
    _7312 = ((*cons)(con_map->getItem(_1365)));
  }
  else
  {
    _7312 = nullptr;
  }
  return (_7312).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1366) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1366); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1366) { return __mosek_2fusion_2Model__getVariable(_1366); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1366){
  return (((*vars)(_1366))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1367) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1367); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1367) { return __mosek_2fusion_2Model__getVariable(_1367); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1367){
  if (var_map->hasItem(_1367))
  {
    {
      int _1368 = var_map->getItem(_1367);
      if ((_1368 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1368,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1368))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_type.reset();natconmap_ub.reset();natconmap_lb.reset();natconmap_efix.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1369,    std::shared_ptr< monty::ndarray< int,1 > > _1370,    std::shared_ptr< monty::ndarray< long long,1 > > _1371,    std::shared_ptr< monty::ndarray< long long,1 > > _1372){ return new mosek::fusion::SliceVariable(_1369,_1370,_1371,_1372); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1369,    std::shared_ptr< monty::ndarray< int,1 > > _1370,    std::shared_ptr< monty::ndarray< long long,1 > > _1371,    std::shared_ptr< monty::ndarray< long long,1 > > _1372) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1369,_1370,_1371,_1372); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1369,    std::shared_ptr< monty::ndarray< int,1 > > _1370,    std::shared_ptr< monty::ndarray< long long,1 > > _1371,    std::shared_ptr< monty::ndarray< long long,1 > > _1372){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1370(_1370 ? _1370->raw() : nullptr, _1370 ? _1370->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1371(_1371 ? _1371->raw() : nullptr, _1371 ? _1371->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1372(_1372 ? _1372->raw() : nullptr, _1372 ? _1372->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1369,_1370,_1371,_1372);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1372;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1371;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1370;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1373,    monty::rc_ptr< ::mosek::fusion::Model > _1374){ return new mosek::fusion::SymRangedVariable(_1373,_1374); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1373,    monty::rc_ptr< ::mosek::fusion::Model > _1374) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1373,_1374); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1373,    monty::rc_ptr< ::mosek::fusion::Model > _1374){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1373,_1374);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1373)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1373)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1373)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1373)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1373)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1375,    const std::string &  _1376,    long long _1377,    int _1378,    std::shared_ptr< monty::ndarray< long long,1 > > _1379,    std::shared_ptr< monty::ndarray< int,1 > > _1380){ return new mosek::fusion::SymRangedVariable(_1375,_1376,_1377,_1378,_1379,_1380); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1375,    const std::string &  _1376,    long long _1377,    int _1378,    std::shared_ptr< monty::ndarray< long long,1 > > _1379,    std::shared_ptr< monty::ndarray< int,1 > > _1380) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1375,_1376,_1377,_1378,_1379,_1380); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1375,    const std::string &  _1376,    long long _1377,    int _1378,    std::shared_ptr< monty::ndarray< long long,1 > > _1379,    std::shared_ptr< monty::ndarray< int,1 > > _1380){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1379(_1379 ? _1379->raw() : nullptr, _1379 ? _1379->size(0) : 0);
    _checked_ptr_1<int> _ptr__1380(_1380 ? _1380->raw() : nullptr, _1380 ? _1380->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1375,_1376,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1378),(int)(_1378)}),_1377,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1378,_1379),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1378,_1379,_1380));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1376;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1380;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1379;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1378;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1381,std::shared_ptr< monty::ndarray< double,1 > > _1382){
  _checked_ptr_1<double> _ptr__1382(_1382 ? _1382->raw() : nullptr, _1382 ? _1382->size(0) : 0);
  dual_lu(_1381,_1382,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1383,std::shared_ptr< monty::ndarray< double,1 > > _1384){
  _checked_ptr_1<double> _ptr__1384(_1384 ? _1384->raw() : nullptr, _1384 ? _1384->size(0) : 0);
  dual_lu(_1383,_1384,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1385 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7314 = (int)0;
          int _7315 = (int)((nativeidxs)->size(0));
          for (int _1386 = _7314; _1386 < _7315; ++_1386)
          {
            {
              std::string _7316;
              bool _7317 = ((int)((name).size()) == (int)0);
              if (_7317)
              {
                _7316 = std::string ("");
              }
              else
              {
                _7316 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1386 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1386 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1385.get())->varname(((*nativeidxs)(_1386)),_7316);
            }
          }
        }
      }
      else
      {
        {
          int _7318 = (int)0;
          int _7319 = (int)((sparsity)->size(0));
          for (int _1387 = _7318; _1387 < _7319; ++_1387)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1385.get())->varname(((*nativeidxs)(_1387)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1387)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1387)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1388){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1388)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1389,std::shared_ptr< monty::ndarray< long long,1 > > _1390,std::shared_ptr< monty::ndarray< int,1 > > _1391){
  _checked_ptr_1<long long> _ptr__1390(_1390 ? _1390->raw() : nullptr, _1390 ? _1390->size(0) : 0);
  _checked_ptr_1<int> _ptr__1391(_1391 ? _1391->raw() : nullptr, _1391 ? _1391->size(0) : 0);
  if ((NULL == _1390.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1392 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1389,_1389 ))));
      _checked_ptr_1<long long> _ptr__1392(_1392 ? _1392->raw() : nullptr,_1392 ? _1392->size(0) : 0);
      int _1393 = (int)0;
      {
        int _7320 = (int)0;
        int _7321 = _1389;
        for (int _1394 = _7320; _1394 < _7321; ++_1394)
        {
          {
            _ptr__1392[safe_add( safe_mul( _1394,_1389 ),_1394 )] = safe_add( _ptr__1391[_1393],(int)1 );
            ++ _1393;
            int _7322 = safe_add( _1394,(int)1 );
            int _7323 = _1389;
            for (int _1395 = _7322; _1395 < _7323; ++_1395)
            {
              {
                _ptr__1392[safe_add( safe_mul( _1394,_1389 ),_1395 )] = safe_add( _ptr__1391[_1393],(int)1 );
                _ptr__1392[safe_add( safe_mul( _1395,_1389 ),_1394 )] = safe_add( _ptr__1391[_1393],(int)1 );
                ++ _1393;
              }
            }
          }
        }
      }
      return _1392;
    }
  }
  else
  {
    {
      int _1396 = (int)0;
      {
        int _7324 = (int)0;
        int _7325 = (int)((_1390)->size(0));
        for (int _1397 = _7324; _1397 < _7325; ++_1397)
        {
          {
            int _7326;
            bool _7327 = ((_ptr__1390[_1397] % safe_add( _1389,(int)1 )) == (int)0);
            if (_7327)
            {
              _7326 = (int)1;
            }
            else
            {
              _7326 = (int)2;
            }
            _1396 += _7326;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1398 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1396)));
      _checked_ptr_1<long long> _ptr__1398(_1398 ? _1398->raw() : nullptr,_1398 ? _1398->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1399 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1396)));
      _checked_ptr_1<long long> _ptr__1399(_1399 ? _1399->raw() : nullptr,_1399 ? _1399->size(0) : 0);
      {
        int _1400 = (int)0;
        int _7328 = (int)0;
        int _7329 = (int)((_1390)->size(0));
        for (int _1401 = _7328; _1401 < _7329; ++_1401)
        {
          {
            long long _1402 = (_ptr__1390[_1401] / _1389);
            long long _1403 = (_ptr__1390[_1401] % _1389);
            _ptr__1398[_1400] = _ptr__1390[_1401];
            _ptr__1399[_1400] = safe_add( _ptr__1391[_1401],(int)1 );
            ++ _1400;
            if ((_1402 != _1403))
            {
              {
                _ptr__1398[_1400] = safe_add( safe_mul( _1403,_1389 ),_1402 );
                _ptr__1399[_1400] = safe_add( _ptr__1391[_1401],(int)1 );
                ++ _1400;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7330;
      for (int _1405 = (int)0, _7331 = _1396; _1405 < _7331 ; ++_1405)
      {
        _7330.push_back(_1405);
      }
      auto _7332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7330.size()),_7330.begin(),_7330.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1404 = _7332;
      _checked_ptr_1<long long> _ptr__1404(_1404 ? _1404->raw() : nullptr,_1404 ? _1404->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1404,_1398,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1396));
      std::vector<long long> _7333;
      for (int _1406 = (int)0, _7334 = _1396; _1406 < _7334 ; ++_1406)
      {
        _7333.push_back(_ptr__1399[_ptr__1404[_1406]]);
      }
      auto _7335 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7333.size()),_7333.begin(),_7333.end()));
      return _7335;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1407,std::shared_ptr< monty::ndarray< long long,1 > > _1408){
  _checked_ptr_1<long long> _ptr__1408(_1408 ? _1408->raw() : nullptr, _1408 ? _1408->size(0) : 0);
  if ((NULL == _1408.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1409 = (int)0;
      {
        int _7336 = (int)0;
        int _7337 = (int)((_1408)->size(0));
        for (int _1410 = _7336; _1410 < _7337; ++_1410)
        {
          {
            int _7338;
            bool _7339 = ((_ptr__1408[_1410] % safe_add( _1407,(int)1 )) == (int)0);
            if (_7339)
            {
              _7338 = (int)1;
            }
            else
            {
              _7338 = (int)2;
            }
            _1409 += _7338;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1411 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1409)));
      _checked_ptr_1<long long> _ptr__1411(_1411 ? _1411->raw() : nullptr,_1411 ? _1411->size(0) : 0);
      {
        int _1412 = (int)0;
        int _7340 = (int)0;
        int _7341 = (int)((_1408)->size(0));
        for (int _1413 = _7340; _1413 < _7341; ++_1413)
        {
          {
            long long _1414 = (_ptr__1408[_1413] / _1407);
            long long _1415 = (_ptr__1408[_1413] % _1407);
            _ptr__1411[_1412] = _ptr__1408[_1413];
            ++ _1412;
            if ((_1414 != _1415))
            {
              {
                _ptr__1411[_1412] = safe_add( safe_mul( _1415,_1407 ),_1414 );
                ++ _1412;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7342;
      for (int _1417 = (int)0, _7343 = _1409; _1417 < _7343 ; ++_1417)
      {
        _7342.push_back(_1417);
      }
      auto _7344 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7342.size()),_7342.begin(),_7342.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1416 = _7344;
      _checked_ptr_1<long long> _ptr__1416(_1416 ? _1416->raw() : nullptr,_1416 ? _1416->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1416,_1411,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1409));
      std::vector<long long> _7345;
      for (int _1418 = (int)0, _7346 = _1409; _1418 < _7346 ; ++_1418)
      {
        _7345.push_back(_ptr__1411[_ptr__1416[_1418]]);
      }
      auto _7347 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7345.size()),_7345.begin(),_7345.end()));
      return _7347;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1419,    monty::rc_ptr< ::mosek::fusion::Model > _1420){ return new mosek::fusion::RangedVariable(_1419,_1420); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1419,    monty::rc_ptr< ::mosek::fusion::Model > _1420) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1419,_1420); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1419,    monty::rc_ptr< ::mosek::fusion::Model > _1420){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1419,_1420);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1419)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1419)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1419)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1419)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1419)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1421,    const std::string &  _1422,    long long _1423,    std::shared_ptr< monty::ndarray< int,1 > > _1424,    std::shared_ptr< monty::ndarray< long long,1 > > _1425,    std::shared_ptr< monty::ndarray< int,1 > > _1426){ return new mosek::fusion::RangedVariable(_1421,_1422,_1423,_1424,_1425,_1426); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1421,    const std::string &  _1422,    long long _1423,    std::shared_ptr< monty::ndarray< int,1 > > _1424,    std::shared_ptr< monty::ndarray< long long,1 > > _1425,    std::shared_ptr< monty::ndarray< int,1 > > _1426) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1421,_1422,_1423,_1424,_1425,_1426); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1421,    const std::string &  _1422,    long long _1423,    std::shared_ptr< monty::ndarray< int,1 > > _1424,    std::shared_ptr< monty::ndarray< long long,1 > > _1425,    std::shared_ptr< monty::ndarray< int,1 > > _1426){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1424(_1424 ? _1424->raw() : nullptr, _1424 ? _1424->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1425(_1425 ? _1425->raw() : nullptr, _1425 ? _1425->size(0) : 0);
    _checked_ptr_1<int> _ptr__1426(_1426 ? _1426->raw() : nullptr, _1426 ? _1426->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1421,_1422,_1424,_1423,_1425,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1426));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1426;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1425;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1422;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1424;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1427,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1428) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1427,_1428); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1427,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1428) { return __mosek_2fusion_2RangedVariable__elementDesc(_1427,_1428); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1427,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1428){
  _pubthis->elementName(_1427,_1428);
  _1428->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1428;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1429 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1430 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1430->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1430->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7348 = (int)1;
          int _7349 = _pubthis->getND();
          for (int _1431 = _7348; _1431 < _7349; ++_1431)
          {
            {
              _1430->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1431);
            }
          }
        }
      }
      {}
      _1430->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1429.get())->varnames(nativeidxs,_1430->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1432,std::shared_ptr< monty::ndarray< double,1 > > _1433){
  _checked_ptr_1<double> _ptr__1433(_1433 ? _1433->raw() : nullptr, _1433 ? _1433->size(0) : 0);
  dual_lu(_1432,_1433,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1434,std::shared_ptr< monty::ndarray< double,1 > > _1435){
  _checked_ptr_1<double> _ptr__1435(_1435 ? _1435->raw() : nullptr, _1435 ? _1435->size(0) : 0);
  dual_lu(_1434,_1435,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1436){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1436)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1437){
  _checked_ptr_1<int> _ptr__1437(_1437 ? _1437->raw() : nullptr, _1437 ? _1437->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1438 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1437)->size(0)))));
  _checked_ptr_1<long long> _ptr__1438(_1438 ? _1438->raw() : nullptr,_1438 ? _1438->size(0) : 0);
  int _7350 = (int)0;
  int _7351 = (int)((_1437)->size(0));
  for (int _1439 = _7350; _1439 < _7351; ++_1439)
  {
    {
      _ptr__1438[_1439] = safe_add( _ptr__1437[_1439],(int)1 );
    }
  }
  return _1438;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1440,    monty::rc_ptr< ::mosek::fusion::Model > _1441){ return new mosek::fusion::LinearPSDVariable(_1440,_1441); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1440,    monty::rc_ptr< ::mosek::fusion::Model > _1441) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1440,_1441); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1440,    monty::rc_ptr< ::mosek::fusion::Model > _1441){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1440,_1441);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1440)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1440)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1440)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1440)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1440)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1442,    const std::string &  _1443,    int _1444,    std::shared_ptr< monty::ndarray< int,1 > > _1445,    int _1446,    std::shared_ptr< monty::ndarray< long long,1 > > _1447){ return new mosek::fusion::LinearPSDVariable(_1442,_1443,_1444,_1445,_1446,_1447); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1442,    const std::string &  _1443,    int _1444,    std::shared_ptr< monty::ndarray< int,1 > > _1445,    int _1446,    std::shared_ptr< monty::ndarray< long long,1 > > _1447) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1442,_1443,_1444,_1445,_1446,_1447); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1442,    const std::string &  _1443,    int _1444,    std::shared_ptr< monty::ndarray< int,1 > > _1445,    int _1446,    std::shared_ptr< monty::ndarray< long long,1 > > _1447){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1445(_1445 ? _1445->raw() : nullptr, _1445 ? _1445->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1447(_1447 ? _1447->raw() : nullptr, _1447 ? _1447->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1442,_1443,_1445,_1444,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1447));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1443;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1446;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1444;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1445;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1447;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1448 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1448->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1448->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1448->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7352 = (int)1;
  int _7353 = (int)((shape)->size(0));
  for (int _1449 = _7352; _1449 < _7353; ++_1449)
  {
    {
      _1448->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1449)));
    }
  }
  _1448->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1448->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1450) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1450); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1450){
  _checked_ptr_1<long long> _ptr__1450(_1450 ? _1450->raw() : nullptr, _1450 ? _1450->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1451) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1451); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1451){
  _checked_ptr_1<long long> _ptr__1451(_1451 ? _1451->raw() : nullptr, _1451 ? _1451->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1452){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1452)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1453){
  _checked_ptr_1<long long> _ptr__1453(_1453 ? _1453->raw() : nullptr, _1453 ? _1453->size(0) : 0);
  std::vector<long long> _7354;
  for (int _1454 = (int)0, _7355 = (int)((_1453)->size(0)); _1454 < _7355 ; ++_1454)
  {
    _7354.push_back((-safe_add( _ptr__1453[_1454],(int)1 )));
  }
  auto _7356 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7354.size()),_7354.begin(),_7354.end()));
  return _7356;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1455,    monty::rc_ptr< ::mosek::fusion::Model > _1456){ return new mosek::fusion::PSDVariable(_1455,_1456); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1455,    monty::rc_ptr< ::mosek::fusion::Model > _1456) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1455,_1456); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1455,    monty::rc_ptr< ::mosek::fusion::Model > _1456){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1455,_1456);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1455)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1455)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1455)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1455)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1455)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1455)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1457,    const std::string &  _1458,    int _1459,    std::shared_ptr< monty::ndarray< int,1 > > _1460,    int _1461,    int _1462,    std::shared_ptr< monty::ndarray< long long,1 > > _1463){ return new mosek::fusion::PSDVariable(_1457,_1458,_1459,_1460,_1461,_1462,_1463); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1457,    const std::string &  _1458,    int _1459,    std::shared_ptr< monty::ndarray< int,1 > > _1460,    int _1461,    int _1462,    std::shared_ptr< monty::ndarray< long long,1 > > _1463) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1457,_1458,_1459,_1460,_1461,_1462,_1463); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1457,    const std::string &  _1458,    int _1459,    std::shared_ptr< monty::ndarray< int,1 > > _1460,    int _1461,    int _1462,    std::shared_ptr< monty::ndarray< long long,1 > > _1463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1460(_1460 ? _1460->raw() : nullptr, _1460 ? _1460->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1463(_1463 ? _1463->raw() : nullptr, _1463 ? _1463->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1457,_1458,_1460,_1459,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1460,_1461,_1462,_1463));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1459;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1463;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1458;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1460;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1461;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1462;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1464 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1464->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1464->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1464->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7357 = (int)1;
  int _7358 = (int)((shape)->size(0));
  for (int _1465 = _7357; _1465 < _7358; ++_1465)
  {
    {
      _1464->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1465)));
    }
  }
  _1464->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1464->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1466,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1467) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1466,_1467); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1466,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1467) { return __mosek_2fusion_2PSDVariable__elementDesc(_1466,_1467); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1466,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1467){
  _pubthis->elementName(_1466,_1467);
  _1467->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1467;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1468){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1468)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1469,int _1470,int _1471,std::shared_ptr< monty::ndarray< long long,1 > > _1472){
  _checked_ptr_1<int> _ptr__1469(_1469 ? _1469->raw() : nullptr, _1469 ? _1469->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1472(_1472 ? _1472->raw() : nullptr, _1472 ? _1472->size(0) : 0);
  int _1473 = (int)((_1469)->size(0));
  bool _1474 = (_1470 < _1471);
  int _7359;
  bool _7360 = _1474;
  if (_7360)
  {
    _7359 = _1470;
  }
  else
  {
    _7359 = _1471;
  }
  int _1475 = _7359;
  int _7361;
  bool _7362 = (!_1474);
  if (_7362)
  {
    _7361 = _1470;
  }
  else
  {
    _7361 = _1471;
  }
  int _1476 = _7361;
  int _1477 = (int)1;
  int _7363 = (int)0;
  int _7364 = _1475;
  for (int _1478 = _7363; _1478 < _7364; ++_1478)
  {
    {
      _1477 *= _ptr__1469[_1478];
    }
  }
  int _1479 = _ptr__1469[_1475];
  int _1480 = (int)1;
  int _7365 = safe_add( _1475,(int)1 );
  int _7366 = _1476;
  for (int _1481 = _7365; _1481 < _7366; ++_1481)
  {
    {
      _1480 *= _ptr__1469[_1481];
    }
  }
  int _1482 = _ptr__1469[_1476];
  int _1483 = (int)1;
  int _7367 = safe_add( _1476,(int)1 );
  int _7368 = _1473;
  for (int _1484 = _7367; _1484 < _7368; ++_1484)
  {
    {
      _1483 *= _ptr__1469[_1484];
    }
  }
  int _1485 = safe_mul( safe_mul( safe_mul( safe_mul( _1477,_1479 ),_1480 ),_1482 ),_1483 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1486 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1485)));
  _checked_ptr_1<long long> _ptr__1486(_1486 ? _1486->raw() : nullptr,_1486 ? _1486->size(0) : 0);
  int _1487 = _1483;
  int _1488 = safe_mul( _1487,_1482 );
  int _1489 = safe_mul( _1488,_1480 );
  int _1490 = safe_mul( _1489,_1489 );
  {
    int _1491 = (int)0;
    int _7369 = (int)0;
    int _7370 = _1477;
    for (int _1492 = _7369; _1492 < _7370; ++_1492)
    {
      {
        int _7371 = (int)0;
        int _7372 = _1482;
        for (int _1493 = _7371; _1493 < _7372; ++_1493)
        {
          {
            int _7373 = (int)0;
            int _7374 = _1480;
            for (int _1494 = _7373; _1494 < _7374; ++_1494)
            {
              {
                int _7375 = _1493;
                int _7376 = _1479;
                for (int _1495 = _7375; _1495 < _7376; ++_1495)
                {
                  {
                    int _7377 = (int)0;
                    int _7378 = _1483;
                    for (int _1496 = _7377; _1496 < _7378; ++_1496)
                    {
                      {
                        _ptr__1486[safe_add( safe_add( safe_add( safe_add( safe_mul( _1492,_1490 ),safe_mul( _1495,_1489 ) ),safe_mul( _1494,_1488 ) ),safe_mul( _1493,_1487 ) ),_1496 )] = (-safe_add( _ptr__1472[_1491],(int)1 ));
                        _ptr__1486[safe_add( safe_add( safe_add( safe_add( safe_mul( _1492,_1490 ),safe_mul( _1493,_1489 ) ),safe_mul( _1494,_1488 ) ),safe_mul( _1495,_1487 ) ),_1496 )] = (-safe_add( _ptr__1472[_1491],(int)1 ));
                        ++ _1491;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1486;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1497,    monty::rc_ptr< ::mosek::fusion::Model > _1498){ return new mosek::fusion::SymLinearVariable(_1497,_1498); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1497,    monty::rc_ptr< ::mosek::fusion::Model > _1498) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1497,_1498); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1497,    monty::rc_ptr< ::mosek::fusion::Model > _1498){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1497,_1498);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1497)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1497)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1497)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1497)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1497)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1499,    const std::string &  _1500,    long long _1501,    int _1502,    std::shared_ptr< monty::ndarray< long long,1 > > _1503,    std::shared_ptr< monty::ndarray< int,1 > > _1504){ return new mosek::fusion::SymLinearVariable(_1499,_1500,_1501,_1502,_1503,_1504); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1499,    const std::string &  _1500,    long long _1501,    int _1502,    std::shared_ptr< monty::ndarray< long long,1 > > _1503,    std::shared_ptr< monty::ndarray< int,1 > > _1504) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1499,_1500,_1501,_1502,_1503,_1504); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1499,    const std::string &  _1500,    long long _1501,    int _1502,    std::shared_ptr< monty::ndarray< long long,1 > > _1503,    std::shared_ptr< monty::ndarray< int,1 > > _1504){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1503(_1503 ? _1503->raw() : nullptr, _1503 ? _1503->size(0) : 0);
    _checked_ptr_1<int> _ptr__1504(_1504 ? _1504->raw() : nullptr, _1504 ? _1504->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1499,_1500,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1502),(int)(_1502)}),_1501,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1502,_1503),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1502,_1503,_1504));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1500;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1504;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1503;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1502;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1505 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7379 = (int)0;
          int _7380 = (int)((nativeidxs)->size(0));
          for (int _1506 = _7379; _1506 < _7380; ++_1506)
          {
            {
              std::string _7381;
              bool _7382 = ((int)((name).size()) == (int)0);
              if (_7382)
              {
                _7381 = std::string ("");
              }
              else
              {
                _7381 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1506 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1506 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1505.get())->varname(((*nativeidxs)(_1506)),_7381);
            }
          }
        }
      }
      else
      {
        {
          int _7383 = (int)0;
          int _7384 = (int)((sparsity)->size(0));
          for (int _1507 = _7383; _1507 < _7384; ++_1507)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1505.get())->varname(((*nativeidxs)(_1507)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1507)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1507)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1508){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1508)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1509,std::shared_ptr< monty::ndarray< long long,1 > > _1510,std::shared_ptr< monty::ndarray< int,1 > > _1511){
  _checked_ptr_1<long long> _ptr__1510(_1510 ? _1510->raw() : nullptr, _1510 ? _1510->size(0) : 0);
  _checked_ptr_1<int> _ptr__1511(_1511 ? _1511->raw() : nullptr, _1511 ? _1511->size(0) : 0);
  if ((NULL == _1510.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1512 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1509,_1509 ))));
      _checked_ptr_1<long long> _ptr__1512(_1512 ? _1512->raw() : nullptr,_1512 ? _1512->size(0) : 0);
      int _1513 = (int)0;
      {
        int _7385 = (int)0;
        int _7386 = _1509;
        for (int _1514 = _7385; _1514 < _7386; ++_1514)
        {
          {
            _ptr__1512[safe_add( safe_mul( _1514,_1509 ),_1514 )] = safe_add( _ptr__1511[_1513],(int)1 );
            ++ _1513;
            int _7387 = safe_add( _1514,(int)1 );
            int _7388 = _1509;
            for (int _1515 = _7387; _1515 < _7388; ++_1515)
            {
              {
                _ptr__1512[safe_add( safe_mul( _1514,_1509 ),_1515 )] = safe_add( _ptr__1511[_1513],(int)1 );
                _ptr__1512[safe_add( safe_mul( _1515,_1509 ),_1514 )] = safe_add( _ptr__1511[_1513],(int)1 );
                ++ _1513;
              }
            }
          }
        }
      }
      return _1512;
    }
  }
  else
  {
    {
      int _1516 = (int)0;
      {
        int _7389 = (int)0;
        int _7390 = (int)((_1510)->size(0));
        for (int _1517 = _7389; _1517 < _7390; ++_1517)
        {
          {
            int _7391;
            bool _7392 = ((_ptr__1510[_1517] % safe_add( _1509,(int)1 )) == (int)0);
            if (_7392)
            {
              _7391 = (int)1;
            }
            else
            {
              _7391 = (int)2;
            }
            _1516 += _7391;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1518 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1516)));
      _checked_ptr_1<long long> _ptr__1518(_1518 ? _1518->raw() : nullptr,_1518 ? _1518->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1519 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1516)));
      _checked_ptr_1<long long> _ptr__1519(_1519 ? _1519->raw() : nullptr,_1519 ? _1519->size(0) : 0);
      {
        int _1520 = (int)0;
        int _7393 = (int)0;
        int _7394 = (int)((_1510)->size(0));
        for (int _1521 = _7393; _1521 < _7394; ++_1521)
        {
          {
            long long _1522 = (_ptr__1510[_1521] / _1509);
            long long _1523 = (_ptr__1510[_1521] % _1509);
            _ptr__1518[_1520] = _ptr__1510[_1521];
            _ptr__1519[_1520] = safe_add( _ptr__1511[_1521],(int)1 );
            ++ _1520;
            if ((_1522 != _1523))
            {
              {
                _ptr__1518[_1520] = safe_add( safe_mul( _1523,_1509 ),_1522 );
                _ptr__1519[_1520] = safe_add( _ptr__1511[_1521],(int)1 );
                ++ _1520;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7395;
      for (int _1525 = (int)0, _7396 = _1516; _1525 < _7396 ; ++_1525)
      {
        _7395.push_back(_1525);
      }
      auto _7397 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7395.size()),_7395.begin(),_7395.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1524 = _7397;
      _checked_ptr_1<long long> _ptr__1524(_1524 ? _1524->raw() : nullptr,_1524 ? _1524->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1524,_1518,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1516));
      std::vector<long long> _7398;
      for (int _1526 = (int)0, _7399 = _1516; _1526 < _7399 ; ++_1526)
      {
        _7398.push_back(_ptr__1519[_ptr__1524[_1526]]);
      }
      auto _7400 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7398.size()),_7398.begin(),_7398.end()));
      return _7400;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1527,std::shared_ptr< monty::ndarray< long long,1 > > _1528){
  _checked_ptr_1<long long> _ptr__1528(_1528 ? _1528->raw() : nullptr, _1528 ? _1528->size(0) : 0);
  if ((NULL == _1528.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1529 = (int)0;
      {
        int _7401 = (int)0;
        int _7402 = (int)((_1528)->size(0));
        for (int _1530 = _7401; _1530 < _7402; ++_1530)
        {
          {
            int _7403;
            bool _7404 = ((_ptr__1528[_1530] % safe_add( _1527,(int)1 )) == (int)0);
            if (_7404)
            {
              _7403 = (int)1;
            }
            else
            {
              _7403 = (int)2;
            }
            _1529 += _7403;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1531 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1529)));
      _checked_ptr_1<long long> _ptr__1531(_1531 ? _1531->raw() : nullptr,_1531 ? _1531->size(0) : 0);
      {
        int _1532 = (int)0;
        int _7405 = (int)0;
        int _7406 = (int)((_1528)->size(0));
        for (int _1533 = _7405; _1533 < _7406; ++_1533)
        {
          {
            long long _1534 = (_ptr__1528[_1533] / _1527);
            long long _1535 = (_ptr__1528[_1533] % _1527);
            _ptr__1531[_1532] = _ptr__1528[_1533];
            ++ _1532;
            if ((_1534 != _1535))
            {
              {
                _ptr__1531[_1532] = safe_add( safe_mul( _1535,_1527 ),_1534 );
                ++ _1532;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7407;
      for (int _1537 = (int)0, _7408 = _1529; _1537 < _7408 ; ++_1537)
      {
        _7407.push_back(_1537);
      }
      auto _7409 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7407.size()),_7407.begin(),_7407.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1536 = _7409;
      _checked_ptr_1<long long> _ptr__1536(_1536 ? _1536->raw() : nullptr,_1536 ? _1536->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1536,_1531,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1529));
      std::vector<long long> _7410;
      for (int _1538 = (int)0, _7411 = _1529; _1538 < _7411 ; ++_1538)
      {
        _7410.push_back(_ptr__1531[_ptr__1536[_1538]]);
      }
      auto _7412 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7410.size()),_7410.begin(),_7410.end()));
      return _7412;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1539,    monty::rc_ptr< ::mosek::fusion::Model > _1540){ return new mosek::fusion::LinearVariable(_1539,_1540); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1539,    monty::rc_ptr< ::mosek::fusion::Model > _1540) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1539,_1540); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1539,    monty::rc_ptr< ::mosek::fusion::Model > _1540){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1539,_1540);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1539)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1539)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1539)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1539)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1539)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1541,    const std::string &  _1542,    long long _1543,    std::shared_ptr< monty::ndarray< int,1 > > _1544,    std::shared_ptr< monty::ndarray< long long,1 > > _1545,    std::shared_ptr< monty::ndarray< int,1 > > _1546){ return new mosek::fusion::LinearVariable(_1541,_1542,_1543,_1544,_1545,_1546); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1541,    const std::string &  _1542,    long long _1543,    std::shared_ptr< monty::ndarray< int,1 > > _1544,    std::shared_ptr< monty::ndarray< long long,1 > > _1545,    std::shared_ptr< monty::ndarray< int,1 > > _1546) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1541,_1542,_1543,_1544,_1545,_1546); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1541,    const std::string &  _1542,    long long _1543,    std::shared_ptr< monty::ndarray< int,1 > > _1544,    std::shared_ptr< monty::ndarray< long long,1 > > _1545,    std::shared_ptr< monty::ndarray< int,1 > > _1546){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1544(_1544 ? _1544->raw() : nullptr, _1544 ? _1544->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1545(_1545 ? _1545->raw() : nullptr, _1545 ? _1545->size(0) : 0);
    _checked_ptr_1<int> _ptr__1546(_1546 ? _1546->raw() : nullptr, _1546 ? _1546->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1541,_1542,_1544,_1543,_1545,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1546));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1542;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1546;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1545;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1544;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1547 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1547->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1547->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7413 = (int)1;
      int _7414 = (int)((shape)->size(0));
      for (int _1548 = _7413; _1548 < _7414; ++_1548)
      {
        {
          _1547->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1548)));
        }
      }
    }
  }
  {}
  _1547->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1547->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1549 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if ((_pubthis->getSize() == (int)0))
  {
    {
      names_flushed = true;
    }
  }
  else
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          names_flushed = true;
        }
      }
      {}
    }
  }
  if ((!names_flushed))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1550 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1550->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1550->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7415 = (int)1;
          int _7416 = _pubthis->getND();
          for (int _1551 = _7415; _1551 < _7416; ++_1551)
          {
            {
              _1550->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1551);
            }
          }
        }
      }
      {}
      _1550->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7417;
      bool _7418 = (_pubthis->getND() > (int)0);
      if (_7418)
      {
        _7417 = _pubthis->getShape();
      }
      else
      {
        _7417 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1549.get())->varnames(nativeidxs,_1550->toString(),_7417,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1552){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1552)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1553){
  _checked_ptr_1<int> _ptr__1553(_1553 ? _1553->raw() : nullptr, _1553 ? _1553->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1554 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1553)->size(0)))));
  _checked_ptr_1<long long> _ptr__1554(_1554 ? _1554->raw() : nullptr,_1554 ? _1554->size(0) : 0);
  int _7419 = (int)0;
  int _7420 = (int)((_1553)->size(0));
  for (int _1555 = _7419; _1555 < _7420; ++_1555)
  {
    {
      _ptr__1554[_1555] = safe_add( _ptr__1553[_1555],(int)1 );
    }
  }
  return _1554;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1556,    monty::rc_ptr< ::mosek::fusion::Model > _1557){ return new mosek::fusion::ConicVariable(_1556,_1557); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1556,    monty::rc_ptr< ::mosek::fusion::Model > _1557) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1556,_1557); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1556,    monty::rc_ptr< ::mosek::fusion::Model > _1557){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1556,_1557);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1556)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1556)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1556)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1556)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1556)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1556)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1558,    const std::string &  _1559,    int _1560,    std::shared_ptr< monty::ndarray< int,1 > > _1561,    std::shared_ptr< monty::ndarray< int,1 > > _1562){ return new mosek::fusion::ConicVariable(_1558,_1559,_1560,_1561,_1562); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1558,    const std::string &  _1559,    int _1560,    std::shared_ptr< monty::ndarray< int,1 > > _1561,    std::shared_ptr< monty::ndarray< int,1 > > _1562) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1558,_1559,_1560,_1561,_1562); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1558,    const std::string &  _1559,    int _1560,    std::shared_ptr< monty::ndarray< int,1 > > _1561,    std::shared_ptr< monty::ndarray< int,1 > > _1562){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1561(_1561 ? _1561->raw() : nullptr, _1561 ? _1561->size(0) : 0);
    _checked_ptr_1<int> _ptr__1562(_1562 ? _1562->raw() : nullptr, _1562 ? _1562->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1558,_1559,_1561,_1560,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1562));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1559;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1560;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1561;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1562;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1563 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1563->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1563->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1563->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1563->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7421 = (int)1;
  int _7422 = (int)((shape)->size(0));
  for (int _1564 = _7421; _1564 < _7422; ++_1564)
  {
    {
      _1563->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1564)));
    }
  }
  _1563->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1563->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1565 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if ((_pubthis->getSize() == (int)0))
  {
    {
      names_flushed = true;
    }
  }
  else
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          names_flushed = true;
        }
      }
      {}
    }
  }
  if ((!names_flushed))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1566 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1566->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1566->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _7423 = (int)1;
      int _7424 = _pubthis->getND();
      for (int _1567 = _7423; _1567 < _7424; ++_1567)
      {
        {
          _1566->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1567);
        }
      }
      _1566->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7425;
      bool _7426 = (_pubthis->getND() > (int)0);
      if (_7426)
      {
        _7425 = _pubthis->getShape();
      }
      else
      {
        _7425 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1565.get())->varnames(nativeidxs,_1566->toString(),_7425,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1568){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1568)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1569){
  _checked_ptr_1<int> _ptr__1569(_1569 ? _1569->raw() : nullptr, _1569 ? _1569->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1570 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1569)->size(0)))));
  _checked_ptr_1<long long> _ptr__1570(_1570 ? _1570->raw() : nullptr,_1570 ? _1570->size(0) : 0);
  int _7427 = (int)0;
  int _7428 = (int)((_1569)->size(0));
  for (int _1571 = _7427; _1571 < _7428; ++_1571)
  {
    {
      _ptr__1570[_1571] = safe_add( _ptr__1569[_1571],(int)1 );
    }
  }
  return _1570;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1572,    monty::rc_ptr< ::mosek::fusion::Model > _1573){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1572,_1573);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1572)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1572)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1572)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1572)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1572)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1574,    const std::string &  _1575,    std::shared_ptr< monty::ndarray< int,1 > > _1576,    long long _1577,    std::shared_ptr< monty::ndarray< long long,1 > > _1578,    std::shared_ptr< monty::ndarray< long long,1 > > _1579){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1576(_1576 ? _1576->raw() : nullptr, _1576 ? _1576->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1578(_1578 ? _1578->raw() : nullptr, _1578 ? _1578->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1579(_1579 ? _1579->raw() : nullptr, _1579 ? _1579->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1574,_1576,_1578,_1579);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1575;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1577;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1576;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1578;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1579;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1580,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1581) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1580,_1581); }void mosek::fusion::p_ModelVariable::elementName(long long _1580,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1581){
  std::string _7429;
  bool _7430 = ((int)((name).size()) == (int)0);
  if (_7430)
  {
    _7429 = std::string ("_");
  }
  else
  {
    _7429 = name;
  }
  _1581->__mosek_2fusion_2Utils_2StringBuffer__a(_7429)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1580))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1583){ return new mosek::fusion::NilVariable(_1583); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1583) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1583); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1583){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1583(_1583 ? _1583->raw() : nullptr, _1583 ? _1583->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1583),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _7431;
    for (int _1584 = (int)0, _7432 = (int)((_1583)->size(0)); _1584 < _7432 ; ++_1584)
    {
      _7431.push_back(_ptr__1583[_1584]);
    }
    auto _7433 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7431.size()),_7431.begin(),_7431.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _7433;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)}));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1585,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1586) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1585,_1586); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1585,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1586) { return __mosek_2fusion_2NilVariable__elementDesc(_1585,_1586); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1585,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1586){
  return _1586;
}
void mosek::fusion::NilVariable :: elementName(long long _1587,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1588) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1587,_1588); }void mosek::fusion::p_NilVariable::elementName(long long _1587,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1588){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1589,std::shared_ptr< monty::ndarray< long long,1 > > _1590,std::shared_ptr< monty::ndarray< long long,1 > > _1591) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1589,_1590,_1591); }int mosek::fusion::p_NilVariable::inst(int _1589,std::shared_ptr< monty::ndarray< long long,1 > > _1590,std::shared_ptr< monty::ndarray< long long,1 > > _1591){
  _checked_ptr_1<long long> _ptr__1590(_1590 ? _1590->raw() : nullptr, _1590 ? _1590->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1591(_1591 ? _1591->raw() : nullptr, _1591 ? _1591->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1592,std::shared_ptr< monty::ndarray< long long,1 > > _1593) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1592,_1593); }void mosek::fusion::p_NilVariable::inst(int _1592,std::shared_ptr< monty::ndarray< long long,1 > > _1593){
  _checked_ptr_1<long long> _ptr__1593(_1593 ? _1593->raw() : nullptr, _1593 ? _1593->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1594,bool _1595) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1594,_1595); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1594,bool _1595){
  _checked_ptr_1<double> _ptr__1594(_1594 ? _1594->raw() : nullptr, _1594 ? _1594->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1596,std::shared_ptr< monty::ndarray< double,1 > > _1597,bool _1598) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1596,_1597,_1598); }void mosek::fusion::p_NilVariable::values(int _1596,std::shared_ptr< monty::ndarray< double,1 > > _1597,bool _1598){
  _checked_ptr_1<double> _ptr__1597(_1597 ? _1597->raw() : nullptr, _1597 ? _1597->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1599) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1599); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__index(_1599); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__index(_1599); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1599) { return __mosek_2fusion_2NilVariable__index(_1599); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1599){
  _checked_ptr_1<int> _ptr__1599(_1599 ? _1599->raw() : nullptr, _1599 ? _1599->size(0) : 0);
  std::vector<int> _7434;
  for (int _1600 = (int)0, _7435 = (int)((shape)->size(0)); _1600 < _7435 ; ++_1600)
  {
    _7434.push_back((int)1);
  }
  auto _7436 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7434.size()),_7434.begin(),_7434.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7436)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1601) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1601); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1601) { return __mosek_2fusion_2NilVariable__index(_1601); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1601) { return __mosek_2fusion_2NilVariable__index(_1601); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1601) { return __mosek_2fusion_2NilVariable__index(_1601); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1601){
  std::vector<int> _7437;
  for (int _1602 = (int)0, _7438 = (int)((shape)->size(0)); _1602 < _7438 ; ++_1602)
  {
    _7437.push_back((int)1);
  }
  auto _7439 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7437.size()),_7437.begin(),_7437.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7439)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1603,_1604); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604) { return __mosek_2fusion_2NilVariable__slice(_1603,_1604); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604) { return __mosek_2fusion_2NilVariable__slice(_1603,_1604); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604) { return __mosek_2fusion_2NilVariable__slice(_1603,_1604); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604){
  _checked_ptr_1<int> _ptr__1603(_1603 ? _1603->raw() : nullptr, _1603 ? _1603->size(0) : 0);
  _checked_ptr_1<int> _ptr__1604(_1604 ? _1604->raw() : nullptr, _1604 ? _1604->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1603)->size(0))) || ((int)((shape)->size(0)) != (int)((_1604)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _7440 = (int)0;
  int _7441 = (int)((_1603)->size(0));
  for (int _1605 = _7440; _1605 < _7441; ++_1605)
  {
    {
      if (((_ptr__1604[_1605] > _ptr__1603[_1605]) || ((_ptr__1603[_1605] < (int)0) || (_ptr__1604[_1605] >= ((*shape)(_1605))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _7442;
  for (int _1606 = (int)0, _7443 = (int)((shape)->size(0)); _1606 < _7443 ; ++_1606)
  {
    _7442.push_back((_ptr__1604[_1606] - _ptr__1603[_1606]));
  }
  auto _7444 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7442.size()),_7442.begin(),_7442.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7444)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1607,int _1608) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1607,_1608); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1607,int _1608) { return __mosek_2fusion_2NilVariable__slice(_1607,_1608); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1607,int _1608) { return __mosek_2fusion_2NilVariable__slice(_1607,_1608); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1607,int _1608) { return __mosek_2fusion_2NilVariable__slice(_1607,_1608); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1607,int _1608){
  if (((_1608 > _1607) || ((_1607 < (int)0) || (_1608 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1608 - _1607))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1609,    monty::rc_ptr< ::mosek::fusion::Model > _1610){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1610;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1609)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1609)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1609)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1611,    std::shared_ptr< monty::ndarray< int,1 > > _1612,    std::shared_ptr< monty::ndarray< long long,1 > > _1613,    std::shared_ptr< monty::ndarray< long long,1 > > _1614){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1612(_1612 ? _1612->raw() : nullptr, _1612 ? _1612->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1613(_1613 ? _1613->raw() : nullptr, _1613 ? _1613->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1614(_1614 ? _1614->raw() : nullptr, _1614 ? _1614->size(0) : 0);
    model = _1611;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1612;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1613;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1614;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1615 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1615->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1615->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7445 = (int)1;
      int _7446 = (int)((shape)->size(0));
      for (int _1616 = _7445; _1616 < _7446; ++_1616)
      {
        {
          _1615->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1616)));
        }
      }
    }
  }
  {}
  _1615->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1615->toString();
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__eval() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::eval() { return __mosek_2fusion_2BaseVariable__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__eval(){
  return _pubthis->__mosek_2fusion_2BaseVariable__asExpr()->__mosek_2fusion_2Expression__eval();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1617,monty::rc_ptr< ::mosek::fusion::WorkStack > _1618,monty::rc_ptr< ::mosek::fusion::WorkStack > _1619) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1617,_1618,_1619); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1617,monty::rc_ptr< ::mosek::fusion::WorkStack > _1618,monty::rc_ptr< ::mosek::fusion::WorkStack > _1619){
  int _1620 = (int)((nativeidxs)->size(0));
  int _1621 = _1620;
  int _1622 = (int)((shape)->size(0));
  bool _1623 = (NULL != sparsity.get());
  _1617->alloc_expr(_1622,_1621,_1620,_1623);
  int _1624 = mosek::fusion::p_WorkStack::_get_impl(_1617)->ptr_base;
  int _1625 = mosek::fusion::p_WorkStack::_get_impl(_1617)->nidxs_base;
  int _1626 = mosek::fusion::p_WorkStack::_get_impl(_1617)->sp_base;
  int _1627 = mosek::fusion::p_WorkStack::_get_impl(_1617)->cof_base;
  int _1628 = mosek::fusion::p_WorkStack::_get_impl(_1617)->bfix_base;
  int _1629 = mosek::fusion::p_WorkStack::_get_impl(_1617)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1630 = mosek::fusion::p_WorkStack::_get_impl(_1617)->i32;
  _checked_ptr_1<int> _ptr__1630(_1630 ? _1630->raw() : nullptr,_1630 ? _1630->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1631 = mosek::fusion::p_WorkStack::_get_impl(_1617)->i64;
  _checked_ptr_1<long long> _ptr__1631(_1631 ? _1631->raw() : nullptr,_1631 ? _1631->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1632 = mosek::fusion::p_WorkStack::_get_impl(_1617)->f64;
  _checked_ptr_1<double> _ptr__1632(_1632 ? _1632->raw() : nullptr,_1632 ? _1632->size(0) : 0);
  int _7447 = (int)0;
  int _7448 = _1622;
  for (int _1633 = _7447; _1633 < _7448; ++_1633)
  {
    {
      _ptr__1630[safe_add( _1629,_1633 )] = ((*shape)(_1633));
    }
  }
  {
    int _7449 = (int)0;
    int _7450 = safe_add( _1620,(int)1 );
    for (int _1634 = _7449; _1634 < _7450; ++_1634)
    {
      {
        _ptr__1630[safe_add( _1624,_1634 )] = _1634;
      }
    }
    int _7451 = (int)0;
    int _7452 = _1620;
    for (int _1635 = _7451; _1635 < _7452; ++_1635)
    {
      {
        _ptr__1631[safe_add( _1625,_1635 )] = ((*nativeidxs)(_1635));
      }
    }
    if (_1623)
    {
      {
        int _7453 = (int)0;
        int _7454 = _1620;
        for (int _1636 = _7453; _1636 < _7454; ++_1636)
        {
          {
            _ptr__1631[safe_add( _1626,_1636 )] = ((*sparsity)(_1636));
          }
        }
      }
    }
    {}
    int _7455 = (int)0;
    int _7456 = _1620;
    for (int _1637 = _7455; _1637 < _7456; ++_1637)
    {
      {
        _ptr__1632[safe_add( _1627,_1637 )] = 1.0;
      }
    }
    int _7457 = (int)0;
    int _7458 = _1620;
    for (int _1638 = _7457; _1638 < _7458; ++_1638)
    {
      {
        _ptr__1632[safe_add( _1628,_1638 )] = 0.0;
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _1639,int _1640,int _1641) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1639,_1640,_1641); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _1639,int _1640,int _1641) { return __mosek_2fusion_2BaseVariable__reshape(_1639,_1640,_1641); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _1639,int _1640,int _1641) { return __mosek_2fusion_2BaseVariable__reshape(_1639,_1640,_1641); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _1639,int _1640,int _1641){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1639),(int)(_1640),(int)(_1641)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _1642,int _1643) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1642,_1643); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _1642,int _1643) { return __mosek_2fusion_2BaseVariable__reshape(_1642,_1643); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _1642,int _1643) { return __mosek_2fusion_2BaseVariable__reshape(_1642,_1643); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _1642,int _1643){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1642),(int)(_1643)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _1644) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _1644) { return __mosek_2fusion_2BaseVariable__reshape(_1644); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _1644) { return __mosek_2fusion_2BaseVariable__reshape(_1644); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _1644){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1644)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1645) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1645); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1645) { return __mosek_2fusion_2BaseVariable__reshape(_1645); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1645) { return __mosek_2fusion_2BaseVariable__reshape(_1645); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1645){
  _checked_ptr_1<int> _ptr__1645(_1645 ? _1645->raw() : nullptr, _1645 ? _1645->size(0) : 0);
  long long _1646 = (int)1;
  int _7459 = (int)0;
  int _7460 = (int)((_1645)->size(0));
  for (int _1647 = _7459; _1647 < _7460; ++_1647)
  {
    {
      if ((_ptr__1645[_1647] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _1646 *= _ptr__1645[_1647];
    }
  }
  if ((_1646 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _7461;
  for (int _1648 = (int)0, _7462 = (int)((_1645)->size(0)); _1648 < _7462 ; ++_1648)
  {
    _7461.push_back(_ptr__1645[_1648]);
  }
  auto _7463 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7461.size()),_7461.begin(),_7461.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_7463,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1649) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_1649); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1649){
  _checked_ptr_1<double> _ptr__1649(_1649 ? _1649->raw() : nullptr, _1649 ? _1649->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_1649)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_1649);
    }
  }
  else
  {
    {
      if (((int)((_1649)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _7464;
      for (int _1651 = (int)0, _7465 = (int)((nativeidxs)->size(0)); _1651 < _7465 ; ++_1651)
      {
        _7464.push_back(_ptr__1649[((*sparsity)(_1651))]);
      }
      auto _7466 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7464.size()),_7464.begin(),_7464.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _1650 = _7466;
      _checked_ptr_1<double> _ptr__1650(_1650 ? _1650->raw() : nullptr,_1650 ? _1650->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_1650);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _1652) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_1652); }int mosek::fusion::p_BaseVariable::getDim(int _1652){
  return ((*shape)(_1652));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _1653 = (long long)1;
  int _7467 = (int)0;
  int _7468 = (int)((shape)->size(0));
  for (int _1654 = _7467; _1654 < _7468; ++_1654)
  {
    {
      _1653 *= ((*shape)(_1654));
    }
  }
  return _1653;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1655 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1655(_1655 ? _1655->raw() : nullptr,_1655 ? _1655->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_1655,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1656 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1656(_1656 ? _1656->raw() : nullptr,_1656 ? _1656->size(0) : 0);
      int _7469 = (int)0;
      int _7470 = (int)((nativeidxs)->size(0));
      for (int _1657 = _7469; _1657 < _7470; ++_1657)
      {
        {
          _ptr__1656[((*sparsity)(_1657))] = _ptr__1655[_1657];
        }
      }
      _1655 = _1656;
      _ptr__1655.update(_1655 ? _1655->raw() : nullptr, _1655 ? _1655->size(0) : 0);
    }
  }
  {}
  return _1655;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _1658 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1658(_1658 ? _1658->raw() : nullptr,_1658 ? _1658->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_1658,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1659 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1659(_1659 ? _1659->raw() : nullptr,_1659 ? _1659->size(0) : 0);
      int _7471 = (int)0;
      int _7472 = (int)((nativeidxs)->size(0));
      for (int _1660 = _7471; _1660 < _7472; ++_1660)
      {
        {
          _ptr__1659[((*sparsity)(_1660))] = _ptr__1658[_1660];
        }
      }
      _1658 = _1659;
      _ptr__1658.update(_1658 ? _1658->raw() : nullptr, _1658 ? _1658->size(0) : 0);
    }
  }
  {}
  return _1658;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1661 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__1661(_1661 ? _1661->raw() : nullptr,_1661 ? _1661->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _7473;
      bool _7474 = (NULL == sparsity.get());
      if (_7474)
      {
        _7473 = nullptr;
      }
      else
      {
        _7473 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1662 = _7473;
      _checked_ptr_1<long long> _ptr__1662(_1662 ? _1662->raw() : nullptr,_1662 ? _1662->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _1663 = (int)0;
          int _7475 = (int)0;
          int _7476 = ((*shape)((int)1));
          for (int _1664 = _7475; _1664 < _7476; ++_1664)
          {
            {
              int _7477 = (int)0;
              int _7478 = ((*shape)((int)0));
              for (int _1665 = _7477; _1665 < _7478; ++_1665)
              {
                {
                  _ptr__1661[_1663] = ((*nativeidxs)(safe_add( safe_mul( _1665,((*shape)((int)1)) ),_1664 )));
                  ++ _1663;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1666 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__1666(_1666 ? _1666->raw() : nullptr,_1666 ? _1666->size(0) : 0);
          int _1667 = ((*shape)((int)0));
          int _1668 = ((*shape)((int)1));
          int _7479 = (int)0;
          int _7480 = (int)((sparsity)->size(0));
          for (int _1669 = _7479; _1669 < _7480; ++_1669)
          {
            {
              ++ _ptr__1666[safe_add( (((*sparsity)(_1669)) % _1668),(int)1 )];
            }
          }
          int _7481 = (int)0;
          int _7482 = _1668;
          for (int _1670 = _7481; _1670 < _7482; ++_1670)
          {
            {
              _ptr__1666[safe_add( _1670,(int)1 )] += _ptr__1666[_1670];
            }
          }
          int _7483 = (int)0;
          int _7484 = (int)((sparsity)->size(0));
          for (int _1671 = _7483; _1671 < _7484; ++_1671)
          {
            {
              long long _1672 = (((*sparsity)(_1671)) % _1668);
              _ptr__1661[_ptr__1666[_1672]] = ((*nativeidxs)(_1671));
              _ptr__1662[_ptr__1666[_1672]] = safe_add( (((*sparsity)(_1671)) / _1668),safe_mul( (((*sparsity)(_1671)) % _1668),_1667 ) );
              ++ _ptr__1666[_1672];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_1662,_1661)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1673,int _1674,int _1675) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1673,_1674,_1675); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1673,int _1674,int _1675) { return __mosek_2fusion_2BaseVariable__index(_1673,_1674,_1675); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1673,int _1674,int _1675) { return __mosek_2fusion_2BaseVariable__index(_1673,_1674,_1675); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1673,int _1674,int _1675){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1673),(int)(_1674),(int)(_1675)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1676,int _1677) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1676,_1677); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1676,int _1677) { return __mosek_2fusion_2BaseVariable__index(_1676,_1677); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1676,int _1677) { return __mosek_2fusion_2BaseVariable__index(_1676,_1677); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1676,int _1677){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1676),(int)(_1677)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1678); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return __mosek_2fusion_2BaseVariable__index(_1678); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1678) { return __mosek_2fusion_2BaseVariable__index(_1678); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1678){
  _checked_ptr_1<int> _ptr__1678(_1678 ? _1678->raw() : nullptr, _1678 ? _1678->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1679 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_1678)->size(0)))));
  int _7485 = (int)0;
  int _7486 = (int)((_1678)->size(0));
  for (int _1680 = _7485; _1680 < _7486; ++_1680)
  {
    {
      ((*_1679)((int)0,_1680)) = _ptr__1678[_1680];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1679)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1681) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1681); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1681) { return __mosek_2fusion_2BaseVariable__index(_1681); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1681) { return __mosek_2fusion_2BaseVariable__index(_1681); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1681){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1681)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1682,std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1682,_1683,_1684); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1682,std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684) { return __mosek_2fusion_2BaseVariable__pick(_1682,_1683,_1684); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1682,std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684) { return __mosek_2fusion_2BaseVariable__pick(_1682,_1683,_1684); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1682,std::shared_ptr< monty::ndarray< int,1 > > _1683,std::shared_ptr< monty::ndarray< int,1 > > _1684){
  _checked_ptr_1<int> _ptr__1682(_1682 ? _1682->raw() : nullptr, _1682 ? _1682->size(0) : 0);
  _checked_ptr_1<int> _ptr__1683(_1683 ? _1683->raw() : nullptr, _1683 ? _1683->size(0) : 0);
  _checked_ptr_1<int> _ptr__1684(_1684 ? _1684->raw() : nullptr, _1684 ? _1684->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_1682)->size(0)) != (int)((_1683)->size(0))) || ((int)((_1682)->size(0)) != (int)((_1684)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1685 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1682)->size(0)),(int)3)));
  int _7487 = (int)0;
  int _7488 = (int)((_1682)->size(0));
  for (int _1686 = _7487; _1686 < _7488; ++_1686)
  {
    {
      ((*_1685)(_1686,(int)0)) = _ptr__1682[_1686];
      ((*_1685)(_1686,(int)1)) = _ptr__1683[_1686];
      ((*_1685)(_1686,(int)2)) = _ptr__1684[_1686];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1685);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1687,std::shared_ptr< monty::ndarray< int,1 > > _1688) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1687,_1688); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1687,std::shared_ptr< monty::ndarray< int,1 > > _1688) { return __mosek_2fusion_2BaseVariable__pick(_1687,_1688); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1687,std::shared_ptr< monty::ndarray< int,1 > > _1688) { return __mosek_2fusion_2BaseVariable__pick(_1687,_1688); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1687,std::shared_ptr< monty::ndarray< int,1 > > _1688){
  _checked_ptr_1<int> _ptr__1687(_1687 ? _1687->raw() : nullptr, _1687 ? _1687->size(0) : 0);
  _checked_ptr_1<int> _ptr__1688(_1688 ? _1688->raw() : nullptr, _1688 ? _1688->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_1687)->size(0)) != (int)((_1688)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1689 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1687)->size(0)),(int)2)));
  int _7489 = (int)0;
  int _7490 = (int)((_1687)->size(0));
  for (int _1690 = _7489; _1690 < _7490; ++_1690)
  {
    {
      ((*_1689)(_1690,(int)0)) = _ptr__1687[_1690];
      ((*_1689)(_1690,(int)1)) = _ptr__1688[_1690];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1689);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1691) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1691); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1691) { return __mosek_2fusion_2BaseVariable__pick(_1691); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1691) { return __mosek_2fusion_2BaseVariable__pick(_1691); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1691){
  if (((int)((shape)->size(0)) != (int)((_1691)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  bool _1692 = false;
  int _7491 = (int)0;
  int _7492 = (int)((_1691)->size(0));
  for (int _1693 = _7491; _1693 < _7492; ++_1693)
  {
    {
      int _7493 = (int)0;
      int _7494 = (int)((_1691)->size(1));
      for (int _1694 = _7493; _1694 < _7494; ++_1694)
      {
        {
          if (((((*_1691)(_1693,_1694)) < (int)0) || (((*_1691)(_1693,_1694)) >= ((*shape)(_1694)))))
          {
            {
              _1692 = true;
            }
          }
          {}
        }
      }
    }
  }
  if (_1692)
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _1695 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1696 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1695)));
  _checked_ptr_1<long long> _ptr__1696(_1696 ? _1696->raw() : nullptr,_1696 ? _1696->size(0) : 0);
  _ptr__1696[(_1695 - (int)1)] = (int)1;
  int _7495 = (int)1;
  int _7496 = _1695;
  for (int _1697 = _7495; _1697 < _7496; ++_1697)
  {
    {
      _ptr__1696[((_1695 - _1697) - (int)1)] = safe_mul( _ptr__1696[(_1695 - _1697)],((*shape)((_1695 - _1697))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1698 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1691)->size(0)))});
  _checked_ptr_1<int> _ptr__1698(_1698 ? _1698->raw() : nullptr,_1698 ? _1698->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1699;
  _checked_ptr_1<long long> _ptr__1699(_1699 ? _1699->raw() : nullptr,_1699 ? _1699->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1700 = nullptr;
  _checked_ptr_1<long long> _ptr__1700(_1700 ? _1700->raw() : nullptr,_1700 ? _1700->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _1699 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1691)->size(0)))));
      _ptr__1699.update(_1699 ? _1699->raw() : nullptr, _1699 ? _1699->size(0) : 0);
      {
        int _7497 = (int)0;
        int _7498 = (int)((_1691)->size(0));
        for (int _1701 = _7497; _1701 < _7498; ++_1701)
        {
          {
            long long _1702 = (long long)0;
            int _7499 = (int)0;
            int _7500 = _1695;
            for (int _1703 = _7499; _1703 < _7500; ++_1703)
            {
              {
                _1702 += safe_mul( _ptr__1696[_1703],((*_1691)(_1701,_1703)) );
              }
            }
            _ptr__1699[_1701] = ((*nativeidxs)(_1702));
          }
        }
      }
    }
  }
  else
  {
    {
      int _1704 = (int)0;
      int _7501 = (int)0;
      int _7502 = (int)((_1691)->size(0));
      for (int _1705 = _7501; _1705 < _7502; ++_1705)
      {
        {
          long long _1706 = (long long)0;
          int _7503 = (int)0;
          int _7504 = _1695;
          for (int _1707 = _7503; _1707 < _7504; ++_1707)
          {
            {
              _1706 += safe_mul( _ptr__1696[_1707],((*_1691)(_1705,_1707)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1706) >= (int)0))
          {
            {
              ++ _1704;
            }
          }
          {}
        }
      }
      _1699 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1704)));
      _ptr__1699.update(_1699 ? _1699->raw() : nullptr, _1699 ? _1699->size(0) : 0);
      _1700 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1704)));
      _ptr__1700.update(_1700 ? _1700->raw() : nullptr, _1700 ? _1700->size(0) : 0);
      {
        int _1708 = (int)0;
        int _7505 = (int)0;
        int _7506 = (int)((_1691)->size(0));
        for (int _1709 = _7505; _1709 < _7506; ++_1709)
        {
          {
            long long _1710 = (long long)0;
            int _7507 = (int)0;
            int _7508 = _1695;
            for (int _1711 = _7507; _1711 < _7508; ++_1711)
            {
              {
                _1710 += safe_mul( _ptr__1696[_1711],((*_1691)(_1709,_1711)) );
              }
            }
            int _1712 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1710);
            if ((_1712 >= (int)0))
            {
              {
                _ptr__1699[_1708] = ((*nativeidxs)(_1712));
                _ptr__1700[_1708] = _1709;
                ++ _1708;
              }
            }
            {}
          }
        }
      }
      if ((_1704 == (int)((_1691)->size(0))))
      {
        {
          _1700 = nullptr;
          _ptr__1700.update(_1700 ? _1700->raw() : nullptr, _1700 ? _1700->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1698,_1700,_1699)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1713) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1713); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1713) { return __mosek_2fusion_2BaseVariable__pick(_1713); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1713) { return __mosek_2fusion_2BaseVariable__pick(_1713); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1713){
  _checked_ptr_1<int> _ptr__1713(_1713 ? _1713->raw() : nullptr, _1713 ? _1713->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  bool _1714 = false;
  int _7509 = (int)0;
  int _7510 = (int)((_1713)->size(0));
  for (int _1715 = _7509; _1715 < _7510; ++_1715)
  {
    {
      if (((_ptr__1713[_1715] < (int)0) || (_ptr__1713[_1715] >= ((*shape)((int)0)))))
      {
        {
          _1714 = true;
        }
      }
      {}
    }
  }
  if (_1714)
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< long long,1 > > _1716;
  _checked_ptr_1<long long> _ptr__1716(_1716 ? _1716->raw() : nullptr,_1716 ? _1716->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1717 = nullptr;
  _checked_ptr_1<long long> _ptr__1717(_1717 ? _1717->raw() : nullptr,_1717 ? _1717->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _7511;
      for (int _1718 = (int)0, _7512 = (int)((_1713)->size(0)); _1718 < _7512 ; ++_1718)
      {
        _7511.push_back(((*nativeidxs)(_ptr__1713[_1718])));
      }
      auto _7513 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7511.size()),_7511.begin(),_7511.end()));
      _1716 = _7513;
      _ptr__1716.update(_1716 ? _1716->raw() : nullptr, _1716 ? _1716->size(0) : 0);
    }
  }
  else
  {
    {
      int _1719 = (int)0;
      int _7514 = (int)0;
      int _7515 = (int)((_1713)->size(0));
      for (int _1720 = _7514; _1720 < _7515; ++_1720)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1713[_1720])) >= (int)0))
          {
            {
              ++ _1719;
            }
          }
          {}
        }
      }
      _1716 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1719)));
      _ptr__1716.update(_1716 ? _1716->raw() : nullptr, _1716 ? _1716->size(0) : 0);
      _1717 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1719)));
      _ptr__1717.update(_1717 ? _1717->raw() : nullptr, _1717 ? _1717->size(0) : 0);
      int _1721 = (int)0;
      int _7516 = (int)0;
      int _7517 = (int)((_1713)->size(0));
      for (int _1722 = _7516; _1722 < _7517; ++_1722)
      {
        {
          int _1723 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1713[_1722]));
          if ((_1723 >= (int)0))
          {
            {
              _ptr__1717[_1721] = _1722;
              _ptr__1716[_1721] = ((*nativeidxs)(_1723));
              ++ _1721;
            }
          }
          {}
        }
      }
      if ((_1719 == (int)((_1713)->size(0))))
      {
        {
          _1717 = nullptr;
          _ptr__1717.update(_1717 ? _1717->raw() : nullptr, _1717 ? _1717->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1713)->size(0)))}),_1717,_1716)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _1724) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_1724); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _1724) { return __mosek_2fusion_2BaseVariable__antidiag(_1724); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _1724) { return __mosek_2fusion_2BaseVariable__antidiag(_1724); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1724){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_1724 >= ((*shape)((int)1))) || ((-_1724) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1724 >= (int)0))
  {
    {
      int _7518;
      bool _7519 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1724));
      if (_7519)
      {
        _7518 = ((*shape)((int)0));
      }
      else
      {
        _7518 = (((*shape)((int)1)) - _1724);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _1724))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7518);
    }
  }
  else
  {
    {
      int _7520;
      bool _7521 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1724 ));
      if (_7521)
      {
        _7520 = ((*shape)((int)1));
      }
      else
      {
        _7520 = safe_add( ((*shape)((int)0)),_1724 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1724)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7520);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7522;
  bool _7523 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7523)
  {
    _7522 = ((*shape)((int)0));
  }
  else
  {
    _7522 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7522);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _1725) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_1725); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _1725) { return __mosek_2fusion_2BaseVariable__diag(_1725); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _1725) { return __mosek_2fusion_2BaseVariable__diag(_1725); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _1725){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_1725 >= ((*shape)((int)1))) || ((-_1725) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1725 >= (int)0))
  {
    {
      int _7524;
      bool _7525 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1725));
      if (_7525)
      {
        _7524 = ((*shape)((int)0));
      }
      else
      {
        _7524 = (((*shape)((int)1)) - _1725);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_1725)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7524);
    }
  }
  else
  {
    {
      int _7526;
      bool _7527 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1725 ));
      if (_7527)
      {
        _7526 = ((*shape)((int)1));
      }
      else
      {
        _7526 = safe_add( ((*shape)((int)0)),_1725 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1725)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7526);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7528;
  bool _7529 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7529)
  {
    _7528 = ((*shape)((int)0));
  }
  else
  {
    _7528 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7528);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1726,std::shared_ptr< monty::ndarray< int,1 > > _1727,int _1728){
  _checked_ptr_1<int> _ptr__1726(_1726 ? _1726->raw() : nullptr, _1726 ? _1726->size(0) : 0);
  _checked_ptr_1<int> _ptr__1727(_1727 ? _1727->raw() : nullptr, _1727 ? _1727->size(0) : 0);
  int _1729 = (int)((shape)->size(0));
  if (((_1729 != (int)((_1726)->size(0))) || (_1729 != (int)((_1727)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _7530 = (int)0;
  int _7531 = _1729;
  for (int _1730 = _7530; _1730 < _7531; ++_1730)
  {
    {
      if (((_ptr__1726[_1730] < (int)0) || (_ptr__1726[_1730] >= ((*shape)(_1730)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1731 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1729)));
  _checked_ptr_1<long long> _ptr__1731(_1731 ? _1731->raw() : nullptr,_1731 ? _1731->size(0) : 0);
  _ptr__1731[(_1729 - (int)1)] = (int)1;
  int _7532 = (int)1;
  int _7533 = _1729;
  for (int _1732 = _7532; _1732 < _7533; ++_1732)
  {
    {
      _ptr__1731[((_1729 - _1732) - (int)1)] = safe_mul( _ptr__1731[(_1729 - _1732)],((*shape)((_1729 - _1732))) );
    }
  }
  long long _1733 = (long long)0;
  int _7534 = (int)0;
  int _7535 = (int)((_1727)->size(0));
  for (int _1734 = _7534; _1734 < _7535; ++_1734)
  {
    {
      _1733 += safe_mul( _ptr__1726[_1734],_ptr__1731[_1734] );
    }
  }
  long long _1735 = (long long)0;
  int _7536 = (int)0;
  int _7537 = (int)((_1727)->size(0));
  for (int _1736 = _7536; _1736 < _7537; ++_1736)
  {
    {
      _1735 += safe_mul( _ptr__1727[_1736],_ptr__1731[_1736] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1737 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1728)));
      _checked_ptr_1<long long> _ptr__1737(_1737 ? _1737->raw() : nullptr,_1737 ? _1737->size(0) : 0);
      int _7538 = (int)0;
      int _7539 = _1728;
      for (int _1738 = _7538; _1738 < _7539; ++_1738)
      {
        {
          _ptr__1737[_1738] = ((*nativeidxs)(safe_add( _1733,safe_mul( _1735,_1738 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1728)}),nullptr,_1737)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1739 = (int)0;
      int _7540 = (int)0;
      int _7541 = _1728;
      for (int _1740 = _7540; _1740 < _7541; ++_1740)
      {
        {
          long long _1741 = safe_add( _1733,safe_mul( _1735,_1740 ) );
          int _1742 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1741);
          if ((_1742 >= (int)0))
          {
            {
              ++ _1739;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1743 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1739)));
      _checked_ptr_1<long long> _ptr__1743(_1743 ? _1743->raw() : nullptr,_1743 ? _1743->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1744 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1739)));
      _checked_ptr_1<long long> _ptr__1744(_1744 ? _1744->raw() : nullptr,_1744 ? _1744->size(0) : 0);
      int _1745 = (int)0;
      int _7542 = (int)0;
      int _7543 = _1728;
      for (int _1746 = _7542; _1746 < _7543; ++_1746)
      {
        {
          _ptr__1743[_1746] = ((*nativeidxs)(safe_add( _1733,safe_mul( _1735,_1746 ) )));
          long long _1747 = safe_add( _1733,safe_mul( _1735,_1746 ) );
          int _1748 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1747);
          if ((_1748 >= (int)0))
          {
            {
              _ptr__1744[_1745] = _1746;
              _ptr__1743[_1745] = ((*nativeidxs)(_1748));
              ++ _1745;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1728)}),_1744,_1743)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1749,std::shared_ptr< monty::ndarray< int,1 > > _1750) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1749,_1750); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1749,std::shared_ptr< monty::ndarray< int,1 > > _1750) { return __mosek_2fusion_2BaseVariable__slice(_1749,_1750); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1749,std::shared_ptr< monty::ndarray< int,1 > > _1750) { return __mosek_2fusion_2BaseVariable__slice(_1749,_1750); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1749,std::shared_ptr< monty::ndarray< int,1 > > _1750){
  _checked_ptr_1<int> _ptr__1749(_1749 ? _1749->raw() : nullptr, _1749 ? _1749->size(0) : 0);
  _checked_ptr_1<int> _ptr__1750(_1750 ? _1750->raw() : nullptr, _1750 ? _1750->size(0) : 0);
  if (((int)((_1749)->size(0)) != (int)((_1750)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_1749)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7544 = (int)0;
      int _7545 = (int)((shape)->size(0));
      for (int _1751 = _7544; _1751 < _7545; ++_1751)
      {
        {
          if (((_ptr__1749[_1751] < (int)0) || (_ptr__1750[_1751] > ((*shape)(_1751)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__1749[_1751] > _ptr__1750[_1751]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _1752 = (int)((shape)->size(0));
      std::vector<int> _7546;
      for (int _1754 = (int)0, _7547 = _1752; _1754 < _7547 ; ++_1754)
      {
        _7546.push_back((_ptr__1750[_1754] - _ptr__1749[_1754]));
      }
      auto _7548 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7546.size()),_7546.begin(),_7546.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1753 = _7548;
      _checked_ptr_1<int> _ptr__1753(_1753 ? _1753->raw() : nullptr,_1753 ? _1753->size(0) : 0);
      int _1755 = (int)1;
      int _7549 = (int)0;
      int _7550 = _1752;
      for (int _1756 = _7549; _1756 < _7550; ++_1756)
      {
        {
          _1755 *= (_ptr__1750[_1756] - _ptr__1749[_1756]);
        }
      }
      if ((_1755 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _1757 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _1758 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1752)));
          _checked_ptr_1<int> _ptr__1758(_1758 ? _1758->raw() : nullptr,_1758 ? _1758->size(0) : 0);
          int _7551 = (int)0;
          int _7552 = (int)((sparsity)->size(0));
          for (int _1759 = _7551; _1759 < _7552; ++_1759)
          {
            {
              long long _1760 = ((*sparsity)(_1759));
              int _7553 = (int)1;
              int _7554 = _1752;
              for (int _1761 = _7553; _1761 < _7554; ++_1761)
              {
                {
                  _ptr__1758[(_1752 - _1761)] = (int)(_1760 % ((*shape)((_1752 - _1761))));
                  _1760 /= ((*shape)((_1752 - _1761)));
                }
              }
              _ptr__1758[(int)0] = (int)_1760;
              int _1762 = (int)0;
              while ( ((_ptr__1758[_1762] >= _ptr__1749[_1762]) && (_ptr__1758[_1762] < _ptr__1750[_1762])) )
              {
                {
                  ++ _1762;
                }
              }
              if ((_1762 == _1752))
              {
                {
                  ++ _1757;
                }
              }
              {}
            }
          }
          int _1763 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _1764 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1757)));
          _checked_ptr_1<long long> _ptr__1764(_1764 ? _1764->raw() : nullptr,_1764 ? _1764->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1765 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1757)));
          _checked_ptr_1<long long> _ptr__1765(_1765 ? _1765->raw() : nullptr,_1765 ? _1765->size(0) : 0);
          int _7555 = (int)0;
          int _7556 = (int)((sparsity)->size(0));
          for (int _1766 = _7555; _1766 < _7556; ++_1766)
          {
            {
              long long _1767 = ((*sparsity)(_1766));
              int _7557 = (int)1;
              int _7558 = _1752;
              for (int _1768 = _7557; _1768 < _7558; ++_1768)
              {
                {
                  _ptr__1758[(_1752 - _1768)] = (int)(_1767 % ((*shape)((_1752 - _1768))));
                  _1767 /= ((*shape)((_1752 - _1768)));
                }
              }
              _ptr__1758[(int)0] = (int)_1767;
              int _1769 = (int)0;
              while ( ((_ptr__1758[_1769] >= _ptr__1749[_1769]) && (_ptr__1758[_1769] < _ptr__1750[_1769])) )
              {
                {
                  ++ _1769;
                }
              }
              if ((_1769 == _1752))
              {
                {
                  _ptr__1764[_1763] = ((*nativeidxs)(_1766));
                  int _1770 = (int)0;
                  int _7559 = (int)0;
                  int _7560 = _1752;
                  for (int _1771 = _7559; _1771 < _7560; ++_1771)
                  {
                    {
                      _1770 = safe_add( safe_mul( _1770,_ptr__1753[_1771] ),(_ptr__1758[_1771] - _ptr__1749[_1771]) );
                    }
                  }
                  _ptr__1765[_1763] = _1770;
                  ++ _1763;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1753,_1765,_1764)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1772 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1755)));
          _checked_ptr_1<long long> _ptr__1772(_1772 ? _1772->raw() : nullptr,_1772 ? _1772->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _1773 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1752)));
            _checked_ptr_1<int> _ptr__1773(_1773 ? _1773->raw() : nullptr,_1773 ? _1773->size(0) : 0);
            _ptr__1773[(_1752 - (int)1)] = (int)1;
            int _7561 = (int)1;
            int _7562 = _1752;
            for (int _1774 = _7561; _1774 < _7562; ++_1774)
            {
              {
                _ptr__1773[((_1752 - _1774) - (int)1)] = safe_mul( _ptr__1773[(_1752 - _1774)],((*shape)((_1752 - _1774))) );
              }
            }
            int _1775 = (int)0;
            int _7563 = (int)0;
            int _7564 = _1752;
            for (int _1776 = _7563; _1776 < _7564; ++_1776)
            {
              {
                _1775 += safe_mul( _ptr__1749[_1776],_ptr__1773[_1776] );
              }
            }
            std::vector<int> _7565;
            for (int _1778 = (int)0, _7566 = _1752; _1778 < _7566 ; ++_1778)
            {
              _7565.push_back(_1775);
            }
            auto _7567 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7565.size()),_7565.begin(),_7565.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1777 = _7567;
            _checked_ptr_1<int> _ptr__1777(_1777 ? _1777->raw() : nullptr,_1777 ? _1777->size(0) : 0);
            std::vector<int> _7568;
            for (int _1780 = (int)0, _7569 = _1752; _1780 < _7569 ; ++_1780)
            {
              _7568.push_back(_ptr__1749[_1780]);
            }
            auto _7570 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7568.size()),_7568.begin(),_7568.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1779 = _7570;
            _checked_ptr_1<int> _ptr__1779(_1779 ? _1779->raw() : nullptr,_1779 ? _1779->size(0) : 0);
            int _7571 = (int)0;
            int _7572 = _1755;
            for (int _1781 = _7571; _1781 < _7572; ++_1781)
            {
              {
                _ptr__1772[_1781] = ((*nativeidxs)(_ptr__1777[(_1752 - (int)1)]));
                _ptr__1779[(_1752 - (int)1)] += (int)1;
                _ptr__1777[(_1752 - (int)1)] += _ptr__1773[(_1752 - (int)1)];
                if ((_ptr__1779[(_1752 - (int)1)] >= _ptr__1750[(_1752 - (int)1)]))
                {
                  {
                    int _1782 = (_1752 - (int)1);
                    while ( ((_1782 > (int)0) && (_ptr__1779[_1782] >= _ptr__1750[_1782])) )
                    {
                      {
                        _ptr__1779[_1782] = _ptr__1749[_1782];
                        _ptr__1779[(_1782 - (int)1)] += (int)1;
                        _ptr__1777[(_1782 - (int)1)] += _ptr__1773[(_1782 - (int)1)];
                        -- _1782;
                      }
                    }
                    int _7573 = safe_add( _1782,(int)1 );
                    int _7574 = _1752;
                    for (int _1783 = _7573; _1783 < _7574; ++_1783)
                    {
                      {
                        _ptr__1777[_1783] = _ptr__1777[_1782];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1753,nullptr,_1772)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _1784,int _1785) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1784,_1785); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _1784,int _1785) { return __mosek_2fusion_2BaseVariable__slice(_1784,_1785); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _1784,int _1785) { return __mosek_2fusion_2BaseVariable__slice(_1784,_1785); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _1784,int _1785){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_1784 == (int)0) && (_1785 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_1784 < (int)0) || (_1785 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_1784 > _1785))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_1784 == _1785))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _1786 = (_1785 - _1784);
      int _1787 = (int)0;
      int _1788 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1784));
      int _1789 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1785));
      std::vector<long long> _7575;
      for (int _1790 = _1788, _7576 = _1789; _1790 < _7576 ; ++_1790)
      {
        _7575.push_back((((*sparsity)(_1790)) - _1784));
      }
      auto _7577 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7575.size()),_7575.begin(),_7575.end()));
      std::vector<long long> _7578;
      for (int _1791 = _1788, _7579 = _1789; _1791 < _7579 ; ++_1791)
      {
        _7578.push_back(((*nativeidxs)(_1791)));
      }
      auto _7580 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7578.size()),_7578.begin(),_7578.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1786)}),_7577,_7580)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1792 = (_1785 - _1784);
      std::shared_ptr< monty::ndarray< long long,1 > > _1793 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1792)));
      _checked_ptr_1<long long> _ptr__1793(_1793 ? _1793->raw() : nullptr,_1793 ? _1793->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_1784,_1793,(int)0,_1792);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1792)}),nullptr,_1793)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _1794,std::shared_ptr< monty::ndarray< long long,1 > > _1795,int _1796,std::shared_ptr< monty::ndarray< long long,1 > > _1797) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1794,_1795,_1796,_1797); }int mosek::fusion::p_BaseVariable::inst(int _1794,std::shared_ptr< monty::ndarray< long long,1 > > _1795,int _1796,std::shared_ptr< monty::ndarray< long long,1 > > _1797){
  _checked_ptr_1<long long> _ptr__1795(_1795 ? _1795->raw() : nullptr, _1795 ? _1795->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1797(_1797 ? _1797->raw() : nullptr, _1797 ? _1797->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1798 = mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs;
  _checked_ptr_1<long long> _ptr__1798(_1798 ? _1798->raw() : nullptr,_1798 ? _1798->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1799 = mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity;
  _checked_ptr_1<long long> _ptr__1799(_1799 ? _1799->raw() : nullptr,_1799 ? _1799->size(0) : 0);
  if ((NULL == _1799.get()))
  {
    {
      int _7581 = (int)0;
      int _7582 = (int)((_1798)->size(0));
      for (int _1800 = _7581; _1800 < _7582; ++_1800)
      {
        {
          _ptr__1795[safe_add( _1800,_1794 )] = _1800;
          _ptr__1797[safe_add( _1800,_1796 )] = _ptr__1798[_1800];
        }
      }
    }
  }
  else
  {
    {
      int _7583 = (int)0;
      int _7584 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _1801 = _7583; _1801 < _7584; ++_1801)
      {
        {
          _ptr__1795[safe_add( _1794,_1801 )] = _ptr__1799[_1801];
          _ptr__1797[safe_add( _1801,_1796 )] = _ptr__1798[_1801];
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _1802,std::shared_ptr< monty::ndarray< long long,1 > > _1803) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1802,_1803); }void mosek::fusion::p_BaseVariable::inst(int _1802,std::shared_ptr< monty::ndarray< long long,1 > > _1803){
  _checked_ptr_1<long long> _ptr__1803(_1803 ? _1803->raw() : nullptr, _1803 ? _1803->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _7585 = (int)0;
      int _7586 = (int)((nativeidxs)->size(0));
      for (int _1804 = _7585; _1804 < _7586; ++_1804)
      {
        {
          _ptr__1803[safe_add( _1802,_1804 )] = ((*nativeidxs)(_1804));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1805 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__1805(_1805 ? _1805->raw() : nullptr,_1805 ? _1805->size(0) : 0);
      int _1806 = (int)1;
      int _7587 = (int)0;
      int _7588 = (int)((_1805)->size(0));
      for (int _1807 = _7587; _1807 < _7588; ++_1807)
      {
        {
          _1806 *= _ptr__1805[_1807];
        }
      }
      int _7589 = (int)0;
      int _7590 = _1806;
      for (int _1808 = _7589; _1808 < _7590; ++_1808)
      {
        {
          _ptr__1803[safe_add( _1802,_1808 )] = (int)0;
        }
      }
      int _7591 = (int)0;
      int _7592 = (int)((sparsity)->size(0));
      for (int _1809 = _7591; _1809 < _7592; ++_1809)
      {
        {
          _ptr__1803[safe_add( _1802,((*sparsity)(_1809)) )] = ((*nativeidxs)(_1809));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1810,bool _1811) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_1810,_1811); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1810,bool _1811){
  _checked_ptr_1<double> _ptr__1810(_1810 ? _1810->raw() : nullptr, _1810 ? _1810->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1811,nativeidxs,_1810);
    }
  }
  else
  {
    {
      int _1812 = (int)1;
      int _7593 = (int)0;
      int _7594 = (int)((shape)->size(0));
      for (int _1813 = _7593; _1813 < _7594; ++_1813)
      {
        {
          _1812 *= ((*shape)(_1813));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1814 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1812)));
      _checked_ptr_1<long long> _ptr__1814(_1814 ? _1814->raw() : nullptr,_1814 ? _1814->size(0) : 0);
      int _7595 = (int)0;
      int _7596 = (int)((nativeidxs)->size(0));
      for (int _1815 = _7595; _1815 < _7596; ++_1815)
      {
        {
          _ptr__1814[((*sparsity)(_1815))] = ((*nativeidxs)(_1815));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1811,_1814,_1810);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _1816,std::shared_ptr< monty::ndarray< double,1 > > _1817,bool _1818){
  _checked_ptr_1<double> _ptr__1817(_1817 ? _1817->raw() : nullptr, _1817 ? _1817->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_1818,nativeidxs,_1817,_1816);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1819 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1819(_1819 ? _1819->raw() : nullptr,_1819 ? _1819->size(0) : 0);
      int _7597 = (int)0;
      int _7598 = (int)((sparsity)->size(0));
      for (int _1820 = _7597; _1820 < _7598; ++_1820)
      {
        {
          _ptr__1819[((*sparsity)(_1820))] = ((*nativeidxs)(_1820));
        }
      }
      model->getVariableDuals(_1818,_1819,_1817,_1816);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _1821,std::shared_ptr< monty::ndarray< double,1 > > _1822,bool _1823) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_1821,_1822,_1823); }void mosek::fusion::p_BaseVariable::values(int _1821,std::shared_ptr< monty::ndarray< double,1 > > _1822,bool _1823){
  _checked_ptr_1<double> _ptr__1822(_1822 ? _1822->raw() : nullptr, _1822 ? _1822->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_1823,nativeidxs,_1822,_1821);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1824 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1824(_1824 ? _1824->raw() : nullptr,_1824 ? _1824->size(0) : 0);
      int _7599 = (int)0;
      int _7600 = (int)((sparsity)->size(0));
      for (int _1825 = _7599; _1825 < _7600; ++_1825)
      {
        {
          _ptr__1824[((*sparsity)(_1825))] = ((*nativeidxs)(_1825));
        }
      }
      model->getVariableValues(_1823,_1824,_1822,_1821);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _1833,int _1834,int _1835) { return __mosek_2fusion_2Variable__reshape(_1833,_1834,_1835); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _1836,int _1837) { return __mosek_2fusion_2Variable__reshape(_1836,_1837); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _1838) { return __mosek_2fusion_2Variable__reshape(_1838); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1839) { return __mosek_2fusion_2Variable__reshape(_1839); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1845,std::shared_ptr< monty::ndarray< int,1 > > _1846,std::shared_ptr< monty::ndarray< int,1 > > _1847) { return __mosek_2fusion_2Variable__pick(_1845,_1846,_1847); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1848,std::shared_ptr< monty::ndarray< int,1 > > _1849) { return __mosek_2fusion_2Variable__pick(_1848,_1849); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _1850) { return __mosek_2fusion_2Variable__pick(_1850); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1850) { return __mosek_2fusion_2Variable__pick(_1850); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _1851) { return __mosek_2fusion_2Variable__pick(_1851); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1851) { return __mosek_2fusion_2Variable__pick(_1851); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _1852) { return __mosek_2fusion_2Variable__antidiag(_1852); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _1853) { return __mosek_2fusion_2Variable__diag(_1853); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _1854) { return __mosek_2fusion_2Variable__index(_1854); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _1854) { return __mosek_2fusion_2Variable__index(_1854); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1855,int _1856,int _1857) { return __mosek_2fusion_2Variable__index(_1855,_1856,_1857); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1858,int _1859) { return __mosek_2fusion_2Variable__index(_1858,_1859); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _1860) { return __mosek_2fusion_2Variable__index(_1860); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1860) { return __mosek_2fusion_2Variable__index(_1860); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _1861,std::shared_ptr< monty::ndarray< int,1 > > _1862) { return __mosek_2fusion_2Variable__slice(_1861,_1862); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1861,std::shared_ptr< monty::ndarray< int,1 > > _1862) { return __mosek_2fusion_2Variable__slice(_1861,_1862); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _1863,int _1864) { return __mosek_2fusion_2Variable__slice(_1863,_1864); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _1863,int _1864) { return __mosek_2fusion_2Variable__slice(_1863,_1864); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _1865) { return mosek::fusion::p_Var::empty(_1865); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _1865){
  _checked_ptr_1<int> _ptr__1865(_1865 ? _1865->raw() : nullptr, _1865 ? _1865->size(0) : 0);
  int _7601 = (int)0;
  int _7602 = (int)((_1865)->size(0));
  for (int _1866 = _7601; _1866 < _7602; ++_1866)
  {
    {
      if ((_ptr__1865[_1866] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_1865)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _1867) { return mosek::fusion::p_Var::compress(_1867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _1867){
  std::shared_ptr< monty::ndarray< int,1 > > _1868 = _1867->getShape();
  _checked_ptr_1<int> _ptr__1868(_1868 ? _1868->raw() : nullptr,_1868 ? _1868->size(0) : 0);
  int _1869 = (int)((_1868)->size(0));
  int _1870 = (int)0;
  int _7603 = (int)0;
  int _7604 = _1869;
  for (int _1871 = _7603; _1871 < _7604; ++_1871)
  {
    {
      if ((_ptr__1868[_1871] != (int)1))
      {
        {
          ++ _1870;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1872 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1870)));
  _checked_ptr_1<int> _ptr__1872(_1872 ? _1872->raw() : nullptr,_1872 ? _1872->size(0) : 0);
  {
    int _1873 = (int)0;
    int _7605 = (int)0;
    int _7606 = _1869;
    for (int _1874 = _7605; _1874 < _7606; ++_1874)
    {
      {
        if ((_ptr__1868[_1874] != (int)1))
        {
          {
            _ptr__1872[_1873] = _ptr__1868[_1874];
            ++ _1873;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_1867,_1872);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1875,    int _1876) { return mosek::fusion::p_Var::reshape(_1875,_1876); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1875,int _1876){
  return ::mosek::fusion::p_Var::reshape(_1875,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1876)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1877,    int _1878,    int _1879) { return mosek::fusion::p_Var::reshape(_1877,_1878,_1879); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1877,int _1878,int _1879){
  return ::mosek::fusion::p_Var::reshape(_1877,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1878),(int)(_1879)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _1880) { return mosek::fusion::p_Var::flatten(_1880); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1880){
  return ::mosek::fusion::p_Var::reshape(_1880,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_1880->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1881,    std::shared_ptr< monty::ndarray< int,1 > > _1882) { return mosek::fusion::p_Var::reshape(_1881,_1882); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1881,std::shared_ptr< monty::ndarray< int,1 > > _1882){
  _checked_ptr_1<int> _ptr__1882(_1882 ? _1882->raw() : nullptr, _1882 ? _1882->size(0) : 0);
  return _1881->__mosek_2fusion_2Variable__reshape(_1882);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1883,std::shared_ptr< monty::ndarray< int,1 > > _1884){
  _checked_ptr_1<int> _ptr__1884(_1884 ? _1884->raw() : nullptr, _1884 ? _1884->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1885;
  _checked_ptr_1<long long> _ptr__1885(_1885 ? _1885->raw() : nullptr,_1885 ? _1885->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1886;
  _checked_ptr_1<long long> _ptr__1886(_1886 ? _1886->raw() : nullptr,_1886 ? _1886->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1887 = _1883->getShape();
  _checked_ptr_1<int> _ptr__1887(_1887 ? _1887->raw() : nullptr,_1887 ? _1887->size(0) : 0);
  int _1888 = (int)((_1887)->size(0));
  int _1889 = (int)1;
  int _7607 = (int)0;
  int _7608 = _1888;
  for (int _1890 = _7607; _1890 < _7608; ++_1890)
  {
    {
      _1889 *= _ptr__1887[_1890];
    }
  }
  int _1891 = _1883->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1892 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1888)));
  _checked_ptr_1<long long> _ptr__1892(_1892 ? _1892->raw() : nullptr,_1892 ? _1892->size(0) : 0);
  _ptr__1892[(_1888 - (int)1)] = (int)1;
  int _7609 = (int)1;
  int _7610 = _1888;
  for (int _1893 = _7609; _1893 < _7610; ++_1893)
  {
    {
      _ptr__1892[((_1888 - _1893) - (int)1)] = safe_mul( _ptr__1892[(_1888 - _1893)],_ptr__1887[_ptr__1884[(_1888 - _1893)]] );
    }
  }
  if ((_1891 < _1889))
  {
    {
      _1885 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1891)));
      _ptr__1885.update(_1885 ? _1885->raw() : nullptr, _1885 ? _1885->size(0) : 0);
      _1886 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1891)));
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
      _1883->inst((int)0,_1885,(int)0,_1886);
    }
  }
  else
  {
    {
      _1885 = nullptr;
      _ptr__1885.update(_1885 ? _1885->raw() : nullptr, _1885 ? _1885->size(0) : 0);
      _1886 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1891)));
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
      _1883->inst((int)0,_1886);
    }
  }
  if ((NULL == _1885.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1894 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1891)));
      _checked_ptr_1<long long> _ptr__1894(_1894 ? _1894->raw() : nullptr,_1894 ? _1894->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1895 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1888)));
        _checked_ptr_1<int> _ptr__1895(_1895 ? _1895->raw() : nullptr,_1895 ? _1895->size(0) : 0);
        int _7611 = (int)0;
        int _7612 = _1891;
        for (int _1896 = _7611; _1896 < _7612; ++_1896)
        {
          {
            int _1897 = _1896;
            int _7613 = (int)0;
            int _7614 = _1888;
            for (int _1898 = _7613; _1898 < _7614; ++_1898)
            {
              {
                _ptr__1895[((_1888 - _1896) - (int)1)] = (_1897 % _ptr__1887[((_1888 - _1896) - (int)1)]);
                _1897 /= _ptr__1887[((_1888 - _1896) - (int)1)];
              }
            }
            int _1899 = (int)0;
            int _7615 = (int)0;
            int _7616 = _1888;
            for (int _1900 = _7615; _1900 < _7616; ++_1900)
            {
              {
                _1899 += (int)safe_mul( _ptr__1895[_ptr__1884[_1900]],_ptr__1892[_1900] );
              }
            }
            _ptr__1894[_1899] = _ptr__1886[_1896];
          }
        }
      }
      _1886 = _1894;
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1901 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1891)));
      _checked_ptr_1<long long> _ptr__1901(_1901 ? _1901->raw() : nullptr,_1901 ? _1901->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1902 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1888)));
        _checked_ptr_1<int> _ptr__1902(_1902 ? _1902->raw() : nullptr,_1902 ? _1902->size(0) : 0);
        int _7617 = (int)0;
        int _7618 = _1891;
        for (int _1903 = _7617; _1903 < _7618; ++_1903)
        {
          {
            int _1904 = _1903;
            int _7619 = (int)0;
            int _7620 = _1888;
            for (int _1905 = _7619; _1905 < _7620; ++_1905)
            {
              {
                _ptr__1902[((_1888 - _1903) - (int)1)] = (_1904 % _ptr__1887[((_1888 - _1903) - (int)1)]);
                _1904 /= _ptr__1887[((_1888 - _1903) - (int)1)];
              }
            }
            int _1906 = (int)0;
            int _7621 = (int)0;
            int _7622 = _1888;
            for (int _1907 = _7621; _1907 < _7622; ++_1907)
            {
              {
                _1906 += (int)safe_mul( _ptr__1902[_ptr__1884[_1907]],_ptr__1892[_1907] );
              }
            }
            _ptr__1901[_1903] = _1906;
          }
        }
      }
      std::vector<long long> _7623;
      for (int _1909 = (int)0, _7624 = _1891; _1909 < _7624 ; ++_1909)
      {
        _7623.push_back(_1909);
      }
      auto _7625 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7623.size()),_7623.begin(),_7623.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1908 = _7625;
      _checked_ptr_1<long long> _ptr__1908(_1908 ? _1908->raw() : nullptr,_1908 ? _1908->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1908,_1901,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1891));
      std::vector<long long> _7626;
      for (int _1910 = (int)0, _7627 = _1891; _1910 < _7627 ; ++_1910)
      {
        _7626.push_back(_ptr__1885[_ptr__1908[_1910]]);
      }
      auto _7628 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7626.size()),_7626.begin(),_7626.end()));
      _1885 = _7628;
      _ptr__1885.update(_1885 ? _1885->raw() : nullptr, _1885 ? _1885->size(0) : 0);
      std::vector<long long> _7629;
      for (int _1911 = (int)0, _7630 = _1891; _1911 < _7630 ; ++_1911)
      {
        _7629.push_back(_ptr__1886[_ptr__1908[_1911]]);
      }
      auto _7631 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7629.size()),_7629.begin(),_7629.end()));
      _1886 = _7631;
      _ptr__1886.update(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
    }
  }
  std::vector<int> _7632;
  for (int _1912 = (int)0, _7633 = _1888; _1912 < _7633 ; ++_1912)
  {
    _7632.push_back(_ptr__1887[_ptr__1884[_1912]]);
  }
  auto _7634 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7632.size()),_7632.begin(),_7632.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1883->__mosek_2fusion_2Variable__getModel(),_7634,_1885,_1886)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1913,    int _1914) { return mosek::fusion::p_Var::hrepeat(_1913,_1914); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1913,int _1914){
  return ::mosek::fusion::p_Var::drepeat(_1913,(int)1,_1914);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1915,    int _1916) { return mosek::fusion::p_Var::vrepeat(_1915,_1916); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1915,int _1916){
  return ::mosek::fusion::p_Var::drepeat(_1915,(int)0,_1916);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1917,    int _1918) { return mosek::fusion::p_Var::repeat(_1917,_1918); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1917,int _1918){
  return ::mosek::fusion::p_Var::drepeat(_1917,(int)0,_1918);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1919,    int _1920,    int _1921) { return mosek::fusion::p_Var::repeat(_1919,_1920,_1921); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1919,int _1920,int _1921){
  return ::mosek::fusion::p_Var::drepeat(_1919,_1920,_1921);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1922,int _1923,int _1924){
  if ((_1924 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_1924 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_1924 == (int)1))
  {
    {
      return _1922;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _1925 = _1922->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _1926 = _1922->getShape();
      _checked_ptr_1<int> _ptr__1926(_1926 ? _1926->raw() : nullptr,_1926 ? _1926->size(0) : 0);
      int _1927 = (int)((_1926)->size(0));
      if (((_1923 < (int)0) || (_1923 > _1927)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _1928 = ::mosek::fusion::p_Set::size(_1926);
      int _1929 = _1922->numInst();
      int _1930 = safe_mul( _1929,_1924 );
      int _1931 = (int)1;
      int _7635 = (int)0;
      int _7636 = _1923;
      for (int _1932 = _7635; _1932 < _7636; ++_1932)
      {
        {
          _1931 *= _ptr__1926[_1932];
        }
      }
      int _7637;
      bool _7638 = (_1923 < _1927);
      if (_7638)
      {
        _7637 = _ptr__1926[_1923];
      }
      else
      {
        _7637 = (int)1;
      }
      int _1933 = _7637;
      int _1934 = safe_mul( _1933,_1924 );
      int _1935 = (int)1;
      int _7639 = safe_add( _1923,(int)1 );
      int _7640 = _1927;
      for (int _1936 = _7639; _1936 < _7640; ++_1936)
      {
        {
          _1935 *= _ptr__1926[_1936];
        }
      }
      int _7641;
      bool _7642 = (_1923 < _1927);
      if (_7642)
      {
        _7641 = _1927;
      }
      else
      {
        _7641 = safe_add( _1923,(int)1 );
      }
      int _1937 = _7641;
      std::shared_ptr< monty::ndarray< int,1 > > _1938 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1937)));
      _checked_ptr_1<int> _ptr__1938(_1938 ? _1938->raw() : nullptr,_1938 ? _1938->size(0) : 0);
      int _7643 = (int)0;
      int _7644 = _1927;
      for (int _1939 = _7643; _1939 < _7644; ++_1939)
      {
        {
          _ptr__1938[_1939] = _ptr__1926[_1939];
        }
      }
      int _7645 = _1927;
      int _7646 = _1937;
      for (int _1940 = _7645; _1940 < _7646; ++_1940)
      {
        {
          _ptr__1938[_1940] = (int)1;
        }
      }
      _ptr__1938[_1923] = _1934;
      if ((_1929 < _1928))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1941 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1929)));
          _checked_ptr_1<long long> _ptr__1941(_1941 ? _1941->raw() : nullptr,_1941 ? _1941->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1942 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1929)));
          _checked_ptr_1<long long> _ptr__1942(_1942 ? _1942->raw() : nullptr,_1942 ? _1942->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1943 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1930)));
          _checked_ptr_1<long long> _ptr__1943(_1943 ? _1943->raw() : nullptr,_1943 ? _1943->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1944 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1930)));
          _checked_ptr_1<long long> _ptr__1944(_1944 ? _1944->raw() : nullptr,_1944 ? _1944->size(0) : 0);
          _1922->inst((int)0,_1942,(int)0,_1941);
          {
            int _1945 = safe_mul( _1934,_1935 );
            int _1946 = safe_mul( _1933,_1935 );
            int _1947 = _1935;
            if ((_1923 == (int)0))
            {
              {
                int _1948 = (int)0;
                int _7647 = (int)0;
                int _7648 = _1924;
                for (int _1949 = _7647; _1949 < _7648; ++_1949)
                {
                  {
                    int _7649 = (int)0;
                    int _7650 = _1929;
                    for (int _1950 = _7649; _1950 < _7650; ++_1950)
                    {
                      {
                        _ptr__1944[_1948] = safe_add( _ptr__1942[_1950],safe_mul( _1949,_1928 ) );
                        _ptr__1943[_1948] = _ptr__1941[_1950];
                        ++ _1948;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1925,_1938,_1944,_1943)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_1923 >= _1927))
            {
              {
                int _1951 = (int)0;
                int _7651 = (int)0;
                int _7652 = _1929;
                for (int _1952 = _7651; _1952 < _7652; ++_1952)
                {
                  {
                    int _7653 = (int)0;
                    int _7654 = _1924;
                    for (int _1953 = _7653; _1953 < _7654; ++_1953)
                    {
                      {
                        _ptr__1944[_1951] = safe_add( safe_mul( _ptr__1942[_1952],_1924 ),_1953 );
                        _ptr__1943[_1951] = _ptr__1941[_1952];
                        ++ _1951;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1925,_1938,_1944,_1943)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _1954 = (int)0;
                int _7655 = (int)0;
                int _7656 = _1929;
                for (int _1955 = _7655; _1955 < _7656; ++_1955)
                {
                  {
                    long long _1956 = (_ptr__1942[_1955] / _1946);
                    long long _1957 = ((_ptr__1942[_1955] / _1947) % _1933);
                    long long _1958 = (_ptr__1942[_1955] % _1935);
                    int _7657 = (int)0;
                    int _7658 = _1924;
                    for (int _1959 = _7657; _1959 < _7658; ++_1959)
                    {
                      {
                        _ptr__1944[_1954] = safe_add( safe_add( safe_mul( _1956,_1945 ),safe_mul( safe_add( _1957,safe_mul( _1933,_1959 ) ),_1935 ) ),_1958 );
                        _ptr__1943[_1954] = _ptr__1941[_1955];
                        ++ _1954;
                      }
                    }
                  }
                }
                int _1960 = (int)1;
                int _7659 = (int)0;
                int _7660 = _1937;
                for (int _1961 = _7659; _1961 < _7660; ++_1961)
                {
                  {
                    if ((_1960 < _ptr__1938[_1961]))
                    {
                      {
                        _1960 = _ptr__1938[_1961];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _1962 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1930)));
                _checked_ptr_1<int> _ptr__1962(_1962 ? _1962->raw() : nullptr,_1962 ? _1962->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _1963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1930)));
                _checked_ptr_1<int> _ptr__1963(_1963 ? _1963->raw() : nullptr,_1963 ? _1963->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _1964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1960,(int)1 ))));
                  _checked_ptr_1<int> _ptr__1964(_1964 ? _1964->raw() : nullptr,_1964 ? _1964->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _1965 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1937)));
                  _checked_ptr_1<long long> _ptr__1965(_1965 ? _1965->raw() : nullptr,_1965 ? _1965->size(0) : 0);
                  _ptr__1965[(_1937 - (int)1)] = (int)1;
                  int _7661 = (int)1;
                  int _7662 = _1937;
                  for (int _1966 = _7661; _1966 < _7662; ++_1966)
                  {
                    {
                      _ptr__1965[((_1937 - _1966) - (int)1)] = safe_mul( _ptr__1965[(_1937 - _1966)],_ptr__1938[(_1937 - _1966)] );
                    }
                  }
                  int _7663 = (int)0;
                  int _7664 = _1930;
                  for (int _1967 = _7663; _1967 < _7664; ++_1967)
                  {
                    {
                      _ptr__1962[_1967] = _1967;
                    }
                  }
                  int _7665 = (int)0;
                  int _7666 = _1937;
                  for (int _1968 = _7665; _1968 < _7666; ++_1968)
                  {
                    {
                      int _1969 = ((_1937 - _1968) - (int)1);
                      int _7667 = (int)0;
                      int _7668 = safe_add( _ptr__1938[_1969],(int)1 );
                      for (int _1970 = _7667; _1970 < _7668; ++_1970)
                      {
                        {
                          _ptr__1964[_1970] = (int)0;
                        }
                      }
                      int _7669 = (int)0;
                      int _7670 = _1930;
                      for (int _1971 = _7669; _1971 < _7670; ++_1971)
                      {
                        {
                          ++ _ptr__1964[safe_add( ((_ptr__1944[_1971] / _ptr__1965[_1969]) % _ptr__1938[_1969]),(int)1 )];
                        }
                      }
                      int _7671 = (int)0;
                      int _7672 = _ptr__1938[_1969];
                      for (int _1972 = _7671; _1972 < _7672; ++_1972)
                      {
                        {
                          _ptr__1964[safe_add( _1972,(int)1 )] += _ptr__1964[_1972];
                        }
                      }
                      int _7673 = (int)0;
                      int _7674 = _1930;
                      for (int _1973 = _7673; _1973 < _7674; ++_1973)
                      {
                        {
                          int _1974 = _ptr__1962[_1973];
                          long long _1975 = ((_ptr__1944[_1974] / _ptr__1965[_1969]) % _ptr__1938[_1969]);
                          _ptr__1963[_ptr__1964[_1975]] = _1974;
                          ++ _ptr__1964[_1975];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _1976 = _1962;
                      _checked_ptr_1<int> _ptr__1976(_1976 ? _1976->raw() : nullptr,_1976 ? _1976->size(0) : 0);
                      _1962 = _1963;
                      _ptr__1962.update(_1962 ? _1962->raw() : nullptr, _1962 ? _1962->size(0) : 0);
                      _1963 = _1976;
                      _ptr__1963.update(_1963 ? _1963->raw() : nullptr, _1963 ? _1963->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _7675;
                for (int _1977 = (int)0, _7676 = _1930; _1977 < _7676 ; ++_1977)
                {
                  _7675.push_back(_ptr__1944[_ptr__1962[_1977]]);
                }
                auto _7677 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7675.size()),_7675.begin(),_7675.end()));
                std::vector<long long> _7678;
                for (int _1978 = (int)0, _7679 = _1930; _1978 < _7679 ; ++_1978)
                {
                  _7678.push_back(_ptr__1943[_ptr__1962[_1978]]);
                }
                auto _7680 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7678.size()),_7678.begin(),_7678.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1925,_1938,_7677,_7680)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1979 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1929)));
          _checked_ptr_1<long long> _ptr__1979(_1979 ? _1979->raw() : nullptr,_1979 ? _1979->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1980 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1929,_1924 ))));
          _checked_ptr_1<long long> _ptr__1980(_1980 ? _1980->raw() : nullptr,_1980 ? _1980->size(0) : 0);
          _1922->inst((int)0,_1979);
          int _1981 = safe_mul( _1934,_1935 );
          int _1982 = _1935;
          int _1983 = (int)0;
          int _7681 = (int)0;
          int _7682 = _1931;
          for (int _1984 = _7681; _1984 < _7682; ++_1984)
          {
            {
              int _7683 = (int)0;
              int _7684 = _1933;
              for (int _1985 = _7683; _1985 < _7684; ++_1985)
              {
                {
                  int _7685 = (int)0;
                  int _7686 = _1935;
                  for (int _1986 = _7685; _1986 < _7686; ++_1986)
                  {
                    {
                      int _7687 = (int)0;
                      int _7688 = _1924;
                      for (int _1987 = _7687; _1987 < _7688; ++_1987)
                      {
                        {
                          _ptr__1980[safe_add( safe_add( safe_mul( _1984,_1981 ),safe_mul( safe_add( _1985,safe_mul( _1987,_1933 ) ),_1982 ) ),_1986 )] = _ptr__1979[_1983];
                        }
                      }
                      ++ _1983;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1925,_1938,nullptr,_1980)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1988) { return mosek::fusion::p_Var::stack(_1988); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1988){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _7689;
  for (int _1989 = (int)0, _7690 = (int)((_1988)->size(0)); _1989 < _7690 ; ++_1989)
  {
    _7689.push_back(::mosek::fusion::p_Var::dstack(((*_1988)(_1989)),(int)1));
  }
  auto _7691 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_7689.size()),_7689.begin(),_7689.end()));
  return ::mosek::fusion::p_Var::dstack(_7691,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1990,    monty::rc_ptr< ::mosek::fusion::Variable > _1991,    monty::rc_ptr< ::mosek::fusion::Variable > _1992) { return mosek::fusion::p_Var::vstack(_1990,_1991,_1992); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1990,monty::rc_ptr< ::mosek::fusion::Variable > _1991,monty::rc_ptr< ::mosek::fusion::Variable > _1992){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1990.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1991.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1992.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1993,    monty::rc_ptr< ::mosek::fusion::Variable > _1994) { return mosek::fusion::p_Var::vstack(_1993,_1994); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1993,monty::rc_ptr< ::mosek::fusion::Variable > _1994){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1993.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1994.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1995) { return mosek::fusion::p_Var::vstack(_1995); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1995){
  return ::mosek::fusion::p_Var::dstack(_1995,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1996,    monty::rc_ptr< ::mosek::fusion::Variable > _1997,    monty::rc_ptr< ::mosek::fusion::Variable > _1998) { return mosek::fusion::p_Var::hstack(_1996,_1997,_1998); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1996,monty::rc_ptr< ::mosek::fusion::Variable > _1997,monty::rc_ptr< ::mosek::fusion::Variable > _1998){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1996.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1997.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1998.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1999,    monty::rc_ptr< ::mosek::fusion::Variable > _2000) { return mosek::fusion::p_Var::hstack(_1999,_2000); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1999,monty::rc_ptr< ::mosek::fusion::Variable > _2000){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1999.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2000.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2001) { return mosek::fusion::p_Var::hstack(_2001); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2001){
  return ::mosek::fusion::p_Var::dstack(_2001,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2002,    monty::rc_ptr< ::mosek::fusion::Variable > _2003,    monty::rc_ptr< ::mosek::fusion::Variable > _2004,    int _2005) { return mosek::fusion::p_Var::stack(_2002,_2003,_2004,_2005); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _2002,monty::rc_ptr< ::mosek::fusion::Variable > _2003,monty::rc_ptr< ::mosek::fusion::Variable > _2004,int _2005){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2002.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2003.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2004.get())}),_2005);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2006,    monty::rc_ptr< ::mosek::fusion::Variable > _2007,    int _2008) { return mosek::fusion::p_Var::stack(_2006,_2007,_2008); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _2006,monty::rc_ptr< ::mosek::fusion::Variable > _2007,int _2008){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2006.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2007.get())}),_2008);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2009,    int _2010) { return mosek::fusion::p_Var::stack(_2009,_2010); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2009,int _2010){
  int _2011 = _2010;
  int _7692 = (int)0;
  int _7693 = (int)((_2009)->size(0));
  for (int _2012 = _7692; _2012 < _7693; ++_2012)
  {
    {
      if ((_2011 < ((*_2009)(_2012))->getND()))
      {
        {
          _2011 = ((*_2009)(_2012))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_2009,_2010);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _2013,    int _2014) { return mosek::fusion::p_Var::promote(_2013,_2014); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _2013,int _2014){
  if ((_2014 > _2013->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2015 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2014)));
      _checked_ptr_1<int> _ptr__2015(_2015 ? _2015->raw() : nullptr,_2015 ? _2015->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2016 = _2013->getShape();
      _checked_ptr_1<int> _ptr__2016(_2016 ? _2016->raw() : nullptr,_2016 ? _2016->size(0) : 0);
      int _7694 = (int)0;
      int _7695 = (int)((_2016)->size(0));
      for (int _2017 = _7694; _2017 < _7695; ++_2017)
      {
        {
          _ptr__2015[_2017] = _ptr__2016[_2017];
        }
      }
      int _7696 = (int)((_2016)->size(0));
      int _7697 = _2014;
      for (int _2018 = _7696; _2018 < _7697; ++_2018)
      {
        {
          _ptr__2015[_2018] = (int)1;
        }
      }
      return _2013->__mosek_2fusion_2Variable__reshape(_2015);
    }
  }
  else
  {
    {
      return _2013;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2019,int _2020){
  if ((_2020 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _2021 = nullptr;
  {
    int _7698 = (int)0;
    int _7699 = (int)((_2019)->size(0));
    for (int _2022 = _7698; _2022 < _7699; ++_2022)
    {
      {
        if ((NULL == _2021.get()))
        {
          {
            _2021 = ((*_2019)(_2022))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_2019)(_2022))->__mosek_2fusion_2Variable__getModel().get()) && (((*_2019)(_2022))->__mosek_2fusion_2Variable__getModel() != _2021)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2023 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7700;
            bool _7701 = ((int)((mosek::fusion::p_Model::_get_impl(_2021.get())->getName()).size()) > (int)0);
            if (_7701)
            {
              _7700 = mosek::fusion::p_Model::_get_impl(_2021.get())->getName();
            }
            else
            {
              _7700 = std::string ("?");
            }
            std::string _2024 = _7700;
            std::string _7702;
            bool _7703 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2019)(_2022))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_7703)
            {
              _7702 = mosek::fusion::p_Model::_get_impl(((*_2019)(_2022))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _7702 = std::string ("?");
            }
            std::string _2025 = _7702;
            _2023->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2024)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2025)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2023->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2019)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_2019)->size(0)) == (int)1))
  {
    {
      return ((*_2019)((int)1));
    }
  }
  else
  {
    {
      int _2026 = (int)((_2019)->size(0));
      std::vector<int> _7704;
      for (int _2028 = (int)0, _7705 = _2026; _2028 < _7705 ; ++_2028)
      {
        _7704.push_back(((*_2019)(_2028))->numInst());
      }
      auto _7706 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7704.size()),_7704.begin(),_7704.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2027 = _7706;
      _checked_ptr_1<int> _ptr__2027(_2027 ? _2027->raw() : nullptr,_2027 ? _2027->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7707;
      for (int _2030 = (int)0, _7708 = _2026; _2030 < _7708 ; ++_2030)
      {
        _7707.push_back(((*_2019)(_2030))->getShape());
      }
      auto _7709 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7707.size()),_7707.begin(),_7707.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2029 = _7709;
      std::vector<int> _7710;
      for (int _2032 = (int)0, _7711 = _2026; _2032 < _7711 ; ++_2032)
      {
        _7710.push_back((int)((((*_2029)(_2032)))->size(0)));
      }
      auto _7712 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7710.size()),_7710.begin(),_7710.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2031 = _7712;
      _checked_ptr_1<int> _ptr__2031(_2031 ? _2031->raw() : nullptr,_2031 ? _2031->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2033 = ((*_2029)((int)0));
      _checked_ptr_1<int> _ptr__2033(_2033 ? _2033->raw() : nullptr,_2033 ? _2033->size(0) : 0);
      int _2034 = _ptr__2031[(int)0];
      int _2035 = (int)0;
      int _7713 = (int)0;
      int _7714 = _2026;
      for (int _2036 = _7713; _2036 < _7714; ++_2036)
      {
        {
          _2035 += _ptr__2027[_2036];
        }
      }
      int _2037 = safe_add( _2020,(int)1 );
      int _7715 = (int)0;
      int _7716 = _2026;
      for (int _2038 = _7715; _2038 < _7716; ++_2038)
      {
        {
          if ((_2037 < _ptr__2031[_2038]))
          {
            {
              _2037 = _ptr__2031[_2038];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2039 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2037)));
      _checked_ptr_1<int> _ptr__2039(_2039 ? _2039->raw() : nullptr,_2039 ? _2039->size(0) : 0);
      int _7717 = (int)0;
      int _7718 = _2034;
      for (int _2040 = _7717; _2040 < _7718; ++_2040)
      {
        {
          _ptr__2039[_2040] = _ptr__2033[_2040];
        }
      }
      int _7719 = _2034;
      int _7720 = _2037;
      for (int _2041 = _7719; _2041 < _7720; ++_2041)
      {
        {
          _ptr__2039[_2041] = (int)1;
        }
      }
      _ptr__2039[_2020] = (int)0;
      int _7721 = (int)0;
      int _7722 = _2026;
      for (int _2042 = _7721; _2042 < _7722; ++_2042)
      {
        {
          int _7723;
          bool _7724 = ((int)((((*_2029)(_2042)))->size(0)) > _2020);
          if (_7724)
          {
            _7723 = ((*((*_2029)(_2042)))(_2020));
          }
          else
          {
            _7723 = (int)1;
          }
          _ptr__2039[_2020] += _7723;
        }
      }
      int _7725 = (int)0;
      int _7726 = _2026;
      for (int _2043 = _7725; _2043 < _7726; ++_2043)
      {
        {
          int _7727 = (int)0;
          int _7728 = (int)((((*_2029)(_2043)))->size(0));
          for (int _2044 = _7727; _2044 < _7728; ++_2044)
          {
            {
              if (((_2044 != _2020) && (((*((*_2029)(_2043)))(_2044)) != _ptr__2039[_2044])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _7729 = (int)((((*_2029)(_2043)))->size(0));
          int _7730 = _2037;
          for (int _2045 = _7729; _2045 < _7730; ++_2045)
          {
            {
              if (((_2045 != _2020) && ((int)1 != _ptr__2039[_2045])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2046 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2035)));
      _checked_ptr_1<long long> _ptr__2046(_2046 ? _2046->raw() : nullptr,_2046 ? _2046->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2047 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2035)));
      _checked_ptr_1<long long> _ptr__2047(_2047 ? _2047->raw() : nullptr,_2047 ? _2047->size(0) : 0);
      std::vector<int> _7731;
      for (int _2049 = (int)0, _7732 = (int)((_2019)->size(0)); _2049 < _7732 ; ++_2049)
      {
        int _7733;
        bool _7734 = (_2020 < (int)((((*_2029)(_2049)))->size(0)));
        if (_7734)
        {
          _7733 = ((*((*_2029)(_2049)))(_2020));
        }
        else
        {
          _7733 = (int)1;
        }
        _7731.push_back(_7733);
      }
      auto _7735 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7731.size()),_7731.begin(),_7731.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2048 = _7735;
      _checked_ptr_1<int> _ptr__2048(_2048 ? _2048->raw() : nullptr,_2048 ? _2048->size(0) : 0);
      int _2050 = (int)1;
      int _7736 = (int)0;
      int _7737 = _2020;
      for (int _2051 = _7736; _2051 < _7737; ++_2051)
      {
        {
          int _7738;
          bool _7739 = (_2051 < (int)((_2033)->size(0)));
          if (_7739)
          {
            _7738 = _ptr__2033[_2051];
          }
          else
          {
            _7738 = (int)1;
          }
          _2050 *= _7738;
        }
      }
      int _2052 = (int)0;
      int _7740 = (int)0;
      int _7741 = _2026;
      for (int _2053 = _7740; _2053 < _7741; ++_2053)
      {
        {
          _2052 += _ptr__2048[_2053];
        }
      }
      int _2054 = (int)1;
      int _7742 = safe_add( _2020,(int)1 );
      int _7743 = (int)((_2033)->size(0));
      for (int _2055 = _7742; _2055 < _7743; ++_2055)
      {
        {
          _2054 *= _ptr__2033[_2055];
        }
      }
      if ((_2050 == (int)1))
      {
        {
          int _2056 = (int)0;
          long long _2057 = (int)0;
          int _7744 = (int)0;
          int _7745 = _2026;
          for (int _2058 = _7744; _2058 < _7745; ++_2058)
          {
            {
              ((*_2019)(_2058))->inst(_2056,_2047,_2056,_2046);
              int _7746 = (int)0;
              int _7747 = _ptr__2027[_2058];
              for (int _2059 = _7746; _2059 < _7747; ++_2059)
              {
                {
                  _ptr__2047[_2056] += _2057;
                  ++ _2056;
                }
              }
              _2057 += ::mosek::fusion::p_Set::size(((*_2029)(_2058)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7748;
          bool _7749 = (_2035 < safe_mul( safe_mul( _2050,_2052 ),_2054 ));
          if (_7749)
          {
            _7748 = _2047;
          }
          else
          {
            _7748 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2021,_2039,_7748,_2046)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2060 = (int)0;
          int _7750 = (int)0;
          int _7751 = _2026;
          for (int _2061 = _7750; _2061 < _7751; ++_2061)
          {
            {
              _2060 += ((*_2019)(_2061))->inst(_2060,_2047,_2060,_2046);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2062 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2035)));
          _checked_ptr_1<int> _ptr__2062(_2062 ? _2062->raw() : nullptr,_2062 ? _2062->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2063 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2035)));
          _checked_ptr_1<int> _ptr__2063(_2063 ? _2063->raw() : nullptr,_2063 ? _2063->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2064 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2026)));
          _checked_ptr_1<int> _ptr__2064(_2064 ? _2064->raw() : nullptr,_2064 ? _2064->size(0) : 0);
          int _7752 = (int)0;
          int _7753 = (_2026 - (int)1);
          for (int _2065 = _7752; _2065 < _7753; ++_2065)
          {
            {
              _ptr__2064[safe_add( _2065,(int)1 )] = safe_add( _ptr__2064[_2065],_ptr__2048[_2065] );
            }
          }
          int _7754 = (int)0;
          int _7755 = _2035;
          for (int _2066 = _7754; _2066 < _7755; ++_2066)
          {
            {
              _ptr__2062[_2066] = _2066;
            }
          }
          int _2067 = (int)0;
          int _7756 = (int)0;
          int _7757 = _2026;
          for (int _2068 = _7756; _2068 < _7757; ++_2068)
          {
            {
              int _7758 = (int)0;
              int _7759 = _ptr__2027[_2068];
              for (int _2069 = _7758; _2069 < _7759; ++_2069)
              {
                {
                  long long _2070 = (_ptr__2047[_2067] / safe_mul( _ptr__2048[_2068],_2054 ));
                  long long _2071 = ((_ptr__2047[_2067] / _2054) % _ptr__2048[_2068]);
                  long long _2072 = (_ptr__2047[_2067] % _2054);
                  _ptr__2047[_2067] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2070,_2052 ),_2071 ),_ptr__2064[_2068] ),_2054 ),_2072 );
                  ++ _2067;
                }
              }
            }
          }
          int _2073 = (int)1;
          int _7760 = (int)0;
          int _7761 = _2037;
          for (int _2074 = _7760; _2074 < _7761; ++_2074)
          {
            {
              int _7762;
              bool _7763 = (_2073 < _ptr__2039[_2074]);
              if (_7763)
              {
                _7762 = _ptr__2039[_2074];
              }
              else
              {
                _7762 = _2073;
              }
              _2073 = _7762;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2075 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2037)));
          _checked_ptr_1<long long> _ptr__2075(_2075 ? _2075->raw() : nullptr,_2075 ? _2075->size(0) : 0);
          _ptr__2075[(_2037 - (int)1)] = (int)1;
          int _7764 = (int)1;
          int _7765 = _2037;
          for (int _2076 = _7764; _2076 < _7765; ++_2076)
          {
            {
              _ptr__2075[((_2037 - _2076) - (int)1)] = safe_mul( _ptr__2075[(_2037 - _2076)],_ptr__2039[(_2037 - _2076)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2077 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2073,(int)1 ))));
          _checked_ptr_1<int> _ptr__2077(_2077 ? _2077->raw() : nullptr,_2077 ? _2077->size(0) : 0);
          int _7766 = (int)0;
          int _7767 = _2037;
          for (int _2078 = _7766; _2078 < _7767; ++_2078)
          {
            {
              int _2079 = ((_2037 - _2078) - (int)1);
              int _7768 = (int)0;
              int _7769 = safe_add( _ptr__2039[_2079],(int)1 );
              for (int _2080 = _7768; _2080 < _7769; ++_2080)
              {
                {
                  _ptr__2077[_2080] = (int)0;
                }
              }
              int _7770 = (int)0;
              int _7771 = _2035;
              for (int _2081 = _7770; _2081 < _7771; ++_2081)
              {
                {
                  ++ _ptr__2077[safe_add( ((_ptr__2047[_2081] / _ptr__2075[_2079]) % _ptr__2039[_2079]),(int)1 )];
                }
              }
              int _7772 = (int)0;
              int _7773 = _ptr__2039[_2079];
              for (int _2082 = _7772; _2082 < _7773; ++_2082)
              {
                {
                  _ptr__2077[safe_add( _2082,(int)1 )] += _ptr__2077[_2082];
                }
              }
              int _7774 = (int)0;
              int _7775 = _2035;
              for (int _2083 = _7774; _2083 < _7775; ++_2083)
              {
                {
                  int _2084 = _ptr__2062[_2083];
                  long long _2085 = ((_ptr__2047[_2084] / _ptr__2075[_2079]) % _ptr__2039[_2079]);
                  _ptr__2063[_ptr__2077[_2085]] = _2084;
                  ++ _ptr__2077[_2085];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2086 = _2062;
              _checked_ptr_1<int> _ptr__2086(_2086 ? _2086->raw() : nullptr,_2086 ? _2086->size(0) : 0);
              _2062 = _2063;
              _ptr__2062.update(_2062 ? _2062->raw() : nullptr, _2062 ? _2062->size(0) : 0);
              _2063 = _2086;
              _ptr__2063.update(_2063 ? _2063->raw() : nullptr, _2063 ? _2063->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7776;
          bool _7777 = (_2035 < safe_mul( safe_mul( _2050,_2052 ),_2054 ));
          if (_7777)
          {
            std::vector<long long> _7778;
            for (int _2087 = (int)0, _7779 = _2035; _2087 < _7779 ; ++_2087)
            {
              _7778.push_back(_ptr__2047[_ptr__2062[_2087]]);
            }
            auto _7780 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7778.size()),_7778.begin(),_7778.end()));
            _7776 = _7780;
          }
          else
          {
            _7776 = nullptr;
          }
          std::vector<long long> _7781;
          for (int _2088 = (int)0, _7782 = _2035; _2088 < _7782 ; ++_2088)
          {
            _7781.push_back(_ptr__2046[_ptr__2062[_2088]]);
          }
          auto _7783 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7781.size()),_7781.begin(),_7781.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2021,_2039,_7776,_7783)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2089,    monty::rc_ptr< ::mosek::fusion::Model > _2090){ return new mosek::fusion::LinearPSDConstraint(_2089,_2090); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2089,    monty::rc_ptr< ::mosek::fusion::Model > _2090) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2089,_2090); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2089,    monty::rc_ptr< ::mosek::fusion::Model > _2090){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2089,_2090);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2089)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2089)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2089)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2089)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2089)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2091,    const std::string &  _2092,    int _2093,    std::shared_ptr< monty::ndarray< int,1 > > _2094,    int _2095,    std::shared_ptr< monty::ndarray< int,1 > > _2096,    std::shared_ptr< monty::ndarray< long long,1 > > _2097){ return new mosek::fusion::LinearPSDConstraint(_2091,_2092,_2093,_2094,_2095,_2096,_2097); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2091,    const std::string &  _2092,    int _2093,    std::shared_ptr< monty::ndarray< int,1 > > _2094,    int _2095,    std::shared_ptr< monty::ndarray< int,1 > > _2096,    std::shared_ptr< monty::ndarray< long long,1 > > _2097) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2091,_2092,_2093,_2094,_2095,_2096,_2097); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2091,    const std::string &  _2092,    int _2093,    std::shared_ptr< monty::ndarray< int,1 > > _2094,    int _2095,    std::shared_ptr< monty::ndarray< int,1 > > _2096,    std::shared_ptr< monty::ndarray< long long,1 > > _2097){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2094(_2094 ? _2094->raw() : nullptr, _2094 ? _2094->size(0) : 0);
    _checked_ptr_1<int> _ptr__2096(_2096 ? _2096->raw() : nullptr, _2096 ? _2096->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2097(_2097 ? _2097->raw() : nullptr, _2097 ? _2097->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2091,_2092,_2094,_2096);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2093;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2097;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2096;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2095;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2094;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2098,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2099){
  std::shared_ptr< monty::ndarray< int,1 > > _2100 = ::mosek::fusion::p_Set::idxtokey(shape,_2098);
  _checked_ptr_1<int> _ptr__2100(_2100 ? _2100->raw() : nullptr,_2100 ? _2100->size(0) : 0);
  _2099->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2100[(int)0]);
  int _7784 = (int)1;
  int _7785 = (int)((_2100)->size(0));
  for (int _2101 = _7784; _2101 < _7785; ++_2101)
  {
    {
      _2099->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2100[_2101]);
    }
  }
  _2099->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7786 = (int)1;
  int _7787 = (int)((_2100)->size(0));
  for (int _2102 = _7786; _2102 < _7787; ++_2102)
  {
    {
      _2099->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2102)));
    }
  }
  _2099->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2103){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2103)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2104,    monty::rc_ptr< ::mosek::fusion::Model > _2105){ return new mosek::fusion::PSDConstraint(_2104,_2105); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2104,    monty::rc_ptr< ::mosek::fusion::Model > _2105) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2104,_2105); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2104,    monty::rc_ptr< ::mosek::fusion::Model > _2105){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2104,_2105);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2104)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2106,    const std::string &  _2107,    int _2108,    std::shared_ptr< monty::ndarray< int,1 > > _2109,    int _2110,    int _2111,    std::shared_ptr< monty::ndarray< long long,1 > > _2112,    std::shared_ptr< monty::ndarray< int,1 > > _2113){ return new mosek::fusion::PSDConstraint(_2106,_2107,_2108,_2109,_2110,_2111,_2112,_2113); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2106,    const std::string &  _2107,    int _2108,    std::shared_ptr< monty::ndarray< int,1 > > _2109,    int _2110,    int _2111,    std::shared_ptr< monty::ndarray< long long,1 > > _2112,    std::shared_ptr< monty::ndarray< int,1 > > _2113) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2106,_2107,_2108,_2109,_2110,_2111,_2112,_2113); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2106,    const std::string &  _2107,    int _2108,    std::shared_ptr< monty::ndarray< int,1 > > _2109,    int _2110,    int _2111,    std::shared_ptr< monty::ndarray< long long,1 > > _2112,    std::shared_ptr< monty::ndarray< int,1 > > _2113){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2109(_2109 ? _2109->raw() : nullptr, _2109 ? _2109->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2112(_2112 ? _2112->raw() : nullptr, _2112 ? _2112->size(0) : 0);
    _checked_ptr_1<int> _ptr__2113(_2113 ? _2113->raw() : nullptr, _2113 ? _2113->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2106,_2107,_2109,::mosek::fusion::p_PSDConstraint::computenidxs(_2109,_2110,_2111,_2113));
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2108;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2113;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2112;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2107;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2109;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2110;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2111;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2114){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2114)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2115,int _2116,int _2117,std::shared_ptr< monty::ndarray< int,1 > > _2118){
  _checked_ptr_1<int> _ptr__2115(_2115 ? _2115->raw() : nullptr, _2115 ? _2115->size(0) : 0);
  _checked_ptr_1<int> _ptr__2118(_2118 ? _2118->raw() : nullptr, _2118 ? _2118->size(0) : 0);
  int _2119 = (int)((_2115)->size(0));
  bool _2120 = (_2116 < _2117);
  int _7788;
  bool _7789 = _2120;
  if (_7789)
  {
    _7788 = _2116;
  }
  else
  {
    _7788 = _2117;
  }
  int _2121 = _7788;
  int _7790;
  bool _7791 = _2120;
  if (_7791)
  {
    _7790 = _2117;
  }
  else
  {
    _7790 = _2116;
  }
  int _2122 = _7790;
  std::shared_ptr< monty::ndarray< int,1 > > _2123 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2123(_2123 ? _2123->raw() : nullptr,_2123 ? _2123->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2124 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2124(_2124 ? _2124->raw() : nullptr,_2124 ? _2124->size(0) : 0);
  int _2125 = (int)1;
  int _7792 = (int)0;
  int _7793 = (int)((_2115)->size(0));
  for (int _2126 = _7792; _2126 < _7793; ++_2126)
  {
    {
      _2125 *= _ptr__2115[_2126];
    }
  }
  int _7794 = (int)0;
  int _7795 = _2121;
  for (int _2127 = _7794; _2127 < _7795; ++_2127)
  {
    {
      _ptr__2123[(int)0] *= _ptr__2115[_2127];
    }
  }
  _ptr__2123[(int)1] = _ptr__2115[_2121];
  int _7796 = safe_add( _2121,(int)1 );
  int _7797 = _2122;
  for (int _2128 = _7796; _2128 < _7797; ++_2128)
  {
    {
      _ptr__2123[(int)2] *= _ptr__2115[_2128];
    }
  }
  _ptr__2123[(int)3] = _ptr__2115[_2122];
  int _7798 = safe_add( _2122,(int)1 );
  int _7799 = _2119;
  for (int _2129 = _7798; _2129 < _7799; ++_2129)
  {
    {
      _ptr__2123[(int)4] *= _ptr__2115[_2129];
    }
  }
  _ptr__2124[(int)4] = (int)1;
  int _7800 = (int)1;
  int _7801 = (int)5;
  for (int _2130 = _7800; _2130 < _7801; ++_2130)
  {
    {
      _ptr__2124[(((int)5 - _2130) - (int)1)] = safe_mul( _ptr__2124[((int)5 - _2130)],_ptr__2123[((int)5 - _2130)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2131 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2125)));
  _checked_ptr_1<int> _ptr__2131(_2131 ? _2131->raw() : nullptr,_2131 ? _2131->size(0) : 0);
  int _2132 = (int)0;
  if (_2120)
  {
    {
      int _7802 = (int)0;
      int _7803 = _ptr__2123[(int)0];
      for (int _2133 = _7802; _2133 < _7803; ++_2133)
      {
        {
          int _7804 = (int)0;
          int _7805 = _ptr__2123[(int)1];
          for (int _2134 = _7804; _2134 < _7805; ++_2134)
          {
            {
              int _7806 = (int)0;
              int _7807 = _ptr__2123[(int)2];
              for (int _2135 = _7806; _2135 < _7807; ++_2135)
              {
                {
                  int _7808 = _2134;
                  int _7809 = _ptr__2123[(int)1];
                  for (int _2136 = _7808; _2136 < _7809; ++_2136)
                  {
                    {
                      int _7810 = (int)0;
                      int _7811 = _ptr__2123[(int)4];
                      for (int _2137 = _7810; _2137 < _7811; ++_2137)
                      {
                        {
                          _ptr__2131[safe_add( safe_add( safe_add( safe_add( safe_mul( _2133,_ptr__2124[(int)0] ),safe_mul( _2134,_ptr__2124[(int)1] ) ),safe_mul( _2135,_ptr__2124[(int)2] ) ),safe_mul( _2136,_ptr__2124[(int)3] ) ),safe_mul( _2137,_ptr__2124[(int)4] ) )] = _ptr__2118[_2132];
                          _ptr__2131[safe_add( safe_add( safe_add( safe_add( safe_mul( _2133,_ptr__2124[(int)0] ),safe_mul( _2136,_ptr__2124[(int)1] ) ),safe_mul( _2135,_ptr__2124[(int)2] ) ),safe_mul( _2134,_ptr__2124[(int)3] ) ),safe_mul( _2137,_ptr__2124[(int)4] ) )] = _ptr__2118[_2132];
                          ++ _2132;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _7812 = (int)0;
      int _7813 = _ptr__2123[(int)0];
      for (int _2138 = _7812; _2138 < _7813; ++_2138)
      {
        {
          int _7814 = (int)0;
          int _7815 = _ptr__2123[(int)1];
          for (int _2139 = _7814; _2139 < _7815; ++_2139)
          {
            {
              int _7816 = (int)0;
              int _7817 = _ptr__2123[(int)2];
              for (int _2140 = _7816; _2140 < _7817; ++_2140)
              {
                {
                  int _7818 = (int)0;
                  int _7819 = safe_add( _2139,(int)1 );
                  for (int _2141 = _7818; _2141 < _7819; ++_2141)
                  {
                    {
                      int _7820 = (int)0;
                      int _7821 = _ptr__2123[(int)4];
                      for (int _2142 = _7820; _2142 < _7821; ++_2142)
                      {
                        {
                          _ptr__2131[safe_add( safe_add( safe_add( safe_add( safe_mul( _2138,_ptr__2124[(int)0] ),safe_mul( _2139,_ptr__2124[(int)1] ) ),safe_mul( _2140,_ptr__2124[(int)2] ) ),safe_mul( _2141,_ptr__2124[(int)3] ) ),safe_mul( _2142,_ptr__2124[(int)4] ) )] = _ptr__2118[_2132];
                          _ptr__2131[safe_add( safe_add( safe_add( safe_add( safe_mul( _2138,_ptr__2124[(int)0] ),safe_mul( _2141,_ptr__2124[(int)1] ) ),safe_mul( _2140,_ptr__2124[(int)2] ) ),safe_mul( _2139,_ptr__2124[(int)3] ) ),safe_mul( _2142,_ptr__2124[(int)4] ) )] = _ptr__2118[_2132];
                          ++ _2132;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2131;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2143){ return new mosek::fusion::ConstraintCache(_2143); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2143) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2143); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2143){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2143)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2143)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7822;
    bool _7823 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->subj.get());
    if (_7823)
    {
      _7822 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->subj);
    }
    else
    {
      _7822 = nullptr;
    }
    subj = _7822;
    std::shared_ptr< monty::ndarray< int,1 > > _7824;
    bool _7825 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->subi.get());
    if (_7825)
    {
      _7824 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->subi);
    }
    else
    {
      _7824 = nullptr;
    }
    subi = _7824;
    std::shared_ptr< monty::ndarray< double,1 > > _7826;
    bool _7827 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->cof.get());
    if (_7827)
    {
      _7826 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->cof);
    }
    else
    {
      _7826 = nullptr;
    }
    cof = _7826;
    std::shared_ptr< monty::ndarray< double,1 > > _7828;
    bool _7829 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->bfix.get());
    if (_7829)
    {
      _7828 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->bfix);
    }
    else
    {
      _7828 = nullptr;
    }
    bfix = _7828;
    std::shared_ptr< monty::ndarray< double,1 > > _7830;
    bool _7831 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->buffer_cof.get());
    if (_7831)
    {
      _7830 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->buffer_cof);
    }
    else
    {
      _7830 = nullptr;
    }
    buffer_cof = _7830;
    std::shared_ptr< monty::ndarray< int,1 > > _7832;
    bool _7833 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->buffer_subj.get());
    if (_7833)
    {
      _7832 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->buffer_subj);
    }
    else
    {
      _7832 = nullptr;
    }
    buffer_subj = _7832;
    std::shared_ptr< monty::ndarray< int,1 > > _7834;
    bool _7835 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->buffer_subi.get());
    if (_7835)
    {
      _7834 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->buffer_subi);
    }
    else
    {
      _7834 = nullptr;
    }
    buffer_subi = _7834;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2143)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2143)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7836;
    bool _7837 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->barsubi.get());
    if (_7837)
    {
      _7836 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->barsubi);
    }
    else
    {
      _7836 = nullptr;
    }
    barsubi = _7836;
    std::shared_ptr< monty::ndarray< int,1 > > _7838;
    bool _7839 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->barsubj.get());
    if (_7839)
    {
      _7838 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->barsubj);
    }
    else
    {
      _7838 = nullptr;
    }
    barsubj = _7838;
    std::shared_ptr< monty::ndarray< int,1 > > _7840;
    bool _7841 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2143)->barmatidx.get());
    if (_7841)
    {
      _7840 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2143)->barmatidx);
    }
    else
    {
      _7840 = nullptr;
    }
    barmatidx = _7840;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2144,    std::shared_ptr< monty::ndarray< double,1 > > _2145,    std::shared_ptr< monty::ndarray< int,1 > > _2146,    std::shared_ptr< monty::ndarray< double,1 > > _2147,    std::shared_ptr< monty::ndarray< int,1 > > _2148,    std::shared_ptr< monty::ndarray< int,1 > > _2149,    std::shared_ptr< monty::ndarray< int,1 > > _2150){ return new mosek::fusion::ConstraintCache(_2144,_2145,_2146,_2147,_2148,_2149,_2150); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2144,    std::shared_ptr< monty::ndarray< double,1 > > _2145,    std::shared_ptr< monty::ndarray< int,1 > > _2146,    std::shared_ptr< monty::ndarray< double,1 > > _2147,    std::shared_ptr< monty::ndarray< int,1 > > _2148,    std::shared_ptr< monty::ndarray< int,1 > > _2149,    std::shared_ptr< monty::ndarray< int,1 > > _2150) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2144,_2145,_2146,_2147,_2148,_2149,_2150); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2144,    std::shared_ptr< monty::ndarray< double,1 > > _2145,    std::shared_ptr< monty::ndarray< int,1 > > _2146,    std::shared_ptr< monty::ndarray< double,1 > > _2147,    std::shared_ptr< monty::ndarray< int,1 > > _2148,    std::shared_ptr< monty::ndarray< int,1 > > _2149,    std::shared_ptr< monty::ndarray< int,1 > > _2150){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2144(_2144 ? _2144->raw() : nullptr, _2144 ? _2144->size(0) : 0);
    _checked_ptr_1<double> _ptr__2145(_2145 ? _2145->raw() : nullptr, _2145 ? _2145->size(0) : 0);
    _checked_ptr_1<int> _ptr__2146(_2146 ? _2146->raw() : nullptr, _2146 ? _2146->size(0) : 0);
    _checked_ptr_1<double> _ptr__2147(_2147 ? _2147->raw() : nullptr, _2147 ? _2147->size(0) : 0);
    _checked_ptr_1<int> _ptr__2148(_2148 ? _2148->raw() : nullptr, _2148 ? _2148->size(0) : 0);
    _checked_ptr_1<int> _ptr__2149(_2149 ? _2149->raw() : nullptr, _2149 ? _2149->size(0) : 0);
    _checked_ptr_1<int> _ptr__2150(_2150 ? _2150->raw() : nullptr, _2150 ? _2150->size(0) : 0);
    nrows = ((int)((_2144)->size(0)) - (int)1);
    nnz = _ptr__2144[((int)((_2144)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2147.get()))
    {
      {
        bfix = _2147;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2148.get()) && ((NULL != _2149.get()) && (NULL != _2150.get()))))
    {
      {
        nbarnz = (int)((_2148)->size(0));
        if ((nbarnz > (int)((_2149)->size(0))))
        {
          {
            nbarnz = (int)((_2149)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2150)->size(0))))
        {
          {
            nbarnz = (int)((_2150)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2148,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2149,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2150,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2146,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2145,(long long)0,cof,(long long)0,nnz);
    int _7842 = (int)0;
    int _7843 = nrows;
    for (int _2151 = _7842; _2151 < _7843; ++_2151)
    {
      {
        long long _7844 = _ptr__2144[_2151];
        long long _7845 = _ptr__2144[safe_add( _2151,(int)1 )];
        for (long long _2152 = _7844; _2152 < _7845; ++_2152)
        {
          {
            ((*subi)(_2152)) = _2151;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2153){
  _checked_ptr_1<double> _ptr__2153(_2153 ? _2153->raw() : nullptr, _2153 ? _2153->size(0) : 0);
  int _7846 = (int)0;
  int _7847 = nrows;
  for (int _2154 = _7846; _2154 < _7847; ++_2154)
  {
    {
      ((*bfix)(_2154)) = (((*bfix)(_2154)) + _ptr__2153[_2154]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _7848;
  for (long long _2156 = (long long)0, _7849 = nbarnz; _2156 < _7849 ; ++_2156)
  {
    _7848.push_back(_2156);
  }
  auto _7850 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7848.size()),_7848.begin(),_7848.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2155 = _7850;
  _checked_ptr_1<long long> _ptr__2155(_2155 ? _2155->raw() : nullptr,_2155 ? _2155->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2155,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2155,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2157 = barsubi;
      _checked_ptr_1<int> _ptr__2157(_2157 ? _2157->raw() : nullptr,_2157 ? _2157->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2158 = barsubj;
      _checked_ptr_1<int> _ptr__2158(_2158 ? _2158->raw() : nullptr,_2158 ? _2158->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2159 = barmatidx;
      _checked_ptr_1<int> _ptr__2159(_2159 ? _2159->raw() : nullptr,_2159 ? _2159->size(0) : 0);
      std::vector<int> _7851;
      for (long long _2160 = (int)0, _7852 = nbarnz; _2160 < _7852 ; ++_2160)
      {
        _7851.push_back(_ptr__2157[_ptr__2155[_2160]]);
      }
      auto _7853 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7851.size()),_7851.begin(),_7851.end()));
      barsubi = _7853;
      std::vector<int> _7854;
      for (long long _2161 = (int)0, _7855 = nbarnz; _2161 < _7855 ; ++_2161)
      {
        _7854.push_back(_ptr__2158[_ptr__2155[_2161]]);
      }
      auto _7856 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7854.size()),_7854.begin(),_7854.end()));
      barsubj = _7856;
      std::vector<int> _7857;
      for (long long _2162 = (int)0, _7858 = nbarnz; _2162 < _7858 ; ++_2162)
      {
        _7857.push_back(_ptr__2159[_ptr__2155[_2162]]);
      }
      auto _7859 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7857.size()),_7857.begin(),_7857.end()));
      barmatidx = _7859;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< int,1 > > _2164,std::shared_ptr< monty::ndarray< int,1 > > _2165){
  _checked_ptr_1<int> _ptr__2163(_2163 ? _2163->raw() : nullptr, _2163 ? _2163->size(0) : 0);
  _checked_ptr_1<int> _ptr__2164(_2164 ? _2164->raw() : nullptr, _2164 ? _2164->size(0) : 0);
  _checked_ptr_1<int> _ptr__2165(_2165 ? _2165->raw() : nullptr, _2165 ? _2165->size(0) : 0);
  if ((NULL != _2163.get()))
  {
    {
      int _2166 = (int)((_2163)->size(0));
      if (((int)((_2163)->size(0)) <= safe_add( nbarnz,_2166 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2167 = barsubi;
          _checked_ptr_1<int> _ptr__2167(_2167 ? _2167->raw() : nullptr,_2167 ? _2167->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2168 = barsubj;
          _checked_ptr_1<int> _ptr__2168(_2168 ? _2168->raw() : nullptr,_2168 ? _2168->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2169 = barmatidx;
          _checked_ptr_1<int> _ptr__2169(_2169 ? _2169->raw() : nullptr,_2169 ? _2169->size(0) : 0);
          long long _7860;
          bool _7861 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2166 ));
          if (_7861)
          {
            _7860 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _7860 = safe_add( nbarnz,safe_mul( _2166,(int)2 ) );
          }
          long long _2170 = _7860;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2170)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2170)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2170)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2167,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2168,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2169,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2163,(long long)((int)0),barsubi,nbarnz,(long long)(_2166));
      ::mosek::fusion::Utils::Tools::arraycopy(_2164,(long long)((int)0),barsubj,nbarnz,(long long)(_2166));
      ::mosek::fusion::Utils::Tools::arraycopy(_2165,(long long)((int)0),barmatidx,nbarnz,(long long)(_2166));
      nbarnz += _2166;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2171,std::shared_ptr< monty::ndarray< int,1 > > _2172,std::shared_ptr< monty::ndarray< double,1 > > _2173,std::shared_ptr< monty::ndarray< double,1 > > _2174){
  _checked_ptr_1<long long> _ptr__2171(_2171 ? _2171->raw() : nullptr, _2171 ? _2171->size(0) : 0);
  _checked_ptr_1<int> _ptr__2172(_2172 ? _2172->raw() : nullptr, _2172 ? _2172->size(0) : 0);
  _checked_ptr_1<double> _ptr__2173(_2173 ? _2173->raw() : nullptr, _2173 ? _2173->size(0) : 0);
  _checked_ptr_1<double> _ptr__2174(_2174 ? _2174->raw() : nullptr, _2174 ? _2174->size(0) : 0);
  long long _2175 = safe_add( nunordered,_ptr__2171[nrows] );
  long long _2176 = _ptr__2171[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2177;
  _checked_ptr_1<int> _ptr__2177(_2177 ? _2177->raw() : nullptr,_2177 ? _2177->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2178;
  _checked_ptr_1<int> _ptr__2178(_2178 ? _2178->raw() : nullptr,_2178 ? _2178->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2179;
  _checked_ptr_1<double> _ptr__2179(_2179 ? _2179->raw() : nullptr,_2179 ? _2179->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2175)))
  {
    {
      _2177 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2175)));
      _ptr__2177.update(_2177 ? _2177->raw() : nullptr, _2177 ? _2177->size(0) : 0);
      _2178 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2175)));
      _ptr__2178.update(_2178 ? _2178->raw() : nullptr, _2178 ? _2178->size(0) : 0);
      _2179 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2175)));
      _ptr__2179.update(_2179 ? _2179->raw() : nullptr, _2179 ? _2179->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2177,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2178,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2179,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2177 = buffer_subi;
      _ptr__2177.update(_2177 ? _2177->raw() : nullptr, _2177 ? _2177->size(0) : 0);
      _2178 = buffer_subj;
      _ptr__2178.update(_2178 ? _2178->raw() : nullptr, _2178 ? _2178->size(0) : 0);
      _2179 = buffer_cof;
      _ptr__2179.update(_2179 ? _2179->raw() : nullptr, _2179 ? _2179->size(0) : 0);
    }
  }
  int _7862 = (int)0;
  int _7863 = nrows;
  for (int _2180 = _7862; _2180 < _7863; ++_2180)
  {
    {
      long long _7864 = _ptr__2171[_2180];
      long long _7865 = _ptr__2171[safe_add( _2180,(int)1 )];
      for (long long _2181 = _7864; _2181 < _7865; ++_2181)
      {
        {
          _ptr__2177[safe_add( nunordered,_2181 )] = _2180;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2172,(long long)0,_2178,nunordered,_2176);
  ::mosek::fusion::Utils::Tools::arraycopy(_2173,(long long)0,_2179,nunordered,_2176);
  buffer_subi = _2177;
  buffer_subj = _2178;
  buffer_cof = _2179;
  if ((NULL != _2174.get()))
  {
    {
      int _7866 = (int)0;
      int _7867 = nrows;
      for (int _2182 = _7866; _2182 < _7867; ++_2182)
      {
        {
          ((*bfix)(_2182)) = (((*bfix)(_2182)) + _ptr__2174[_2182]);
        }
      }
    }
  }
  {}
  nunordered = _2175;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2183,std::shared_ptr< monty::ndarray< int,1 > > _2184,std::shared_ptr< monty::ndarray< double,1 > > _2185,std::shared_ptr< monty::ndarray< double,1 > > _2186) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2183,_2184,_2185,_2186); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2183,std::shared_ptr< monty::ndarray< int,1 > > _2184,std::shared_ptr< monty::ndarray< double,1 > > _2185,std::shared_ptr< monty::ndarray< double,1 > > _2186){
  _checked_ptr_1<long long> _ptr__2183(_2183 ? _2183->raw() : nullptr, _2183 ? _2183->size(0) : 0);
  _checked_ptr_1<int> _ptr__2184(_2184 ? _2184->raw() : nullptr, _2184 ? _2184->size(0) : 0);
  _checked_ptr_1<double> _ptr__2185(_2185 ? _2185->raw() : nullptr, _2185 ? _2185->size(0) : 0);
  _checked_ptr_1<double> _ptr__2186(_2186 ? _2186->raw() : nullptr, _2186 ? _2186->size(0) : 0);
  if ((((int)((_2183)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2186.get()) && ((int)((_2186)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2183,_2184,_2185,_2186);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2187,std::shared_ptr< monty::ndarray< int,1 > > _2188,std::shared_ptr< monty::ndarray< double,1 > > _2189,std::shared_ptr< monty::ndarray< double,1 > > _2190) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2187,_2188,_2189,_2190); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2187,std::shared_ptr< monty::ndarray< int,1 > > _2188,std::shared_ptr< monty::ndarray< double,1 > > _2189,std::shared_ptr< monty::ndarray< double,1 > > _2190){
  _checked_ptr_1<int> _ptr__2187(_2187 ? _2187->raw() : nullptr, _2187 ? _2187->size(0) : 0);
  _checked_ptr_1<int> _ptr__2188(_2188 ? _2188->raw() : nullptr, _2188 ? _2188->size(0) : 0);
  _checked_ptr_1<double> _ptr__2189(_2189 ? _2189->raw() : nullptr, _2189 ? _2189->size(0) : 0);
  _checked_ptr_1<double> _ptr__2190(_2190 ? _2190->raw() : nullptr, _2190 ? _2190->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2191 = nullptr;
  _checked_ptr_1<long long> _ptr__2191(_2191 ? _2191->raw() : nullptr,_2191 ? _2191->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2190.get())))
  {
    {
      int _7868 = (int)0;
      int _7869 = nrows;
      for (int _2192 = _7868; _2192 < _7869; ++_2192)
      {
        {
          _ptr__2190[_2192] = ((*bfix)(_2192));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2193 = false;
  {
    int _2194 = (int)1;
    while ( ((_2194 < nunordered) && ((((*buffer_subi)((_2194 - (int)1))) < ((*buffer_subi)(_2194))) || ((((*buffer_subi)((_2194 - (int)1))) == ((*buffer_subi)(_2194))) && (((*buffer_subj)((_2194 - (int)1))) <= ((*buffer_subj)(_2194)))))) )
    {
      {
        ++ _2194;
      }
    }
    _2193 = (_2194 == nunordered);
  }
  if ((!_2193))
  {
    {
      std::vector<long long> _7870;
      for (long long _2195 = (int)0, _7871 = nunordered; _2195 < _7871 ; ++_2195)
      {
        _7870.push_back(_2195);
      }
      auto _7872 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7870.size()),_7870.begin(),_7870.end()));
      _2191 = _7872;
      _ptr__2191.update(_2191 ? _2191->raw() : nullptr, _2191 ? _2191->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2191,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2196 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2197 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2196 ))));
  _checked_ptr_1<int> _ptr__2197(_2197 ? _2197->raw() : nullptr,_2197 ? _2197->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2198 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2196 ))));
  _checked_ptr_1<int> _ptr__2198(_2198 ? _2198->raw() : nullptr,_2198 ? _2198->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2199 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2196 ))));
  _checked_ptr_1<double> _ptr__2199(_2199 ? _2199->raw() : nullptr,_2199 ? _2199->size(0) : 0);
  long long _2200 = (long long)0;
  if (_2193)
  {
    {
      long long _2201 = (long long)0;
      int _2202 = (int)0;
      long long _2203 = nunordered;
      long long _2204 = _2196;
      int _2205 = (int)0;
      int _2206 = (int)0;
      while ( ((_2206 < _2204) && (_2205 < _2203)) )
      {
        {
          if (((((*subi)(_2206)) < ((*buffer_subi)(_2205))) || ((((*subi)(_2206)) == ((*buffer_subi)(_2205))) && (((*subj)(_2206)) < ((*buffer_subj)(_2205))))))
          {
            {
              _ptr__2197[_2202] = ((*subi)(_2206));
              _ptr__2198[_2202] = ((*subj)(_2206));
              _ptr__2199[_2202] = ((*cof)(_2206));
              ++ _2206;
              ++ _2202;
            }
          }
          else if(((((*subi)(_2206)) > ((*buffer_subi)(_2205))) || ((((*subi)(_2206)) == ((*buffer_subi)(_2205))) && (((*subj)(_2206)) > ((*buffer_subj)(_2205))))))
          {
            {
              _ptr__2197[_2202] = ((*buffer_subi)(_2205));
              _ptr__2198[_2202] = ((*buffer_subj)(_2205));
              _ptr__2199[_2202] = ((*buffer_cof)(_2205));
              _ptr__2187[_2200] = _ptr__2197[_2202];
              _ptr__2188[_2200] = _ptr__2198[_2202];
              _ptr__2189[_2200] = _ptr__2199[_2202];
              ++ _2200;
              ++ _2205;
              ++ _2202;
            }
          }
          else
          {
            {
              _ptr__2197[_2202] = ((*subi)(_2206));
              _ptr__2198[_2202] = ((*subj)(_2206));
              _ptr__2199[_2202] = ((*cof)(_2206));
              while ( ((_2206 < (int)((subi)->size(0))) && ((_2205 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2206)) == ((*buffer_subi)(_2205))) && (((*subj)(_2206)) == ((*buffer_subj)(_2205)))))) )
              {
                {
                  _ptr__2199[_2202] = (_ptr__2199[_2202] + ((*buffer_cof)(_2205)));
                  ++ _2205;
                }
              }
              _ptr__2187[_2200] = _ptr__2197[_2202];
              _ptr__2188[_2200] = _ptr__2198[_2202];
              _ptr__2189[_2200] = _ptr__2199[_2202];
              ++ _2200;
              ++ _2206;
              ++ _2202;
            }
          }
        }
      }
      while ( (_2206 < _2204) )
      {
        {
          _ptr__2197[_2202] = ((*subi)(_2206));
          _ptr__2198[_2202] = ((*subj)(_2206));
          _ptr__2199[_2202] = ((*cof)(_2206));
          ++ _2206;
          ++ _2202;
        }
      }
      while ( (_2205 < _2203) )
      {
        {
          _ptr__2197[_2202] = ((*buffer_subi)(_2205));
          _ptr__2198[_2202] = ((*buffer_subj)(_2205));
          _ptr__2199[_2202] = ((*buffer_cof)(_2205));
          _ptr__2187[_2200] = _ptr__2197[_2202];
          _ptr__2188[_2200] = _ptr__2198[_2202];
          _ptr__2189[_2200] = _ptr__2199[_2202];
          ++ _2200;
          ++ _2205;
          ++ _2202;
        }
      }
      nnz = _2202;
    }
  }
  else
  {
    {
      long long _2207 = (long long)0;
      int _2208 = (int)0;
      long long _2209 = nunordered;
      long long _2210 = _2196;
      int _2211 = (int)0;
      int _2212 = (int)0;
      while ( ((_2212 < _2210) && (_2211 < _2209)) )
      {
        {
          if (((((*subi)(_2212)) < ((*buffer_subi)(_ptr__2191[_2211]))) || ((((*subi)(_2212)) == ((*buffer_subi)(_ptr__2191[_2211]))) && (((*subj)(_2212)) < ((*buffer_subj)(_ptr__2191[_2211]))))))
          {
            {
              _ptr__2197[_2208] = ((*subi)(_2212));
              _ptr__2198[_2208] = ((*subj)(_2212));
              _ptr__2199[_2208] = ((*cof)(_2212));
              ++ _2212;
              ++ _2208;
            }
          }
          else if(((((*subi)(_2212)) > ((*buffer_subi)(_ptr__2191[_2211]))) || ((((*subi)(_2212)) == ((*buffer_subi)(_ptr__2191[_2211]))) && (((*subj)(_2212)) > ((*buffer_subj)(_ptr__2191[_2211]))))))
          {
            {
              _ptr__2197[_2208] = ((*buffer_subi)(_ptr__2191[_2211]));
              _ptr__2198[_2208] = ((*buffer_subj)(_ptr__2191[_2211]));
              _ptr__2199[_2208] = ((*buffer_cof)(_ptr__2191[_2211]));
              _ptr__2187[_2200] = _ptr__2197[_2208];
              _ptr__2188[_2200] = _ptr__2198[_2208];
              _ptr__2189[_2200] = _ptr__2199[_2208];
              ++ _2200;
              ++ _2211;
              ++ _2208;
            }
          }
          else
          {
            {
              _ptr__2197[_2208] = ((*subi)(_2212));
              _ptr__2198[_2208] = ((*subj)(_2212));
              _ptr__2199[_2208] = ((*cof)(_2212));
              while ( ((((*subi)(_2212)) == ((*buffer_subi)(_ptr__2191[_2211]))) && (((*subj)(_2212)) == ((*buffer_subj)(_ptr__2191[_2211])))) )
              {
                {
                  _ptr__2199[_2208] = (_ptr__2199[_2208] + ((*buffer_cof)(_ptr__2191[_2211])));
                  ++ _2211;
                }
              }
              _ptr__2187[_2200] = _ptr__2197[_2208];
              _ptr__2188[_2200] = _ptr__2198[_2208];
              _ptr__2189[_2200] = _ptr__2199[_2208];
              ++ _2200;
              ++ _2212;
              ++ _2208;
            }
          }
        }
      }
      nnz = _2208;
    }
  }
  subi = _2197;
  subj = _2198;
  cof = _2199;
  nunordered = (long long)0;
  return _2200;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2213,    std::shared_ptr< monty::ndarray< int,1 > > _2214,    std::shared_ptr< monty::ndarray< int,1 > > _2215){ return new mosek::fusion::SliceConstraint(_2213,_2214,_2215); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2213,    std::shared_ptr< monty::ndarray< int,1 > > _2214,    std::shared_ptr< monty::ndarray< int,1 > > _2215) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2213,_2214,_2215); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2213,    std::shared_ptr< monty::ndarray< int,1 > > _2214,    std::shared_ptr< monty::ndarray< int,1 > > _2215){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2214(_2214 ? _2214->raw() : nullptr, _2214 ? _2214->size(0) : 0);
    _checked_ptr_1<int> _ptr__2215(_2215 ? _2215->raw() : nullptr, _2215 ? _2215->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2213,_2214,_2215);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2216 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2216->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2216->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2217,    monty::rc_ptr< ::mosek::fusion::Model > _2218){ return new mosek::fusion::RangedConstraint(_2217,_2218); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2217,    monty::rc_ptr< ::mosek::fusion::Model > _2218) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2217,_2218); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2217,    monty::rc_ptr< ::mosek::fusion::Model > _2218){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2217,_2218);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2217)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2217)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2219,    const std::string &  _2220,    std::shared_ptr< monty::ndarray< int,1 > > _2221,    std::shared_ptr< monty::ndarray< int,1 > > _2222){ return new mosek::fusion::RangedConstraint(_2219,_2220,_2221,_2222); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2219,    const std::string &  _2220,    std::shared_ptr< monty::ndarray< int,1 > > _2221,    std::shared_ptr< monty::ndarray< int,1 > > _2222) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2219,_2220,_2221,_2222); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2219,    const std::string &  _2220,    std::shared_ptr< monty::ndarray< int,1 > > _2221,    std::shared_ptr< monty::ndarray< int,1 > > _2222){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2221(_2221 ? _2221->raw() : nullptr, _2221 ? _2221->size(0) : 0);
    _checked_ptr_1<int> _ptr__2222(_2222 ? _2222->raw() : nullptr, _2222 ? _2222->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2219,_2220,_2221,_2222);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2221;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2222;
  }
}monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2223){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2223)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2224,    monty::rc_ptr< ::mosek::fusion::Model > _2225){ return new mosek::fusion::ConicConstraint(_2224,_2225); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2224,    monty::rc_ptr< ::mosek::fusion::Model > _2225) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2224,_2225); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2224,    monty::rc_ptr< ::mosek::fusion::Model > _2225){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2224,_2225);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2224)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2226,    const std::string &  _2227,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2228,    std::shared_ptr< monty::ndarray< int,1 > > _2229,    int _2230,    std::shared_ptr< monty::ndarray< int,1 > > _2231,    std::shared_ptr< monty::ndarray< int,1 > > _2232){ return new mosek::fusion::ConicConstraint(_2226,_2227,_2228,_2229,_2230,_2231,_2232); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2226,    const std::string &  _2227,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2228,    std::shared_ptr< monty::ndarray< int,1 > > _2229,    int _2230,    std::shared_ptr< monty::ndarray< int,1 > > _2231,    std::shared_ptr< monty::ndarray< int,1 > > _2232) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2226,_2227,_2228,_2229,_2230,_2231,_2232); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2226,    const std::string &  _2227,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2228,    std::shared_ptr< monty::ndarray< int,1 > > _2229,    int _2230,    std::shared_ptr< monty::ndarray< int,1 > > _2231,    std::shared_ptr< monty::ndarray< int,1 > > _2232){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2229(_2229 ? _2229->raw() : nullptr, _2229 ? _2229->size(0) : 0);
    _checked_ptr_1<int> _ptr__2231(_2231 ? _2231->raw() : nullptr, _2231 ? _2231->size(0) : 0);
    _checked_ptr_1<int> _ptr__2232(_2232 ? _2232->raw() : nullptr, _2232 ? _2232->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2226,_2227,_2229,_2231);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2228;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2229;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2227;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2231;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2232;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2230;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2233 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2234 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _7873 = (int)0;
          int _7874 = _2233;
          for (int _2235 = _7873; _2235 < _7874; ++_2235)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2234.get())->task_var_name(((*nativeslack)(_2235)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2236 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _7875 = (int)0;
          int _7876 = _2233;
          for (int _2237 = _7875; _2237 < _7876; ++_2237)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2234.get())->task_var_name(((*nativeslack)(_2237)),_2236->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2237)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2238 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2238->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2238->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2239,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2240){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2241){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2241)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2242,    monty::rc_ptr< ::mosek::fusion::Model > _2243){ return new mosek::fusion::LinearConstraint(_2242,_2243); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2242,    monty::rc_ptr< ::mosek::fusion::Model > _2243) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2242,_2243); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2242,    monty::rc_ptr< ::mosek::fusion::Model > _2243){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2242,_2243);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2242)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2242)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2244,    const std::string &  _2245,    int _2246,    std::shared_ptr< monty::ndarray< int,1 > > _2247,    std::shared_ptr< monty::ndarray< int,1 > > _2248){ return new mosek::fusion::LinearConstraint(_2244,_2245,_2246,_2247,_2248); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2244,    const std::string &  _2245,    int _2246,    std::shared_ptr< monty::ndarray< int,1 > > _2247,    std::shared_ptr< monty::ndarray< int,1 > > _2248) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2244,_2245,_2246,_2247,_2248); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2244,    const std::string &  _2245,    int _2246,    std::shared_ptr< monty::ndarray< int,1 > > _2247,    std::shared_ptr< monty::ndarray< int,1 > > _2248){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2247(_2247 ? _2247->raw() : nullptr, _2247 ? _2247->size(0) : 0);
    _checked_ptr_1<int> _ptr__2248(_2248 ? _2248->raw() : nullptr, _2248 ? _2248->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2244,_2245,_2247,_2248);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2246;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2245;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2249 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2249->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2249->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2250,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2251){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2252){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2252)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2253,    monty::rc_ptr< ::mosek::fusion::Model > _2254){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2253,_2254);
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2253)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2253)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2253)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2253)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2255,    const std::string &  _2256,    std::shared_ptr< monty::ndarray< int,1 > > _2257,    std::shared_ptr< monty::ndarray< int,1 > > _2258){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2257(_2257 ? _2257->raw() : nullptr, _2257 ? _2257->size(0) : 0);
    _checked_ptr_1<int> _ptr__2258(_2258 ? _2258->raw() : nullptr, _2258 ? _2258->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2255,_2257,_2258);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2256;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2258;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2257;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2259 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2259->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2259->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2260 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if ((_pubthis->getSize() == (int)0))
      {
        {
          names_flushed = true;
        }
      }
      else
      {
        {
          if (((int)((name).size()) == (int)0))
          {
            {
              mosek::fusion::p_Model::_get_impl(_2260.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
            }
          }
          else
          {
            {
              monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2261 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
              _2261->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
              if ((_pubthis->getND() > (int)0))
              {
                {
                  _2261->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
                  int _7877 = (int)1;
                  int _7878 = _pubthis->getND();
                  for (int _2262 = _7877; _2262 < _7878; ++_2262)
                  {
                    {
                      _2261->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2262);
                    }
                  }
                }
              }
              {}
              _2261->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
              std::shared_ptr< monty::ndarray< int,1 > > _7879;
              bool _7880 = (_pubthis->getND() > (int)0);
              if (_7880)
              {
                _7879 = _pubthis->getShape();
              }
              else
              {
                _7879 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
              }
              mosek::fusion::p_Model::_get_impl(_2260.get())->connames(nativeidxs,_2261->toString(),_7879,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
              names_flushed = true;
            }
          }
        }
      }
    }
  }
  {}
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2264,    monty::rc_ptr< ::mosek::fusion::Model > _2265){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2265;
    shape = mosek::fusion::p_Constraint::_get_impl(_2264)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2264)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2266,    std::shared_ptr< monty::ndarray< int,1 > > _2267,    std::shared_ptr< monty::ndarray< int,1 > > _2268){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2267(_2267 ? _2267->raw() : nullptr, _2267 ? _2267->size(0) : 0);
    _checked_ptr_1<int> _ptr__2268(_2268 ? _2268->raw() : nullptr, _2268 ? _2268->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2266;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2267;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2268;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2269,long long _2270,std::shared_ptr< monty::ndarray< std::string,1 > > _2271){
  _checked_ptr_1<long long> _ptr__2269(_2269 ? _2269->raw() : nullptr, _2269 ? _2269->size(0) : 0);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2272 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2272(_2272 ? _2272->raw() : nullptr,_2272 ? _2272->size(0) : 0);
  values(false,(int)0,_2272);
  return _2272;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2273 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2273(_2273 ? _2273->raw() : nullptr,_2273 ? _2273->size(0) : 0);
  values(true,(int)0,_2273);
  return _2273;
}
void mosek::fusion::p_Constraint::values(bool _2274,int _2275,std::shared_ptr< monty::ndarray< double,1 > > _2276){
  _checked_ptr_1<double> _ptr__2276(_2276 ? _2276->raw() : nullptr, _2276 ? _2276->size(0) : 0);
  model->getConstraintValues(_2274,nativeidxs,_2276,_2275);
}
void mosek::fusion::Constraint :: update(std::shared_ptr< monty::ndarray< double,1 > > _2277) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2277); }void mosek::fusion::p_Constraint::update(std::shared_ptr< monty::ndarray< double,1 > > _2277){
  _checked_ptr_1<double> _ptr__2277(_2277 ? _2277->raw() : nullptr, _2277 ? _2277->size(0) : 0);
  mosek::fusion::p_Model::_get_impl(model.get())->update_bfix(nativeidxs,_2277);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2278) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2278); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2278){
  std::shared_ptr< monty::ndarray< int,1 > > _2279 = _2278->getShape();
  _checked_ptr_1<int> _ptr__2279(_2279 ? _2279->raw() : nullptr,_2279 ? _2279->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2279)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7881 = (int)0;
  int _7882 = (int)((_2279)->size(0));
  for (int _2280 = _7881; _2280 < _7882; ++_2280)
  {
    {
      if ((_ptr__2279[_2280] != ((*shape)(_2280))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7883 = (int)((_2279)->size(0));
  int _7884 = (int)((shape)->size(0));
  for (int _2281 = _7883; _2281 < _7884; ++_2281)
  {
    {
      if ((((*shape)(_2281)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2278);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2282,monty::rc_ptr< ::mosek::fusion::Variable > _2283,bool _2284) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2282,_2283,_2284); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2282,monty::rc_ptr< ::mosek::fusion::Variable > _2283,bool _2284){
  int _2285 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2286 = _2282->getShape();
  _checked_ptr_1<int> _ptr__2286(_2286 ? _2286->raw() : nullptr,_2286 ? _2286->size(0) : 0);
  if ((_2285 < (int)((_2286)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7885 = (int)0;
  int _7886 = (int)((_2286)->size(0));
  for (int _2287 = _7885; _2287 < _7886; ++_2287)
  {
    {
      if ((_ptr__2286[_2287] != ((*shape)(_2287))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7887 = (int)((_2286)->size(0));
  int _7888 = (int)((shape)->size(0));
  for (int _2288 = _7887; _2288 < _7888; ++_2288)
  {
    {
      if ((((*shape)(_2288)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2289 = _2283->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2290 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2289)));
  _checked_ptr_1<long long> _ptr__2290(_2290 ? _2290->raw() : nullptr,_2290 ? _2290->size(0) : 0);
  if ((_2289 < _2283->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2291 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2289)));
      _checked_ptr_1<long long> _ptr__2291(_2291 ? _2291->raw() : nullptr,_2291 ? _2291->size(0) : 0);
      _2283->inst((int)0,_2291,(int)0,_2290);
    }
  }
  else
  {
    {
      _2283->inst((int)0,_2290);
    }
  }
  int _7889 = (int)0;
  int _7890 = _2289;
  for (int _2292 = _7889; _2292 < _7890; ++_2292)
  {
    {
      if ((_ptr__2290[_2292] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2293;
  _checked_ptr_1<int> _ptr__2293(_2293 ? _2293->raw() : nullptr,_2293 ? _2293->size(0) : 0);
  {
    bool _2294 = true;
    int _7891 = (int)0;
    int _7892 = (_2289 - (int)1);
    for (int _2295 = _7891; _2295 < _7892; ++_2295)
    {
      {
        _2294 = (_2294 && (_ptr__2290[_2295] < _ptr__2290[safe_add( _2295,(int)1 )]));
      }
    }
    if (_2294)
    {
      {
        std::vector<int> _7893;
        for (int _2296 = (int)0, _7894 = _2289; _2296 < _7894 ; ++_2296)
        {
          _7893.push_back((int)(_ptr__2290[_2296] - (int)1));
        }
        auto _7895 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7893.size()),_7893.begin(),_7893.end()));
        _2293 = _7895;
        _ptr__2293.update(_2293 ? _2293->raw() : nullptr, _2293 ? _2293->size(0) : 0);
      }
    }
    else
    {
      {
        std::vector<long long> _7896;
        for (int _2298 = (int)0, _7897 = _2289; _2298 < _7897 ; ++_2298)
        {
          _7896.push_back(_2298);
        }
        auto _7898 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7896.size()),_7896.begin(),_7896.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2297 = _7898;
        _checked_ptr_1<long long> _ptr__2297(_2297 ? _2297->raw() : nullptr,_2297 ? _2297->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2297,_2290,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2289));
        int _2299 = (int)1;
        int _7899 = (int)1;
        int _7900 = _2289;
        for (int _2300 = _7899; _2300 < _7900; ++_2300)
        {
          {
            if ((_ptr__2290[_ptr__2297[(_2300 - (int)1)]] < _ptr__2290[_ptr__2297[_2300]]))
            {
              {
                ++ _2299;
              }
            }
            {}
          }
        }
        _2293 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2299)));
        _ptr__2293.update(_2293 ? _2293->raw() : nullptr, _2293 ? _2293->size(0) : 0);
        int _2301 = (int)0;
        _ptr__2293[(int)0] = (int)(_ptr__2290[_ptr__2297[(int)0]] - (int)1);
        int _7901 = (int)1;
        int _7902 = _2289;
        for (int _2302 = _7901; _2302 < _7902; ++_2302)
        {
          {
            if ((_ptr__2290[(_2302 - (int)1)] < _ptr__2290[_2302]))
            {
              {
                _ptr__2293[_2301] = (int)(_ptr__2290[_ptr__2297[_2302]] - (int)1);
                ++ _2301;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2282,_2293,_2284);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2303,monty::rc_ptr< ::mosek::fusion::Variable > _2304) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2303,_2304); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2303,monty::rc_ptr< ::mosek::fusion::Variable > _2304){
  _pubthis->update(_2303,_2304,false);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2305 = (int)1;
  int _7903 = (int)0;
  int _7904 = (int)((shape)->size(0));
  for (int _2306 = _7903; _2306 < _7904; ++_2306)
  {
    {
      _2305 *= ((*shape)(_2306));
    }
  }
  return _2305;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2307,    int _2308) { return mosek::fusion::p_Constraint::stack(_2307,_2308); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2307,int _2308){
  return ::mosek::fusion::p_Constraint::dstack(_2307,_2308);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2309,    monty::rc_ptr< ::mosek::fusion::Constraint > _2310,    monty::rc_ptr< ::mosek::fusion::Constraint > _2311,    int _2312) { return mosek::fusion::p_Constraint::stack(_2309,_2310,_2311,_2312); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2309,monty::rc_ptr< ::mosek::fusion::Constraint > _2310,monty::rc_ptr< ::mosek::fusion::Constraint > _2311,int _2312){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2309.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2310.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2311.get())}),_2312);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2313,    monty::rc_ptr< ::mosek::fusion::Constraint > _2314,    int _2315) { return mosek::fusion::p_Constraint::stack(_2313,_2314,_2315); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2313,monty::rc_ptr< ::mosek::fusion::Constraint > _2314,int _2315){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2313.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2314.get())}),_2315);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2316) { return mosek::fusion::p_Constraint::hstack(_2316); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2316){
  return ::mosek::fusion::p_Constraint::dstack(_2316,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2317) { return mosek::fusion::p_Constraint::vstack(_2317); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2317){
  return ::mosek::fusion::p_Constraint::dstack(_2317,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2318,    monty::rc_ptr< ::mosek::fusion::Constraint > _2319,    monty::rc_ptr< ::mosek::fusion::Constraint > _2320) { return mosek::fusion::p_Constraint::hstack(_2318,_2319,_2320); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2318,monty::rc_ptr< ::mosek::fusion::Constraint > _2319,monty::rc_ptr< ::mosek::fusion::Constraint > _2320){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2318.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2319.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2320.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2321,    monty::rc_ptr< ::mosek::fusion::Constraint > _2322,    monty::rc_ptr< ::mosek::fusion::Constraint > _2323) { return mosek::fusion::p_Constraint::vstack(_2321,_2322,_2323); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2321,monty::rc_ptr< ::mosek::fusion::Constraint > _2322,monty::rc_ptr< ::mosek::fusion::Constraint > _2323){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2321.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2322.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2323.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2324,    monty::rc_ptr< ::mosek::fusion::Constraint > _2325) { return mosek::fusion::p_Constraint::hstack(_2324,_2325); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2324,monty::rc_ptr< ::mosek::fusion::Constraint > _2325){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2324.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2325.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2326,    monty::rc_ptr< ::mosek::fusion::Constraint > _2327) { return mosek::fusion::p_Constraint::vstack(_2326,_2327); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2326,monty::rc_ptr< ::mosek::fusion::Constraint > _2327){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2326.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2327.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2328,int _2329){
  monty::rc_ptr< ::mosek::fusion::Model > _2330 = nullptr;
  {
    int _7905 = (int)0;
    int _7906 = (int)((_2328)->size(0));
    for (int _2331 = _7905; _2331 < _7906; ++_2331)
    {
      {
        if ((NULL == _2330.get()))
        {
          {
            _2330 = ((*_2328)(_2331))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2328)(_2331)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2328)(_2331)))->model != _2330)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2332 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7907;
            bool _7908 = ((int)((mosek::fusion::p_Model::_get_impl(_2330.get())->getName()).size()) > (int)0);
            if (_7908)
            {
              _7907 = mosek::fusion::p_Model::_get_impl(_2330.get())->getName();
            }
            else
            {
              _7907 = std::string ("?");
            }
            std::string _2333 = _7907;
            std::string _7909;
            bool _7910 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2328)(_2331))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_7910)
            {
              _7909 = mosek::fusion::p_Model::_get_impl(((*_2328)(_2331))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _7909 = std::string ("?");
            }
            std::string _2334 = _7909;
            _2332->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2333)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2334)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2332->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2328)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2328)->size(0)) == (int)1))
  {
    {
      return ((*_2328)((int)1));
    }
  }
  else
  {
    {
      int _2335 = (int)((_2328)->size(0));
      int _2336 = (int)1;
      int _7911 = (int)0;
      int _7912 = _2335;
      for (int _2337 = _7911; _2337 < _7912; ++_2337)
      {
        {
          int _7913;
          bool _7914 = (((*_2328)(_2337))->getND() > _2336);
          if (_7914)
          {
            _7913 = ((*_2328)(_2337))->getND();
          }
          else
          {
            _7913 = _2336;
          }
          _2336 = _7913;
        }
      }
      if ((_2329 == _2336))
      {
        {
          ++ _2336;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2338 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2335,_2336)));
      int _7915 = (int)0;
      int _7916 = _2335;
      for (int _2339 = _7915; _2339 < _7916; ++_2339)
      {
        {
          int _7917 = (int)0;
          int _7918 = _2336;
          for (int _2340 = _7917; _2340 < _7918; ++_2340)
          {
            {
              ((*_2338)(_2339,_2340)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _7919;
      for (int _2342 = (int)0, _7920 = _2335; _2342 < _7920 ; ++_2342)
      {
        _7919.push_back(((*_2328)(_2342))->getSize());
      }
      auto _7921 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7919.size()),_7919.begin(),_7919.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2341 = _7921;
      _checked_ptr_1<int> _ptr__2341(_2341 ? _2341->raw() : nullptr,_2341 ? _2341->size(0) : 0);
      int _2343 = (int)0;
      int _7922 = (int)0;
      int _7923 = _2335;
      for (int _2344 = _7922; _2344 < _7923; ++_2344)
      {
        {
          _2343 += _ptr__2341[_2344];
        }
      }
      int _7924 = (int)0;
      int _7925 = _2335;
      for (int _2345 = _7924; _2345 < _7925; ++_2345)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2346 = ((*_2328)(_2345))->getShape();
          _checked_ptr_1<int> _ptr__2346(_2346 ? _2346->raw() : nullptr,_2346 ? _2346->size(0) : 0);
          int _7926 = (int)0;
          int _7927 = (int)((_2346)->size(0));
          for (int _2347 = _7926; _2347 < _7927; ++_2347)
          {
            {
              ((*_2338)(_2345,_2347)) = _ptr__2346[_2347];
            }
          }
        }
      }
      if (((_2329 < (int)0) || (_2329 > _2336)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _7928 = (int)0;
      int _7929 = _2329;
      for (int _2348 = _7928; _2348 < _7929; ++_2348)
      {
        {
          int _7930 = (int)1;
          int _7931 = _2335;
          for (int _2349 = _7930; _2349 < _7931; ++_2349)
          {
            {
              if ((((*_2338)((int)0,_2348)) != ((*_2338)(_2349,_2348))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _7932 = safe_add( _2329,(int)1 );
      int _7933 = _2336;
      for (int _2350 = _7932; _2350 < _7933; ++_2350)
      {
        {
          int _7934 = (int)1;
          int _7935 = _2335;
          for (int _2351 = _7934; _2351 < _7935; ++_2351)
          {
            {
              if ((((*_2338)((int)0,_2350)) != ((*_2338)(_2351,_2350))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2352 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2343)));
      _checked_ptr_1<int> _ptr__2352(_2352 ? _2352->raw() : nullptr,_2352 ? _2352->size(0) : 0);
      std::vector<int> _7936;
      for (int _2354 = (int)0, _7937 = _2336; _2354 < _7937 ; ++_2354)
      {
        _7936.push_back(((*_2338)((int)0,_2354)));
      }
      auto _7938 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7936.size()),_7936.begin(),_7936.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2353 = _7938;
      _checked_ptr_1<int> _ptr__2353(_2353 ? _2353->raw() : nullptr,_2353 ? _2353->size(0) : 0);
      int _7939 = (int)0;
      int _7940 = _2336;
      for (int _2355 = _7939; _2355 < _7940; ++_2355)
      {
        {
          _ptr__2353[_2329] += ((*_2338)(_2355,_2329));
        }
      }
      {
        int _2356 = (int)((_2353)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2357 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2328)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2357(_2357 ? _2357->raw() : nullptr,_2357 ? _2357->size(0) : 0);
        int _7941 = (int)0;
        int _7942 = (int)((_2328)->size(0));
        for (int _2358 = _7941; _2358 < _7942; ++_2358)
        {
          {
            _ptr__2357[safe_add( _2358,(int)1 )] = safe_add( _ptr__2357[_2358],((*_2338)(_2358,_2329)) );
          }
        }
        if ((_2329 == (int)0))
        {
          {
            int _2359 = (int)0;
            int _7943 = (int)0;
            int _7944 = _2335;
            for (int _2360 = _7943; _2360 < _7944; ++_2360)
            {
              {
                int _2361 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2328)(_2360)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2328)(_2360)))->nativeidxs,(int)0,_2352,_2359,_2361);
                _2359 += _2361;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7945;
            for (int _2363 = (int)0, _7946 = _2335; _2363 < _7946 ; ++_2363)
            {
              _7945.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2328)(_2363)))->nativeidxs);
            }
            auto _7947 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7945.size()),_7945.begin(),_7945.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2362 = _7947;
            if ((_2329 < _2336))
            {
              {
                int _2364 = (int)1;
                int _7948 = (int)0;
                int _7949 = _2329;
                for (int _2365 = _7948; _2365 < _7949; ++_2365)
                {
                  {
                    _2364 *= _ptr__2353[_2365];
                  }
                }
                int _2366 = (int)1;
                int _7950 = safe_add( _2329,(int)1 );
                int _7951 = _2336;
                for (int _2367 = _7950; _2367 < _7951; ++_2367)
                {
                  {
                    _2366 *= _ptr__2353[_2367];
                  }
                }
                int _2368 = (int)0;
                int _7952 = (int)0;
                int _7953 = _2364;
                for (int _2369 = _7952; _2369 < _7953; ++_2369)
                {
                  {
                    int _7954 = (int)0;
                    int _7955 = _2335;
                    for (int _2370 = _7954; _2370 < _7955; ++_2370)
                    {
                      {
                        int _2371 = (int)0;
                        int _2372 = ((*_2338)(_2370,_2329));
                        int _7956 = (int)0;
                        int _7957 = _2372;
                        for (int _2373 = _7956; _2373 < _7957; ++_2373)
                        {
                          {
                            int _7958 = (int)0;
                            int _7959 = _2366;
                            for (int _2374 = _7958; _2374 < _7959; ++_2374)
                            {
                              {
                                _ptr__2352[_2368] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2328)(_2335)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2369,_2366 ),_2372 ),_2371 )));
                                ++ _2368;
                                ++ _2371;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2375 = (int)1;
                int _7960 = (int)0;
                int _7961 = _2336;
                for (int _2376 = _7960; _2376 < _7961; ++_2376)
                {
                  {
                    _2375 *= _ptr__2353[_2376];
                  }
                }
                int _2377 = (int)0;
                int _7962 = (int)0;
                int _7963 = _2375;
                for (int _2378 = _7962; _2378 < _7963; ++_2378)
                {
                  {
                    int _7964 = (int)0;
                    int _7965 = _2335;
                    for (int _2379 = _7964; _2379 < _7965; ++_2379)
                    {
                      {
                        _ptr__2352[_2377] = ((*((*_2362)(_2379)))(_2378));
                        ++ _2377;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2330,_2353,_2352)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2380) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2380); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2380) { return __mosek_2fusion_2Constraint__index(_2380); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2380){
  _checked_ptr_1<int> _ptr__2380(_2380 ? _2380->raw() : nullptr, _2380 ? _2380->size(0) : 0);
  if (((int)((_2380)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7966 = (int)0;
      int _7967 = (int)((shape)->size(0));
      for (int _2381 = _7966; _2381 < _7967; ++_2381)
      {
        {
          if (((_ptr__2380[_2381] < (int)0) || (_ptr__2380[_2381] > ((*shape)(_2381)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2382 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2383 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2382)));
      _checked_ptr_1<long long> _ptr__2383(_2383 ? _2383->raw() : nullptr,_2383 ? _2383->size(0) : 0);
      _ptr__2383[(_2382 - (int)1)] = (int)1;
      int _7968 = (int)1;
      int _7969 = _2382;
      for (int _2384 = _7968; _2384 < _7969; ++_2384)
      {
        {
          _ptr__2383[((_2382 - _2384) - (int)1)] = safe_mul( _ptr__2383[(_2382 - _2384)],((*shape)(_2384)) );
        }
      }
      int _2385 = (int)0;
      int _7970 = (int)0;
      int _7971 = _2382;
      for (int _2386 = _7970; _2386 < _7971; ++_2386)
      {
        {
          _2385 += (int)safe_mul( _ptr__2383[_2386],_ptr__2380[_2386] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2385)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2387) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2387); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2387) { return __mosek_2fusion_2Constraint__index(_2387); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2387){
  if ((((int)((shape)->size(0)) == (int)0) && (_2387 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2387 < (int)0) || (_2387 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2387)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2388,std::shared_ptr< monty::ndarray< int,1 > > _2389) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2388,_2389); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2388,std::shared_ptr< monty::ndarray< int,1 > > _2389) { return __mosek_2fusion_2Constraint__slice(_2388,_2389); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2388,std::shared_ptr< monty::ndarray< int,1 > > _2389){
  _checked_ptr_1<int> _ptr__2388(_2388 ? _2388->raw() : nullptr, _2388 ? _2388->size(0) : 0);
  _checked_ptr_1<int> _ptr__2389(_2389 ? _2389->raw() : nullptr, _2389 ? _2389->size(0) : 0);
  if (((int)((_2388)->size(0)) != (int)((_2389)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2388)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7972 = (int)0;
      int _7973 = (int)((shape)->size(0));
      for (int _2390 = _7972; _2390 < _7973; ++_2390)
      {
        {
          if (((_ptr__2388[_2390] < (int)0) || (_ptr__2389[_2390] > ((*shape)(_2390)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2388[_2390] > _ptr__2389[_2390]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2391 = (int)((shape)->size(0));
      std::vector<int> _7974;
      for (int _2393 = (int)0, _7975 = _2391; _2393 < _7975 ; ++_2393)
      {
        _7974.push_back((_ptr__2389[_2393] - _ptr__2388[_2393]));
      }
      auto _7976 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7974.size()),_7974.begin(),_7974.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2392 = _7976;
      _checked_ptr_1<int> _ptr__2392(_2392 ? _2392->raw() : nullptr,_2392 ? _2392->size(0) : 0);
      int _2394 = (int)1;
      int _7977 = (int)0;
      int _7978 = _2391;
      for (int _2395 = _7977; _2395 < _7978; ++_2395)
      {
        {
          _2394 *= (_ptr__2389[_2395] - _ptr__2388[_2395]);
        }
      }
      if ((_2394 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2392,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2396 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2394)));
          _checked_ptr_1<int> _ptr__2396(_2396 ? _2396->raw() : nullptr,_2396 ? _2396->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2397 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2391)));
            _checked_ptr_1<int> _ptr__2397(_2397 ? _2397->raw() : nullptr,_2397 ? _2397->size(0) : 0);
            _ptr__2397[(_2391 - (int)1)] = (int)1;
            int _7979 = (int)1;
            int _7980 = _2391;
            for (int _2398 = _7979; _2398 < _7980; ++_2398)
            {
              {
                _ptr__2397[((_2391 - _2398) - (int)1)] = safe_mul( _ptr__2397[(_2391 - _2398)],((*shape)((_2391 - _2398))) );
              }
            }
            int _2399 = (int)0;
            int _7981 = (int)0;
            int _7982 = _2391;
            for (int _2400 = _7981; _2400 < _7982; ++_2400)
            {
              {
                _2399 += safe_mul( _ptr__2388[_2400],_ptr__2397[_2400] );
              }
            }
            std::vector<int> _7983;
            for (int _2402 = (int)0, _7984 = _2391; _2402 < _7984 ; ++_2402)
            {
              _7983.push_back(_2399);
            }
            auto _7985 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7983.size()),_7983.begin(),_7983.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2401 = _7985;
            _checked_ptr_1<int> _ptr__2401(_2401 ? _2401->raw() : nullptr,_2401 ? _2401->size(0) : 0);
            std::vector<int> _7986;
            for (int _2404 = (int)0, _7987 = _2391; _2404 < _7987 ; ++_2404)
            {
              _7986.push_back(_ptr__2388[_2404]);
            }
            auto _7988 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7986.size()),_7986.begin(),_7986.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2403 = _7988;
            _checked_ptr_1<int> _ptr__2403(_2403 ? _2403->raw() : nullptr,_2403 ? _2403->size(0) : 0);
            int _7989 = (int)0;
            int _7990 = _2394;
            for (int _2405 = _7989; _2405 < _7990; ++_2405)
            {
              {
                _ptr__2396[_2405] = ((*nativeidxs)(_ptr__2401[(_2391 - (int)1)]));
                _ptr__2403[(_2391 - (int)1)] += (int)1;
                _ptr__2401[(_2391 - (int)1)] += _ptr__2397[(_2391 - (int)1)];
                if ((_ptr__2403[(_2391 - (int)1)] >= _ptr__2389[(_2391 - (int)1)]))
                {
                  {
                    int _2406 = (_2391 - (int)1);
                    while ( ((_2406 > (int)0) && (_ptr__2403[_2406] >= _ptr__2389[_2406])) )
                    {
                      {
                        _ptr__2403[_2406] = _ptr__2388[_2406];
                        _ptr__2403[(_2406 - (int)1)] += (int)1;
                        _ptr__2401[(_2406 - (int)1)] += _ptr__2397[(_2406 - (int)1)];
                        -- _2406;
                      }
                    }
                    int _7991 = safe_add( _2406,(int)1 );
                    int _7992 = _2391;
                    for (int _2407 = _7991; _2407 < _7992; ++_2407)
                    {
                      {
                        _ptr__2401[_2407] = _ptr__2401[_2406];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2392,_2396)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2408,int _2409) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2408,_2409); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2408,int _2409) { return __mosek_2fusion_2Constraint__slice(_2408,_2409); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2408,int _2409){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2408 == (int)0) && (_2409 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2408 < (int)0) || (_2409 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2408 > _2409))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _7993;
      for (int _2410 = _2408, _7994 = _2409; _2410 < _7994 ; ++_2410)
      {
        _7993.push_back(((*nativeidxs)(_2410)));
      }
      auto _7995 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7993.size()),_7993.begin(),_7993.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2409 - _2408))}),_7995)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2411 = (int)1;
  int _7996 = (int)0;
  int _7997 = (int)((shape)->size(0));
  for (int _2412 = _7996; _2412 < _7997; ++_2412)
  {
    {
      _2411 *= ((*shape)(_2412));
    }
  }
  return _2411;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _7998;
  for (int _2413 = (int)0, _7999 = (int)((shape)->size(0)); _2413 < _7999 ; ++_2413)
  {
    _7998.push_back(((*shape)(_2413)));
  }
  auto _8000 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7998.size()),_7998.begin(),_7998.end()));
  return _8000;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2414) { return mosek::fusion::p_Set::size(_2414); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2414){
  _checked_ptr_1<int> _ptr__2414(_2414 ? _2414->raw() : nullptr, _2414 ? _2414->size(0) : 0);
  long long _2415 = (long long)1;
  int _8001 = (int)0;
  int _8002 = (int)((_2414)->size(0));
  for (int _2416 = _8001; _2416 < _8002; ++_2416)
  {
    {
      _2415 *= _ptr__2414[_2416];
    }
  }
  return _2415;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2417,    std::shared_ptr< monty::ndarray< int,1 > > _2418) { return mosek::fusion::p_Set::match(_2417,_2418); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2417,std::shared_ptr< monty::ndarray< int,1 > > _2418){
  _checked_ptr_1<int> _ptr__2417(_2417 ? _2417->raw() : nullptr, _2417 ? _2417->size(0) : 0);
  _checked_ptr_1<int> _ptr__2418(_2418 ? _2418->raw() : nullptr, _2418 ? _2418->size(0) : 0);
  if (((int)((_2417)->size(0)) != (int)((_2418)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _8003 = (int)0;
  int _8004 = (int)((_2417)->size(0));
  for (int _2419 = _8003; _2419 < _8004; ++_2419)
  {
    {
      if ((_ptr__2417[_2419] != _ptr__2418[_2419]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2420,    std::shared_ptr< monty::ndarray< int,1 > > _2421) { return mosek::fusion::p_Set::linearidx(_2420,_2421); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2420,std::shared_ptr< monty::ndarray< int,1 > > _2421){
  _checked_ptr_1<int> _ptr__2420(_2420 ? _2420->raw() : nullptr, _2420 ? _2420->size(0) : 0);
  _checked_ptr_1<int> _ptr__2421(_2421 ? _2421->raw() : nullptr, _2421 ? _2421->size(0) : 0);
  long long _2422 = _ptr__2421[(int)0];
  int _8005 = (int)1;
  int _8006 = (int)((_2421)->size(0));
  for (int _2423 = _8005; _2423 < _8006; ++_2423)
  {
    {
      _2422 = safe_add( safe_mul( _2422,_ptr__2420[_2423] ),_ptr__2421[_2423] );
    }
  }
  return _2422;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2424,    long long _2425) { return mosek::fusion::p_Set::idxtokey(_2424,_2425); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2424,long long _2425){
  _checked_ptr_1<int> _ptr__2424(_2424 ? _2424->raw() : nullptr, _2424 ? _2424->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2426 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2424)->size(0)))));
  _checked_ptr_1<int> _ptr__2426(_2426 ? _2426->raw() : nullptr,_2426 ? _2426->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2424,_2425,_2426);
  return _2426;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2427,    long long _2428,    std::shared_ptr< monty::ndarray< int,1 > > _2429) { mosek::fusion::p_Set::idxtokey(_2427,_2428,_2429); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2427,long long _2428,std::shared_ptr< monty::ndarray< int,1 > > _2429){
  _checked_ptr_1<int> _ptr__2427(_2427 ? _2427->raw() : nullptr, _2427 ? _2427->size(0) : 0);
  _checked_ptr_1<int> _ptr__2429(_2429 ? _2429->raw() : nullptr, _2429 ? _2429->size(0) : 0);
  int _2430 = (int)((_2427)->size(0));
  if ((_2430 > (int)0))
  {
    {
      long long _2431 = _2428;
      int _8007 = (int)0;
      int _8008 = (_2430 - (int)1);
      for (int _2432 = _8007; _2432 < _8008; ++_2432)
      {
        {
          _ptr__2429[((_2430 - _2432) - (int)1)] = (int)(_2431 % _ptr__2427[((_2430 - _2432) - (int)1)]);
          _2431 /= _ptr__2427[((_2430 - _2432) - (int)1)];
        }
      }
      _ptr__2429[(int)0] = (int)_2431;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2433,    long long _2434) { return mosek::fusion::p_Set::indexToString(_2433,_2434); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2433,long long _2434){
  _checked_ptr_1<int> _ptr__2433(_2433 ? _2433->raw() : nullptr, _2433 ? _2433->size(0) : 0);
  int _2435 = (int)((_2433)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2436 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2435 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2435 == (int)1))
  {
    {
      return _2436->__mosek_2fusion_2Utils_2StringBuffer__a(_2434)->toString();
    }
  }
  else
  {
    {
      long long _2437 = _2434;
      std::shared_ptr< monty::ndarray< int,1 > > _2438 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2435)));
      _checked_ptr_1<int> _ptr__2438(_2438 ? _2438->raw() : nullptr,_2438 ? _2438->size(0) : 0);
      int _8009 = (int)1;
      int _8010 = _2435;
      for (int _2439 = _8009; _2439 < _8010; ++_2439)
      {
        {
          _ptr__2438[(_2435 - _2439)] = (int)(_2437 % _ptr__2433[(_2435 - _2439)]);
          _2437 /= _ptr__2433[(_2435 - _2439)];
        }
      }
      _ptr__2438[(int)0] = (int)_2437;
      _2436->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2438[(int)0]);
      int _8011 = (int)1;
      int _8012 = _2435;
      for (int _2440 = _8011; _2440 < _8012; ++_2440)
      {
        {
          _2436->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2438[_2440]);
        }
      }
      return _2436->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2441) { return mosek::fusion::p_Set::keyToString(_2441); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2441){
  _checked_ptr_1<int> _ptr__2441(_2441 ? _2441->raw() : nullptr, _2441 ? _2441->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2442 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2442->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2441[(int)0]);
  int _8013 = (int)1;
  int _8014 = (int)((_2441)->size(0));
  for (int _2443 = _8013; _2443 < _8014; ++_2443)
  {
    {
      _2442->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2441[_2443]);
    }
  }
  return _2442->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2444,    long long _2445,    std::shared_ptr< monty::ndarray< int,1 > > _2446) { mosek::fusion::p_Set::indexToKey(_2444,_2445,_2446); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2444,long long _2445,std::shared_ptr< monty::ndarray< int,1 > > _2446){
  _checked_ptr_1<int> _ptr__2444(_2444 ? _2444->raw() : nullptr, _2444 ? _2444->size(0) : 0);
  _checked_ptr_1<int> _ptr__2446(_2446 ? _2446->raw() : nullptr, _2446 ? _2446->size(0) : 0);
  int _2447 = (int)((_2444)->size(0));
  if ((_2447 == (int)1))
  {
    {
      _ptr__2446[(int)0] = (int)_2445;
    }
  }
  else
  {
    {
      long long _2448 = _2445;
      int _8015 = (int)1;
      int _8016 = _2447;
      for (int _2449 = _8015; _2449 < _8016; ++_2449)
      {
        {
          _ptr__2446[(_2447 - _2449)] = (int)(_2448 % _ptr__2444[(_2447 - _2449)]);
          _2448 /= _ptr__2444[(_2447 - _2449)];
        }
      }
      _ptr__2446[(int)0] = (int)_2448;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2450) { return mosek::fusion::p_Set::strides(_2450); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2450){
  _checked_ptr_1<int> _ptr__2450(_2450 ? _2450->raw() : nullptr, _2450 ? _2450->size(0) : 0);
  int _2451 = (int)((_2450)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2452 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2451)));
  _checked_ptr_1<long long> _ptr__2452(_2452 ? _2452->raw() : nullptr,_2452 ? _2452->size(0) : 0);
  _ptr__2452[(_2451 - (int)1)] = (int)1;
  int _8017 = (int)1;
  int _8018 = _2451;
  for (int _2453 = _8017; _2453 < _8018; ++_2453)
  {
    {
      _ptr__2452[((_2451 - _2453) - (int)1)] = safe_mul( _ptr__2452[(_2451 - _2453)],_ptr__2450[(_2451 - _2453)] );
    }
  }
  return _2452;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2454,    std::shared_ptr< monty::ndarray< int,1 > > _2455) { return mosek::fusion::p_Set::make(_2454,_2455); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2454,std::shared_ptr< monty::ndarray< int,1 > > _2455){
  _checked_ptr_1<int> _ptr__2454(_2454 ? _2454->raw() : nullptr, _2454 ? _2454->size(0) : 0);
  _checked_ptr_1<int> _ptr__2455(_2455 ? _2455->raw() : nullptr, _2455 ? _2455->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2456 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2454)->size(0)),(int)((_2455)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2456(_2456 ? _2456->raw() : nullptr,_2456 ? _2456->size(0) : 0);
  int _8019 = (int)0;
  int _8020 = (int)((_2454)->size(0));
  for (int _2457 = _8019; _2457 < _8020; ++_2457)
  {
    {
      _ptr__2456[_2457] = _ptr__2454[_2457];
    }
  }
  int _8021 = (int)0;
  int _8022 = (int)((_2455)->size(0));
  for (int _2458 = _8021; _2458 < _8022; ++_2458)
  {
    {
      _ptr__2456[safe_add( (int)((_2454)->size(0)),_2458 )] = _ptr__2455[_2458];
    }
  }
  return _2456;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2459) { return mosek::fusion::p_Set::make(_2459); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2459){
  _checked_ptr_1<int> _ptr__2459(_2459 ? _2459->raw() : nullptr, _2459 ? _2459->size(0) : 0);
  std::vector<int> _8023;
  for (int _2460 = (int)0, _8024 = (int)((_2459)->size(0)); _2460 < _8024 ; ++_2460)
  {
    _8023.push_back(_ptr__2459[_2460]);
  }
  auto _8025 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8023.size()),_8023.begin(),_8023.end()));
  return _8025;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2461,    int _2462,    int _2463) { return mosek::fusion::p_Set::make(_2461,_2462,_2463); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2461,int _2462,int _2463){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2461),(int)(_2462),(int)(_2463)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2464,    int _2465) { return mosek::fusion::p_Set::make(_2464,_2465); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2464,int _2465){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2464),(int)(_2465)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2466) { return mosek::fusion::p_Set::make(_2466); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2466){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2466)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2467) { return mosek::fusion::p_Set::make(_2467); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2467){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2467)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2468,    double _2469,    std::shared_ptr< monty::ndarray< int,1 > > _2470){ return new mosek::fusion::ConeDomain(_2468,_2469,_2470); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2468,    double _2469,    std::shared_ptr< monty::ndarray< int,1 > > _2470) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2468,_2469,_2470); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2468,    double _2469,    std::shared_ptr< monty::ndarray< int,1 > > _2470){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2470(_2470 ? _2470->raw() : nullptr, _2470 ? _2470->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _8026;
    bool _8027 = (NULL != _2470.get());
    if (_8027)
    {
      _8026 = ::mosek::fusion::p_Set::make(_2470);
    }
    else
    {
      _8026 = nullptr;
    }
    shape = _8026;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2469;
    key = _2468;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2469;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2471,    std::shared_ptr< monty::ndarray< int,1 > > _2472){ return new mosek::fusion::ConeDomain(_2471,_2472); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2471,    std::shared_ptr< monty::ndarray< int,1 > > _2472) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2471,_2472); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2471,    std::shared_ptr< monty::ndarray< int,1 > > _2472){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2472(_2472 ? _2472->raw() : nullptr, _2472 ? _2472->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2471,1.0,_2472);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2473){
  _checked_ptr_1<int> _ptr__2473(_2473 ? _2473->raw() : nullptr, _2473 ? _2473->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2473,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2474) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2474); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2474) { return __mosek_2fusion_2ConeDomain__axis(_2474); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2474){
  axisidx = _2474;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2475,    int _2476){ return new mosek::fusion::LinPSDDomain(_2475,_2476); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2475,    int _2476) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2475,_2476); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2475,    int _2476){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2475(_2475 ? _2475->raw() : nullptr, _2475 ? _2475->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2476;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2475);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2477){ return new mosek::fusion::LinPSDDomain(_2477); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2477) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2477); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2477){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2477(_2477 ? _2477->raw() : nullptr, _2477 ? _2477->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2477);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2478,    std::shared_ptr< monty::ndarray< int,1 > > _2479,    int _2480,    int _2481){ return new mosek::fusion::PSDDomain(_2478,_2479,_2480,_2481); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2478,    std::shared_ptr< monty::ndarray< int,1 > > _2479,    int _2480,    int _2481) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2478,_2479,_2480,_2481); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2478,    std::shared_ptr< monty::ndarray< int,1 > > _2479,    int _2480,    int _2481){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2479(_2479 ? _2479->raw() : nullptr, _2479 ? _2479->size(0) : 0);
    axisIsSet = true;
    shape = _2479;
    key = _2478;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2480;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2481;
    int _2482 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2480) && (((int)((shape)->size(0)) > _2481) && ((_2480 >= (int)0) && ((_2481 >= (int)0) && (_2480 != _2481)))))) && (((*shape)(_2480)) == ((*shape)(_2481)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2483,    std::shared_ptr< monty::ndarray< int,1 > > _2484){ return new mosek::fusion::PSDDomain(_2483,_2484); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2483,    std::shared_ptr< monty::ndarray< int,1 > > _2484) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2483,_2484); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2483,    std::shared_ptr< monty::ndarray< int,1 > > _2484){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2484(_2484 ? _2484->raw() : nullptr, _2484 ? _2484->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2483,_2484,((int)((_2484)->size(0)) - (int)2),((int)((_2484)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2485){ return new mosek::fusion::PSDDomain(_2485); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2485) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2485); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2485){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2485;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2486,int _2487) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2486,_2487); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2486,int _2487) { return __mosek_2fusion_2PSDDomain__axis(_2486,_2487); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2486,int _2487){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2486;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2487;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2486 >= (int)0) && ((_2487 >= (int)0) && (_2486 != _2487))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2486) && (((int)((shape)->size(0)) > _2487) && ((_2486 >= (int)0) && ((_2487 >= (int)0) && (_2486 != _2487)))))) && (((*shape)(_2486)) == ((*shape)(_2487))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2488){ return new mosek::fusion::SymmetricRangeDomain(_2488); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2488) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2488); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2488){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2488);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _8028;
    bool _8029 = (NULL == shape.get());
    if (_8029)
    {
      _8028 = (int)0;
    }
    else
    {
      _8028 = ((*shape)((int)0));
    }
    dim = _8028;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2489,    std::shared_ptr< monty::ndarray< double,1 > > _2490,    std::shared_ptr< monty::ndarray< double,1 > > _2491,    std::shared_ptr< monty::ndarray< int,1 > > _2492){ return new mosek::fusion::RangeDomain(_2489,_2490,_2491,_2492); }mosek::fusion::RangeDomain::RangeDomain  (bool _2489,    std::shared_ptr< monty::ndarray< double,1 > > _2490,    std::shared_ptr< monty::ndarray< double,1 > > _2491,    std::shared_ptr< monty::ndarray< int,1 > > _2492) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2489,_2490,_2491,_2492); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2489,    std::shared_ptr< monty::ndarray< double,1 > > _2490,    std::shared_ptr< monty::ndarray< double,1 > > _2491,    std::shared_ptr< monty::ndarray< int,1 > > _2492){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2490(_2490 ? _2490->raw() : nullptr, _2490 ? _2490->size(0) : 0);
    _checked_ptr_1<double> _ptr__2491(_2491 ? _2491->raw() : nullptr, _2491 ? _2491->size(0) : 0);
    _checked_ptr_1<int> _ptr__2492(_2492 ? _2492->raw() : nullptr, _2492 ? _2492->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2489,_2490,_2491,_2492,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2493,    std::shared_ptr< monty::ndarray< double,1 > > _2494,    std::shared_ptr< monty::ndarray< double,1 > > _2495,    std::shared_ptr< monty::ndarray< int,1 > > _2496,    std::shared_ptr< monty::ndarray< int,2 > > _2497){ return new mosek::fusion::RangeDomain(_2493,_2494,_2495,_2496,_2497); }mosek::fusion::RangeDomain::RangeDomain  (bool _2493,    std::shared_ptr< monty::ndarray< double,1 > > _2494,    std::shared_ptr< monty::ndarray< double,1 > > _2495,    std::shared_ptr< monty::ndarray< int,1 > > _2496,    std::shared_ptr< monty::ndarray< int,2 > > _2497) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2493,_2494,_2495,_2496,_2497); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2493,    std::shared_ptr< monty::ndarray< double,1 > > _2494,    std::shared_ptr< monty::ndarray< double,1 > > _2495,    std::shared_ptr< monty::ndarray< int,1 > > _2496,    std::shared_ptr< monty::ndarray< int,2 > > _2497){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2494(_2494 ? _2494->raw() : nullptr, _2494 ? _2494->size(0) : 0);
    _checked_ptr_1<double> _ptr__2495(_2495 ? _2495->raw() : nullptr, _2495 ? _2495->size(0) : 0);
    _checked_ptr_1<int> _ptr__2496(_2496 ? _2496->raw() : nullptr, _2496 ? _2496->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2493,_2494,_2495,_2496,_2497,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2498,    std::shared_ptr< monty::ndarray< double,1 > > _2499,    std::shared_ptr< monty::ndarray< double,1 > > _2500,    std::shared_ptr< monty::ndarray< int,1 > > _2501,    std::shared_ptr< monty::ndarray< int,2 > > _2502,    int _2503){ return new mosek::fusion::RangeDomain(_2498,_2499,_2500,_2501,_2502,_2503); }mosek::fusion::RangeDomain::RangeDomain  (bool _2498,    std::shared_ptr< monty::ndarray< double,1 > > _2499,    std::shared_ptr< monty::ndarray< double,1 > > _2500,    std::shared_ptr< monty::ndarray< int,1 > > _2501,    std::shared_ptr< monty::ndarray< int,2 > > _2502,    int _2503) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2498,_2499,_2500,_2501,_2502,_2503); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2498,    std::shared_ptr< monty::ndarray< double,1 > > _2499,    std::shared_ptr< monty::ndarray< double,1 > > _2500,    std::shared_ptr< monty::ndarray< int,1 > > _2501,    std::shared_ptr< monty::ndarray< int,2 > > _2502,    int _2503){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2499(_2499 ? _2499->raw() : nullptr, _2499 ? _2499->size(0) : 0);
    _checked_ptr_1<double> _ptr__2500(_2500 ? _2500->raw() : nullptr, _2500 ? _2500->size(0) : 0);
    _checked_ptr_1<int> _ptr__2501(_2501 ? _2501->raw() : nullptr, _2501 ? _2501->size(0) : 0);
    cardinal_flag = false;
    shape = _2501;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2498;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2500;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2499;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2502;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2504){ return new mosek::fusion::RangeDomain(_2504); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2504) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2504); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2504){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2504)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2504)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2504)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2504)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2504)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2504)->lb;
    empty = mosek::fusion::p_RangeDomain::_get_impl(_2504)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2505) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2505); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2505) { return __mosek_2fusion_2RangeDomain__sparse(_2505); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2505){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2505)->size(0)),(int)((_2505)->size(1)))));
  {
    int _2506 = (int)0;
    for(;(_2506 < (int)((_2505)->size(0)));++ _2506)
    {
      {
        {
          int _2507 = (int)0;
          for(;(_2507 < (int)((_2505)->size(1)));++ _2507)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2506,_2507)) = ((*_2505)(_2506,_2507));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2508) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2508); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2508) { return __mosek_2fusion_2RangeDomain__sparse(_2508); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2508){
  _checked_ptr_1<int> _ptr__2508(_2508 ? _2508->raw() : nullptr, _2508 ? _2508->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2508)->size(0)),(int)1)));
  int _8030 = (int)0;
  int _8031 = (int)((_2508)->size(0));
  for (int _2509 = _8030; _2509 < _8031; ++_2509)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2509,(int)0)) = _ptr__2508[_2509];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse() { return __mosek_2fusion_2RangeDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2510) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2510); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2510) { return __mosek_2fusion_2RangeDomain__withShape(_2510); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2510){
  _checked_ptr_1<int> _ptr__2510(_2510 ? _2510->raw() : nullptr, _2510 ? _2510->size(0) : 0);
  shape = _2510;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2511){
  _checked_ptr_1<int> _ptr__2511(_2511 ? _2511->raw() : nullptr, _2511 ? _2511->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2511)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _8032 = (int)0;
      int _8033 = (int)((shape)->size(0));
      for (int _2512 = _8032; _2512 < _8033; ++_2512)
      {
        {
          if ((((*shape)(_2512)) != _ptr__2511[_2512]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2513){ return new mosek::fusion::SymmetricLinearDomain(_2513); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2513) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2513); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2513){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2513;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2513)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2513)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2513)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2513)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _8034;
    bool _8035 = (NULL == shape.get());
    if (_8035)
    {
      _8034 = (int)0;
    }
    else
    {
      _8034 = ((*shape)((int)0));
    }
    dim = _8034;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2514) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2514); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2514) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2514); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2514){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2514)->size(0)),(int)((_2514)->size(1)))));
  {
    int _2515 = (int)0;
    for(;(_2515 < (int)((_2514)->size(0)));++ _2515)
    {
      {
        {
          int _2516 = (int)0;
          for(;(_2516 < (int)((_2514)->size(1)));++ _2516)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2515,_2516)) = ((*_2514)(_2515,_2516));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2517) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2517); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2517) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2517); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2517){
  _checked_ptr_1<int> _ptr__2517(_2517 ? _2517->raw() : nullptr, _2517 ? _2517->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2517)->size(0)),(int)1)));
  int _8036 = (int)0;
  int _8037 = (int)((_2517)->size(0));
  for (int _2518 = _8036; _2518 < _8037; ++_2518)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2518,(int)0)) = _ptr__2517[_2518];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2519){
  _checked_ptr_1<int> _ptr__2519(_2519 ? _2519->raw() : nullptr, _2519 ? _2519->size(0) : 0);
  int _8038 = (int)0;
  int _8039 = (int)((_2519)->size(0));
  for (int _2520 = _8038; _2520 < _8039; ++_2520)
  {
    {
      if ((_ptr__2519[_2520] == ((*shape)(_2520))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2521,    bool _2522,    std::shared_ptr< monty::ndarray< double,1 > > _2523,    std::shared_ptr< monty::ndarray< int,1 > > _2524){ return new mosek::fusion::LinearDomain(_2521,_2522,_2523,_2524); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2521,    bool _2522,    std::shared_ptr< monty::ndarray< double,1 > > _2523,    std::shared_ptr< monty::ndarray< int,1 > > _2524) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2521,_2522,_2523,_2524); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2521,    bool _2522,    std::shared_ptr< monty::ndarray< double,1 > > _2523,    std::shared_ptr< monty::ndarray< int,1 > > _2524){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2523(_2523 ? _2523->raw() : nullptr, _2523 ? _2523->size(0) : 0);
    _checked_ptr_1<int> _ptr__2524(_2524 ? _2524->raw() : nullptr, _2524 ? _2524->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2521,_2522,_2523,_2524,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2525,    bool _2526,    std::shared_ptr< monty::ndarray< double,1 > > _2527,    std::shared_ptr< monty::ndarray< int,1 > > _2528,    std::shared_ptr< monty::ndarray< int,2 > > _2529,    int _2530){ return new mosek::fusion::LinearDomain(_2525,_2526,_2527,_2528,_2529,_2530); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2525,    bool _2526,    std::shared_ptr< monty::ndarray< double,1 > > _2527,    std::shared_ptr< monty::ndarray< int,1 > > _2528,    std::shared_ptr< monty::ndarray< int,2 > > _2529,    int _2530) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2525,_2526,_2527,_2528,_2529,_2530); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2525,    bool _2526,    std::shared_ptr< monty::ndarray< double,1 > > _2527,    std::shared_ptr< monty::ndarray< int,1 > > _2528,    std::shared_ptr< monty::ndarray< int,2 > > _2529,    int _2530){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2527(_2527 ? _2527->raw() : nullptr, _2527 ? _2527->size(0) : 0);
    _checked_ptr_1<int> _ptr__2528(_2528 ? _2528->raw() : nullptr, _2528 ? _2528->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2526;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2528;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2525;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2527;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2529;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2531){ return new mosek::fusion::LinearDomain(_2531); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2531) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2531); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2531){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2531)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2531)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2531)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2531)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2531)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2531)->cardinal_flag;
    empty = mosek::fusion::p_LinearDomain::_get_impl(_2531)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2532) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2532); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2532) { return __mosek_2fusion_2LinearDomain__sparse(_2532); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2532){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2532)->size(0)),(int)((_2532)->size(1)))));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  {
    int _2533 = (int)0;
    for(;(_2533 < (int)((_2532)->size(0)));++ _2533)
    {
      {
        {
          int _2534 = (int)0;
          for(;(_2534 < (int)((_2532)->size(1)));++ _2534)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2533,_2534)) = ((*_2532)(_2533,_2534));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2535) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2535); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2535) { return __mosek_2fusion_2LinearDomain__sparse(_2535); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2535){
  _checked_ptr_1<int> _ptr__2535(_2535 ? _2535->raw() : nullptr, _2535 ? _2535->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2535)->size(0)),(int)1)));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  int _8040 = (int)0;
  int _8041 = (int)((_2535)->size(0));
  for (int _2536 = _8040; _2536 < _8041; ++_2536)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2536,(int)0)) = _ptr__2535[_2536];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse() { return __mosek_2fusion_2LinearDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2537) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2537); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2537) { return __mosek_2fusion_2LinearDomain__withShape(_2537); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2537){
  _checked_ptr_1<int> _ptr__2537(_2537 ? _2537->raw() : nullptr, _2537 ? _2537->size(0) : 0);
  shape = _2537;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2538){
  _checked_ptr_1<int> _ptr__2538(_2538 ? _2538->raw() : nullptr, _2538 ? _2538->size(0) : 0);
  if ((!scalable))
  {
    {
      int _8042 = (int)0;
      int _8043 = (int)((_2538)->size(0));
      for (int _2539 = _8042; _2539 < _8043; ++_2539)
      {
        {
          if ((_ptr__2538[_2539] == ((*shape)(_2539))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2540){
  _checked_ptr_1<int> _ptr__2540(_2540 ? _2540->raw() : nullptr, _2540 ? _2540->size(0) : 0);
  long long _2541 = (long long)1;
  int _8044 = (int)0;
  int _8045 = (int)((_2540)->size(0));
  for (int _2542 = _8044; _2542 < _8045; ++_2542)
  {
    {
      _2541 *= _ptr__2540[_2542];
    }
  }
  return _2541;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::mkRangedDomain(monty::rc_ptr< ::mosek::fusion::Matrix > _2543,monty::rc_ptr< ::mosek::fusion::Matrix > _2544){
  if (((mosek::fusion::p_Matrix::_get_impl(_2543)->dimi != mosek::fusion::p_Matrix::_get_impl(_2544)->dimi) || (mosek::fusion::p_Matrix::_get_impl(_2543)->dimj != mosek::fusion::p_Matrix::_get_impl(_2544)->dimj)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions in domain"));
    }
  }
  {}
  if ((_2543->isSparse() && _2544->isSparse()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2545 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2543->numNonzeros())));
      _checked_ptr_1<int> _ptr__2545(_2545 ? _2545->raw() : nullptr,_2545 ? _2545->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2546 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2543->numNonzeros())));
      _checked_ptr_1<int> _ptr__2546(_2546 ? _2546->raw() : nullptr,_2546 ? _2546->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2547 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2543->numNonzeros())));
      _checked_ptr_1<double> _ptr__2547(_2547 ? _2547->raw() : nullptr,_2547 ? _2547->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2548 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2544->numNonzeros())));
      _checked_ptr_1<int> _ptr__2548(_2548 ? _2548->raw() : nullptr,_2548 ? _2548->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2544->numNonzeros())));
      _checked_ptr_1<int> _ptr__2549(_2549 ? _2549->raw() : nullptr,_2549 ? _2549->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2550 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2544->numNonzeros())));
      _checked_ptr_1<double> _ptr__2550(_2550 ? _2550->raw() : nullptr,_2550 ? _2550->size(0) : 0);
      _2543->getDataAsTriplets(_2545,_2546,_2547);
      _2544->getDataAsTriplets(_2548,_2549,_2550);
      long long _2551 = (int)0;
      {
        int _2552 = (int)0;
        int _2553 = (int)0;
        while ( ((_2553 < (int)((_2545)->size(0))) && (_2552 < (int)((_2548)->size(0)))) )
        {
          {
            if (((_ptr__2545[_2553] < _ptr__2548[_2552]) || ((_ptr__2545[_2553] == _ptr__2548[_2552]) && (_ptr__2546[_2553] < _ptr__2549[_2552]))))
            {
              {
                ++ _2551;
                ++ _2553;
              }
            }
            else
            {
              {
                if (((_ptr__2545[_2553] > _ptr__2548[_2552]) || ((_ptr__2545[_2553] == _ptr__2548[_2552]) && (_ptr__2546[_2553] > _ptr__2549[_2552]))))
                {
                  {
                    ++ _2551;
                    ++ _2552;
                  }
                }
                else
                {
                  {
                    ++ _2551;
                    ++ _2553;
                    ++ _2552;
                  }
                }
              }
            }
          }
        }
        _2551 += ((int)((_2545)->size(0)) - _2553);
        _2551 += ((int)((_2548)->size(0)) - _2552);
      }
      std::shared_ptr< monty::ndarray< int,2 > > _2554 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2551,(int)2)));
      std::shared_ptr< monty::ndarray< double,1 > > _2555 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2551)));
      _checked_ptr_1<double> _ptr__2555(_2555 ? _2555->raw() : nullptr,_2555 ? _2555->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2556 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2551)));
      _checked_ptr_1<double> _ptr__2556(_2556 ? _2556->raw() : nullptr,_2556 ? _2556->size(0) : 0);
      {
        int _2557 = (int)0;
        int _2558 = (int)0;
        int _2559 = (int)0;
        while ( ((_2559 < (int)((_2545)->size(0))) && (_2558 < (int)((_2548)->size(0)))) )
        {
          {
            if (((_ptr__2545[_2559] < _ptr__2548[_2558]) || ((_ptr__2545[_2559] == _ptr__2548[_2558]) && (_ptr__2546[_2559] < _ptr__2549[_2558]))))
            {
              {
                ((*_2554)(_2557,(int)0)) = _ptr__2545[_2559];
                ((*_2554)(_2557,(int)1)) = _ptr__2546[_2559];
                _ptr__2555[_2557] = _ptr__2547[_2559];
                _ptr__2556[_2557] = 0.0;
                ++ _2557;
                ++ _2559;
              }
            }
            else
            {
              {
                if (((_ptr__2545[_2559] > _ptr__2548[_2558]) || ((_ptr__2545[_2559] == _ptr__2548[_2558]) && (_ptr__2546[_2559] > _ptr__2549[_2558]))))
                {
                  {
                    ((*_2554)(_2557,(int)0)) = _ptr__2548[_2558];
                    ((*_2554)(_2557,(int)1)) = _ptr__2549[_2558];
                    _ptr__2555[_2557] = 0.0;
                    _ptr__2556[_2557] = _ptr__2550[_2558];
                    ++ _2557;
                    ++ _2558;
                  }
                }
                else
                {
                  {
                    ((*_2554)(_2557,(int)0)) = _ptr__2548[_2558];
                    ((*_2554)(_2557,(int)1)) = _ptr__2549[_2558];
                    _ptr__2555[_2557] = _ptr__2547[_2558];
                    _ptr__2556[_2557] = _ptr__2550[_2558];
                    ++ _2557;
                    ++ _2559;
                    ++ _2558;
                  }
                }
              }
            }
          }
        }
        while ( (_2559 < (int)((_2545)->size(0))) )
        {
          {
            ((*_2554)(_2557,(int)0)) = _ptr__2545[_2559];
            ((*_2554)(_2557,(int)1)) = _ptr__2546[_2559];
            _ptr__2555[_2557] = _ptr__2547[_2559];
            _ptr__2556[_2557] = 0.0;
            ++ _2557;
            ++ _2559;
          }
        }
        while ( (_2558 < (int)((_2548)->size(0))) )
        {
          {
            ((*_2554)(_2557,(int)0)) = _ptr__2548[_2558];
            ((*_2554)(_2557,(int)1)) = _ptr__2549[_2558];
            _ptr__2555[_2557] = 0.0;
            _ptr__2556[_2557] = _ptr__2550[_2558];
            ++ _2557;
            ++ _2558;
          }
        }
      }
      return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2555,_2556,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2543)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2543)->dimj)}),_2554,(int)1);
    }
  }
  else
  {
    {
      int _2560 = mosek::fusion::p_Matrix::_get_impl(_2543)->dimj;
      int _2561 = mosek::fusion::p_Matrix::_get_impl(_2543)->dimi;
      int _2562 = safe_mul( _2561,_2560 );
      std::shared_ptr< monty::ndarray< double,1 > > _2563;
      _checked_ptr_1<double> _ptr__2563(_2563 ? _2563->raw() : nullptr,_2563 ? _2563->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2564;
      _checked_ptr_1<double> _ptr__2564(_2564 ? _2564->raw() : nullptr,_2564 ? _2564->size(0) : 0);
      if (_2543->isSparse())
      {
        {
          _2563 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2562)));
          _ptr__2563.update(_2563 ? _2563->raw() : nullptr, _2563 ? _2563->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2565 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2543->numNonzeros())));
          _checked_ptr_1<int> _ptr__2565(_2565 ? _2565->raw() : nullptr,_2565 ? _2565->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2566 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2543->numNonzeros())));
          _checked_ptr_1<int> _ptr__2566(_2566 ? _2566->raw() : nullptr,_2566 ? _2566->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _2567 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2543->numNonzeros())));
          _checked_ptr_1<double> _ptr__2567(_2567 ? _2567->raw() : nullptr,_2567 ? _2567->size(0) : 0);
          _2543->getDataAsTriplets(_2565,_2566,_2567);
          int _8046 = (int)0;
          int _8047 = (int)((_2565)->size(0));
          for (int _2568 = _8046; _2568 < _8047; ++_2568)
          {
            {
              _ptr__2563[safe_add( safe_mul( _ptr__2565[_2568],_2560 ),_ptr__2566[_2568] )] = _ptr__2567[_2568];
            }
          }
        }
      }
      else
      {
        {
          _2563 = _2543->getDataAsArray();
          _ptr__2563.update(_2563 ? _2563->raw() : nullptr, _2563 ? _2563->size(0) : 0);
        }
      }
      if (_2544->isSparse())
      {
        {
          _2564 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2562)));
          _ptr__2564.update(_2564 ? _2564->raw() : nullptr, _2564 ? _2564->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2569 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2544->numNonzeros())));
          _checked_ptr_1<int> _ptr__2569(_2569 ? _2569->raw() : nullptr,_2569 ? _2569->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2570 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2544->numNonzeros())));
          _checked_ptr_1<int> _ptr__2570(_2570 ? _2570->raw() : nullptr,_2570 ? _2570->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _2571 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2544->numNonzeros())));
          _checked_ptr_1<double> _ptr__2571(_2571 ? _2571->raw() : nullptr,_2571 ? _2571->size(0) : 0);
          _2544->getDataAsTriplets(_2569,_2570,_2571);
          int _8048 = (int)0;
          int _8049 = (int)((_2569)->size(0));
          for (int _2572 = _8048; _2572 < _8049; ++_2572)
          {
            {
              _ptr__2564[safe_add( safe_mul( _ptr__2569[_2572],_2560 ),_ptr__2570[_2572] )] = _ptr__2571[_2572];
            }
          }
        }
      }
      else
      {
        {
          _2564 = _2544->getDataAsArray();
          _ptr__2564.update(_2564 ? _2564->raw() : nullptr, _2564 ? _2564->size(0) : 0);
        }
      }
      return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2563,_2564,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2543)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2543)->dimj)}),nullptr,(int)1);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::mkRangedDomain(std::shared_ptr< monty::ndarray< double,2 > > _2573,std::shared_ptr< monty::ndarray< double,2 > > _2574){
  if ((((int)((_2573)->size(0)) != (int)((_2574)->size(0))) || ((int)((_2573)->size(1)) != (int)((_2574)->size(1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions in domain"));
    }
  }
  {}
  int _2575 = (int)((_2573)->size(1));
  int _2576 = (int)((_2573)->size(0));
  int _2577 = safe_mul( _2576,_2575 );
  std::shared_ptr< monty::ndarray< double,1 > > _2578 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2577)));
  _checked_ptr_1<double> _ptr__2578(_2578 ? _2578->raw() : nullptr,_2578 ? _2578->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2579 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2577)));
  _checked_ptr_1<double> _ptr__2579(_2579 ? _2579->raw() : nullptr,_2579 ? _2579->size(0) : 0);
  int _2580 = (int)0;
  int _8050 = (int)0;
  int _8051 = _2576;
  for (int _2581 = _8050; _2581 < _8051; ++_2581)
  {
    {
      int _8052 = (int)0;
      int _8053 = _2575;
      for (int _2582 = _8052; _2582 < _8053; ++_2582)
      {
        {
          _ptr__2578[_2580] = ((*_2573)(_2581,_2582));
          _ptr__2579[_2580] = ((*_2574)(_2581,_2582));
          ++ _2580;
        }
      }
    }
  }
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2578,_2579,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2576),(int)(_2575)}),nullptr,(int)1);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _2583,monty::rc_ptr< ::mosek::fusion::Matrix > _2584){
  if (_2584->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2585 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2584->numNonzeros())));
      _checked_ptr_1<int> _ptr__2585(_2585 ? _2585->raw() : nullptr,_2585 ? _2585->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2586 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2584->numNonzeros())));
      _checked_ptr_1<int> _ptr__2586(_2586 ? _2586->raw() : nullptr,_2586 ? _2586->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2587 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2584->numNonzeros())));
      _checked_ptr_1<double> _ptr__2587(_2587 ? _2587->raw() : nullptr,_2587 ? _2587->size(0) : 0);
      _2584->getDataAsTriplets(_2585,_2586,_2587);
      std::shared_ptr< monty::ndarray< int,2 > > _2588 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2585)->size(0)),(int)2)));
      int _8054 = (int)0;
      int _8055 = (int)((_2585)->size(0));
      for (int _2589 = _8054; _2589 < _8055; ++_2589)
      {
        {
          ((*_2588)(_2589,(int)0)) = _ptr__2585[_2589];
          ((*_2588)(_2589,(int)1)) = _ptr__2586[_2589];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2583,false,_2587,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2584)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2584)->dimj)}),_2588,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2583,false,_2584->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2584)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2584)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _2590){
  _checked_ptr_1<int> _ptr__2590(_2590 ? _2590->raw() : nullptr, _2590 ? _2590->size(0) : 0);
  long long _2591 = (int)1;
  int _8056 = (int)0;
  int _8057 = (int)((_2590)->size(0));
  for (int _2592 = _8056; _2592 < _8057; ++_2592)
  {
    {
      _2591 *= _ptr__2590[_2592];
    }
  }
  return _2591;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _2593,std::shared_ptr< monty::ndarray< double,1 > > _2594,std::shared_ptr< monty::ndarray< double,1 > > _2595,std::shared_ptr< monty::ndarray< int,2 > > _2596,std::shared_ptr< monty::ndarray< int,1 > > _2597){
  _checked_ptr_1<double> _ptr__2594(_2594 ? _2594->raw() : nullptr, _2594 ? _2594->size(0) : 0);
  _checked_ptr_1<double> _ptr__2595(_2595 ? _2595->raw() : nullptr, _2595 ? _2595->size(0) : 0);
  _checked_ptr_1<int> _ptr__2597(_2597 ? _2597->raw() : nullptr, _2597 ? _2597->size(0) : 0);
  if (((!_2593) && ((int)((_2594)->size(0)) != (int)((_2595)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _2596.get()) && ((int)((_2596)->size(0)) != (int)((_2594)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _8058 = (int)0;
  int _8059 = (int)((_2595)->size(0));
  for (int _2598 = _8058; _2598 < _8059; ++_2598)
  {
    {
      if ((_ptr__2594[_2598] > _ptr__2595[_2598]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _2597.get()) && (::mosek::fusion::p_Domain::dimsize(_2597) != (int)((_2594)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_2593,_2594,_2595,_2597)->__mosek_2fusion_2RangeDomain__sparse(_2596);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2599) { return mosek::fusion::p_Domain::symmetric(_2599); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2599){
  return _2599->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2600) { return mosek::fusion::p_Domain::symmetric(_2600); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2600){
  return _2600->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2601,    std::shared_ptr< monty::ndarray< int,2 > > _2602) { return mosek::fusion::p_Domain::sparse(_2601,_2602); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2601,std::shared_ptr< monty::ndarray< int,2 > > _2602){
  return _2601->__mosek_2fusion_2RangeDomain__sparse(_2602);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2603,    std::shared_ptr< monty::ndarray< int,1 > > _2604) { return mosek::fusion::p_Domain::sparse(_2603,_2604); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2603,std::shared_ptr< monty::ndarray< int,1 > > _2604){
  _checked_ptr_1<int> _ptr__2604(_2604 ? _2604->raw() : nullptr, _2604 ? _2604->size(0) : 0);
  return _2603->__mosek_2fusion_2RangeDomain__sparse(_2604);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2605,    std::shared_ptr< monty::ndarray< int,2 > > _2606) { return mosek::fusion::p_Domain::sparse(_2605,_2606); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2605,std::shared_ptr< monty::ndarray< int,2 > > _2606){
  return _2605->__mosek_2fusion_2LinearDomain__sparse(_2606);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2607,    std::shared_ptr< monty::ndarray< int,1 > > _2608) { return mosek::fusion::p_Domain::sparse(_2607,_2608); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2607,std::shared_ptr< monty::ndarray< int,1 > > _2608){
  _checked_ptr_1<int> _ptr__2608(_2608 ? _2608->raw() : nullptr, _2608 ? _2608->size(0) : 0);
  return _2607->__mosek_2fusion_2LinearDomain__sparse(_2608);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2609) { return mosek::fusion::p_Domain::integral(_2609); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2609){
  return _2609->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2610) { return mosek::fusion::p_Domain::integral(_2610); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2610){
  return _2610->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2611) { return mosek::fusion::p_Domain::integral(_2611); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2611){
  return _2611->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2612,    int _2613) { return mosek::fusion::p_Domain::axis(_2612,_2613); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2612,int _2613){
  return _2612->__mosek_2fusion_2ConeDomain__axis(_2613);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2614,    std::shared_ptr< monty::ndarray< int,1 > > _2615) { return mosek::fusion::p_Domain::inDPowerCone(_2614,_2615); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2614,std::shared_ptr< monty::ndarray< int,1 > > _2615){
  _checked_ptr_1<int> _ptr__2615(_2615 ? _2615->raw() : nullptr, _2615 ? _2615->size(0) : 0);
  std::vector<int> _8060;
  for (int _2616 = (int)0, _8061 = (int)((_2615)->size(0)); _2616 < _8061 ; ++_2616)
  {
    _8060.push_back(_ptr__2615[_2616]);
  }
  auto _8062 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8060.size()),_8060.begin(),_8060.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2614,_8062);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2617,    int _2618) { return mosek::fusion::p_Domain::inDPowerCone(_2617,_2618); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2617,int _2618){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2617,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2618),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2619) { return mosek::fusion::p_Domain::inDPowerCone(_2619); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2619){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2619,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2620,    std::shared_ptr< monty::ndarray< int,1 > > _2621) { return mosek::fusion::p_Domain::inPPowerCone(_2620,_2621); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2620,std::shared_ptr< monty::ndarray< int,1 > > _2621){
  _checked_ptr_1<int> _ptr__2621(_2621 ? _2621->raw() : nullptr, _2621 ? _2621->size(0) : 0);
  std::vector<int> _8063;
  for (int _2622 = (int)0, _8064 = (int)((_2621)->size(0)); _2622 < _8064 ; ++_2622)
  {
    _8063.push_back(_ptr__2621[_2622]);
  }
  auto _8065 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8063.size()),_8063.begin(),_8063.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2620,_8065);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2623,    int _2624) { return mosek::fusion::p_Domain::inPPowerCone(_2623,_2624); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2623,int _2624){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2623,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2624),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2625) { return mosek::fusion::p_Domain::inPPowerCone(_2625); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2625){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2625,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2626) { return mosek::fusion::p_Domain::inDExpCone(_2626); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2626){
  _checked_ptr_1<int> _ptr__2626(_2626 ? _2626->raw() : nullptr, _2626 ? _2626->size(0) : 0);
  std::vector<int> _8066;
  for (int _2627 = (int)0, _8067 = (int)((_2626)->size(0)); _2627 < _8067 ; ++_2627)
  {
    _8066.push_back(_ptr__2626[_2627]);
  }
  auto _8068 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8066.size()),_8066.begin(),_8066.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_8068);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _2628) { return mosek::fusion::p_Domain::inDExpCone(_2628); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _2628){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2628),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2629) { return mosek::fusion::p_Domain::inPExpCone(_2629); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2629){
  _checked_ptr_1<int> _ptr__2629(_2629 ? _2629->raw() : nullptr, _2629 ? _2629->size(0) : 0);
  std::vector<int> _8069;
  for (int _2630 = (int)0, _8070 = (int)((_2629)->size(0)); _2630 < _8070 ; ++_2630)
  {
    _8069.push_back(_ptr__2629[_2630]);
  }
  auto _8071 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8069.size()),_8069.begin(),_8069.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_8071);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _2631) { return mosek::fusion::p_Domain::inPExpCone(_2631); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _2631){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2631),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2632) { return mosek::fusion::p_Domain::inRotatedQCone(_2632); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2632){
  _checked_ptr_1<int> _ptr__2632(_2632 ? _2632->raw() : nullptr, _2632 ? _2632->size(0) : 0);
  std::vector<int> _8072;
  for (int _2633 = (int)0, _8073 = (int)((_2632)->size(0)); _2633 < _8073 ; ++_2633)
  {
    _8072.push_back(_ptr__2632[_2633]);
  }
  auto _8074 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8072.size()),_8072.begin(),_8072.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_8074);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2634,    int _2635) { return mosek::fusion::p_Domain::inRotatedQCone(_2634,_2635); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2634,int _2635){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2634),(int)(_2635)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2636) { return mosek::fusion::p_Domain::inRotatedQCone(_2636); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2636){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2636)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2637) { return mosek::fusion::p_Domain::inQCone(_2637); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2637){
  _checked_ptr_1<int> _ptr__2637(_2637 ? _2637->raw() : nullptr, _2637 ? _2637->size(0) : 0);
  std::vector<int> _8075;
  for (int _2638 = (int)0, _8076 = (int)((_2637)->size(0)); _2638 < _8076 ; ++_2638)
  {
    _8075.push_back(_ptr__2637[_2638]);
  }
  auto _8077 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8075.size()),_8075.begin(),_8075.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_8077);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2639,    int _2640) { return mosek::fusion::p_Domain::inQCone(_2639,_2640); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2639,int _2640){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2639),(int)(_2640)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2641) { return mosek::fusion::p_Domain::inQCone(_2641); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2641){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2641)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2642,    int _2643) { return mosek::fusion::p_Domain::isLinPSD(_2642,_2643); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2642,int _2643){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2642,safe_add( _2642,(int)1 ) ) / (int)2),_2643));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2644) { return mosek::fusion::p_Domain::isLinPSD(_2644); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2644){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2644,safe_add( _2644,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2645,    int _2646) { return mosek::fusion::p_Domain::isTrilPSD(_2645,_2646); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2645,int _2646){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2646),(int)(_2645),(int)(_2645)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2647) { return mosek::fusion::p_Domain::isTrilPSD(_2647); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2647){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2647),(int)(_2647)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2648,    int _2649) { return mosek::fusion::p_Domain::inPSDCone(_2648,_2649); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2648,int _2649){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2649),(int)(_2648),(int)(_2648)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2650) { return mosek::fusion::p_Domain::inPSDCone(_2650); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2650){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2650),(int)(_2650)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _2651) { return mosek::fusion::p_Domain::binary(_2651); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _2651){
  _checked_ptr_1<int> _ptr__2651(_2651 ? _2651->raw() : nullptr, _2651 ? _2651->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_2651)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2652,    int _2653) { return mosek::fusion::p_Domain::binary(_2652,_2653); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2652,int _2653){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2652),(int)(_2653)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2654) { return mosek::fusion::p_Domain::binary(_2654); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2654){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2654)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2655,    monty::rc_ptr< ::mosek::fusion::Matrix > _2656) { return mosek::fusion::p_Domain::inRange(_2655,_2656); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(monty::rc_ptr< ::mosek::fusion::Matrix > _2655,monty::rc_ptr< ::mosek::fusion::Matrix > _2656){
  return ::mosek::fusion::p_Domain::mkRangedDomain(_2656,_2655);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,2 > > _2657,    std::shared_ptr< monty::ndarray< double,2 > > _2658) { return mosek::fusion::p_Domain::inRange(_2657,_2658); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,2 > > _2657,std::shared_ptr< monty::ndarray< double,2 > > _2658){
  return ::mosek::fusion::p_Domain::mkRangedDomain(_2658,_2657);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2659,    std::shared_ptr< monty::ndarray< double,1 > > _2660,    std::shared_ptr< monty::ndarray< int,1 > > _2661) { return mosek::fusion::p_Domain::inRange(_2659,_2660,_2661); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2659,std::shared_ptr< monty::ndarray< double,1 > > _2660,std::shared_ptr< monty::ndarray< int,1 > > _2661){
  _checked_ptr_1<double> _ptr__2659(_2659 ? _2659->raw() : nullptr, _2659 ? _2659->size(0) : 0);
  _checked_ptr_1<double> _ptr__2660(_2660 ? _2660->raw() : nullptr, _2660 ? _2660->size(0) : 0);
  _checked_ptr_1<int> _ptr__2661(_2661 ? _2661->raw() : nullptr, _2661 ? _2661->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2659,_2660,_2661);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2662,    double _2663,    std::shared_ptr< monty::ndarray< int,1 > > _2664) { return mosek::fusion::p_Domain::inRange(_2662,_2663,_2664); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2662,double _2663,std::shared_ptr< monty::ndarray< int,1 > > _2664){
  _checked_ptr_1<double> _ptr__2662(_2662 ? _2662->raw() : nullptr, _2662 ? _2662->size(0) : 0);
  _checked_ptr_1<int> _ptr__2664(_2664 ? _2664->raw() : nullptr, _2664 ? _2664->size(0) : 0);
  std::vector<double> _8078;
  for (int _2665 = (int)0, _8079 = (int)((_2662)->size(0)); _2665 < _8079 ; ++_2665)
  {
    _8078.push_back(_2663);
  }
  auto _8080 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8078.size()),_8078.begin(),_8078.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2662,_8080,_2664);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2666,    std::shared_ptr< monty::ndarray< double,1 > > _2667,    std::shared_ptr< monty::ndarray< int,1 > > _2668) { return mosek::fusion::p_Domain::inRange(_2666,_2667,_2668); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2666,std::shared_ptr< monty::ndarray< double,1 > > _2667,std::shared_ptr< monty::ndarray< int,1 > > _2668){
  _checked_ptr_1<double> _ptr__2667(_2667 ? _2667->raw() : nullptr, _2667 ? _2667->size(0) : 0);
  _checked_ptr_1<int> _ptr__2668(_2668 ? _2668->raw() : nullptr, _2668 ? _2668->size(0) : 0);
  std::vector<double> _8081;
  for (int _2669 = (int)0, _8082 = (int)((_2667)->size(0)); _2669 < _8082 ; ++_2669)
  {
    _8081.push_back(_2666);
  }
  auto _8083 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8081.size()),_8081.begin(),_8081.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8083,_2667,_2668);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2670,    double _2671,    std::shared_ptr< monty::ndarray< int,1 > > _2672) { return mosek::fusion::p_Domain::inRange(_2670,_2671,_2672); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2670,double _2671,std::shared_ptr< monty::ndarray< int,1 > > _2672){
  _checked_ptr_1<int> _ptr__2672(_2672 ? _2672->raw() : nullptr, _2672 ? _2672->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2670)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2671)}),_2672);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2673,    std::shared_ptr< monty::ndarray< double,1 > > _2674) { return mosek::fusion::p_Domain::inRange(_2673,_2674); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2673,std::shared_ptr< monty::ndarray< double,1 > > _2674){
  _checked_ptr_1<double> _ptr__2673(_2673 ? _2673->raw() : nullptr, _2673 ? _2673->size(0) : 0);
  _checked_ptr_1<double> _ptr__2674(_2674 ? _2674->raw() : nullptr, _2674 ? _2674->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2673,_2674,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2673)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2675,    double _2676) { return mosek::fusion::p_Domain::inRange(_2675,_2676); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2675,double _2676){
  _checked_ptr_1<double> _ptr__2675(_2675 ? _2675->raw() : nullptr, _2675 ? _2675->size(0) : 0);
  std::vector<double> _8084;
  for (int _2677 = (int)0, _8085 = (int)((_2675)->size(0)); _2677 < _8085 ; ++_2677)
  {
    _8084.push_back(_2676);
  }
  auto _8086 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8084.size()),_8084.begin(),_8084.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2675,_8086,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2675)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2678,    std::shared_ptr< monty::ndarray< double,1 > > _2679) { return mosek::fusion::p_Domain::inRange(_2678,_2679); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2678,std::shared_ptr< monty::ndarray< double,1 > > _2679){
  _checked_ptr_1<double> _ptr__2679(_2679 ? _2679->raw() : nullptr, _2679 ? _2679->size(0) : 0);
  std::vector<double> _8087;
  for (int _2680 = (int)0, _8088 = (int)((_2679)->size(0)); _2680 < _8088 ; ++_2680)
  {
    _8087.push_back(_2678);
  }
  auto _8089 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8087.size()),_8087.begin(),_8087.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8089,_2679,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2679)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2681,    double _2682) { return mosek::fusion::p_Domain::inRange(_2681,_2682); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2681,double _2682){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2681)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2682)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2683) { return mosek::fusion::p_Domain::greaterThan(_2683); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2683){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_2683);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2684,    std::shared_ptr< monty::ndarray< int,1 > > _2685) { return mosek::fusion::p_Domain::greaterThan(_2684,_2685); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2684,std::shared_ptr< monty::ndarray< int,1 > > _2685){
  _checked_ptr_1<double> _ptr__2684(_2684 ? _2684->raw() : nullptr, _2684 ? _2684->size(0) : 0);
  _checked_ptr_1<int> _ptr__2685(_2685 ? _2685->raw() : nullptr, _2685 ? _2685->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2684),_2685);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2686) { return mosek::fusion::p_Domain::greaterThan(_2686); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2686){
  std::vector<double> _8090;
  for (int _2687 = (int)0, _8091 = (int)((_2686)->size(0)); _2687 < _8091 ; ++_2687)
  {
    for (int _2688 = (int)0, _8092 = (int)((_2686)->size(1)); _2688 < _8092 ; ++_2688)
    {
      _8090.push_back(((*_2686)(_2687,_2688)));
    }
  }
  auto _8093 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8090.size()),_8090.begin(),_8090.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_8093,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2686)->size(0))),(int)((int)((_2686)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2689) { return mosek::fusion::p_Domain::greaterThan(_2689); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2689){
  _checked_ptr_1<double> _ptr__2689(_2689 ? _2689->raw() : nullptr, _2689 ? _2689->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2689),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2689)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2690,    std::shared_ptr< monty::ndarray< int,1 > > _2691) { return mosek::fusion::p_Domain::greaterThan(_2690,_2691); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2690,std::shared_ptr< monty::ndarray< int,1 > > _2691){
  _checked_ptr_1<int> _ptr__2691(_2691 ? _2691->raw() : nullptr, _2691 ? _2691->size(0) : 0);
  std::vector<double> _8094;
  for (long long _2692 = (int)0, _8095 = ::mosek::fusion::p_Domain::prod(_2691); _2692 < _8095 ; ++_2692)
  {
    _8094.push_back(_2690);
  }
  auto _8096 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8094.size()),_8094.begin(),_8094.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8096,_2691);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2693,    int _2694,    int _2695) { return mosek::fusion::p_Domain::greaterThan(_2693,_2694,_2695); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2693,int _2694,int _2695){
  std::vector<double> _8097;
  for (int _2696 = (int)0, _8098 = safe_mul( _2695,_2694 ); _2696 < _8098 ; ++_2696)
  {
    _8097.push_back(_2693);
  }
  auto _8099 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8097.size()),_8097.begin(),_8097.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8099,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2694),(int)(_2695)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2697,    int _2698) { return mosek::fusion::p_Domain::greaterThan(_2697,_2698); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2697,int _2698){
  std::vector<double> _8100;
  for (int _2699 = (int)0, _8101 = _2698; _2699 < _8101 ; ++_2699)
  {
    _8100.push_back(_2697);
  }
  auto _8102 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8100.size()),_8100.begin(),_8100.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8102,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2698)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2700) { return mosek::fusion::p_Domain::greaterThan(_2700); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2700){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2700)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2701) { return mosek::fusion::p_Domain::lessThan(_2701); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2701){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_2701);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2702,    std::shared_ptr< monty::ndarray< int,1 > > _2703) { return mosek::fusion::p_Domain::lessThan(_2702,_2703); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2702,std::shared_ptr< monty::ndarray< int,1 > > _2703){
  _checked_ptr_1<double> _ptr__2702(_2702 ? _2702->raw() : nullptr, _2702 ? _2702->size(0) : 0);
  _checked_ptr_1<int> _ptr__2703(_2703 ? _2703->raw() : nullptr, _2703 ? _2703->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2702),_2703);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2704) { return mosek::fusion::p_Domain::lessThan(_2704); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2704){
  std::vector<double> _8103;
  for (int _2705 = (int)0, _8104 = (int)((_2704)->size(0)); _2705 < _8104 ; ++_2705)
  {
    for (int _2706 = (int)0, _8105 = (int)((_2704)->size(1)); _2706 < _8105 ; ++_2706)
    {
      _8103.push_back(((*_2704)(_2705,_2706)));
    }
  }
  auto _8106 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8103.size()),_8103.begin(),_8103.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_8106,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2704)->size(0))),(int)((int)((_2704)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2707) { return mosek::fusion::p_Domain::lessThan(_2707); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2707){
  _checked_ptr_1<double> _ptr__2707(_2707 ? _2707->raw() : nullptr, _2707 ? _2707->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2707),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2707)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2708,    std::shared_ptr< monty::ndarray< int,1 > > _2709) { return mosek::fusion::p_Domain::lessThan(_2708,_2709); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2708,std::shared_ptr< monty::ndarray< int,1 > > _2709){
  _checked_ptr_1<int> _ptr__2709(_2709 ? _2709->raw() : nullptr, _2709 ? _2709->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2708)}),_2709);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2710,    int _2711,    int _2712) { return mosek::fusion::p_Domain::lessThan(_2710,_2711,_2712); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2710,int _2711,int _2712){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2710)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2711),(int)(_2712)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2713,    int _2714) { return mosek::fusion::p_Domain::lessThan(_2713,_2714); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2713,int _2714){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2713)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2714)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2715) { return mosek::fusion::p_Domain::lessThan(_2715); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2715){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2715)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2716) { return mosek::fusion::p_Domain::equalsTo(_2716); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2716){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_2716);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2717,    std::shared_ptr< monty::ndarray< int,1 > > _2718) { return mosek::fusion::p_Domain::equalsTo(_2717,_2718); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2717,std::shared_ptr< monty::ndarray< int,1 > > _2718){
  _checked_ptr_1<double> _ptr__2717(_2717 ? _2717->raw() : nullptr, _2717 ? _2717->size(0) : 0);
  _checked_ptr_1<int> _ptr__2718(_2718 ? _2718->raw() : nullptr, _2718 ? _2718->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2717),_2718);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _2719) { return mosek::fusion::p_Domain::equalsTo(_2719); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2719){
  std::vector<double> _8107;
  for (int _2720 = (int)0, _8108 = (int)((_2719)->size(0)); _2720 < _8108 ; ++_2720)
  {
    for (int _2721 = (int)0, _8109 = (int)((_2719)->size(1)); _2721 < _8109 ; ++_2721)
    {
      _8107.push_back(((*_2719)(_2720,_2721)));
    }
  }
  auto _8110 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8107.size()),_8107.begin(),_8107.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_8110,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2719)->size(0))),(int)((int)((_2719)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2722) { return mosek::fusion::p_Domain::equalsTo(_2722); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2722){
  _checked_ptr_1<double> _ptr__2722(_2722 ? _2722->raw() : nullptr, _2722 ? _2722->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2722),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2722)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2723,    std::shared_ptr< monty::ndarray< int,1 > > _2724) { return mosek::fusion::p_Domain::equalsTo(_2723,_2724); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2723,std::shared_ptr< monty::ndarray< int,1 > > _2724){
  _checked_ptr_1<int> _ptr__2724(_2724 ? _2724->raw() : nullptr, _2724 ? _2724->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2723)}),_2724);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2725,    int _2726,    int _2727) { return mosek::fusion::p_Domain::equalsTo(_2725,_2726,_2727); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2725,int _2726,int _2727){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2725)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2726),(int)(_2727)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2728,    int _2729) { return mosek::fusion::p_Domain::equalsTo(_2728,_2729); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2728,int _2729){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2728)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2729)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2730) { return mosek::fusion::p_Domain::equalsTo(_2730); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2730){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2730)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _2731) { return mosek::fusion::p_Domain::unbounded(_2731); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2731){
  _checked_ptr_1<int> _ptr__2731(_2731 ? _2731->raw() : nullptr, _2731 ? _2731->size(0) : 0);
  std::vector<int> _8111;
  for (int _2732 = (int)0, _8112 = (int)((_2731)->size(0)); _2732 < _8112 ; ++_2732)
  {
    _8111.push_back(_ptr__2731[_2732]);
  }
  auto _8113 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8111.size()),_8111.begin(),_8111.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_8113);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2733,    int _2734) { return mosek::fusion::p_Domain::unbounded(_2733,_2734); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2733,int _2734){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2733),(int)(_2734)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2735) { return mosek::fusion::p_Domain::unbounded(_2735); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2735){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2735)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2736,    std::shared_ptr< monty::ndarray< long long,1 > > _2737,    std::shared_ptr< monty::ndarray< double,1 > > _2738){ return new mosek::fusion::ExprConst(_2736,_2737,_2738); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2736,    std::shared_ptr< monty::ndarray< long long,1 > > _2737,    std::shared_ptr< monty::ndarray< double,1 > > _2738) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2736,_2737,_2738); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2736,    std::shared_ptr< monty::ndarray< long long,1 > > _2737,    std::shared_ptr< monty::ndarray< double,1 > > _2738){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2736(_2736 ? _2736->raw() : nullptr, _2736 ? _2736->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2737(_2737 ? _2737->raw() : nullptr, _2737 ? _2737->size(0) : 0);
    _checked_ptr_1<double> _ptr__2738(_2738 ? _2738->raw() : nullptr, _2738 ? _2738->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2736);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_2738);
    std::shared_ptr< monty::ndarray< long long,1 > > _8114;
    bool _8115 = (NULL != _2737.get());
    if (_8115)
    {
      _8114 = ::mosek::fusion::Utils::Tools::arraycopy(_2737);
    }
    else
    {
      _8114 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8114;
    ::mosek::fusion::p_ExprConst::validate(_2736,_2738,_2737);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2739,    std::shared_ptr< monty::ndarray< long long,1 > > _2740,    double _2741){ return new mosek::fusion::ExprConst(_2739,_2740,_2741); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2739,    std::shared_ptr< monty::ndarray< long long,1 > > _2740,    double _2741) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2739,_2740,_2741); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2739,    std::shared_ptr< monty::ndarray< long long,1 > > _2740,    double _2741){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2739(_2739 ? _2739->raw() : nullptr, _2739 ? _2739->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2740(_2740 ? _2740->raw() : nullptr, _2740 ? _2740->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2739);
    long long _8116;
    bool _8117 = (NULL == _2740.get());
    if (_8117)
    {
      _8116 = ::mosek::fusion::p_Set::size(_2739);
    }
    else
    {
      _8116 = (int)((_2740)->size(0));
    }
    long long _2742 = _8116;
    std::vector<double> _8118;
    for (long long _2743 = (int)0, _8119 = _2742; _2743 < _8119 ; ++_2743)
    {
      _8118.push_back(_2741);
    }
    auto _8120 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8118.size()),_8118.begin(),_8118.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _8120;
    std::shared_ptr< monty::ndarray< long long,1 > > _8121;
    bool _8122 = (NULL != _2740.get());
    if (_8122)
    {
      _8121 = ::mosek::fusion::Utils::Tools::arraycopy(_2740);
    }
    else
    {
      _8121 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8121;
    ::mosek::fusion::p_ExprConst::validate(_2739,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_2740);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2744,monty::rc_ptr< ::mosek::fusion::WorkStack > _2745,monty::rc_ptr< ::mosek::fusion::WorkStack > _2746) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_2744,_2745,_2746); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2744,monty::rc_ptr< ::mosek::fusion::WorkStack > _2745,monty::rc_ptr< ::mosek::fusion::WorkStack > _2746){
  std::shared_ptr< monty::ndarray< int,1 > > _2747 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__2747(_2747 ? _2747->raw() : nullptr,_2747 ? _2747->size(0) : 0);
  int _2748 = (int)((_2747)->size(0));
  int _2749 = (int)((bfix)->size(0));
  bool _2750 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_2747)));
  _2744->alloc_expr(_2748,_2749,(int)0,_2750);
  int _2751 = mosek::fusion::p_WorkStack::_get_impl(_2744)->shape_base;
  int _2752 = mosek::fusion::p_WorkStack::_get_impl(_2744)->ptr_base;
  int _2753 = mosek::fusion::p_WorkStack::_get_impl(_2744)->sp_base;
  int _2754 = mosek::fusion::p_WorkStack::_get_impl(_2744)->nidxs_base;
  int _2755 = mosek::fusion::p_WorkStack::_get_impl(_2744)->bfix_base;
  int _2756 = mosek::fusion::p_WorkStack::_get_impl(_2744)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2757 = mosek::fusion::p_WorkStack::_get_impl(_2744)->i32;
  _checked_ptr_1<int> _ptr__2757(_2757 ? _2757->raw() : nullptr,_2757 ? _2757->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2758 = mosek::fusion::p_WorkStack::_get_impl(_2744)->i64;
  _checked_ptr_1<long long> _ptr__2758(_2758 ? _2758->raw() : nullptr,_2758 ? _2758->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2759 = mosek::fusion::p_WorkStack::_get_impl(_2744)->f64;
  _checked_ptr_1<double> _ptr__2759(_2759 ? _2759->raw() : nullptr,_2759 ? _2759->size(0) : 0);
  int _8123 = (int)0;
  int _8124 = _2748;
  for (int _2760 = _8123; _2760 < _8124; ++_2760)
  {
    {
      _ptr__2757[safe_add( _2751,_2760 )] = _ptr__2747[_2760];
    }
  }
  if (_2750)
  {
    {
      int _8125 = (int)0;
      int _8126 = (int)((sparsity)->size(0));
      for (int _2761 = _8125; _2761 < _8126; ++_2761)
      {
        {
          _ptr__2758[safe_add( _2753,_2761 )] = ((*sparsity)(_2761));
        }
      }
    }
  }
  {}
  int _8127 = (int)0;
  int _8128 = _2749;
  for (int _2762 = _8127; _2762 < _8128; ++_2762)
  {
    {
      _ptr__2759[safe_add( _2755,_2762 )] = ((*bfix)(_2762));
    }
  }
  int _8129 = (int)0;
  int _8130 = safe_add( _2749,(int)1 );
  for (int _2763 = _8129; _2763 < _8130; ++_2763)
  {
    {
      _ptr__2757[safe_add( _2752,_2763 )] = (int)0;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _2764,std::shared_ptr< monty::ndarray< double,1 > > _2765,std::shared_ptr< monty::ndarray< long long,1 > > _2766){
  _checked_ptr_1<int> _ptr__2764(_2764 ? _2764->raw() : nullptr, _2764 ? _2764->size(0) : 0);
  _checked_ptr_1<double> _ptr__2765(_2765 ? _2765->raw() : nullptr, _2765 ? _2765->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2766(_2766 ? _2766->raw() : nullptr, _2766 ? _2766->size(0) : 0);
  long long _2767 = ::mosek::fusion::p_Set::size(_2764);
  if ((NULL != _2766.get()))
  {
    {
      if (((int)((_2766)->size(0)) != (int)((_2765)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      bool _2768 = false;
      int _8131 = (int)0;
      int _8132 = (int)((_2766)->size(0));
      for (int _2769 = _8131; _2769 < _8132; ++_2769)
      {
        {
          if (((_ptr__2766[_2769] < (int)0) || (_ptr__2766[_2769] >= _2767)))
          {
            {
              _2768 = true;
            }
          }
          {}
        }
      }
      if (_2768)
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
        }
      }
      {}
    }
  }
  else
  {
    {
      if (((int)((_2765)->size(0)) != _2767))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2770,    std::shared_ptr< monty::ndarray< int,2 > > _2771){ return new mosek::fusion::ExprPick(_2770,_2771); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2770,    std::shared_ptr< monty::ndarray< int,2 > > _2771) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2770,_2771); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2770,    std::shared_ptr< monty::ndarray< int,2 > > _2771){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2771)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _2772 = _2770->getShape();
    _checked_ptr_1<int> _ptr__2772(_2772 ? _2772->raw() : nullptr,_2772 ? _2772->size(0) : 0);
    int _2773 = (int)((_2772)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2770;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2771)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _2774 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__2774(_2774 ? _2774->raw() : nullptr,_2774 ? _2774->size(0) : 0);
    if (((int)((_2771)->size(1)) != _2773))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    bool _2775 = false;
    int _8133 = (int)0;
    int _8134 = (int)((_2771)->size(0));
    for (int _2776 = _8133; _2776 < _8134; ++_2776)
    {
      {
        int _8135 = (int)0;
        int _8136 = _2773;
        for (int _2777 = _8135; _2777 < _8136; ++_2777)
        {
          {
            if (((((*_2771)(_2776,_2777)) < (int)0) || (((*_2771)(_2776,_2777)) >= _ptr__2772[_2777])))
            {
              {
                _2775 = true;
              }
            }
            {}
          }
        }
      }
    }
    if (_2775)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
      }
    }
    {}
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2778 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2773)));
      _checked_ptr_1<long long> _ptr__2778(_2778 ? _2778->raw() : nullptr,_2778 ? _2778->size(0) : 0);
      _ptr__2778[(_2773 - (int)1)] = (int)1;
      int _8137 = (int)1;
      int _8138 = _2773;
      for (int _2779 = _8137; _2779 < _8138; ++_2779)
      {
        {
          _ptr__2778[((_2773 - _2779) - (int)1)] = safe_mul( _ptr__2778[(_2773 - _2779)],_ptr__2772[(_2773 - _2779)] );
        }
      }
      int _8139 = (int)0;
      int _8140 = (int)((_2771)->size(0));
      for (int _2780 = _8139; _2780 < _8140; ++_2780)
      {
        {
          long long _2781 = (long long)0;
          int _8141 = (int)0;
          int _8142 = _2773;
          for (int _2782 = _8141; _2782 < _8142; ++_2782)
          {
            {
              _2781 += safe_mul( _ptr__2778[_2782],((*_2771)(_2780,_2782)) );
            }
          }
          _ptr__2774[_2780] = _2781;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2783,    std::shared_ptr< monty::ndarray< long long,1 > > _2784){ return new mosek::fusion::ExprPick(_2783,_2784); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2783,    std::shared_ptr< monty::ndarray< long long,1 > > _2784) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2783,_2784); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2783,    std::shared_ptr< monty::ndarray< long long,1 > > _2784){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2784(_2784 ? _2784->raw() : nullptr, _2784 ? _2784->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2784)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2783;
    std::shared_ptr< monty::ndarray< int,1 > > _2785 = _2783->getShape();
    _checked_ptr_1<int> _ptr__2785(_2785 ? _2785->raw() : nullptr,_2785 ? _2785->size(0) : 0);
    long long _2786 = ::mosek::fusion::p_Set::size(_2785);
    bool _2787 = false;
    int _8143 = (int)0;
    int _8144 = (int)((_2784)->size(0));
    for (int _2788 = _8143; _2788 < _8144; ++_2788)
    {
      {
        if (((_ptr__2784[_2788] < (int)0) || (_ptr__2784[_2788] >= _2786)))
        {
          {
            _2787 = true;
          }
        }
        {}
      }
    }
    if (_2787)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
      }
    }
    {}
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_2784);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2789,monty::rc_ptr< ::mosek::fusion::WorkStack > _2790,monty::rc_ptr< ::mosek::fusion::WorkStack > _2791) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_2789,_2790,_2791); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2789,monty::rc_ptr< ::mosek::fusion::WorkStack > _2790,monty::rc_ptr< ::mosek::fusion::WorkStack > _2791){
  expr->eval(_2790,_2789,_2791);
  _2790->pop_expr();
  int _2792 = mosek::fusion::p_WorkStack::_get_impl(_2790)->nd;
  int _2793 = mosek::fusion::p_WorkStack::_get_impl(_2790)->shape_base;
  int _2794 = mosek::fusion::p_WorkStack::_get_impl(_2790)->nelem;
  int _2795 = mosek::fusion::p_WorkStack::_get_impl(_2790)->nnz;
  bool _2796 = mosek::fusion::p_WorkStack::_get_impl(_2790)->hassp;
  int _2797 = mosek::fusion::p_WorkStack::_get_impl(_2790)->ptr_base;
  int _2798 = mosek::fusion::p_WorkStack::_get_impl(_2790)->sp_base;
  int _2799 = mosek::fusion::p_WorkStack::_get_impl(_2790)->nidxs_base;
  int _2800 = mosek::fusion::p_WorkStack::_get_impl(_2790)->bfix_base;
  int _2801 = mosek::fusion::p_WorkStack::_get_impl(_2790)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2802 = mosek::fusion::p_WorkStack::_get_impl(_2790)->i32;
  _checked_ptr_1<int> _ptr__2802(_2802 ? _2802->raw() : nullptr,_2802 ? _2802->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2803 = mosek::fusion::p_WorkStack::_get_impl(_2790)->i64;
  _checked_ptr_1<long long> _ptr__2803(_2803 ? _2803->raw() : nullptr,_2803 ? _2803->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2804 = mosek::fusion::p_WorkStack::_get_impl(_2790)->f64;
  _checked_ptr_1<double> _ptr__2804(_2804 ? _2804->raw() : nullptr,_2804 ? _2804->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2805 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__2805(_2805 ? _2805->raw() : nullptr,_2805 ? _2805->size(0) : 0);
  if ((!_2796))
  {
    {
      int _2806 = (int)((_2805)->size(0));
      int _2807 = (int)1;
      int _2808 = (int)0;
      int _8145 = (int)0;
      int _8146 = (int)((_2805)->size(0));
      for (int _2809 = _8145; _2809 < _8146; ++_2809)
      {
        {
          _2808 += (_ptr__2802[safe_add( safe_add( _2797,_ptr__2805[_2809] ),(int)1 )] - _ptr__2802[safe_add( _2797,_ptr__2805[_2809] )]);
        }
      }
      _2789->alloc_expr(_2807,_2806,_2808,false);
      int _2810 = mosek::fusion::p_WorkStack::_get_impl(_2789)->cof_base;
      int _2811 = mosek::fusion::p_WorkStack::_get_impl(_2789)->bfix_base;
      int _2812 = mosek::fusion::p_WorkStack::_get_impl(_2789)->nidxs_base;
      int _2813 = mosek::fusion::p_WorkStack::_get_impl(_2789)->ptr_base;
      int _2814 = mosek::fusion::p_WorkStack::_get_impl(_2789)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2815 = mosek::fusion::p_WorkStack::_get_impl(_2789)->i32;
      _checked_ptr_1<int> _ptr__2815(_2815 ? _2815->raw() : nullptr,_2815 ? _2815->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2816 = mosek::fusion::p_WorkStack::_get_impl(_2789)->i64;
      _checked_ptr_1<long long> _ptr__2816(_2816 ? _2816->raw() : nullptr,_2816 ? _2816->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2817 = mosek::fusion::p_WorkStack::_get_impl(_2789)->f64;
      _checked_ptr_1<double> _ptr__2817(_2817 ? _2817->raw() : nullptr,_2817 ? _2817->size(0) : 0);
      _ptr__2815[_2814] = (int)((_2805)->size(0));
      int _2818 = (int)0;
      _ptr__2815[_2813] = (int)0;
      int _8147 = (int)0;
      int _8148 = (int)((_2805)->size(0));
      for (int _2819 = _8147; _2819 < _8148; ++_2819)
      {
        {
          int _8149 = _ptr__2802[safe_add( _2797,_ptr__2805[_2819] )];
          int _8150 = _ptr__2802[safe_add( safe_add( _2797,_ptr__2805[_2819] ),(int)1 )];
          for (int _2820 = _8149; _2820 < _8150; ++_2820)
          {
            {
              _ptr__2816[safe_add( _2812,_2818 )] = _ptr__2803[safe_add( _2799,_2820 )];
              _ptr__2817[safe_add( _2810,_2818 )] = _ptr__2804[safe_add( _2801,_2820 )];
              ++ _2818;
            }
          }
          _ptr__2817[safe_add( _2811,_2819 )] = _ptr__2804[safe_add( _2800,_ptr__2805[_2819] )];
          _ptr__2815[safe_add( safe_add( _2813,_2819 ),(int)1 )] = _2818;
        }
      }
    }
  }
  else
  {
    {
      int _2821 = (int)1;
      int _2822 = (int)((_2805)->size(0));
      int _2823 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _2824 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__2824(_2824 ? _2824->raw() : nullptr,_2824 ? _2824->size(0) : 0);
      int _2825 = _2791->alloci32((int)((_2824)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _2826 = mosek::fusion::p_WorkStack::_get_impl(_2791)->i32;
      _checked_ptr_1<int> _ptr__2826(_2826 ? _2826->raw() : nullptr,_2826 ? _2826->size(0) : 0);
      int _8151 = (int)0;
      int _8152 = (int)((_2824)->size(0));
      for (int _2827 = _8151; _2827 < _8152; ++_2827)
      {
        {
          int _2828 = _2794;
          int _2829 = (int)0;
          while ( (_2829 < (_2828 - (int)1)) )
          {
            {
              int _2830 = (safe_add( safe_add( _2828,_2829 ),(int)1 ) / (int)2);
              if ((_ptr__2803[safe_add( _2798,_2830 )] >= _ptr__2824[_2827]))
              {
                {
                  _2828 = _2830;
                }
              }
              else
              {
                {
                  _2829 = _2830;
                }
              }
            }
          }
          ++ _2829;
          if (((_2829 < _2794) && (_ptr__2803[safe_add( _2798,_2829 )] == _ptr__2824[_2827])))
          {
            {
              _ptr__2826[safe_add( _2825,_2827 )] = _2829;
              _2823 += (_ptr__2802[safe_add( safe_add( _2797,_2829 ),(int)1 )] - _ptr__2802[safe_add( _2797,_2829 )]);
            }
          }
          else
          {
            {
              _ptr__2826[safe_add( _2825,_2827 )] = (-(int)1);
            }
          }
        }
      }
      _2789->alloc_expr(_2821,_2822,_2823,false);
      int _2831 = mosek::fusion::p_WorkStack::_get_impl(_2789)->ptr_base;
      int _2832 = mosek::fusion::p_WorkStack::_get_impl(_2789)->nidxs_base;
      int _2833 = mosek::fusion::p_WorkStack::_get_impl(_2789)->cof_base;
      int _2834 = mosek::fusion::p_WorkStack::_get_impl(_2789)->bfix_base;
      int _2835 = mosek::fusion::p_WorkStack::_get_impl(_2789)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2836 = mosek::fusion::p_WorkStack::_get_impl(_2789)->i32;
      _checked_ptr_1<int> _ptr__2836(_2836 ? _2836->raw() : nullptr,_2836 ? _2836->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2837 = mosek::fusion::p_WorkStack::_get_impl(_2789)->i64;
      _checked_ptr_1<long long> _ptr__2837(_2837 ? _2837->raw() : nullptr,_2837 ? _2837->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2838 = mosek::fusion::p_WorkStack::_get_impl(_2789)->f64;
      _checked_ptr_1<double> _ptr__2838(_2838 ? _2838->raw() : nullptr,_2838 ? _2838->size(0) : 0);
      _ptr__2836[_2835] = (int)((_2824)->size(0));
      _ptr__2836[_2831] = (int)0;
      int _2839 = (int)0;
      int _8153 = (int)0;
      int _8154 = (int)((_2824)->size(0));
      for (int _2840 = _8153; _2840 < _8154; ++_2840)
      {
        {
          if ((_ptr__2826[safe_add( _2825,_2840 )] >= (int)0))
          {
            {
              int _2841 = _ptr__2826[safe_add( _2825,_2840 )];
              int _8155 = _ptr__2802[safe_add( _2797,_2841 )];
              int _8156 = _ptr__2802[safe_add( safe_add( _2797,_2841 ),(int)1 )];
              for (int _2842 = _8155; _2842 < _8156; ++_2842)
              {
                {
                  _ptr__2837[safe_add( _2832,_2839 )] = _ptr__2803[safe_add( _2799,_2842 )];
                  _ptr__2838[safe_add( _2833,_2839 )] = _ptr__2804[safe_add( _2801,_2842 )];
                  ++ _2839;
                }
              }
              _ptr__2838[safe_add( _2834,_2840 )] = _ptr__2804[safe_add( _2800,_2841 )];
            }
          }
          else
          {
            {
              _ptr__2838[safe_add( _2834,_2840 )] = 0.0;
            }
          }
          _ptr__2836[safe_add( safe_add( _2831,_2840 ),(int)1 )] = _2839;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2843,    std::shared_ptr< monty::ndarray< int,1 > > _2844,    std::shared_ptr< monty::ndarray< int,1 > > _2845){ return new mosek::fusion::ExprSlice(_2843,_2844,_2845); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2843,    std::shared_ptr< monty::ndarray< int,1 > > _2844,    std::shared_ptr< monty::ndarray< int,1 > > _2845) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_2843,_2844,_2845); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2843,    std::shared_ptr< monty::ndarray< int,1 > > _2844,    std::shared_ptr< monty::ndarray< int,1 > > _2845){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2844(_2844 ? _2844->raw() : nullptr, _2844 ? _2844->size(0) : 0);
    _checked_ptr_1<int> _ptr__2845(_2845 ? _2845->raw() : nullptr, _2845 ? _2845->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_2843->getShape(),_2844,_2845));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _2843;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _2844;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _2845;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2846,monty::rc_ptr< ::mosek::fusion::WorkStack > _2847,monty::rc_ptr< ::mosek::fusion::WorkStack > _2848) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_2846,_2847,_2848); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2846,monty::rc_ptr< ::mosek::fusion::WorkStack > _2847,monty::rc_ptr< ::mosek::fusion::WorkStack > _2848){
  expr->eval(_2847,_2846,_2848);
  int _2849 = _2847->popi32();
  int _2850 = _2847->popi32(_2849);
  int _2851 = _2847->popi32();
  int _2852 = _2847->popi32();
  bool _2853 = (_2847->popi32() != (int)0);
  int _2854 = _2847->popi32(safe_add( _2851,(int)1 ));
  int _8157;
  bool _8158 = _2853;
  if (_8158)
  {
    _8157 = _2847->popi64(_2851);
  }
  else
  {
    _8157 = (-(int)1);
  }
  int _2855 = _8157;
  int _2856 = _2847->popi64(_2852);
  int _2857 = _2847->popf64(_2851);
  int _2858 = _2847->popf64(_2852);
  std::shared_ptr< monty::ndarray< int,1 > > _2859 = mosek::fusion::p_WorkStack::_get_impl(_2847)->i32;
  _checked_ptr_1<int> _ptr__2859(_2859 ? _2859->raw() : nullptr,_2859 ? _2859->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2860 = mosek::fusion::p_WorkStack::_get_impl(_2847)->i64;
  _checked_ptr_1<long long> _ptr__2860(_2860 ? _2860->raw() : nullptr,_2860 ? _2860->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2861 = mosek::fusion::p_WorkStack::_get_impl(_2847)->f64;
  _checked_ptr_1<double> _ptr__2861(_2861 ? _2861->raw() : nullptr,_2861 ? _2861->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2862 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2849)));
  _checked_ptr_1<long long> _ptr__2862(_2862 ? _2862->raw() : nullptr,_2862 ? _2862->size(0) : 0);
  _ptr__2862[(_2849 - (int)1)] = (int)1;
  int _8159 = (int)1;
  int _8160 = _2849;
  for (int _2863 = _8159; _2863 < _8160; ++_2863)
  {
    {
      _ptr__2862[((_2849 - _2863) - (int)1)] = safe_mul( _ptr__2862[(_2849 - _2863)],_ptr__2859[(safe_add( _2850,_2849 ) - _2863)] );
    }
  }
  int _2864 = (int)0;
  int _2865 = (int)0;
  if (_2853)
  {
    {
      int _8161 = (int)0;
      int _8162 = _2851;
      for (int _2866 = _8161; _2866 < _8162; ++_2866)
      {
        {
          bool _2867 = true;
          int _8163 = (int)0;
          int _8164 = _2849;
          for (int _2868 = _8163; _2868 < _8164; ++_2868)
          {
            {
              long long _2869 = ((_ptr__2860[safe_add( _2855,_2866 )] / _ptr__2862[_2868]) % _ptr__2859[safe_add( _2850,_2868 )]);
              _2867 = (_2867 && ((_2869 >= ((*first)(_2868))) && (_2869 < ((*last)(_2868)))));
            }
          }
          if (_2867)
          {
            {
              _2865 += (_ptr__2859[safe_add( safe_add( _2854,_2866 ),(int)1 )] - _ptr__2859[safe_add( _2854,_2866 )]);
              ++ _2864;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _2864 = (int)1;
      int _8165 = (int)0;
      int _8166 = _2849;
      for (int _2870 = _8165; _2870 < _8166; ++_2870)
      {
        {
          _2864 *= (((*last)(_2870)) - ((*first)(_2870)));
        }
      }
      int _8167 = (int)0;
      int _8168 = _2851;
      for (int _2871 = _8167; _2871 < _8168; ++_2871)
      {
        {
          bool _2872 = true;
          int _8169 = (int)0;
          int _8170 = _2849;
          for (int _2873 = _8169; _2873 < _8170; ++_2873)
          {
            {
              long long _2874 = ((_2871 / _ptr__2862[_2873]) % _ptr__2859[safe_add( _2850,_2873 )]);
              _2872 = (_2872 && ((_2874 >= ((*first)(_2873))) && (_2874 < ((*last)(_2873)))));
            }
          }
          if (_2872)
          {
            {
              _2865 += (_ptr__2859[safe_add( safe_add( _2854,_2871 ),(int)1 )] - _ptr__2859[safe_add( _2854,_2871 )]);
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _8171;
  for (int _2876 = (int)0, _8172 = _2849; _2876 < _8172 ; ++_2876)
  {
    _8171.push_back((((*last)(_2876)) - ((*first)(_2876))));
  }
  auto _8173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8171.size()),_8171.begin(),_8171.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _2875 = _8173;
  _checked_ptr_1<int> _ptr__2875(_2875 ? _2875->raw() : nullptr,_2875 ? _2875->size(0) : 0);
  int _2877 = _2846->allocf64(_2865);
  int _2878 = _2846->allocf64(_2864);
  int _2879 = _2846->alloci64(_2865);
  int _8174;
  bool _8175 = _2853;
  if (_8175)
  {
    _8174 = _2846->alloci64(_2864);
  }
  else
  {
    _8174 = (-(int)1);
  }
  int _2880 = _8174;
  int _2881 = _2846->alloci32(safe_add( _2864,(int)1 ));
  int _8176;
  bool _8177 = _2853;
  if (_8177)
  {
    _8176 = (int)1;
  }
  else
  {
    _8176 = (int)0;
  }
  _2846->pushi32(_8176);
  _2846->pushi32(_2865);
  _2846->pushi32(_2864);
  int _8178 = (int)0;
  int _8179 = _2849;
  for (int _2882 = _8178; _2882 < _8179; ++_2882)
  {
    {
      _2846->pushi32(_ptr__2875[_2882]);
    }
  }
  _2846->pushi32(_2849);
  std::shared_ptr< monty::ndarray< int,1 > > _2883 = mosek::fusion::p_WorkStack::_get_impl(_2846)->i32;
  _checked_ptr_1<int> _ptr__2883(_2883 ? _2883->raw() : nullptr,_2883 ? _2883->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2884 = mosek::fusion::p_WorkStack::_get_impl(_2846)->i64;
  _checked_ptr_1<long long> _ptr__2884(_2884 ? _2884->raw() : nullptr,_2884 ? _2884->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2885 = mosek::fusion::p_WorkStack::_get_impl(_2846)->f64;
  _checked_ptr_1<double> _ptr__2885(_2885 ? _2885->raw() : nullptr,_2885 ? _2885->size(0) : 0);
  _ptr__2883[_2881] = (int)0;
  std::shared_ptr< monty::ndarray< long long,1 > > _2886 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2849)));
  _checked_ptr_1<long long> _ptr__2886(_2886 ? _2886->raw() : nullptr,_2886 ? _2886->size(0) : 0);
  _ptr__2886[(_2849 - (int)1)] = (int)1;
  int _8180 = (int)1;
  int _8181 = _2849;
  for (int _2887 = _8180; _2887 < _8181; ++_2887)
  {
    {
      _ptr__2886[((_2849 - _2887) - (int)1)] = safe_mul( _ptr__2886[(_2849 - _2887)],_ptr__2875[(_2849 - _2887)] );
    }
  }
  int _2888 = (int)0;
  int _2889 = (int)0;
  if (_2853)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2890 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2849)));
      _checked_ptr_1<int> _ptr__2890(_2890 ? _2890->raw() : nullptr,_2890 ? _2890->size(0) : 0);
      int _8182 = (int)0;
      int _8183 = _2851;
      for (int _2891 = _8182; _2891 < _8183; ++_2891)
      {
        {
          bool _2892 = true;
          int _8184 = (int)0;
          int _8185 = _2849;
          for (int _2893 = _8184; _2893 < _8185; ++_2893)
          {
            {
              _ptr__2890[_2893] = (int)((_ptr__2860[safe_add( _2855,_2891 )] / _ptr__2862[_2893]) % _ptr__2859[safe_add( _2850,_2893 )]);
              _2892 = (_2892 && ((_ptr__2890[_2893] >= ((*first)(_2893))) && (_ptr__2890[_2893] < ((*last)(_2893)))));
            }
          }
          if (_2892)
          {
            {
              int _8186 = _ptr__2859[safe_add( _2854,_2891 )];
              int _8187 = _ptr__2859[safe_add( safe_add( _2854,_2891 ),(int)1 )];
              for (int _2894 = _8186; _2894 < _8187; ++_2894)
              {
                {
                  _ptr__2884[safe_add( _2879,_2889 )] = _ptr__2860[safe_add( _2856,_2894 )];
                  _ptr__2885[safe_add( _2877,_2889 )] = _ptr__2861[safe_add( _2858,_2894 )];
                  ++ _2889;
                }
              }
              long long _2895 = (long long)0;
              int _8188 = (int)0;
              int _8189 = _2849;
              for (int _2896 = _8188; _2896 < _8189; ++_2896)
              {
                {
                  _2895 += safe_mul( _ptr__2886[_2896],(_ptr__2890[_2896] - ((*first)(_2896))) );
                }
              }
              _ptr__2884[safe_add( _2880,_2888 )] = _2895;
              _ptr__2885[safe_add( _2878,_2888 )] = _ptr__2861[safe_add( _2857,_2891 )];
              _ptr__2883[safe_add( safe_add( _2881,_2888 ),(int)1 )] = _2889;
              ++ _2888;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _8190 = (int)0;
      int _8191 = _2851;
      for (int _2897 = _8190; _2897 < _8191; ++_2897)
      {
        {
          bool _2898 = true;
          int _8192 = (int)0;
          int _8193 = _2849;
          for (int _2899 = _8192; _2899 < _8193; ++_2899)
          {
            {
              long long _2900 = ((_2897 / _ptr__2862[_2899]) % _ptr__2859[safe_add( _2850,_2899 )]);
              _2898 = (_2898 && ((_2900 >= ((*first)(_2899))) && (_2900 < ((*last)(_2899)))));
            }
          }
          if (_2898)
          {
            {
              int _8194 = _ptr__2859[safe_add( _2854,_2897 )];
              int _8195 = _ptr__2859[safe_add( safe_add( _2854,_2897 ),(int)1 )];
              for (int _2901 = _8194; _2901 < _8195; ++_2901)
              {
                {
                  _ptr__2884[safe_add( _2879,_2889 )] = _ptr__2860[safe_add( _2856,_2901 )];
                  _ptr__2885[safe_add( _2877,_2889 )] = _ptr__2861[safe_add( _2858,_2901 )];
                  ++ _2889;
                }
              }
              _ptr__2885[safe_add( _2878,_2888 )] = _ptr__2861[safe_add( _2857,_2897 )];
              _ptr__2883[safe_add( safe_add( _2881,_2888 ),(int)1 )] = _2889;
              ++ _2888;
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2902,std::shared_ptr< monty::ndarray< int,1 > > _2903,std::shared_ptr< monty::ndarray< int,1 > > _2904){
  _checked_ptr_1<int> _ptr__2902(_2902 ? _2902->raw() : nullptr, _2902 ? _2902->size(0) : 0);
  _checked_ptr_1<int> _ptr__2903(_2903 ? _2903->raw() : nullptr, _2903 ? _2903->size(0) : 0);
  _checked_ptr_1<int> _ptr__2904(_2904 ? _2904->raw() : nullptr, _2904 ? _2904->size(0) : 0);
  if ((((int)((_2902)->size(0)) != (int)((_2903)->size(0))) || ((int)((_2902)->size(0)) != (int)((_2904)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _8196 = (int)0;
  int _8197 = (int)((_2902)->size(0));
  for (int _2905 = _8196; _2905 < _8197; ++_2905)
  {
    {
      if (((_ptr__2903[_2905] < (int)0) || ((_ptr__2904[_2905] < _ptr__2903[_2905]) || (_ptr__2904[_2905] > _ptr__2902[_2905]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _8198;
  for (int _2906 = (int)0, _8199 = (int)((_2902)->size(0)); _2906 < _8199 ; ++_2906)
  {
    _8198.push_back((_ptr__2904[_2906] - _ptr__2903[_2906]));
  }
  auto _8200 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8198.size()),_8198.begin(),_8198.end()));
  return _8200;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2907 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _8201 = (int)1;
  int _8202 = (int)((first)->size(0));
  for (int _2908 = _8201; _2908 < _8202; ++_2908)
  {
    {
      _2907->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_2908)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_2908)));
    }
  }
  _2907->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _2907->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2909,    monty::rc_ptr< ::mosek::fusion::Expression > _2910){ return new mosek::fusion::ExprPermuteDims(_2909,_2910); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2909,    monty::rc_ptr< ::mosek::fusion::Expression > _2910) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2909,_2910); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2909,    monty::rc_ptr< ::mosek::fusion::Expression > _2910){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2909(_2909 ? _2909->raw() : nullptr, _2909 ? _2909->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_2909,_2910,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _2911 = _2910->getShape();
    _checked_ptr_1<int> _ptr__2911(_2911 ? _2911->raw() : nullptr,_2911 ? _2911->size(0) : 0);
    if (((int)((_2909)->size(0)) != (int)((_2911)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _8203;
    for (int _2913 = (int)0, _8204 = (int)((_2909)->size(0)); _2913 < _8204 ; ++_2913)
    {
      _8203.push_back((int)0);
    }
    auto _8205 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8203.size()),_8203.begin(),_8203.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _2912 = _8205;
    _checked_ptr_1<int> _ptr__2912(_2912 ? _2912->raw() : nullptr,_2912 ? _2912->size(0) : 0);
    int _8206 = (int)0;
    int _8207 = (int)((_2912)->size(0));
    for (int _2914 = _8206; _2914 < _8207; ++_2914)
    {
      {
        if (((_ptr__2909[_2914] < (int)0) || (_ptr__2909[_2914] > (int)((_2911)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__2912[_ptr__2909[_2914]];
      }
    }
    int _8208 = (int)0;
    int _8209 = (int)((_2912)->size(0));
    for (int _2915 = _8208; _2915 < _8209; ++_2915)
    {
      {
        if (((_ptr__2912[_2915] < (int)1) || (_ptr__2912[_2915] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2916,    monty::rc_ptr< ::mosek::fusion::Expression > _2917,    int _2918){ return new mosek::fusion::ExprPermuteDims(_2916,_2917,_2918); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2916,    monty::rc_ptr< ::mosek::fusion::Expression > _2917,    int _2918) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2916,_2917,_2918); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2916,    monty::rc_ptr< ::mosek::fusion::Expression > _2917,    int _2918){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2916(_2916 ? _2916->raw() : nullptr, _2916 ? _2916->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_2916,_2917->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _2917;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_2916);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2919,monty::rc_ptr< ::mosek::fusion::WorkStack > _2920,monty::rc_ptr< ::mosek::fusion::WorkStack > _2921) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_2919,_2920,_2921); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2919,monty::rc_ptr< ::mosek::fusion::WorkStack > _2920,monty::rc_ptr< ::mosek::fusion::WorkStack > _2921){
  expr->eval(_2920,_2919,_2921);
  int _2922 = _2920->popi32();
  int _2923 = _2920->popi32(_2922);
  std::shared_ptr< monty::ndarray< long long,1 > > _2924 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2922)));
  _checked_ptr_1<long long> _ptr__2924(_2924 ? _2924->raw() : nullptr,_2924 ? _2924->size(0) : 0);
  _ptr__2924[(_2922 - (int)1)] = (int)1;
  int _8210 = (int)1;
  int _8211 = _2922;
  for (int _2925 = _8210; _2925 < _8211; ++_2925)
  {
    {
      _ptr__2924[((_2922 - _2925) - (int)1)] = safe_mul( _ptr__2924[(_2922 - _2925)],((*mosek::fusion::p_WorkStack::_get_impl(_2920)->i32)((safe_add( _2923,_2922 ) - _2925))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2926 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2922)));
  _checked_ptr_1<int> _ptr__2926(_2926 ? _2926->raw() : nullptr,_2926 ? _2926->size(0) : 0);
  _ptr__2926[(_2922 - (int)1)] = (int)1;
  int _8212 = (int)1;
  int _8213 = _2922;
  for (int _2927 = _8212; _2927 < _8213; ++_2927)
  {
    {
      _ptr__2926[((_2922 - _2927) - (int)1)] = safe_mul( _ptr__2926[(_2922 - _2927)],((*mosek::fusion::p_WorkStack::_get_impl(_2920)->i32)(safe_add( _2923,((*dperm)((_2922 - _2927))) ))) );
    }
  }
  int _2928 = _2920->popi32();
  int _2929 = _2920->popi32();
  bool _2930 = (_2920->popi32() != (int)0);
  int _2931 = _2920->popi32(safe_add( _2928,(int)1 ));
  int _8214;
  bool _8215 = (!_2930);
  if (_8215)
  {
    _8214 = (-(int)1);
  }
  else
  {
    _8214 = _2920->popi64(_2928);
  }
  int _2932 = _8214;
  int _2933 = _2920->popi64(_2929);
  int _2934 = _2920->popf64(_2928);
  int _2935 = _2920->popf64(_2929);
  std::shared_ptr< monty::ndarray< int,1 > > _2936 = mosek::fusion::p_WorkStack::_get_impl(_2920)->i32;
  _checked_ptr_1<int> _ptr__2936(_2936 ? _2936->raw() : nullptr,_2936 ? _2936->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2937 = mosek::fusion::p_WorkStack::_get_impl(_2920)->i64;
  _checked_ptr_1<long long> _ptr__2937(_2937 ? _2937->raw() : nullptr,_2937 ? _2937->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2938 = mosek::fusion::p_WorkStack::_get_impl(_2920)->f64;
  _checked_ptr_1<double> _ptr__2938(_2938 ? _2938->raw() : nullptr,_2938 ? _2938->size(0) : 0);
  if (_2930)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2939 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2928)));
      _checked_ptr_1<long long> _ptr__2939(_2939 ? _2939->raw() : nullptr,_2939 ? _2939->size(0) : 0);
      {
        int _8216 = (int)0;
        int _8217 = _2928;
        for (int _2940 = _8216; _2940 < _8217; ++_2940)
        {
          {
            long long _2941 = (long long)0;
            int _8218 = (int)0;
            int _8219 = _2922;
            for (int _2942 = _8218; _2942 < _8219; ++_2942)
            {
              {
                _2941 += safe_mul( ((_ptr__2937[safe_add( _2932,_2940 )] / _ptr__2924[_2942]) % _ptr__2936[safe_add( _2923,_2942 )]),_ptr__2926[((*dperm)(_2942))] );
              }
            }
            _ptr__2939[_2940] = _2941;
          }
        }
      }
      std::vector<long long> _8220;
      for (int _2944 = (int)0, _8221 = _2928; _2944 < _8221 ; ++_2944)
      {
        _8220.push_back(_2944);
      }
      auto _8222 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8220.size()),_8220.begin(),_8220.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2943 = _8222;
      _checked_ptr_1<long long> _ptr__2943(_2943 ? _2943->raw() : nullptr,_2943 ? _2943->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2943,_2939,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2928));
      int _2945 = _2919->alloci32(safe_add( _2928,(int)1 ));
      int _2946 = _2919->alloci64(_2929);
      int _2947 = _2919->alloci64(_2928);
      int _2948 = _2919->allocf64(_2929);
      int _2949 = _2919->allocf64(_2928);
      _2919->pushi32((int)1);
      _2919->pushi32(_2929);
      _2919->pushi32(_2928);
      int _8223 = (int)0;
      int _8224 = _2922;
      for (int _2950 = _8223; _2950 < _8224; ++_2950)
      {
        {
          _2919->pushi32(_ptr__2936[safe_add( _2923,((*dperm)(_2950)) )]);
        }
      }
      _2919->pushi32(_2922);
      std::shared_ptr< monty::ndarray< int,1 > > _2951 = mosek::fusion::p_WorkStack::_get_impl(_2919)->i32;
      _checked_ptr_1<int> _ptr__2951(_2951 ? _2951->raw() : nullptr,_2951 ? _2951->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2952 = mosek::fusion::p_WorkStack::_get_impl(_2919)->i64;
      _checked_ptr_1<long long> _ptr__2952(_2952 ? _2952->raw() : nullptr,_2952 ? _2952->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2953 = mosek::fusion::p_WorkStack::_get_impl(_2919)->f64;
      _checked_ptr_1<double> _ptr__2953(_2953 ? _2953->raw() : nullptr,_2953 ? _2953->size(0) : 0);
      _ptr__2951[_2945] = (int)0;
      int _2954 = (int)0;
      int _2955 = (int)0;
      int _8225 = (int)0;
      int _8226 = _2928;
      for (int _2956 = _8225; _2956 < _8226; ++_2956)
      {
        {
          long long _2957 = _ptr__2943[_2956];
          int _8227 = _ptr__2936[safe_add( _2931,_2957 )];
          int _8228 = _ptr__2936[safe_add( safe_add( _2931,_2957 ),(int)1 )];
          for (int _2958 = _8227; _2958 < _8228; ++_2958)
          {
            {
              _ptr__2952[safe_add( _2946,_2955 )] = _ptr__2937[safe_add( _2933,_2958 )];
              _ptr__2953[safe_add( _2948,_2955 )] = _ptr__2938[safe_add( _2935,_2958 )];
              ++ _2955;
            }
          }
          _ptr__2952[safe_add( _2947,_2956 )] = _ptr__2939[_2957];
          _ptr__2953[safe_add( _2949,_2956 )] = _ptr__2938[safe_add( _2934,_2957 )];
          ++ _2954;
          _ptr__2951[safe_add( safe_add( _2945,_2956 ),(int)1 )] = _2955;
        }
      }
    }
  }
  else
  {
    {
      int _2959 = _2919->alloci32(safe_add( _2928,(int)1 ));
      int _2960 = _2919->alloci64(_2929);
      int _2961 = _2919->allocf64(_2929);
      int _2962 = _2919->allocf64(_2928);
      _2919->pushi32((int)0);
      _2919->pushi32(_2929);
      _2919->pushi32(_2928);
      int _8229 = (int)0;
      int _8230 = _2922;
      for (int _2963 = _8229; _2963 < _8230; ++_2963)
      {
        {
          _2919->pushi32(_ptr__2936[safe_add( _2923,((*dperm)(_2963)) )]);
        }
      }
      _2919->pushi32(_2922);
      std::shared_ptr< monty::ndarray< int,1 > > _2964 = mosek::fusion::p_WorkStack::_get_impl(_2919)->i32;
      _checked_ptr_1<int> _ptr__2964(_2964 ? _2964->raw() : nullptr,_2964 ? _2964->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2965 = mosek::fusion::p_WorkStack::_get_impl(_2919)->i64;
      _checked_ptr_1<long long> _ptr__2965(_2965 ? _2965->raw() : nullptr,_2965 ? _2965->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2966 = mosek::fusion::p_WorkStack::_get_impl(_2919)->f64;
      _checked_ptr_1<double> _ptr__2966(_2966 ? _2966->raw() : nullptr,_2966 ? _2966->size(0) : 0);
      _ptr__2964[_2959] = (int)0;
      int _2967 = (int)0;
      int _2968 = (int)0;
      int _8231 = (int)0;
      int _8232 = _2928;
      for (int _2969 = _8231; _2969 < _8232; ++_2969)
      {
        {
          long long _2970 = (long long)0;
          int _8233 = (int)0;
          int _8234 = _2922;
          for (int _2971 = _8233; _2971 < _8234; ++_2971)
          {
            {
              _2970 += safe_mul( ((_2969 / _ptr__2924[((*dperm)(_2971))]) % _ptr__2936[safe_add( _2923,((*dperm)(_2971)) )]),_ptr__2926[_2971] );
            }
          }
          int _8235 = _ptr__2936[safe_add( _2931,_2970 )];
          int _8236 = _ptr__2936[safe_add( safe_add( _2931,_2970 ),(int)1 )];
          for (int _2972 = _8235; _2972 < _8236; ++_2972)
          {
            {
              _ptr__2965[safe_add( _2960,_2968 )] = _ptr__2937[safe_add( _2933,_2972 )];
              _ptr__2966[safe_add( _2961,_2968 )] = _ptr__2938[safe_add( _2935,_2972 )];
              ++ _2968;
            }
          }
          _ptr__2966[safe_add( _2962,_2967 )] = _ptr__2938[safe_add( _2934,_2970 )];
          ++ _2967;
          _ptr__2964[safe_add( _2959,_2967 )] = _2968;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2973,std::shared_ptr< monty::ndarray< int,1 > > _2974){
  _checked_ptr_1<int> _ptr__2973(_2973 ? _2973->raw() : nullptr, _2973 ? _2973->size(0) : 0);
  _checked_ptr_1<int> _ptr__2974(_2974 ? _2974->raw() : nullptr, _2974 ? _2974->size(0) : 0);
  std::vector<int> _8237;
  for (int _2975 = (int)0, _8238 = (int)((_2973)->size(0)); _2975 < _8238 ; ++_2975)
  {
    _8237.push_back(_ptr__2974[_ptr__2973[_2975]]);
  }
  auto _8239 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8237.size()),_8237.begin(),_8237.end()));
  return _8239;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2976){ return new mosek::fusion::ExprTranspose(_2976); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2976) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_2976); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2976){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_2976->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _2976;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2977,monty::rc_ptr< ::mosek::fusion::WorkStack > _2978,monty::rc_ptr< ::mosek::fusion::WorkStack > _2979) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_2977,_2978,_2979); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2977,monty::rc_ptr< ::mosek::fusion::WorkStack > _2978,monty::rc_ptr< ::mosek::fusion::WorkStack > _2979){
  expr->eval(_2978,_2977,_2979);
  _2978->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_2978)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _2980 = mosek::fusion::p_WorkStack::_get_impl(_2978)->shape_base;
      int _2981 = mosek::fusion::p_WorkStack::_get_impl(_2978)->nelem;
      int _2982 = mosek::fusion::p_WorkStack::_get_impl(_2978)->nnz;
      bool _2983 = mosek::fusion::p_WorkStack::_get_impl(_2978)->hassp;
      int _2984 = mosek::fusion::p_WorkStack::_get_impl(_2978)->ptr_base;
      int _2985 = mosek::fusion::p_WorkStack::_get_impl(_2978)->sp_base;
      int _2986 = mosek::fusion::p_WorkStack::_get_impl(_2978)->nidxs_base;
      int _2987 = mosek::fusion::p_WorkStack::_get_impl(_2978)->bfix_base;
      int _2988 = mosek::fusion::p_WorkStack::_get_impl(_2978)->cof_base;
      int _2989 = ((*mosek::fusion::p_WorkStack::_get_impl(_2978)->i32)(_2980));
      int _2990 = ((*mosek::fusion::p_WorkStack::_get_impl(_2978)->i32)(safe_add( _2980,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _2991 = mosek::fusion::p_WorkStack::_get_impl(_2978)->i32;
      _checked_ptr_1<int> _ptr__2991(_2991 ? _2991->raw() : nullptr,_2991 ? _2991->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2992 = mosek::fusion::p_WorkStack::_get_impl(_2978)->i64;
      _checked_ptr_1<long long> _ptr__2992(_2992 ? _2992->raw() : nullptr,_2992 ? _2992->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2993 = mosek::fusion::p_WorkStack::_get_impl(_2978)->f64;
      _checked_ptr_1<double> _ptr__2993(_2993 ? _2993->raw() : nullptr,_2993 ? _2993->size(0) : 0);
      _2977->alloc_expr((int)2,_2981,_2982,_2983);
      int _2994 = mosek::fusion::p_WorkStack::_get_impl(_2977)->ptr_base;
      int _2995 = mosek::fusion::p_WorkStack::_get_impl(_2977)->nidxs_base;
      int _2996 = mosek::fusion::p_WorkStack::_get_impl(_2977)->sp_base;
      int _2997 = mosek::fusion::p_WorkStack::_get_impl(_2977)->cof_base;
      int _2998 = mosek::fusion::p_WorkStack::_get_impl(_2977)->bfix_base;
      int _2999 = mosek::fusion::p_WorkStack::_get_impl(_2977)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3000 = mosek::fusion::p_WorkStack::_get_impl(_2977)->i32;
      _checked_ptr_1<int> _ptr__3000(_3000 ? _3000->raw() : nullptr,_3000 ? _3000->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3001 = mosek::fusion::p_WorkStack::_get_impl(_2977)->i64;
      _checked_ptr_1<long long> _ptr__3001(_3001 ? _3001->raw() : nullptr,_3001 ? _3001->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3002 = mosek::fusion::p_WorkStack::_get_impl(_2977)->f64;
      _checked_ptr_1<double> _ptr__3002(_3002 ? _3002->raw() : nullptr,_3002 ? _3002->size(0) : 0);
      _ptr__3000[_2999] = _2990;
      _ptr__3000[safe_add( _2999,(int)1 )] = _2989;
      if (_2983)
      {
        {
          int _3003 = _2979->alloci32(_2981);
          int _3004 = _2979->alloci32(safe_add( _2990,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _3005 = mosek::fusion::p_WorkStack::_get_impl(_2979)->i32;
          _checked_ptr_1<int> _ptr__3005(_3005 ? _3005->raw() : nullptr,_3005 ? _3005->size(0) : 0);
          {
            int _8240 = (int)0;
            int _8241 = safe_add( _2990,(int)1 );
            for (int _3006 = _8240; _3006 < _8241; ++_3006)
            {
              {
                _ptr__3005[safe_add( _3004,_3006 )] = (int)0;
              }
            }
            int _8242 = (int)0;
            int _8243 = _2981;
            for (int _3007 = _8242; _3007 < _8243; ++_3007)
            {
              {
                ++ _ptr__3005[safe_add( safe_add( _3004,(_ptr__2992[safe_add( _2985,_3007 )] % _2990) ),(int)1 )];
              }
            }
            int _8244 = (int)0;
            int _8245 = _2990;
            for (int _3008 = _8244; _3008 < _8245; ++_3008)
            {
              {
                _ptr__3005[safe_add( safe_add( _3004,_3008 ),(int)1 )] += _ptr__3005[safe_add( _3004,_3008 )];
              }
            }
            int _8246 = (int)0;
            int _8247 = _2981;
            for (int _3009 = _8246; _3009 < _8247; ++_3009)
            {
              {
                long long _3010 = (_ptr__2992[safe_add( _2985,_3009 )] % _2990);
                _ptr__3005[safe_add( _3003,_ptr__3005[safe_add( _3004,_3010 )] )] = _3009;
                ++ _ptr__3005[safe_add( _3004,_3010 )];
              }
            }
            _ptr__3000[_2994] = (int)0;
            int _3011 = (int)0;
            int _8248 = (int)0;
            int _8249 = _2981;
            for (int _3012 = _8248; _3012 < _8249; ++_3012)
            {
              {
                int _3013 = _ptr__3005[safe_add( _3003,_3012 )];
                int _8250 = _ptr__2991[safe_add( _2984,_3013 )];
                int _8251 = _ptr__2991[safe_add( safe_add( _2984,_3013 ),(int)1 )];
                for (int _3014 = _8250; _3014 < _8251; ++_3014)
                {
                  {
                    _ptr__3001[safe_add( _2995,_3011 )] = _ptr__2992[safe_add( _2986,_3014 )];
                    _ptr__3002[safe_add( _2997,_3011 )] = _ptr__2993[safe_add( _2988,_3014 )];
                    ++ _3011;
                  }
                }
                long long _3015 = (_ptr__2992[safe_add( _2985,_3013 )] / _2990);
                long long _3016 = (_ptr__2992[safe_add( _2985,_3013 )] % _2990);
                _ptr__3000[safe_add( safe_add( _2994,_3012 ),(int)1 )] = _3011;
                _ptr__3001[safe_add( _2996,_3012 )] = safe_add( safe_mul( _3016,_2989 ),_3015 );
                _ptr__3002[safe_add( _2998,_3012 )] = _ptr__2993[safe_add( _2987,_3013 )];
              }
            }
          }
        }
      }
      else
      {
        {
          _ptr__3000[_2994] = (int)0;
          int _3017 = (int)0;
          int _3018 = (int)0;
          int _8252 = (int)0;
          int _8253 = _2990;
          for (int _3019 = _8252; _3019 < _8253; ++_3019)
          {
            {
              int _8254 = (int)0;
              int _8255 = _2989;
              for (int _3020 = _8254; _3020 < _8255; ++_3020)
              {
                {
                  int _3021 = safe_add( safe_mul( _3020,_2990 ),_3019 );
                  int _8256 = _ptr__2991[safe_add( _2984,_3021 )];
                  int _8257 = _ptr__2991[safe_add( safe_add( _2984,_3021 ),(int)1 )];
                  for (int _3022 = _8256; _3022 < _8257; ++_3022)
                  {
                    {
                      _ptr__3001[safe_add( _2995,_3017 )] = _ptr__2992[safe_add( _2986,_3022 )];
                      _ptr__3002[safe_add( _2997,_3017 )] = _ptr__2993[safe_add( _2988,_3022 )];
                      ++ _3017;
                    }
                  }
                  _ptr__3002[safe_add( _2998,_3018 )] = _ptr__2993[safe_add( _2987,_3021 )];
                  _ptr__3000[safe_add( safe_add( _2994,_3018 ),(int)1 )] = _3017;
                  ++ _3018;
                }
              }
            }
          }
        }
      }
      _2979->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _3023){
  _checked_ptr_1<int> _ptr__3023(_3023 ? _3023->raw() : nullptr, _3023 ? _3023->size(0) : 0);
  if (((int)((_3023)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3023[(int)1]),(int)(_ptr__3023[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3024,    int _3025){ return new mosek::fusion::ExprStack(_3024,_3025); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3024,    int _3025) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_3024,_3025); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3024,    int _3025){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_3024,_3025));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8258;
    for (int _3026 = (int)0, _8259 = (int)((_3024)->size(0)); _3026 < _8259 ; ++_3026)
    {
      _8258.push_back(((*_3024)(_3026)));
    }
    auto _8260 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8258.size()),_8258.begin(),_8258.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _8260;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _3025;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3027,monty::rc_ptr< ::mosek::fusion::WorkStack > _3028,monty::rc_ptr< ::mosek::fusion::WorkStack > _3029) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_3027,_3028,_3029); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3027,monty::rc_ptr< ::mosek::fusion::WorkStack > _3028,monty::rc_ptr< ::mosek::fusion::WorkStack > _3029){
  int _3030 = (int)((exprs)->size(0));
  if ((_3030 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_3027,_3028,_3029);
    }
  }
  else
  {
    {
      int _8261 = (int)0;
      int _8262 = _3030;
      for (int _3031 = _8261; _3031 < _8262; ++_3031)
      {
        {
          ((*exprs)(((_3030 - _3031) - (int)1)))->eval(_3028,_3027,_3029);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3032 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3032(_3032 ? _3032->raw() : nullptr,_3032 ? _3032->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3033 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3033(_3033 ? _3033->raw() : nullptr,_3033 ? _3033->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3034 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3034(_3034 ? _3034->raw() : nullptr,_3034 ? _3034->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3035 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3035(_3035 ? _3035->raw() : nullptr,_3035 ? _3035->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _3036 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_3030)));
      std::shared_ptr< monty::ndarray< int,1 > > _3037 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3037(_3037 ? _3037->raw() : nullptr,_3037 ? _3037->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3038 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3038(_3038 ? _3038->raw() : nullptr,_3038 ? _3038->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3039 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3039(_3039 ? _3039->raw() : nullptr,_3039 ? _3039->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3040 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3040(_3040 ? _3040->raw() : nullptr,_3040 ? _3040->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3041 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3041(_3041 ? _3041->raw() : nullptr,_3041 ? _3041->size(0) : 0);
      int _8263 = (int)0;
      int _8264 = _3030;
      for (int _3042 = _8263; _3042 < _8264; ++_3042)
      {
        {
          _3028->pop_expr();
          _ptr__3032[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->nd;
          _ptr__3033[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->shape_base;
          _ptr__3034[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->nelem;
          _ptr__3035[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->nnz;
          ((*_3036)(_3042)) = mosek::fusion::p_WorkStack::_get_impl(_3028)->hassp;
          _ptr__3037[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->ptr_base;
          _ptr__3039[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->sp_base;
          _ptr__3038[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->nidxs_base;
          _ptr__3041[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->bfix_base;
          _ptr__3040[_3042] = mosek::fusion::p_WorkStack::_get_impl(_3028)->cof_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3043 = mosek::fusion::p_WorkStack::_get_impl(_3028)->i32;
      _checked_ptr_1<int> _ptr__3043(_3043 ? _3043->raw() : nullptr,_3043 ? _3043->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3044 = mosek::fusion::p_WorkStack::_get_impl(_3028)->i64;
      _checked_ptr_1<long long> _ptr__3044(_3044 ? _3044->raw() : nullptr,_3044 ? _3044->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3045 = mosek::fusion::p_WorkStack::_get_impl(_3028)->f64;
      _checked_ptr_1<double> _ptr__3045(_3045 ? _3045->raw() : nullptr,_3045 ? _3045->size(0) : 0);
      int _3046 = _ptr__3032[(int)0];
      int _3047 = _ptr__3033[(int)0];
      bool _3048 = (!((*_3036)((int)0)));
      bool _3049 = false;
      int _8265 = (int)1;
      int _8266 = _3030;
      for (int _3050 = _8265; _3050 < _8266; ++_3050)
      {
        {
          {
            _3049 = (_3049 || ((dim != _3050) && (_ptr__3032[_3050] != _3046)));
            if ((!_3049))
            {
              {
                int _8267 = (int)0;
                int _8268 = dim;
                for (int _3051 = _8267; _3051 < _8268; ++_3051)
                {
                  {
                    _3049 = (_3049 || (_ptr__3043[safe_add( _3047,_3051 )] != _ptr__3043[safe_add( _ptr__3033[_3050],_3051 )]));
                  }
                }
              }
            }
            {}
            if ((!_3049))
            {
              {
                int _8269 = safe_add( dim,(int)1 );
                int _8270 = _3046;
                for (int _3052 = _8269; _3052 < _8270; ++_3052)
                {
                  {
                    _3049 = (_3049 || (_ptr__3043[safe_add( _3047,_3052 )] != _ptr__3043[safe_add( _ptr__3033[_3050],_3052 )]));
                  }
                }
              }
            }
            {}
          }
          _3048 = (_3048 && (!((*_3036)(_3050))));
        }
      }
      if (_3049)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _3053 = (int)0;
      if ((dim < _3046))
      {
        {
          int _8271 = (int)0;
          int _8272 = _3030;
          for (int _3054 = _8271; _3054 < _8272; ++_3054)
          {
            {
              _3053 += _ptr__3043[safe_add( _ptr__3033[_3054],dim )];
            }
          }
        }
      }
      else
      {
        {
          _3053 = _3030;
        }
      }
      int _8273;
      bool _8274 = (dim < _3046);
      if (_8274)
      {
        _8273 = _3046;
      }
      else
      {
        _8273 = safe_add( _3046,(int)1 );
      }
      int _3055 = _8273;
      if ((_3055 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Oops!!"));
        }
      }
      {}
      int _3056 = (int)0;
      int _3057 = (int)0;
      {
        int _8275 = (int)0;
        int _8276 = _3030;
        for (int _3058 = _8275; _3058 < _8276; ++_3058)
        {
          {
            _3057 += _ptr__3035[_3058];
          }
        }
        int _8277 = (int)0;
        int _8278 = _3030;
        for (int _3059 = _8277; _3059 < _8278; ++_3059)
        {
          {
            _3056 += _ptr__3034[_3059];
          }
        }
      }
      int _3060 = (int)1;
      int _8279 = (int)0;
      int _8280 = dim;
      for (int _3061 = _8279; _3061 < _8280; ++_3061)
      {
        {
          _3060 *= _ptr__3043[safe_add( _3047,_3061 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _8281;
      bool _8282 = (dim < _3046);
      if (_8282)
      {
        std::vector<int> _8283;
        for (int _3063 = (int)0, _8284 = _3030; _3063 < _8284 ; ++_3063)
        {
          _8283.push_back(_ptr__3043[safe_add( _ptr__3033[_3063],dim )]);
        }
        auto _8285 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8283.size()),_8283.begin(),_8283.end()));
        _8281 = _8285;
      }
      else
      {
        std::vector<int> _8286;
        for (int _3064 = (int)0, _8287 = _3030; _3064 < _8287 ; ++_3064)
        {
          _8286.push_back((int)1);
        }
        auto _8288 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8286.size()),_8286.begin(),_8286.end()));
        _8281 = _8288;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3062 = _8281;
      _checked_ptr_1<int> _ptr__3062(_3062 ? _3062->raw() : nullptr,_3062 ? _3062->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3065 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3030)));
      _checked_ptr_1<int> _ptr__3065(_3065 ? _3065->raw() : nullptr,_3065 ? _3065->size(0) : 0);
      _ptr__3065[(int)0] = (int)0;
      int _8289 = (int)1;
      int _8290 = _3030;
      for (int _3066 = _8289; _3066 < _8290; ++_3066)
      {
        {
          _ptr__3065[_3066] = safe_add( _ptr__3065[(_3066 - (int)1)],_ptr__3062[(_3066 - (int)1)] );
        }
      }
      int _3067 = (int)0;
      int _8291 = (int)0;
      int _8292 = _3030;
      for (int _3068 = _8291; _3068 < _8292; ++_3068)
      {
        {
          _3067 += _ptr__3062[_3068];
        }
      }
      int _3069 = (int)1;
      int _8293 = safe_add( dim,(int)1 );
      int _8294 = _3046;
      for (int _3070 = _8293; _3070 < _8294; ++_3070)
      {
        {
          _3069 *= _ptr__3043[safe_add( _3047,_3070 )];
        }
      }
      if (_3048)
      {
        {
          _3027->alloc_expr(_3055,_3056,_3057,false);
          int _3071 = mosek::fusion::p_WorkStack::_get_impl(_3027)->ptr_base;
          int _3072 = mosek::fusion::p_WorkStack::_get_impl(_3027)->shape_base;
          int _3073 = mosek::fusion::p_WorkStack::_get_impl(_3027)->nidxs_base;
          int _3074 = mosek::fusion::p_WorkStack::_get_impl(_3027)->cof_base;
          int _3075 = mosek::fusion::p_WorkStack::_get_impl(_3027)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3076 = mosek::fusion::p_WorkStack::_get_impl(_3027)->i32;
          _checked_ptr_1<int> _ptr__3076(_3076 ? _3076->raw() : nullptr,_3076 ? _3076->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3077 = mosek::fusion::p_WorkStack::_get_impl(_3027)->i64;
          _checked_ptr_1<long long> _ptr__3077(_3077 ? _3077->raw() : nullptr,_3077 ? _3077->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3078 = mosek::fusion::p_WorkStack::_get_impl(_3027)->f64;
          _checked_ptr_1<double> _ptr__3078(_3078 ? _3078->raw() : nullptr,_3078 ? _3078->size(0) : 0);
          int _8295 = (int)0;
          int _8296 = _3046;
          for (int _3079 = _8295; _3079 < _8296; ++_3079)
          {
            {
              _ptr__3076[safe_add( _3072,_3079 )] = _ptr__3043[safe_add( _3047,_3079 )];
            }
          }
          _ptr__3076[safe_add( _3072,dim )] = _3053;
          {
            _ptr__3076[_3071] = (int)0;
            {
              int _3080 = (int)0;
              int _8297 = (int)0;
              int _8298 = _3030;
              for (int _3081 = _8297; _3081 < _8298; ++_3081)
              {
                {
                  int _3082 = _ptr__3037[_3081];
                  int _3083 = (int)0;
                  int _8299 = (int)0;
                  int _8300 = _3060;
                  for (int _3084 = _8299; _3084 < _8300; ++_3084)
                  {
                    {
                      int _8301 = (int)0;
                      int _8302 = _ptr__3062[_3081];
                      for (int _3085 = _8301; _3085 < _8302; ++_3085)
                      {
                        {
                          int _8303 = (int)0;
                          int _8304 = _3069;
                          for (int _3086 = _8303; _3086 < _8304; ++_3086)
                          {
                            {
                              int _3087 = safe_add( safe_add( _3086,safe_mul( safe_add( _3085,_3080 ),_3069 ) ),safe_mul( safe_mul( _3084,_3067 ),_3069 ) );
                              int _3088 = (_ptr__3043[safe_add( safe_add( _3082,_3083 ),(int)1 )] - _ptr__3043[safe_add( _3082,_3083 )]);
                              _ptr__3076[safe_add( safe_add( _3071,_3087 ),(int)1 )] = _3088;
                              _ptr__3078[safe_add( _3075,_3087 )] = _ptr__3045[safe_add( _ptr__3041[_3081],_3083 )];
                              ++ _3083;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3080 += _ptr__3062[_3081];
                }
              }
              int _8305 = (int)0;
              int _8306 = _3056;
              for (int _3089 = _8305; _3089 < _8306; ++_3089)
              {
                {
                  _ptr__3076[safe_add( safe_add( _3071,_3089 ),(int)1 )] += _ptr__3076[safe_add( _3071,_3089 )];
                }
              }
            }
            {
              int _3090 = (int)0;
              int _8307 = (int)0;
              int _8308 = _3030;
              for (int _3091 = _8307; _3091 < _8308; ++_3091)
              {
                {
                  int _3092 = _ptr__3037[_3091];
                  int _3093 = (int)0;
                  int _8309 = (int)0;
                  int _8310 = _3060;
                  for (int _3094 = _8309; _3094 < _8310; ++_3094)
                  {
                    {
                      int _8311 = (int)0;
                      int _8312 = _ptr__3062[_3091];
                      for (int _3095 = _8311; _3095 < _8312; ++_3095)
                      {
                        {
                          int _8313 = (int)0;
                          int _8314 = _3069;
                          for (int _3096 = _8313; _3096 < _8314; ++_3096)
                          {
                            {
                              int _3097 = safe_add( safe_add( _3096,safe_mul( safe_add( _3095,_3090 ),_3069 ) ),safe_mul( safe_mul( _3094,_3067 ),_3069 ) );
                              int _3098 = _ptr__3043[safe_add( _3092,_3093 )];
                              int _3099 = (_ptr__3043[safe_add( safe_add( _3092,_3093 ),(int)1 )] - _3098);
                              int _8315 = (int)0;
                              int _8316 = _3099;
                              for (int _3100 = _8315; _3100 < _8316; ++_3100)
                              {
                                {
                                  _ptr__3077[safe_add( safe_add( _3073,_ptr__3076[safe_add( _3071,_3097 )] ),_3100 )] = _ptr__3044[safe_add( safe_add( _ptr__3038[_3091],_3098 ),_3100 )];
                                }
                              }
                              int _8317 = (int)0;
                              int _8318 = _3099;
                              for (int _3101 = _8317; _3101 < _8318; ++_3101)
                              {
                                {
                                  _ptr__3078[safe_add( safe_add( _3074,_ptr__3076[safe_add( _3071,_3097 )] ),_3101 )] = _ptr__3045[safe_add( safe_add( _ptr__3040[_3091],_3098 ),_3101 )];
                                }
                              }
                              ++ _3093;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3090 += _ptr__3062[_3091];
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3102 = (int)1;
          int _8319 = (int)0;
          int _8320 = dim;
          for (int _3103 = _8319; _3103 < _8320; ++_3103)
          {
            {
              _3102 *= _ptr__3043[safe_add( _3047,_3103 )];
            }
          }
          _3102 *= _3053;
          int _8321 = safe_add( dim,(int)1 );
          int _8322 = _3046;
          for (int _3104 = _8321; _3104 < _8322; ++_3104)
          {
            {
              _3102 *= _ptr__3043[safe_add( _3047,_3104 )];
            }
          }
          bool _3105 = (_3056 < _3102);
          _3027->alloc_expr(_3055,_3056,_3057,_3105);
          int _3106 = mosek::fusion::p_WorkStack::_get_impl(_3027)->ptr_base;
          int _3107 = mosek::fusion::p_WorkStack::_get_impl(_3027)->nidxs_base;
          int _8323;
          bool _8324 = _3105;
          if (_8324)
          {
            _8323 = mosek::fusion::p_WorkStack::_get_impl(_3027)->sp_base;
          }
          else
          {
            _8323 = _3027->alloci64(_3056);
          }
          int _3108 = _8323;
          int _3109 = mosek::fusion::p_WorkStack::_get_impl(_3027)->cof_base;
          int _3110 = mosek::fusion::p_WorkStack::_get_impl(_3027)->bfix_base;
          int _3111 = mosek::fusion::p_WorkStack::_get_impl(_3027)->shape_base;
          int _8325 = (int)0;
          int _8326 = _3046;
          for (int _3112 = _8325; _3112 < _8326; ++_3112)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_3027)->i32)(safe_add( _3111,_3112 ))) = _ptr__3043[safe_add( _3047,_3112 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_3027)->i32)(safe_add( _3111,dim ))) = _3053;
          int _3113 = _3029->alloci32(safe_add( _3056,(int)1 ));
          int _3114 = _3029->alloci64(_3057);
          int _3115 = _3029->alloci64(_3056);
          int _3116 = _3029->allocf64(_3057);
          int _3117 = _3029->allocf64(_3056);
          std::shared_ptr< monty::ndarray< int,1 > > _3118 = mosek::fusion::p_WorkStack::_get_impl(_3027)->i32;
          _checked_ptr_1<int> _ptr__3118(_3118 ? _3118->raw() : nullptr,_3118 ? _3118->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3119 = mosek::fusion::p_WorkStack::_get_impl(_3027)->i64;
          _checked_ptr_1<long long> _ptr__3119(_3119 ? _3119->raw() : nullptr,_3119 ? _3119->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3120 = mosek::fusion::p_WorkStack::_get_impl(_3027)->f64;
          _checked_ptr_1<double> _ptr__3120(_3120 ? _3120->raw() : nullptr,_3120 ? _3120->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _3121 = mosek::fusion::p_WorkStack::_get_impl(_3029)->i32;
          _checked_ptr_1<int> _ptr__3121(_3121 ? _3121->raw() : nullptr,_3121 ? _3121->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3122 = mosek::fusion::p_WorkStack::_get_impl(_3029)->i64;
          _checked_ptr_1<long long> _ptr__3122(_3122 ? _3122->raw() : nullptr,_3122 ? _3122->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3123 = mosek::fusion::p_WorkStack::_get_impl(_3029)->f64;
          _checked_ptr_1<double> _ptr__3123(_3123 ? _3123->raw() : nullptr,_3123 ? _3123->size(0) : 0);
          {
            int _3124 = (int)0;
            int _3125 = (int)0;
            int _8327 = (int)0;
            int _8328 = _3030;
            for (int _3126 = _8327; _3126 < _8328; ++_3126)
            {
              {
                ::mosek::fusion::Utils::Tools::arraycopy(_3044,_ptr__3038[_3126],_3122,safe_add( _3114,_3125 ),_ptr__3035[_3126]);
                ::mosek::fusion::Utils::Tools::arraycopy(_3045,_ptr__3040[_3126],_3123,safe_add( _3116,_3125 ),_ptr__3035[_3126]);
                ::mosek::fusion::Utils::Tools::arraycopy(_3045,_ptr__3041[_3126],_3123,safe_add( _3117,_3124 ),_ptr__3034[_3126]);
                _3125 += _ptr__3035[_3126];
                _3124 += _ptr__3034[_3126];
              }
            }
          }
          {
            _ptr__3121[_3113] = (int)0;
            int _3127 = (int)0;
            int _3128 = (int)0;
            int _8329 = (int)0;
            int _8330 = _3030;
            for (int _3129 = _8329; _3129 < _8330; ++_3129)
            {
              {
                int _3130 = _ptr__3062[_3129];
                int _3131 = safe_mul( _3130,_3069 );
                int _3132 = _3069;
                if (((*_3036)(_3129)))
                {
                  {
                    int _8331 = (int)0;
                    int _8332 = _ptr__3034[_3129];
                    for (int _3133 = _8331; _3133 < _8332; ++_3133)
                    {
                      {
                        long long _3134 = (_ptr__3044[safe_add( _ptr__3039[_3129],_3133 )] / _3131);
                        long long _3135 = ((_ptr__3044[safe_add( _ptr__3039[_3129],_3133 )] / _3132) % _3130);
                        long long _3136 = (_ptr__3044[safe_add( _ptr__3039[_3129],_3133 )] % _3069);
                        _ptr__3122[safe_add( _3115,_3128 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3134,_3053 ),_3135 ),_ptr__3065[_3129] ),_3069 ),_3136 );
                        _ptr__3121[safe_add( safe_add( _3113,_3128 ),(int)1 )] = safe_add( _3127,_ptr__3043[safe_add( safe_add( _ptr__3037[_3129],_3133 ),(int)1 )] );
                        ++ _3128;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _3137 = (int)0;
                    int _8333 = (int)0;
                    int _8334 = _3060;
                    for (int _3138 = _8333; _3138 < _8334; ++_3138)
                    {
                      {
                        int _8335 = (int)0;
                        int _8336 = _3130;
                        for (int _3139 = _8335; _3139 < _8336; ++_3139)
                        {
                          {
                            int _8337 = (int)0;
                            int _8338 = _3069;
                            for (int _3140 = _8337; _3140 < _8338; ++_3140)
                            {
                              {
                                _ptr__3122[safe_add( _3115,_3128 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3138,_3053 ),_3139 ),_ptr__3065[_3129] ),_3069 ),_3140 );
                                _ptr__3121[safe_add( safe_add( _3113,_3128 ),(int)1 )] = safe_add( _3127,_ptr__3043[safe_add( safe_add( _ptr__3037[_3129],_3137 ),(int)1 )] );
                                ++ _3128;
                                ++ _3137;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                _3127 += _ptr__3035[_3129];
              }
            }
          }
          if ((dim > (int)0))
          {
            {
              int _3141 = (int)0;
              int _8339 = (int)0;
              int _8340 = _3055;
              for (int _3142 = _8339; _3142 < _8340; ++_3142)
              {
                {
                  if ((_3141 < _ptr__3118[safe_add( _3111,_3142 )]))
                  {
                    {
                      _3141 = _ptr__3118[safe_add( _3111,_3142 )];
                    }
                  }
                  {}
                }
              }
              std::shared_ptr< monty::ndarray< long long,1 > > _3143 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3055)));
              _checked_ptr_1<long long> _ptr__3143(_3143 ? _3143->raw() : nullptr,_3143 ? _3143->size(0) : 0);
              _ptr__3143[(_3055 - (int)1)] = (int)1;
              int _8341 = (int)1;
              int _8342 = _3055;
              for (int _3144 = _8341; _3144 < _8342; ++_3144)
              {
                {
                  _ptr__3143[((_3055 - _3144) - (int)1)] = safe_mul( _ptr__3143[(_3055 - _3144)],_ptr__3118[(safe_add( _3111,_3055 ) - _3144)] );
                }
              }
              int _3145 = _3029->alloci32(_3056);
              int _3146 = _3029->alloci32(_3056);
              int _3147 = _3029->alloci32(safe_add( _3141,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _3148 = mosek::fusion::p_WorkStack::_get_impl(_3029)->i32;
              _checked_ptr_1<int> _ptr__3148(_3148 ? _3148->raw() : nullptr,_3148 ? _3148->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _3149 = mosek::fusion::p_WorkStack::_get_impl(_3029)->i64;
              _checked_ptr_1<long long> _ptr__3149(_3149 ? _3149->raw() : nullptr,_3149 ? _3149->size(0) : 0);
              std::shared_ptr< monty::ndarray< double,1 > > _3150 = mosek::fusion::p_WorkStack::_get_impl(_3029)->f64;
              _checked_ptr_1<double> _ptr__3150(_3150 ? _3150->raw() : nullptr,_3150 ? _3150->size(0) : 0);
              {
                int _8343 = (int)0;
                int _8344 = _3056;
                for (int _3151 = _8343; _3151 < _8344; ++_3151)
                {
                  {
                    _ptr__3148[safe_add( _3145,_3151 )] = _3151;
                  }
                }
                int _8345 = (int)0;
                int _8346 = _3055;
                for (int _3152 = _8345; _3152 < _8346; ++_3152)
                {
                  {
                    int _3153 = ((_3055 - _3152) - (int)1);
                    int _3154 = _ptr__3118[safe_add( _3111,_3153 )];
                    int _8347 = (int)0;
                    int _8348 = safe_add( _3154,(int)1 );
                    for (int _3155 = _8347; _3155 < _8348; ++_3155)
                    {
                      {
                        _ptr__3148[safe_add( _3147,_3155 )] = (int)0;
                      }
                    }
                    int _8349 = (int)0;
                    int _8350 = _3056;
                    for (int _3156 = _8349; _3156 < _8350; ++_3156)
                    {
                      {
                        int _3157 = _ptr__3148[safe_add( _3145,_3156 )];
                        long long _3158 = ((_ptr__3149[safe_add( _3115,_3157 )] / _ptr__3143[_3153]) % _3154);
                        ++ _ptr__3148[safe_add( safe_add( _3147,_3158 ),(int)1 )];
                      }
                    }
                    {
                      int _8351 = (int)0;
                      int _8352 = _3154;
                      for (int _3159 = _8351; _3159 < _8352; ++_3159)
                      {
                        {
                          _ptr__3148[safe_add( safe_add( _3147,_3159 ),(int)1 )] += _ptr__3148[safe_add( _3147,_3159 )];
                        }
                      }
                      int _8353 = (int)0;
                      int _8354 = _3056;
                      for (int _3160 = _8353; _3160 < _8354; ++_3160)
                      {
                        {
                          int _3161 = _ptr__3148[safe_add( _3145,_3160 )];
                          long long _3162 = ((_ptr__3149[safe_add( _3115,_3161 )] / _ptr__3143[_3153]) % _3154);
                          _ptr__3148[safe_add( _3146,_ptr__3148[safe_add( _3147,_3162 )] )] = _3161;
                          ++ _ptr__3148[safe_add( _3147,_3162 )];
                        }
                      }
                    }
                    int _3163 = _3145;
                    _3145 = _3146;
                    _3146 = _3163;
                  }
                }
                int _3164 = (int)0;
                _ptr__3118[_3106] = (int)0;
                int _8355 = (int)0;
                int _8356 = _3056;
                for (int _3165 = _8355; _3165 < _8356; ++_3165)
                {
                  {
                    int _3166 = _ptr__3148[safe_add( _3145,_3165 )];
                    int _3167 = _ptr__3148[safe_add( _3113,_3166 )];
                    int _3168 = _ptr__3148[safe_add( safe_add( _3113,_3166 ),(int)1 )];
                    int _3169 = (_3168 - _3167);
                    _ptr__3118[safe_add( safe_add( _3106,_3165 ),(int)1 )] = safe_add( _ptr__3118[safe_add( _3106,_3165 )],_3169 );
                    _ptr__3120[safe_add( _3110,_3165 )] = _ptr__3150[safe_add( _3117,_3166 )];
                    _ptr__3119[safe_add( _3108,_3165 )] = _ptr__3149[safe_add( _3115,_3166 )];
                    int _8357 = _3167;
                    int _8358 = _3168;
                    for (int _3170 = _8357; _3170 < _8358; ++_3170)
                    {
                      {
                        _ptr__3119[safe_add( _3107,_3164 )] = _ptr__3149[safe_add( _3114,_3170 )];
                        _ptr__3120[safe_add( _3109,_3164 )] = _ptr__3150[safe_add( _3116,_3170 )];
                        ++ _3164;
                      }
                    }
                  }
                }
              }
            }
          }
          else
          {
            {
              int _3171 = (int)0;
              _ptr__3118[_3106] = (int)0;
              int _8359 = (int)0;
              int _8360 = _3056;
              for (int _3172 = _8359; _3172 < _8360; ++_3172)
              {
                {
                  int _3173 = _ptr__3121[safe_add( _3113,_3172 )];
                  int _3174 = _ptr__3121[safe_add( safe_add( _3113,_3172 ),(int)1 )];
                  int _3175 = (_3174 - _3173);
                  _ptr__3118[safe_add( safe_add( _3106,_3172 ),(int)1 )] = safe_add( _ptr__3118[safe_add( _3106,_3172 )],_3175 );
                  _ptr__3120[safe_add( _3110,_3172 )] = _ptr__3123[safe_add( _3117,_3172 )];
                  _ptr__3119[safe_add( _3108,_3172 )] = _ptr__3122[safe_add( _3115,_3172 )];
                  int _8361 = _3173;
                  int _8362 = _3174;
                  for (int _3176 = _8361; _3176 < _8362; ++_3176)
                  {
                    {
                      _ptr__3119[safe_add( _3107,_3171 )] = _ptr__3122[safe_add( _3114,_3176 )];
                      _ptr__3120[safe_add( _3109,_3171 )] = _ptr__3123[safe_add( _3116,_3176 )];
                      ++ _3171;
                    }
                  }
                }
              }
            }
          }
          if ((!_3105))
          {
            {
              _3027->popi64(_3056);
            }
          }
          {}
          _3029->clear();
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3177,int _3178){
  if (((int)((_3177)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_3177)->size(0)) == (int)1))
  {
    {
      return ((*_3177)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _8363;
      for (int _3180 = (int)0, _8364 = (int)((_3177)->size(0)); _3180 < _8364 ; ++_3180)
      {
        _8363.push_back(((*_3177)(_3180))->getShape());
      }
      auto _8365 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_8363.size()),_8363.begin(),_8363.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _3179 = _8365;
      std::shared_ptr< monty::ndarray< int,1 > > _3181 = ((*_3179)((int)0));
      _checked_ptr_1<int> _ptr__3181(_3181 ? _3181->raw() : nullptr,_3181 ? _3181->size(0) : 0);
      int _3182 = (int)((_3181)->size(0));
      int _8366 = (int)1;
      int _8367 = (int)((_3179)->size(0));
      for (int _3183 = _8366; _3183 < _8367; ++_3183)
      {
        {
          if ((_3182 != (int)((((*_3179)(_3183)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _8368 = (int)0;
          int _8369 = _3178;
          for (int _3184 = _8368; _3184 < _8369; ++_3184)
          {
            {
              if ((_ptr__3181[_3184] != ((*((*_3179)(_3183)))(_3184))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _8370 = safe_add( _3178,(int)1 );
          int _8371 = _3182;
          for (int _3185 = _8370; _3185 < _8371; ++_3185)
          {
            {
              if ((_ptr__3181[_3185] != ((*((*_3179)(_3183)))(_3185))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_3178 == _3182))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3186 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3182,(int)1 ))));
          _checked_ptr_1<int> _ptr__3186(_3186 ? _3186->raw() : nullptr,_3186 ? _3186->size(0) : 0);
          int _8372 = (int)0;
          int _8373 = _3182;
          for (int _3187 = _8372; _3187 < _8373; ++_3187)
          {
            {
              _ptr__3186[_3187] = _ptr__3181[_3187];
            }
          }
          _ptr__3186[_3182] = (int)((_3179)->size(0));
          return _3186;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3188 = _3181;
          _checked_ptr_1<int> _ptr__3188(_3188 ? _3188->raw() : nullptr,_3188 ? _3188->size(0) : 0);
          int _8374 = (int)1;
          int _8375 = (int)((_3179)->size(0));
          for (int _3189 = _8374; _3189 < _8375; ++_3189)
          {
            {
              _ptr__3188[_3178] += ((*((*_3179)(_3189)))(_3178));
            }
          }
          return _3188;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _3190 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _8376 = (int)1;
  int _8377 = (int)((exprs)->size(0));
  for (int _3191 = _8376; _3191 < _8377; ++_3191)
  {
    {
      _3190->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_3191))->toString());
    }
  }
  _3190->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _3190->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3192,    std::shared_ptr< monty::ndarray< long long,1 > > _3193,    std::shared_ptr< monty::ndarray< double,1 > > _3194){ return new mosek::fusion::ExprInner(_3192,_3193,_3194); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3192,    std::shared_ptr< monty::ndarray< long long,1 > > _3193,    std::shared_ptr< monty::ndarray< double,1 > > _3194) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3192,_3193,_3194); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3192,    std::shared_ptr< monty::ndarray< long long,1 > > _3193,    std::shared_ptr< monty::ndarray< double,1 > > _3194){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__3193(_3193 ? _3193->raw() : nullptr, _3193 ? _3193->size(0) : 0);
    _checked_ptr_1<double> _ptr__3194(_3194 ? _3194->raw() : nullptr, _3194 ? _3194->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _3192;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _3193;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _3194;
    if (((int)((_3193)->size(0)) != (int)((_3194)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _3195 = _3192->getShape();
    _checked_ptr_1<int> _ptr__3195(_3195 ? _3195->raw() : nullptr,_3195 ? _3195->size(0) : 0);
    long long _3196 = ::mosek::fusion::p_Set::size(_3195);
    bool _3197 = false;
    bool _3198 = false;
    {
      int _8378 = (int)1;
      int _8379 = (int)((_3193)->size(0));
      for (int _3199 = _8378; _3199 < _8379; ++_3199)
      {
        {
          if ((_ptr__3193[_3199] <= _ptr__3193[(_3199 - (int)1)]))
          {
            {
              _3197 = true;
            }
          }
          {}
        }
      }
      if (((int)((_3193)->size(0)) > (int)0))
      {
        {
          if (((_ptr__3193[(int)0] < (int)0) || (_ptr__3193[((int)((_3193)->size(0)) - (int)1)] > _3196)))
          {
            {
              _3198 = true;
            }
          }
          {}
        }
      }
      {}
    }
    if (_3197)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
      }
    }
    {}
    if (_3198)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3200,    std::shared_ptr< monty::ndarray< double,1 > > _3201){ return new mosek::fusion::ExprInner(_3200,_3201); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3200,    std::shared_ptr< monty::ndarray< double,1 > > _3201) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3200,_3201); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3200,    std::shared_ptr< monty::ndarray< double,1 > > _3201){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3201(_3201 ? _3201->raw() : nullptr, _3201 ? _3201->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3200,::mosek::fusion::p_ExprInner::range((int)((_3201)->size(0))),_3201);
    std::shared_ptr< monty::ndarray< int,1 > > _3202 = _3200->getShape();
    _checked_ptr_1<int> _ptr__3202(_3202 ? _3202->raw() : nullptr,_3202 ? _3202->size(0) : 0);
    if ((((int)((_3202)->size(0)) != (int)1) || (_ptr__3202[(int)0] != (int)((_3201)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3203,    std::shared_ptr< monty::ndarray< int,2 > > _3204,    std::shared_ptr< monty::ndarray< double,1 > > _3205){ return new mosek::fusion::ExprInner(_3203,_3204,_3205); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3203,    std::shared_ptr< monty::ndarray< int,2 > > _3204,    std::shared_ptr< monty::ndarray< double,1 > > _3205) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3203,_3204,_3205); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3203,    std::shared_ptr< monty::ndarray< int,2 > > _3204,    std::shared_ptr< monty::ndarray< double,1 > > _3205){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3205(_3205 ? _3205->raw() : nullptr, _3205 ? _3205->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3203,::mosek::fusion::p_ExprInner::convert(_3203->getShape(),_3204),_3205);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3206,monty::rc_ptr< ::mosek::fusion::WorkStack > _3207,monty::rc_ptr< ::mosek::fusion::WorkStack > _3208) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_3206,_3207,_3208); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3206,monty::rc_ptr< ::mosek::fusion::WorkStack > _3207,monty::rc_ptr< ::mosek::fusion::WorkStack > _3208){
  expr->eval(_3207,_3206,_3208);
  int _3209 = _3207->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _3210 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3209)));
  _checked_ptr_1<int> _ptr__3210(_3210 ? _3210->raw() : nullptr,_3210 ? _3210->size(0) : 0);
  _3207->popi32(_3209,_3210,(int)0);
  int _3211 = _3207->popi32();
  int _3212 = _3207->popi32();
  bool _3213 = (_3207->popi32() != (int)0);
  int _3214 = _3207->popi32(safe_add( _3211,(int)1 ));
  int _8380;
  bool _8381 = _3213;
  if (_8381)
  {
    _8380 = _3207->popi64(_3211);
  }
  else
  {
    _8380 = (int)0;
  }
  int _3215 = _8380;
  int _3216 = _3207->popi64(_3212);
  int _3217 = _3207->popf64(_3211);
  int _3218 = _3207->popf64(_3212);
  std::shared_ptr< monty::ndarray< int,1 > > _3219 = mosek::fusion::p_WorkStack::_get_impl(_3207)->i32;
  _checked_ptr_1<int> _ptr__3219(_3219 ? _3219->raw() : nullptr,_3219 ? _3219->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3220 = mosek::fusion::p_WorkStack::_get_impl(_3207)->i64;
  _checked_ptr_1<long long> _ptr__3220(_3220 ? _3220->raw() : nullptr,_3220 ? _3220->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3221 = mosek::fusion::p_WorkStack::_get_impl(_3207)->f64;
  _checked_ptr_1<double> _ptr__3221(_3221 ? _3221->raw() : nullptr,_3221 ? _3221->size(0) : 0);
  int _3222 = (int)0;
  if (_3213)
  {
    {
      int _3223 = (int)0;
      int _3224 = (int)0;
      while ( ((_3224 < (int)((vsub)->size(0))) && (_3223 < _3211)) )
      {
        {
          if ((_ptr__3220[safe_add( _3215,_3223 )] < ((*vsub)(_3224))))
          {
            {
              ++ _3223;
            }
          }
          else if((_ptr__3220[safe_add( _3215,_3223 )] > ((*vsub)(_3224))))
          {
            {
              ++ _3224;
            }
          }
          else
          {
            {
              _3222 += (_ptr__3219[safe_add( safe_add( _3214,_3223 ),(int)1 )] - _ptr__3219[safe_add( _3214,_3223 )]);
              ++ _3224;
              ++ _3223;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8382 = (int)0;
      int _8383 = (int)((vsub)->size(0));
      for (int _3225 = _8382; _3225 < _8383; ++_3225)
      {
        {
          _3222 += (_ptr__3219[safe_add( safe_add( _3214,((*vsub)(_3225)) ),(int)1 )] - _ptr__3219[safe_add( _3214,((*vsub)(_3225)) )]);
        }
      }
    }
  }
  int _3226 = _3206->alloci32((int)2);
  int _3227 = _3206->alloci64(_3222);
  int _3228 = _3206->allocf64(_3222);
  int _3229 = _3206->allocf64((int)1);
  _3206->pushi32((int)0);
  _3206->pushi32(_3222);
  _3206->pushi32((int)1);
  _3206->pushi32((int)0);
  std::shared_ptr< monty::ndarray< int,1 > > _3230 = mosek::fusion::p_WorkStack::_get_impl(_3206)->i32;
  _checked_ptr_1<int> _ptr__3230(_3230 ? _3230->raw() : nullptr,_3230 ? _3230->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3231 = mosek::fusion::p_WorkStack::_get_impl(_3206)->i64;
  _checked_ptr_1<long long> _ptr__3231(_3231 ? _3231->raw() : nullptr,_3231 ? _3231->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3232 = mosek::fusion::p_WorkStack::_get_impl(_3206)->f64;
  _checked_ptr_1<double> _ptr__3232(_3232 ? _3232->raw() : nullptr,_3232 ? _3232->size(0) : 0);
  _ptr__3230[_3226] = (int)0;
  _ptr__3230[safe_add( _3226,(int)1 )] = _3222;
  int _3233 = (int)0;
  double _3234 = 0.0;
  if (_3213)
  {
    {
      int _3235 = (int)0;
      int _3236 = (int)0;
      while ( ((_3236 < (int)((vsub)->size(0))) && (_3235 < _3211)) )
      {
        {
          if ((_ptr__3220[safe_add( _3215,_3235 )] < ((*vsub)(_3236))))
          {
            {
              ++ _3235;
            }
          }
          else if((_ptr__3220[safe_add( _3215,_3235 )] > ((*vsub)(_3236))))
          {
            {
              ++ _3236;
            }
          }
          else
          {
            {
              int _3237 = _ptr__3219[safe_add( _3214,_3235 )];
              int _3238 = _ptr__3219[safe_add( safe_add( _3214,_3235 ),(int)1 )];
              int _8384 = _3237;
              int _8385 = _3238;
              for (int _3239 = _8384; _3239 < _8385; ++_3239)
              {
                {
                  _ptr__3231[safe_add( _3227,_3233 )] = _ptr__3220[safe_add( _3216,_3239 )];
                  _ptr__3232[safe_add( _3228,_3233 )] = (((*vcof)(_3236)) * _ptr__3221[safe_add( _3218,_3239 )]);
                  ++ _3233;
                }
              }
              _3234 += (((*vcof)(_3236)) * _ptr__3221[safe_add( _3217,_3235 )]);
              ++ _3236;
              ++ _3235;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8386 = (int)0;
      int _8387 = (int)((vsub)->size(0));
      for (int _3240 = _8386; _3240 < _8387; ++_3240)
      {
        {
          int _3241 = _ptr__3219[safe_add( _3214,((*vsub)(_3240)) )];
          int _3242 = _ptr__3219[safe_add( safe_add( _3214,((*vsub)(_3240)) ),(int)1 )];
          int _8388 = _3241;
          int _8389 = _3242;
          for (int _3243 = _8388; _3243 < _8389; ++_3243)
          {
            {
              _ptr__3231[safe_add( _3227,_3233 )] = _ptr__3220[safe_add( _3216,_3243 )];
              _ptr__3232[safe_add( _3228,_3233 )] = (((*vcof)(_3240)) * _ptr__3221[safe_add( _3218,_3243 )]);
              ++ _3233;
            }
          }
          _3234 += (((*vcof)(_3240)) * _ptr__3221[safe_add( _3217,((*vsub)(_3240)) )]);
        }
      }
    }
  }
  _ptr__3232[_3229] = _3234;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _3244){
  std::vector<long long> _8390;
  for (int _3245 = (int)0, _8391 = _3244; _3245 < _8391 ; ++_3245)
  {
    _8390.push_back(_3245);
  }
  auto _8392 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8390.size()),_8390.begin(),_8390.end()));
  return _8392;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _3246,std::shared_ptr< monty::ndarray< int,2 > > _3247){
  _checked_ptr_1<int> _ptr__3246(_3246 ? _3246->raw() : nullptr, _3246 ? _3246->size(0) : 0);
  int _3248 = (int)((_3246)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _3249 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3248)));
  _checked_ptr_1<long long> _ptr__3249(_3249 ? _3249->raw() : nullptr,_3249 ? _3249->size(0) : 0);
  _ptr__3249[(_3248 - (int)1)] = (int)1;
  int _8393 = (int)1;
  int _8394 = _3248;
  for (int _3250 = _8393; _3250 < _8394; ++_3250)
  {
    {
      _ptr__3249[((_3248 - _3250) - (int)1)] = safe_mul( _ptr__3249[(_3248 - _3250)],_ptr__3246[(_3248 - _3250)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3251 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3247)->size(0)))));
  _checked_ptr_1<long long> _ptr__3251(_3251 ? _3251->raw() : nullptr,_3251 ? _3251->size(0) : 0);
  int _8395 = (int)0;
  int _8396 = (int)((_3247)->size(0));
  for (int _3252 = _8395; _3252 < _8396; ++_3252)
  {
    {
      int _8397 = (int)0;
      int _8398 = _3248;
      for (int _3253 = _8397; _3253 < _8398; ++_3253)
      {
        {
          _ptr__3251[_3252] += safe_mul( _ptr__3249[_3253],((*_3247)(_3252,_3253)) );
        }
      }
    }
  }
  return _3251;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3254,    int _3255,    std::shared_ptr< monty::ndarray< int,1 > > _3256,    std::shared_ptr< monty::ndarray< int,1 > > _3257,    std::shared_ptr< monty::ndarray< double,1 > > _3258,    monty::rc_ptr< ::mosek::fusion::Expression > _3259,    int _3260){ return new mosek::fusion::ExprMulDiagRight(_3254,_3255,_3256,_3257,_3258,_3259,_3260); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3254,    int _3255,    std::shared_ptr< monty::ndarray< int,1 > > _3256,    std::shared_ptr< monty::ndarray< int,1 > > _3257,    std::shared_ptr< monty::ndarray< double,1 > > _3258,    monty::rc_ptr< ::mosek::fusion::Expression > _3259,    int _3260) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3254,_3255,_3256,_3257,_3258,_3259,_3260); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3254,    int _3255,    std::shared_ptr< monty::ndarray< int,1 > > _3256,    std::shared_ptr< monty::ndarray< int,1 > > _3257,    std::shared_ptr< monty::ndarray< double,1 > > _3258,    monty::rc_ptr< ::mosek::fusion::Expression > _3259,    int _3260){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3256(_3256 ? _3256->raw() : nullptr, _3256 ? _3256->size(0) : 0);
    _checked_ptr_1<int> _ptr__3257(_3257 ? _3257->raw() : nullptr, _3257 ? _3257->size(0) : 0);
    _checked_ptr_1<double> _ptr__3258(_3258 ? _3258->raw() : nullptr, _3258 ? _3258->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3255)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _3254;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _3255;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _3256;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _3257;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _3258;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _3259;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3261,    int _3262,    std::shared_ptr< monty::ndarray< int,1 > > _3263,    std::shared_ptr< monty::ndarray< int,1 > > _3264,    std::shared_ptr< monty::ndarray< double,1 > > _3265,    monty::rc_ptr< ::mosek::fusion::Expression > _3266){ return new mosek::fusion::ExprMulDiagRight(_3261,_3262,_3263,_3264,_3265,_3266); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3261,    int _3262,    std::shared_ptr< monty::ndarray< int,1 > > _3263,    std::shared_ptr< monty::ndarray< int,1 > > _3264,    std::shared_ptr< monty::ndarray< double,1 > > _3265,    monty::rc_ptr< ::mosek::fusion::Expression > _3266) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3261,_3262,_3263,_3264,_3265,_3266); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3261,    int _3262,    std::shared_ptr< monty::ndarray< int,1 > > _3263,    std::shared_ptr< monty::ndarray< int,1 > > _3264,    std::shared_ptr< monty::ndarray< double,1 > > _3265,    monty::rc_ptr< ::mosek::fusion::Expression > _3266){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3263(_3263 ? _3263->raw() : nullptr, _3263 ? _3263->size(0) : 0);
    _checked_ptr_1<int> _ptr__3264(_3264 ? _3264->raw() : nullptr, _3264 ? _3264->size(0) : 0);
    _checked_ptr_1<double> _ptr__3265(_3265 ? _3265->raw() : nullptr, _3265 ? _3265->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_3261,_3262,_3263,_3264,_3265,_3266,::mosek::fusion::p_ExprMulDiagRight::validate(_3261,_3262,_3263,_3264,_3265,_3266));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3267,monty::rc_ptr< ::mosek::fusion::WorkStack > _3268,monty::rc_ptr< ::mosek::fusion::WorkStack > _3269) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_3267,_3268,_3269); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3267,monty::rc_ptr< ::mosek::fusion::WorkStack > _3268,monty::rc_ptr< ::mosek::fusion::WorkStack > _3269){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_3268,_3267,_3269);
  int _3270 = (int)0;
  int _3271 = (int)99999;
  int _3272 = (int)0;
  bool _3273 = (_3268->peeki32((int)5) != (int)0);
  if (_3273)
  {
    {
      _3272 = _3268->peeki32((int)2);
      _3271 = _3268->alloci32(safe_add( _3272,(int)1 ));
      _3270 += safe_add( _3272,(int)1 );
    }
  }
  {}
  int _3274 = (int)((mval)->size(0));
  int _3275 = _3268->alloci32(_3274);
  int _3276 = _3268->alloci32(safe_add( mdim1,(int)1 ));
  _3270 += safe_add( safe_add( _3274,mdim1 ),(int)1 );
  {
    std::shared_ptr< monty::ndarray< int,1 > > _3277 = mosek::fusion::p_WorkStack::_get_impl(_3268)->i32;
    _checked_ptr_1<int> _ptr__3277(_3277 ? _3277->raw() : nullptr,_3277 ? _3277->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _3278 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj;
    _checked_ptr_1<int> _ptr__3278(_3278 ? _3278->raw() : nullptr,_3278 ? _3278->size(0) : 0);
    {
      int _8399 = (int)0;
      int _8400 = safe_add( mdim1,(int)1 );
      for (int _3279 = _8399; _3279 < _8400; ++_3279)
      {
        {
          _ptr__3277[safe_add( _3276,_3279 )] = (int)0;
        }
      }
      int _8401 = (int)0;
      int _8402 = _3274;
      for (int _3280 = _8401; _3280 < _8402; ++_3280)
      {
        {
          ++ _ptr__3277[safe_add( safe_add( _3276,_ptr__3278[_3280] ),(int)1 )];
        }
      }
      int _8403 = (int)0;
      int _8404 = mdim1;
      for (int _3281 = _8403; _3281 < _8404; ++_3281)
      {
        {
          _ptr__3277[safe_add( safe_add( _3276,_3281 ),(int)1 )] += _ptr__3277[safe_add( _3276,_3281 )];
        }
      }
      int _8405 = (int)0;
      int _8406 = _3274;
      for (int _3282 = _8405; _3282 < _8406; ++_3282)
      {
        {
          _ptr__3277[safe_add( _3275,_ptr__3277[safe_add( _3276,_ptr__3278[_3282] )] )] = _3282;
          ++ _ptr__3277[safe_add( _3276,_ptr__3278[_3282] )];
        }
      }
      int _8407 = (int)0;
      int _8408 = mdim1;
      for (int _3283 = _8407; _3283 < _8408; ++_3283)
      {
        {
          _ptr__3277[(safe_add( _3276,mdim1 ) - _3283)] = _ptr__3277[((safe_add( _3276,mdim1 ) - _3283) - (int)1)];
        }
      }
      _ptr__3277[_3276] = (int)0;
    }
  }
  _3268->popi32(_3270);
  int _3284 = _3268->popi32();
  if ((_3284 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3285 = _3268->popi32();
  int _3286 = _3268->popi32();
  int _3287 = _3268->popi32();
  int _3288 = _3268->popi32();
  bool _3289 = (_3268->popi32() != (int)0);
  int _3290 = _3268->popi32(safe_add( _3287,(int)1 ));
  int _8409;
  bool _8410 = _3289;
  if (_8410)
  {
    _8409 = _3268->popi64(_3287);
  }
  else
  {
    _8409 = (int)9999;
  }
  int _3291 = _8409;
  int _3292 = _3268->popi64(_3288);
  int _3293 = _3268->popf64(_3287);
  int _3294 = _3268->popf64(_3288);
  std::shared_ptr< monty::ndarray< int,1 > > _3295 = mosek::fusion::p_WorkStack::_get_impl(_3268)->i32;
  _checked_ptr_1<int> _ptr__3295(_3295 ? _3295->raw() : nullptr,_3295 ? _3295->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3296 = mosek::fusion::p_WorkStack::_get_impl(_3268)->i64;
  _checked_ptr_1<long long> _ptr__3296(_3296 ? _3296->raw() : nullptr,_3296 ? _3296->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3297 = mosek::fusion::p_WorkStack::_get_impl(_3268)->f64;
  _checked_ptr_1<double> _ptr__3297(_3297 ? _3297->raw() : nullptr,_3297 ? _3297->size(0) : 0);
  if (_3289)
  {
    {
      int _8411 = (int)0;
      int _8412 = safe_add( _3286,(int)1 );
      for (int _3298 = _8411; _3298 < _8412; ++_3298)
      {
        {
          _ptr__3295[safe_add( _3271,_3298 )] = (int)0;
        }
      }
      int _8413 = (int)0;
      int _8414 = _3287;
      for (int _3299 = _8413; _3299 < _8414; ++_3299)
      {
        {
          ++ _ptr__3295[safe_add( safe_add( _3271,(_ptr__3296[safe_add( _3291,_3299 )] / _3285) ),(int)1 )];
        }
      }
      int _8415 = (int)0;
      int _8416 = _3286;
      for (int _3300 = _8415; _3300 < _8416; ++_3300)
      {
        {
          _ptr__3295[safe_add( safe_add( _3271,_3300 ),(int)1 )] += _ptr__3295[safe_add( _3271,_3300 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3301 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3301(_3301 ? _3301->raw() : nullptr,_3301 ? _3301->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3302 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3302(_3302 ? _3302->raw() : nullptr,_3302 ? _3302->size(0) : 0);
      int _3303 = (int)0;
      int _3304 = (int)0;
      {
        int _8417 = (int)0;
        int _8418 = _3286;
        for (int _3305 = _8417; _3305 < _8418; ++_3305)
        {
          {
            int _3306 = _ptr__3295[safe_add( safe_add( _3276,_3305 ),(int)1 )];
            int _3307 = _ptr__3295[safe_add( _3276,_3305 )];
            int _3308 = _ptr__3295[safe_add( safe_add( _3271,_3305 ),(int)1 )];
            int _3309 = _ptr__3295[safe_add( _3271,_3305 )];
            bool _3310 = false;
            while ( ((_3309 < _3308) && (_3307 < _3306)) )
            {
              {
                int _3311 = _ptr__3295[safe_add( _3275,_3307 )];
                long long _3312 = (_ptr__3296[safe_add( _3291,_3309 )] % _3285);
                if ((_ptr__3301[_3311] < _3312))
                {
                  {
                    ++ _3307;
                  }
                }
                else if((_ptr__3301[_3311] > _3312))
                {
                  {
                    ++ _3309;
                  }
                }
                else
                {
                  {
                    _3310 = true;
                    _3303 += (_ptr__3295[safe_add( safe_add( _3290,_3309 ),(int)1 )] - _ptr__3295[safe_add( _3290,_3309 )]);
                    ++ _3309;
                    ++ _3307;
                  }
                }
              }
            }
            if (_3310)
            {
              {
                ++ _3304;
              }
            }
            {}
          }
        }
      }
      bool _3313 = (_3304 < _3286);
      int _3314 = _3267->alloci32(safe_add( _3304,(int)1 ));
      int _3315 = _3267->alloci64(_3303);
      int _3316 = _3267->alloci64(_3304);
      int _3317 = _3267->allocf64(_3303);
      int _3318 = _3267->allocf64(_3304);
      int _8419;
      bool _8420 = _3313;
      if (_8420)
      {
        _8419 = (int)1;
      }
      else
      {
        _8419 = (int)0;
      }
      _3267->pushi32(_8419);
      _3267->pushi32(_3303);
      _3267->pushi32(_3304);
      _3267->pushi32(_3286);
      _3267->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3319 = mosek::fusion::p_WorkStack::_get_impl(_3267)->i32;
      _checked_ptr_1<int> _ptr__3319(_3319 ? _3319->raw() : nullptr,_3319 ? _3319->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3320 = mosek::fusion::p_WorkStack::_get_impl(_3267)->i64;
      _checked_ptr_1<long long> _ptr__3320(_3320 ? _3320->raw() : nullptr,_3320 ? _3320->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3321 = mosek::fusion::p_WorkStack::_get_impl(_3267)->f64;
      _checked_ptr_1<double> _ptr__3321(_3321 ? _3321->raw() : nullptr,_3321 ? _3321->size(0) : 0);
      {
        int _3322 = (int)0;
        int _3323 = (int)0;
        _ptr__3319[_3314] = (int)0;
        int _8421 = (int)0;
        int _8422 = _3286;
        for (int _3324 = _8421; _3324 < _8422; ++_3324)
        {
          {
            int _3325 = _ptr__3295[safe_add( safe_add( _3276,_3324 ),(int)1 )];
            int _3326 = _ptr__3295[safe_add( _3276,_3324 )];
            int _3327 = _ptr__3295[safe_add( safe_add( _3271,_3324 ),(int)1 )];
            int _3328 = _ptr__3295[safe_add( _3271,_3324 )];
            bool _3329 = false;
            double _3330 = 0.0;
            while ( ((_3328 < _3327) && (_3326 < _3325)) )
            {
              {
                int _3331 = _ptr__3295[safe_add( _3275,_3326 )];
                long long _3332 = (_ptr__3296[safe_add( _3291,_3328 )] % _3285);
                if ((_ptr__3301[_3331] < _3332))
                {
                  {
                    ++ _3326;
                  }
                }
                else if((_ptr__3301[_3331] > _3332))
                {
                  {
                    ++ _3328;
                  }
                }
                else
                {
                  {
                    _3329 = true;
                    int _8423 = _ptr__3295[safe_add( _3290,_3328 )];
                    int _8424 = _ptr__3295[safe_add( safe_add( _3290,_3328 ),(int)1 )];
                    for (int _3333 = _8423; _3333 < _8424; ++_3333)
                    {
                      {
                        _ptr__3320[safe_add( _3315,_3323 )] = _ptr__3296[safe_add( _3292,_3333 )];
                        _ptr__3321[safe_add( _3317,_3323 )] = (_ptr__3297[safe_add( _3294,_3333 )] * _ptr__3302[_3331]);
                        ++ _3323;
                      }
                    }
                    _3330 += (_ptr__3297[safe_add( _3293,_3328 )] * _ptr__3302[_3331]);
                    ++ _3328;
                    ++ _3326;
                  }
                }
              }
            }
            if (_3329)
            {
              {
                _ptr__3319[safe_add( safe_add( _3314,_3322 ),(int)1 )] = _3323;
                _ptr__3320[safe_add( _3316,_3322 )] = _3324;
                _ptr__3321[safe_add( _3318,_3322 )] = _3330;
                ++ _3322;
              }
            }
            {}
          }
        }
      }
      if ((!_3313))
      {
        {
          _3267->popi64(_3304);
        }
      }
      {}
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3334 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3334(_3334 ? _3334->raw() : nullptr,_3334 ? _3334->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3335 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3335(_3335 ? _3335->raw() : nullptr,_3335 ? _3335->size(0) : 0);
      int _3336 = (int)0;
      int _3337 = (int)0;
      {
        int _8425 = (int)0;
        int _8426 = _3286;
        for (int _3338 = _8425; _3338 < _8426; ++_3338)
        {
          {
            bool _3339 = false;
            int _8427 = _ptr__3295[safe_add( _3276,_3338 )];
            int _8428 = _ptr__3295[safe_add( safe_add( _3276,_3338 ),(int)1 )];
            for (int _3340 = _8427; _3340 < _8428; ++_3340)
            {
              {
                int _3341 = _ptr__3295[safe_add( _3275,_3340 )];
                int _3342 = safe_add( safe_mul( _3338,_3285 ),_ptr__3334[_3341] );
                _3337 += (_ptr__3295[safe_add( safe_add( _3290,_3342 ),(int)1 )] - _ptr__3295[safe_add( _3290,_3342 )]);
                if ((_ptr__3295[safe_add( safe_add( _3290,_3342 ),(int)1 )] > _ptr__3295[safe_add( _3290,_3342 )]))
                {
                  {
                    _3339 = true;
                  }
                }
                {}
              }
            }
            if (_3339)
            {
              {
                ++ _3336;
              }
            }
            {}
          }
        }
      }
      bool _3343 = (_3336 < _3286);
      int _3344 = _3267->alloci32(safe_add( _3336,(int)1 ));
      int _3345 = _3267->alloci64(_3337);
      int _3346 = _3267->alloci64(_3336);
      int _3347 = _3267->allocf64(_3337);
      int _3348 = _3267->allocf64(_3336);
      int _8429;
      bool _8430 = _3343;
      if (_8430)
      {
        _8429 = (int)1;
      }
      else
      {
        _8429 = (int)0;
      }
      _3267->pushi32(_8429);
      _3267->pushi32(_3337);
      _3267->pushi32(_3336);
      _3267->pushi32(_3286);
      _3267->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3349 = mosek::fusion::p_WorkStack::_get_impl(_3267)->i32;
      _checked_ptr_1<int> _ptr__3349(_3349 ? _3349->raw() : nullptr,_3349 ? _3349->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3350 = mosek::fusion::p_WorkStack::_get_impl(_3267)->i64;
      _checked_ptr_1<long long> _ptr__3350(_3350 ? _3350->raw() : nullptr,_3350 ? _3350->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3351 = mosek::fusion::p_WorkStack::_get_impl(_3267)->f64;
      _checked_ptr_1<double> _ptr__3351(_3351 ? _3351->raw() : nullptr,_3351 ? _3351->size(0) : 0);
      {
        int _3352 = (int)0;
        int _3353 = (int)0;
        _ptr__3349[_3344] = (int)0;
        int _8431 = (int)0;
        int _8432 = _3286;
        for (int _3354 = _8431; _3354 < _8432; ++_3354)
        {
          {
            bool _3355 = false;
            double _3356 = 0.0;
            int _8433 = _ptr__3295[safe_add( _3276,_3354 )];
            int _8434 = _ptr__3295[safe_add( safe_add( _3276,_3354 ),(int)1 )];
            for (int _3357 = _8433; _3357 < _8434; ++_3357)
            {
              {
                int _3358 = _ptr__3295[safe_add( _3275,_3357 )];
                int _3359 = safe_add( safe_mul( _3354,_3285 ),_ptr__3334[_3358] );
                int _8435 = _ptr__3295[safe_add( _3290,_3359 )];
                int _8436 = _ptr__3295[safe_add( safe_add( _3290,_3359 ),(int)1 )];
                for (int _3360 = _8435; _3360 < _8436; ++_3360)
                {
                  {
                    _3355 = true;
                    _ptr__3350[safe_add( _3345,_3353 )] = _ptr__3296[safe_add( _3292,_3360 )];
                    _ptr__3351[safe_add( _3347,_3353 )] = (_ptr__3297[safe_add( _3294,_3360 )] * _ptr__3335[_3358]);
                    ++ _3353;
                  }
                }
                _3356 += (_ptr__3297[safe_add( _3293,_3359 )] * _ptr__3335[_3358]);
              }
            }
            if (_3355)
            {
              {
                _ptr__3351[safe_add( _3348,_3352 )] = _3356;
                _ptr__3350[safe_add( _3346,_3352 )] = _3354;
                _ptr__3349[safe_add( safe_add( _3344,_3352 ),(int)1 )] = _3353;
                ++ _3352;
              }
            }
            {}
          }
        }
      }
      if ((!_3343))
      {
        {
          _3267->popi64(_3336);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _3361,int _3362,std::shared_ptr< monty::ndarray< int,1 > > _3363,std::shared_ptr< monty::ndarray< int,1 > > _3364,std::shared_ptr< monty::ndarray< double,1 > > _3365,monty::rc_ptr< ::mosek::fusion::Expression > _3366){
  _checked_ptr_1<int> _ptr__3363(_3363 ? _3363->raw() : nullptr, _3363 ? _3363->size(0) : 0);
  _checked_ptr_1<int> _ptr__3364(_3364 ? _3364->raw() : nullptr, _3364 ? _3364->size(0) : 0);
  _checked_ptr_1<double> _ptr__3365(_3365 ? _3365->raw() : nullptr, _3365 ? _3365->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3367 = _3366->getShape();
  _checked_ptr_1<int> _ptr__3367(_3367 ? _3367->raw() : nullptr,_3367 ? _3367->size(0) : 0);
  if (((int)((_3367)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3368 = _ptr__3367[(int)0];
  int _3369 = _ptr__3367[(int)1];
  if (((_3361 < (int)0) || ((_3362 < (int)0) || ((_3368 < (int)0) || (_3369 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3361 != _3369) || (_3362 != _3368)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3363)->size(0)) != (int)((_3364)->size(0))) || ((int)((_3363)->size(0)) != (int)((_3365)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3370 = (int)((_3363)->size(0));
  bool _3371 = false;
  bool _3372 = false;
  {
    int _8437 = (int)0;
    int _8438 = _3370;
    for (int _3373 = _8437; _3373 < _8438; ++_3373)
    {
      {
        if (((_ptr__3363[_3373] < (int)0) || ((_ptr__3363[_3373] >= _3361) || ((_ptr__3364[_3373] < (int)0) || (_ptr__3364[_3373] >= _3362)))))
        {
          {
            _3371 = true;
          }
        }
        {}
      }
    }
    int _8439 = (int)0;
    int _8440 = (_3370 - (int)1);
    for (int _3374 = _8439; _3374 < _8440; ++_3374)
    {
      {
        if (((_ptr__3363[_3374] > _ptr__3363[safe_add( _3374,(int)1 )]) || ((_ptr__3363[_3374] == _ptr__3363[safe_add( _3374,(int)1 )]) && (_ptr__3364[_3374] >= _ptr__3364[safe_add( _3374,(int)1 )]))))
        {
          {
            _3372 = true;
          }
        }
        {}
      }
    }
  }
  if (_3371)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3372)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return std::string ("ExprMulDiagRight()");
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3375,    int _3376,    std::shared_ptr< monty::ndarray< int,1 > > _3377,    std::shared_ptr< monty::ndarray< int,1 > > _3378,    std::shared_ptr< monty::ndarray< double,1 > > _3379,    monty::rc_ptr< ::mosek::fusion::Expression > _3380,    int _3381){ return new mosek::fusion::ExprMulDiagLeft(_3375,_3376,_3377,_3378,_3379,_3380,_3381); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3375,    int _3376,    std::shared_ptr< monty::ndarray< int,1 > > _3377,    std::shared_ptr< monty::ndarray< int,1 > > _3378,    std::shared_ptr< monty::ndarray< double,1 > > _3379,    monty::rc_ptr< ::mosek::fusion::Expression > _3380,    int _3381) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3375,_3376,_3377,_3378,_3379,_3380,_3381); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3375,    int _3376,    std::shared_ptr< monty::ndarray< int,1 > > _3377,    std::shared_ptr< monty::ndarray< int,1 > > _3378,    std::shared_ptr< monty::ndarray< double,1 > > _3379,    monty::rc_ptr< ::mosek::fusion::Expression > _3380,    int _3381){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3377(_3377 ? _3377->raw() : nullptr, _3377 ? _3377->size(0) : 0);
    _checked_ptr_1<int> _ptr__3378(_3378 ? _3378->raw() : nullptr, _3378 ? _3378->size(0) : 0);
    _checked_ptr_1<double> _ptr__3379(_3379 ? _3379->raw() : nullptr, _3379 ? _3379->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3375)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _3375;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _3376;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _3377;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _3378;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _3379;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _3380;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3382,    int _3383,    std::shared_ptr< monty::ndarray< int,1 > > _3384,    std::shared_ptr< monty::ndarray< int,1 > > _3385,    std::shared_ptr< monty::ndarray< double,1 > > _3386,    monty::rc_ptr< ::mosek::fusion::Expression > _3387){ return new mosek::fusion::ExprMulDiagLeft(_3382,_3383,_3384,_3385,_3386,_3387); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3382,    int _3383,    std::shared_ptr< monty::ndarray< int,1 > > _3384,    std::shared_ptr< monty::ndarray< int,1 > > _3385,    std::shared_ptr< monty::ndarray< double,1 > > _3386,    monty::rc_ptr< ::mosek::fusion::Expression > _3387) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3382,_3383,_3384,_3385,_3386,_3387); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3382,    int _3383,    std::shared_ptr< monty::ndarray< int,1 > > _3384,    std::shared_ptr< monty::ndarray< int,1 > > _3385,    std::shared_ptr< monty::ndarray< double,1 > > _3386,    monty::rc_ptr< ::mosek::fusion::Expression > _3387){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3384(_3384 ? _3384->raw() : nullptr, _3384 ? _3384->size(0) : 0);
    _checked_ptr_1<int> _ptr__3385(_3385 ? _3385->raw() : nullptr, _3385 ? _3385->size(0) : 0);
    _checked_ptr_1<double> _ptr__3386(_3386 ? _3386->raw() : nullptr, _3386 ? _3386->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_3382,_3383,_3384,_3385,_3386,_3387,::mosek::fusion::p_ExprMulDiagLeft::validate(_3382,_3383,_3384,_3385,_3386,_3387));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3388,monty::rc_ptr< ::mosek::fusion::WorkStack > _3389,monty::rc_ptr< ::mosek::fusion::WorkStack > _3390) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_3388,_3389,_3390); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3388,monty::rc_ptr< ::mosek::fusion::WorkStack > _3389,monty::rc_ptr< ::mosek::fusion::WorkStack > _3390){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_3389,_3388,_3390);
  if ((_3389->peeki32() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3391 = (int)((msubi)->size(0));
  int _3392 = (int)9999;
  int _3393 = (int)9999;
  int _3394 = (int)0;
  int _3395 = _3389->peeki32((int)5);
  if ((_3395 != (int)0))
  {
    {
      int _3396 = _3389->peeki32((int)1);
      int _3397 = _3389->peeki32((int)3);
      _3392 = _3389->alloci32(safe_add( _3396,(int)1 ));
      _3393 = _3389->alloci32(_3397);
      _3394 += safe_add( safe_add( _3397,_3396 ),(int)1 );
    }
  }
  {}
  int _3398 = _3389->alloci32(safe_add( mdim0,(int)1 ));
  _3394 += safe_add( mdim0,(int)1 );
  _3389->popi32(_3394);
  std::shared_ptr< monty::ndarray< int,1 > > _3399 = mosek::fusion::p_WorkStack::_get_impl(_3389)->i32;
  _checked_ptr_1<int> _ptr__3399(_3399 ? _3399->raw() : nullptr,_3399 ? _3399->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3400 = mosek::fusion::p_WorkStack::_get_impl(_3389)->i64;
  _checked_ptr_1<long long> _ptr__3400(_3400 ? _3400->raw() : nullptr,_3400 ? _3400->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3401 = mosek::fusion::p_WorkStack::_get_impl(_3389)->f64;
  _checked_ptr_1<double> _ptr__3401(_3401 ? _3401->raw() : nullptr,_3401 ? _3401->size(0) : 0);
  int _8441 = (int)0;
  int _8442 = safe_add( mdim0,(int)1 );
  for (int _3402 = _8441; _3402 < _8442; ++_3402)
  {
    {
      _ptr__3399[safe_add( _3398,_3402 )] = (int)0;
    }
  }
  int _8443 = (int)0;
  int _8444 = _3391;
  for (int _3403 = _8443; _3403 < _8444; ++_3403)
  {
    {
      ++ _ptr__3399[safe_add( safe_add( _3398,((*msubi)(_3403)) ),(int)1 )];
    }
  }
  int _8445 = (int)0;
  int _8446 = mdim0;
  for (int _3404 = _8445; _3404 < _8446; ++_3404)
  {
    {
      _ptr__3399[safe_add( safe_add( _3398,_3404 ),(int)1 )] += _ptr__3399[safe_add( _3398,_3404 )];
    }
  }
  int _3405 = _3389->popi32();
  int _3406 = _3389->popi32();
  int _3407 = _3389->popi32();
  int _3408 = _3389->popi32();
  int _3409 = _3389->popi32();
  bool _3410 = (_3389->popi32() != (int)0);
  int _3411 = _3389->popi32(safe_add( _3408,(int)1 ));
  int _8447;
  bool _8448 = _3410;
  if (_8448)
  {
    _8447 = _3389->popi64(_3408);
  }
  else
  {
    _8447 = (int)9999;
  }
  int _3412 = _8447;
  int _3413 = _3389->popi64(_3409);
  int _3414 = _3389->popf64(_3408);
  int _3415 = _3389->popf64(_3409);
  if ((!_3410))
  {
    {
      int _3416 = (int)((msubi)->size(0));
      int _3417 = (int)0;
      int _8449 = (int)0;
      int _8450 = mdim0;
      for (int _3418 = _8449; _3418 < _8450; ++_3418)
      {
        {
          if ((_ptr__3399[safe_add( _3398,_3418 )] < _ptr__3399[safe_add( safe_add( _3398,_3418 ),(int)1 )]))
          {
            {
              ++ _3417;
            }
          }
          {}
        }
      }
      bool _3419 = (_3417 < mdim0);
      _3388->alloc_expr((int)1,_3417,_3416,_3419);
      int _3420 = mosek::fusion::p_WorkStack::_get_impl(_3388)->ptr_base;
      int _3421 = mosek::fusion::p_WorkStack::_get_impl(_3388)->nidxs_base;
      int _8451;
      bool _8452 = _3419;
      if (_8452)
      {
        _8451 = mosek::fusion::p_WorkStack::_get_impl(_3388)->sp_base;
      }
      else
      {
        _8451 = _3388->alloci64(_3417);
      }
      int _3422 = _8451;
      int _3423 = mosek::fusion::p_WorkStack::_get_impl(_3388)->cof_base;
      int _3424 = mosek::fusion::p_WorkStack::_get_impl(_3388)->bfix_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3388)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3388)->shape_base)) = mdim0;
      std::shared_ptr< monty::ndarray< int,1 > > _3425 = mosek::fusion::p_WorkStack::_get_impl(_3388)->i32;
      _checked_ptr_1<int> _ptr__3425(_3425 ? _3425->raw() : nullptr,_3425 ? _3425->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3426 = mosek::fusion::p_WorkStack::_get_impl(_3388)->i64;
      _checked_ptr_1<long long> _ptr__3426(_3426 ? _3426->raw() : nullptr,_3426 ? _3426->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3427 = mosek::fusion::p_WorkStack::_get_impl(_3388)->f64;
      _checked_ptr_1<double> _ptr__3427(_3427 ? _3427->raw() : nullptr,_3427 ? _3427->size(0) : 0);
      {
        _ptr__3425[_3420] = (int)0;
        int _3428 = (int)0;
        int _3429 = (int)0;
        int _8453 = (int)0;
        int _8454 = mdim0;
        for (int _3430 = _8453; _3430 < _8454; ++_3430)
        {
          {
            if ((_ptr__3399[safe_add( _3398,_3430 )] < _ptr__3399[safe_add( safe_add( _3398,_3430 ),(int)1 )]))
            {
              {
                int _3431 = (int)0;
                int _8455 = _ptr__3399[safe_add( _3398,_3430 )];
                int _8456 = _ptr__3399[safe_add( safe_add( _3398,_3430 ),(int)1 )];
                for (int _3432 = _8455; _3432 < _8456; ++_3432)
                {
                  {
                    int _3433 = ((*msubj)(_3432));
                    int _3434 = safe_add( safe_mul( _3433,_3406 ),_3430 );
                    int _8457 = _ptr__3399[safe_add( _3411,_3434 )];
                    int _8458 = _ptr__3399[safe_add( safe_add( _3411,_3434 ),(int)1 )];
                    for (int _3435 = _8457; _3435 < _8458; ++_3435)
                    {
                      {
                        _ptr__3426[safe_add( _3421,_3429 )] = _ptr__3400[safe_add( _3413,_3435 )];
                        _ptr__3427[safe_add( _3423,_3429 )] = (_ptr__3401[safe_add( _3415,_3435 )] * ((*mval)(_3432)));
                        ++ _3429;
                      }
                    }
                  }
                }
                _ptr__3427[safe_add( _3424,_3428 )] = _3431;
                _ptr__3426[safe_add( _3422,_3428 )] = _3430;
                _ptr__3425[safe_add( safe_add( _3420,_3428 ),(int)1 )] = _3429;
                ++ _3428;
              }
            }
            {}
          }
        }
      }
      if ((!_3419))
      {
        {
          _3388->popi64(_3417);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _8459 = (int)0;
      int _8460 = safe_add( _3406,(int)1 );
      for (int _3436 = _8459; _3436 < _8460; ++_3436)
      {
        {
          _ptr__3399[safe_add( _3392,_3436 )] = (int)0;
        }
      }
      int _8461 = (int)0;
      int _8462 = _3408;
      for (int _3437 = _8461; _3437 < _8462; ++_3437)
      {
        {
          ++ _ptr__3399[safe_add( safe_add( _3392,(_ptr__3400[safe_add( _3412,_3437 )] % _3406) ),(int)1 )];
        }
      }
      int _8463 = (int)0;
      int _8464 = _3406;
      for (int _3438 = _8463; _3438 < _8464; ++_3438)
      {
        {
          _ptr__3399[safe_add( safe_add( _3392,_3438 ),(int)1 )] += _ptr__3399[safe_add( _3392,_3438 )];
        }
      }
      int _8465 = (int)0;
      int _8466 = _3408;
      for (int _3439 = _8465; _3439 < _8466; ++_3439)
      {
        {
          long long _3440 = (_ptr__3400[safe_add( _3412,_3439 )] % _3406);
          _ptr__3399[safe_add( _3393,_ptr__3399[safe_add( _3392,_3440 )] )] = _3439;
          ++ _ptr__3399[safe_add( _3392,_3440 )];
        }
      }
      int _8467 = (int)0;
      int _8468 = _3406;
      for (int _3441 = _8467; _3441 < _8468; ++_3441)
      {
        {
          _ptr__3399[(safe_add( _3392,_3406 ) - _3441)] = _ptr__3399[((safe_add( _3392,_3406 ) - _3441) - (int)1)];
        }
      }
      _ptr__3399[_3392] = (int)0;
      int _3442 = (int)0;
      int _3443 = (int)0;
      {
        int _8469 = (int)0;
        int _8470 = mdim0;
        for (int _3444 = _8469; _3444 < _8470; ++_3444)
        {
          {
            int _3445 = _ptr__3399[safe_add( safe_add( _3392,_3444 ),(int)1 )];
            int _3446 = _ptr__3399[safe_add( _3392,_3444 )];
            int _3447 = _ptr__3399[safe_add( safe_add( _3398,_3444 ),(int)1 )];
            int _3448 = _ptr__3399[safe_add( _3398,_3444 )];
            bool _3449 = false;
            while ( ((_3448 < _3447) && (_3446 < _3445)) )
            {
              {
                int _3450 = _ptr__3399[safe_add( _3393,_3446 )];
                long long _3451 = (_ptr__3400[safe_add( _3412,_3450 )] / _3406);
                if ((((*msubj)(_3448)) < _3451))
                {
                  {
                    ++ _3448;
                  }
                }
                else if((((*msubj)(_3448)) > _3451))
                {
                  {
                    ++ _3446;
                  }
                }
                else
                {
                  {
                    _3449 = true;
                    _3443 += (_ptr__3399[safe_add( safe_add( _3411,_3450 ),(int)1 )] - _ptr__3399[safe_add( _3411,_3450 )]);
                    ++ _3448;
                    ++ _3446;
                  }
                }
              }
            }
            if (_3449)
            {
              {
                ++ _3442;
              }
            }
            {}
          }
        }
      }
      int _3452 = _3442;
      int _3453 = _3443;
      bool _3454 = (_3452 < mdim0);
      int _3455 = _3388->alloci32(safe_add( _3452,(int)1 ));
      int _3456 = _3388->alloci64(_3453);
      int _3457 = _3388->alloci64(_3452);
      int _3458 = _3388->allocf64(_3453);
      int _3459 = _3388->allocf64(_3452);
      int _8471;
      bool _8472 = _3454;
      if (_8472)
      {
        _8471 = (int)1;
      }
      else
      {
        _8471 = (int)0;
      }
      _3388->pushi32(_8471);
      _3388->pushi32(_3453);
      _3388->pushi32(_3452);
      _3388->pushi32(mdim0);
      _3388->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3460 = mosek::fusion::p_WorkStack::_get_impl(_3388)->i32;
      _checked_ptr_1<int> _ptr__3460(_3460 ? _3460->raw() : nullptr,_3460 ? _3460->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3461 = mosek::fusion::p_WorkStack::_get_impl(_3388)->i64;
      _checked_ptr_1<long long> _ptr__3461(_3461 ? _3461->raw() : nullptr,_3461 ? _3461->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3462 = mosek::fusion::p_WorkStack::_get_impl(_3388)->f64;
      _checked_ptr_1<double> _ptr__3462(_3462 ? _3462->raw() : nullptr,_3462 ? _3462->size(0) : 0);
      {
        _ptr__3460[_3455] = (int)0;
        int _3463 = (int)0;
        int _3464 = (int)0;
        int _8473 = (int)0;
        int _8474 = mdim0;
        for (int _3465 = _8473; _3465 < _8474; ++_3465)
        {
          {
            int _3466 = _ptr__3399[safe_add( safe_add( _3392,_3465 ),(int)1 )];
            int _3467 = _ptr__3399[safe_add( _3392,_3465 )];
            int _3468 = _ptr__3399[safe_add( safe_add( _3398,_3465 ),(int)1 )];
            int _3469 = _ptr__3399[safe_add( _3398,_3465 )];
            bool _3470 = false;
            double _3471 = 0.0;
            while ( ((_3469 < _3468) && (_3467 < _3466)) )
            {
              {
                int _3472 = _ptr__3399[safe_add( _3393,_3467 )];
                long long _3473 = (_ptr__3400[safe_add( _3412,_3472 )] / _3406);
                if ((((*msubj)(_3469)) < _3473))
                {
                  {
                    ++ _3469;
                  }
                }
                else if((((*msubj)(_3469)) > _3473))
                {
                  {
                    ++ _3467;
                  }
                }
                else
                {
                  {
                    _3470 = true;
                    int _8475 = _ptr__3399[safe_add( _3411,_3472 )];
                    int _8476 = _ptr__3399[safe_add( safe_add( _3411,_3472 ),(int)1 )];
                    for (int _3474 = _8475; _3474 < _8476; ++_3474)
                    {
                      {
                        _ptr__3461[safe_add( _3456,_3464 )] = _ptr__3400[safe_add( _3413,_3474 )];
                        _ptr__3462[safe_add( _3458,_3464 )] = (_ptr__3401[safe_add( _3415,_3474 )] * ((*mval)(_3469)));
                        ++ _3464;
                      }
                    }
                    _3471 += _ptr__3401[safe_add( _3414,_3472 )];
                    ++ _3469;
                    ++ _3467;
                  }
                }
              }
            }
            if (_3470)
            {
              {
                _ptr__3461[safe_add( _3457,_3463 )] = _3465;
                _ptr__3462[safe_add( _3459,_3463 )] = (_3471 * ((*mval)(_3469)));
                _ptr__3460[safe_add( safe_add( _3455,_3463 ),(int)1 )] = _3464;
                ++ _3463;
              }
            }
            {}
          }
        }
      }
      if ((!_3454))
      {
        {
          _3388->popi64(_3452);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _3475,int _3476,std::shared_ptr< monty::ndarray< int,1 > > _3477,std::shared_ptr< monty::ndarray< int,1 > > _3478,std::shared_ptr< monty::ndarray< double,1 > > _3479,monty::rc_ptr< ::mosek::fusion::Expression > _3480){
  _checked_ptr_1<int> _ptr__3477(_3477 ? _3477->raw() : nullptr, _3477 ? _3477->size(0) : 0);
  _checked_ptr_1<int> _ptr__3478(_3478 ? _3478->raw() : nullptr, _3478 ? _3478->size(0) : 0);
  _checked_ptr_1<double> _ptr__3479(_3479 ? _3479->raw() : nullptr, _3479 ? _3479->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3481 = _3480->getShape();
  _checked_ptr_1<int> _ptr__3481(_3481 ? _3481->raw() : nullptr,_3481 ? _3481->size(0) : 0);
  if (((int)((_3481)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3482 = _ptr__3481[(int)0];
  int _3483 = _ptr__3481[(int)1];
  if (((_3475 < (int)0) || (_3476 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3476 != _3482) || (_3475 != _3483)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3477)->size(0)) != (int)((_3478)->size(0))) || ((int)((_3477)->size(0)) != (int)((_3479)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3484 = (int)((_3477)->size(0));
  bool _3485 = false;
  bool _3486 = false;
  {
    int _8477 = (int)0;
    int _8478 = _3484;
    for (int _3487 = _8477; _3487 < _8478; ++_3487)
    {
      {
        if (((_ptr__3477[_3487] < (int)0) || ((_ptr__3477[_3487] >= _3475) || ((_ptr__3478[_3487] < (int)0) || (_ptr__3478[_3487] >= _3476)))))
        {
          {
            _3485 = true;
          }
        }
        {}
      }
    }
    int _8479 = (int)0;
    int _8480 = (_3484 - (int)1);
    for (int _3488 = _8479; _3488 < _8480; ++_3488)
    {
      {
        if (((_ptr__3477[_3488] > _ptr__3477[safe_add( _3488,(int)1 )]) || ((_ptr__3477[_3488] == _ptr__3477[safe_add( _3488,(int)1 )]) && (_ptr__3478[_3488] >= _ptr__3478[safe_add( _3488,(int)1 )]))))
        {
          {
            _3486 = true;
          }
        }
        {}
      }
    }
  }
  if (_3485)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3486)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return std::string ("ExprMulDiagLeft()");
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3489,    std::shared_ptr< monty::ndarray< long long,1 > > _3490,    monty::rc_ptr< ::mosek::fusion::Expression > _3491){ return new mosek::fusion::ExprMulElement(_3489,_3490,_3491); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3489,    std::shared_ptr< monty::ndarray< long long,1 > > _3490,    monty::rc_ptr< ::mosek::fusion::Expression > _3491) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3489,_3490,_3491); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3489,    std::shared_ptr< monty::ndarray< long long,1 > > _3490,    monty::rc_ptr< ::mosek::fusion::Expression > _3491){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3489(_3489 ? _3489->raw() : nullptr, _3489 ? _3489->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3490(_3490 ? _3490->raw() : nullptr, _3490 ? _3490->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_3489,_3490,_3491,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3492 = _3491->getShape();
    _checked_ptr_1<int> _ptr__3492(_3492 ? _3492->raw() : nullptr,_3492 ? _3492->size(0) : 0);
    if (((int)((_3489)->size(0)) != (int)((_3490)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _3493 = ::mosek::fusion::p_Set::size(_3492);
    bool _3494 = false;
    bool _3495 = false;
    {
      int _8481 = (int)0;
      int _8482 = (int)((_3490)->size(0));
      for (int _3496 = _8481; _3496 < _8482; ++_3496)
      {
        {
          if (((_ptr__3490[_3496] < (int)0) || (_ptr__3490[_3496] >= _3493)))
          {
            {
              _3494 = true;
            }
          }
          {}
        }
      }
      int _8483 = (int)0;
      int _8484 = ((int)((_3490)->size(0)) - (int)1);
      for (int _3497 = _8483; _3497 < _8484; ++_3497)
      {
        {
          if ((_ptr__3490[_3497] >= _ptr__3490[safe_add( _3497,(int)1 )]))
          {
            {
              _3495 = true;
            }
          }
          {}
        }
      }
    }
    if (_3494)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
      }
    }
    {}
    if (_3495)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
      }
    }
    {}
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3498,    std::shared_ptr< monty::ndarray< long long,1 > > _3499,    monty::rc_ptr< ::mosek::fusion::Expression > _3500,    int _3501){ return new mosek::fusion::ExprMulElement(_3498,_3499,_3500,_3501); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3498,    std::shared_ptr< monty::ndarray< long long,1 > > _3499,    monty::rc_ptr< ::mosek::fusion::Expression > _3500,    int _3501) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3498,_3499,_3500,_3501); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3498,    std::shared_ptr< monty::ndarray< long long,1 > > _3499,    monty::rc_ptr< ::mosek::fusion::Expression > _3500,    int _3501){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3498(_3498 ? _3498->raw() : nullptr, _3498 ? _3498->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3499(_3499 ? _3499->raw() : nullptr, _3499 ? _3499->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_3500->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _3500;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _3498;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _3499;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3502,monty::rc_ptr< ::mosek::fusion::WorkStack > _3503,monty::rc_ptr< ::mosek::fusion::WorkStack > _3504) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_3502,_3503,_3504); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3502,monty::rc_ptr< ::mosek::fusion::WorkStack > _3503,monty::rc_ptr< ::mosek::fusion::WorkStack > _3504){
  expr->eval(_3503,_3502,_3504);
  int _3505 = _3503->popi32();
  int _3506 = _3503->popi32(_3505);
  int _3507 = _3503->popi32();
  int _3508 = _3503->popi32();
  bool _3509 = (_3503->popi32() != (int)0);
  int _3510 = _3503->popi32(safe_add( _3507,(int)1 ));
  int _8485;
  bool _8486 = _3509;
  if (_8486)
  {
    _8485 = _3503->popi64(_3507);
  }
  else
  {
    _8485 = (-(int)1);
  }
  int _3511 = _8485;
  int _3512 = _3503->popi64(_3508);
  int _3513 = _3503->popf64(_3507);
  int _3514 = _3503->popf64(_3508);
  std::shared_ptr< monty::ndarray< int,1 > > _3515 = mosek::fusion::p_WorkStack::_get_impl(_3503)->i32;
  _checked_ptr_1<int> _ptr__3515(_3515 ? _3515->raw() : nullptr,_3515 ? _3515->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3516 = mosek::fusion::p_WorkStack::_get_impl(_3503)->i64;
  _checked_ptr_1<long long> _ptr__3516(_3516 ? _3516->raw() : nullptr,_3516 ? _3516->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3517 = mosek::fusion::p_WorkStack::_get_impl(_3503)->f64;
  _checked_ptr_1<double> _ptr__3517(_3517 ? _3517->raw() : nullptr,_3517 ? _3517->size(0) : 0);
  int _3518 = (int)0;
  int _3519 = (int)0;
  if ((!_3509))
  {
    {
      _3519 = (int)((msp)->size(0));
      int _8487 = (int)0;
      int _8488 = (int)((msp)->size(0));
      for (int _3520 = _8487; _3520 < _8488; ++_3520)
      {
        {
          _3518 += (_ptr__3515[safe_add( safe_add( _3510,((*msp)(_3520)) ),(int)1 )] - _ptr__3515[safe_add( _3510,((*msp)(_3520)) )]);
        }
      }
    }
  }
  else
  {
    {
      int _3521 = (int)((msp)->size(0));
      int _3522 = (int)0;
      int _3523 = _3507;
      int _3524 = (int)0;
      while ( ((_3522 < _3521) && (_3524 < _3523)) )
      {
        {
          if ((((*msp)(_3522)) < _ptr__3516[safe_add( _3511,_3524 )]))
          {
            {
              ++ _3522;
            }
          }
          else if((((*msp)(_3522)) > _ptr__3516[safe_add( _3511,_3524 )]))
          {
            {
              ++ _3524;
            }
          }
          else
          {
            {
              _3518 += (_ptr__3515[safe_add( safe_add( _3510,_3524 ),(int)1 )] - _ptr__3515[safe_add( _3510,_3524 )]);
              ++ _3522;
              ++ _3524;
              ++ _3519;
            }
          }
        }
      }
    }
  }
  int _3525 = _3502->alloci32(safe_add( _3519,(int)1 ));
  int _3526 = _3502->alloci64(_3518);
  int _3527 = _3502->alloci64(_3519);
  int _3528 = _3502->allocf64(_3518);
  int _3529 = _3502->allocf64(_3519);
  int _3530 = (int)1;
  int _8489 = (int)0;
  int _8490 = _3505;
  for (int _3531 = _8489; _3531 < _8490; ++_3531)
  {
    {
      _3530 *= _ptr__3515[safe_add( _3506,_3531 )];
    }
  }
  bool _3532 = (_3519 < _3530);
  int _8491;
  bool _8492 = _3532;
  if (_8492)
  {
    _8491 = (int)1;
  }
  else
  {
    _8491 = (int)0;
  }
  _3502->pushi32(_8491);
  _3502->pushi32(_3518);
  _3502->pushi32(_3519);
  int _3533 = _3502->alloci32(_3505);
  _3502->pushi32(_3505);
  std::shared_ptr< monty::ndarray< int,1 > > _3534 = mosek::fusion::p_WorkStack::_get_impl(_3502)->i32;
  _checked_ptr_1<int> _ptr__3534(_3534 ? _3534->raw() : nullptr,_3534 ? _3534->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3535 = mosek::fusion::p_WorkStack::_get_impl(_3502)->i64;
  _checked_ptr_1<long long> _ptr__3535(_3535 ? _3535->raw() : nullptr,_3535 ? _3535->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3536 = mosek::fusion::p_WorkStack::_get_impl(_3502)->f64;
  _checked_ptr_1<double> _ptr__3536(_3536 ? _3536->raw() : nullptr,_3536 ? _3536->size(0) : 0);
  {
    int _3537 = (int)0;
    int _3538 = (int)0;
    _ptr__3534[_3525] = (int)0;
    int _8493 = (int)0;
    int _8494 = _3505;
    for (int _3539 = _8493; _3539 < _8494; ++_3539)
    {
      {
        _ptr__3534[safe_add( _3533,_3539 )] = _ptr__3515[safe_add( _3506,_3539 )];
      }
    }
    if ((!_3509))
    {
      {
        int _8495 = (int)0;
        int _8496 = (int)((msp)->size(0));
        for (int _3540 = _8495; _3540 < _8496; ++_3540)
        {
          {
            int _3541 = _ptr__3515[safe_add( _3510,((*msp)(_3540)) )];
            int _3542 = _ptr__3515[safe_add( safe_add( _3510,((*msp)(_3540)) ),(int)1 )];
            int _8497 = _3541;
            int _8498 = _3542;
            for (int _3543 = _8497; _3543 < _8498; ++_3543)
            {
              {
                _ptr__3535[safe_add( _3526,_3538 )] = _ptr__3516[safe_add( _3512,_3543 )];
                _ptr__3536[safe_add( _3528,_3538 )] = (_ptr__3517[safe_add( _3514,_3543 )] * ((*mcof)(_3540)));
                ++ _3538;
              }
            }
            _ptr__3534[safe_add( safe_add( _3525,_3540 ),(int)1 )] = _3538;
            _ptr__3536[safe_add( _3529,_3540 )] = (_ptr__3517[safe_add( _3513,((*msp)(_3540)) )] * ((*mcof)(_3540)));
            _ptr__3535[safe_add( _3527,_3540 )] = ((*msp)(_3540));
          }
        }
      }
    }
    else
    {
      {
        int _3544 = (int)((msp)->size(0));
        int _3545 = (int)0;
        int _3546 = _3507;
        int _3547 = (int)0;
        while ( ((_3545 < _3544) && (_3547 < _3546)) )
        {
          {
            if ((((*msp)(_3545)) < _ptr__3516[safe_add( _3511,_3547 )]))
            {
              {
                ++ _3545;
              }
            }
            else if((((*msp)(_3545)) > _ptr__3516[safe_add( _3511,_3547 )]))
            {
              {
                ++ _3547;
              }
            }
            else
            {
              {
                int _3548 = _ptr__3515[safe_add( _3510,_3547 )];
                int _3549 = _ptr__3515[safe_add( safe_add( _3510,_3547 ),(int)1 )];
                int _8499 = _3548;
                int _8500 = _3549;
                for (int _3550 = _8499; _3550 < _8500; ++_3550)
                {
                  {
                    _ptr__3535[safe_add( _3526,_3538 )] = _ptr__3516[safe_add( _3512,_3550 )];
                    _ptr__3536[safe_add( _3526,_3538 )] = (_ptr__3517[safe_add( _3512,_3550 )] * ((*mcof)(_3545)));
                    ++ _3538;
                  }
                }
                _ptr__3534[safe_add( safe_add( _3525,_3537 ),(int)1 )] = _3538;
                _ptr__3536[safe_add( _3529,_3537 )] = (_ptr__3517[safe_add( _3513,_3547 )] * ((*mcof)(_3545)));
                _ptr__3535[safe_add( _3527,_3537 )] = ((*msp)(_3545));
                ++ _3537;
                ++ _3545;
                ++ _3547;
              }
            }
          }
        }
      }
    }
  }
  if ((!_3532))
  {
    {
      _3502->popi64(_3519);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return std::string ("ExprMulElement()");
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _3551,    monty::rc_ptr< ::mosek::fusion::Expression > _3552){ return new mosek::fusion::ExprMulScalarConst(_3551,_3552); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _3551,    monty::rc_ptr< ::mosek::fusion::Expression > _3552) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_3551,_3552); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _3551,    monty::rc_ptr< ::mosek::fusion::Expression > _3552){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3552->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _3551;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _3552;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3553,monty::rc_ptr< ::mosek::fusion::WorkStack > _3554,monty::rc_ptr< ::mosek::fusion::WorkStack > _3555) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_3553,_3554,_3555); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3553,monty::rc_ptr< ::mosek::fusion::WorkStack > _3554,monty::rc_ptr< ::mosek::fusion::WorkStack > _3555){
  expr->eval(_3553,_3554,_3555);
  int _3556 = _3553->peeki32((int)0);
  int _3557 = _3553->peeki32(safe_add( _3556,(int)1 ));
  int _3558 = _3553->peeki32(safe_add( _3556,(int)2 ));
  int _3559 = (mosek::fusion::p_WorkStack::_get_impl(_3553)->pf64 - _3557);
  int _3560 = (_3559 - _3558);
  std::shared_ptr< monty::ndarray< double,1 > > _3561 = mosek::fusion::p_WorkStack::_get_impl(_3553)->f64;
  _checked_ptr_1<double> _ptr__3561(_3561 ? _3561->raw() : nullptr,_3561 ? _3561->size(0) : 0);
  int _8501 = (int)0;
  int _8502 = safe_add( _3558,_3557 );
  for (int _3562 = _8501; _3562 < _8502; ++_3562)
  {
    {
      _ptr__3561[safe_add( _3560,_3562 )] *= c;
    }
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3563,    int _3564,    std::shared_ptr< monty::ndarray< int,1 > > _3565,    std::shared_ptr< monty::ndarray< int,1 > > _3566,    std::shared_ptr< monty::ndarray< double,1 > > _3567,    monty::rc_ptr< ::mosek::fusion::Expression > _3568,    int _3569){ return new mosek::fusion::ExprScalarMul(_3563,_3564,_3565,_3566,_3567,_3568,_3569); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3563,    int _3564,    std::shared_ptr< monty::ndarray< int,1 > > _3565,    std::shared_ptr< monty::ndarray< int,1 > > _3566,    std::shared_ptr< monty::ndarray< double,1 > > _3567,    monty::rc_ptr< ::mosek::fusion::Expression > _3568,    int _3569) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3563,_3564,_3565,_3566,_3567,_3568,_3569); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3563,    int _3564,    std::shared_ptr< monty::ndarray< int,1 > > _3565,    std::shared_ptr< monty::ndarray< int,1 > > _3566,    std::shared_ptr< monty::ndarray< double,1 > > _3567,    monty::rc_ptr< ::mosek::fusion::Expression > _3568,    int _3569){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3565(_3565 ? _3565->raw() : nullptr, _3565 ? _3565->size(0) : 0);
    _checked_ptr_1<int> _ptr__3566(_3566 ? _3566->raw() : nullptr, _3566 ? _3566->size(0) : 0);
    _checked_ptr_1<double> _ptr__3567(_3567 ? _3567->raw() : nullptr, _3567 ? _3567->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3563),(int)(_3564)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _3563;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _3564;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _3565;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _3566;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _3567;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _3568;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3570,    int _3571,    std::shared_ptr< monty::ndarray< int,1 > > _3572,    std::shared_ptr< monty::ndarray< int,1 > > _3573,    std::shared_ptr< monty::ndarray< double,1 > > _3574,    monty::rc_ptr< ::mosek::fusion::Expression > _3575){ return new mosek::fusion::ExprScalarMul(_3570,_3571,_3572,_3573,_3574,_3575); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3570,    int _3571,    std::shared_ptr< monty::ndarray< int,1 > > _3572,    std::shared_ptr< monty::ndarray< int,1 > > _3573,    std::shared_ptr< monty::ndarray< double,1 > > _3574,    monty::rc_ptr< ::mosek::fusion::Expression > _3575) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3570,_3571,_3572,_3573,_3574,_3575); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3570,    int _3571,    std::shared_ptr< monty::ndarray< int,1 > > _3572,    std::shared_ptr< monty::ndarray< int,1 > > _3573,    std::shared_ptr< monty::ndarray< double,1 > > _3574,    monty::rc_ptr< ::mosek::fusion::Expression > _3575){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3572(_3572 ? _3572->raw() : nullptr, _3572 ? _3572->size(0) : 0);
    _checked_ptr_1<int> _ptr__3573(_3573 ? _3573->raw() : nullptr, _3573 ? _3573->size(0) : 0);
    _checked_ptr_1<double> _ptr__3574(_3574 ? _3574->raw() : nullptr, _3574 ? _3574->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_3570,_3571,_3572,_3573,_3574,_3575,::mosek::fusion::p_ExprScalarMul::validate(_3570,_3571,_3572,_3573,_3574,_3575));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3576,monty::rc_ptr< ::mosek::fusion::WorkStack > _3577,monty::rc_ptr< ::mosek::fusion::WorkStack > _3578) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_3576,_3577,_3578); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3576,monty::rc_ptr< ::mosek::fusion::WorkStack > _3577,monty::rc_ptr< ::mosek::fusion::WorkStack > _3578){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_3577,_3576,_3578);
  _3577->pop_expr();
  int _3579 = mosek::fusion::p_WorkStack::_get_impl(_3577)->nd;
  int _3580 = mosek::fusion::p_WorkStack::_get_impl(_3577)->nelem;
  int _3581 = mosek::fusion::p_WorkStack::_get_impl(_3577)->nnz;
  bool _3582 = mosek::fusion::p_WorkStack::_get_impl(_3577)->hassp;
  int _3583 = mosek::fusion::p_WorkStack::_get_impl(_3577)->ptr_base;
  int _3584 = mosek::fusion::p_WorkStack::_get_impl(_3577)->sp_base;
  int _3585 = mosek::fusion::p_WorkStack::_get_impl(_3577)->nidxs_base;
  int _3586 = mosek::fusion::p_WorkStack::_get_impl(_3577)->bfix_base;
  int _3587 = mosek::fusion::p_WorkStack::_get_impl(_3577)->cof_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3588 = mosek::fusion::p_WorkStack::_get_impl(_3577)->i64;
  _checked_ptr_1<long long> _ptr__3588(_3588 ? _3588->raw() : nullptr,_3588 ? _3588->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3589 = mosek::fusion::p_WorkStack::_get_impl(_3577)->f64;
  _checked_ptr_1<double> _ptr__3589(_3589 ? _3589->raw() : nullptr,_3589 ? _3589->size(0) : 0);
  int _3590 = (int)((mval)->size(0));
  if ((_3579 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_3580 == (int)0))
  {
    {
      _3576->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_3576)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3576)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3576)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3576)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      _3576->alloc_expr((int)2,_3590,safe_mul( _3590,_3581 ),true);
      int _3591 = mosek::fusion::p_WorkStack::_get_impl(_3576)->ptr_base;
      int _3592 = mosek::fusion::p_WorkStack::_get_impl(_3576)->nidxs_base;
      int _3593 = mosek::fusion::p_WorkStack::_get_impl(_3576)->sp_base;
      int _3594 = mosek::fusion::p_WorkStack::_get_impl(_3576)->cof_base;
      int _3595 = mosek::fusion::p_WorkStack::_get_impl(_3576)->bfix_base;
      int _3596 = mosek::fusion::p_WorkStack::_get_impl(_3576)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3597 = mosek::fusion::p_WorkStack::_get_impl(_3576)->i32;
      _checked_ptr_1<int> _ptr__3597(_3597 ? _3597->raw() : nullptr,_3597 ? _3597->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3598 = mosek::fusion::p_WorkStack::_get_impl(_3576)->i64;
      _checked_ptr_1<long long> _ptr__3598(_3598 ? _3598->raw() : nullptr,_3598 ? _3598->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3599 = mosek::fusion::p_WorkStack::_get_impl(_3576)->f64;
      _checked_ptr_1<double> _ptr__3599(_3599 ? _3599->raw() : nullptr,_3599 ? _3599->size(0) : 0);
      _ptr__3597[_3596] = mdim0;
      _ptr__3597[safe_add( _3596,(int)1 )] = mdim1;
      int _3600 = (int)0;
      _ptr__3597[_3591] = (int)0;
      int _8503 = (int)0;
      int _8504 = _3590;
      for (int _3601 = _8503; _3601 < _8504; ++_3601)
      {
        {
          int _8505 = (int)0;
          int _8506 = _3581;
          for (int _3602 = _8505; _3602 < _8506; ++_3602)
          {
            {
              _ptr__3598[safe_add( _3592,_3600 )] = _ptr__3588[safe_add( _3585,_3602 )];
              _ptr__3599[safe_add( _3594,_3600 )] = (_ptr__3589[safe_add( _3587,_3602 )] * ((*mval)(_3601)));
              ++ _3600;
            }
          }
          _ptr__3598[safe_add( _3593,_3601 )] = safe_add( safe_mul( ((*msubi)(_3601)),mdim1 ),((*msubj)(_3601)) );
          _ptr__3599[safe_add( _3595,_3601 )] = (((*mval)(_3601)) * _ptr__3589[_3586]);
          _ptr__3597[safe_add( safe_add( _3591,_3601 ),(int)1 )] = _3600;
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _3603,int _3604,std::shared_ptr< monty::ndarray< int,1 > > _3605,std::shared_ptr< monty::ndarray< int,1 > > _3606,std::shared_ptr< monty::ndarray< double,1 > > _3607,monty::rc_ptr< ::mosek::fusion::Expression > _3608){
  _checked_ptr_1<int> _ptr__3605(_3605 ? _3605->raw() : nullptr, _3605 ? _3605->size(0) : 0);
  _checked_ptr_1<int> _ptr__3606(_3606 ? _3606->raw() : nullptr, _3606 ? _3606->size(0) : 0);
  _checked_ptr_1<double> _ptr__3607(_3607 ? _3607->raw() : nullptr, _3607 ? _3607->size(0) : 0);
  int _3609 = _3608->getND();
  if ((_3609 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3603 < (int)0) || (_3604 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_3605)->size(0)) != (int)((_3606)->size(0))) || ((int)((_3605)->size(0)) != (int)((_3607)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3610 = (int)((_3605)->size(0));
  bool _3611 = false;
  bool _3612 = false;
  {
    int _8507 = (int)0;
    int _8508 = _3610;
    for (int _3613 = _8507; _3613 < _8508; ++_3613)
    {
      {
        if (((_ptr__3605[_3613] < (int)0) || ((_ptr__3605[_3613] >= _3603) || ((_ptr__3606[_3613] < (int)0) || (_ptr__3606[_3613] >= _3604)))))
        {
          {
            _3611 = true;
          }
        }
        {}
      }
    }
    int _8509 = (int)0;
    int _8510 = (_3610 - (int)1);
    for (int _3614 = _8509; _3614 < _8510; ++_3614)
    {
      {
        if (((_ptr__3605[_3614] > _ptr__3605[safe_add( _3614,(int)1 )]) || ((_ptr__3605[_3614] == _ptr__3605[safe_add( _3614,(int)1 )]) && (_ptr__3606[_3614] >= _ptr__3606[safe_add( _3614,(int)1 )]))))
        {
          {
            _3612 = true;
          }
        }
        {}
      }
    }
  }
  if (_3611)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3612)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3615,    int _3616,    std::shared_ptr< monty::ndarray< int,1 > > _3617,    std::shared_ptr< monty::ndarray< int,1 > > _3618,    std::shared_ptr< monty::ndarray< double,1 > > _3619,    monty::rc_ptr< ::mosek::fusion::Expression > _3620,    int _3621){ return new mosek::fusion::ExprMulRight(_3615,_3616,_3617,_3618,_3619,_3620,_3621); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3615,    int _3616,    std::shared_ptr< monty::ndarray< int,1 > > _3617,    std::shared_ptr< monty::ndarray< int,1 > > _3618,    std::shared_ptr< monty::ndarray< double,1 > > _3619,    monty::rc_ptr< ::mosek::fusion::Expression > _3620,    int _3621) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3615,_3616,_3617,_3618,_3619,_3620,_3621); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3615,    int _3616,    std::shared_ptr< monty::ndarray< int,1 > > _3617,    std::shared_ptr< monty::ndarray< int,1 > > _3618,    std::shared_ptr< monty::ndarray< double,1 > > _3619,    monty::rc_ptr< ::mosek::fusion::Expression > _3620,    int _3621){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3617(_3617 ? _3617->raw() : nullptr, _3617 ? _3617->size(0) : 0);
    _checked_ptr_1<int> _ptr__3618(_3618 ? _3618->raw() : nullptr, _3618 ? _3618->size(0) : 0);
    _checked_ptr_1<double> _ptr__3619(_3619 ? _3619->raw() : nullptr, _3619 ? _3619->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_3616,_3620->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _3615;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _3616;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _3617;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _3618;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _3619;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _3620;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3622,    int _3623,    std::shared_ptr< monty::ndarray< int,1 > > _3624,    std::shared_ptr< monty::ndarray< int,1 > > _3625,    std::shared_ptr< monty::ndarray< double,1 > > _3626,    monty::rc_ptr< ::mosek::fusion::Expression > _3627){ return new mosek::fusion::ExprMulRight(_3622,_3623,_3624,_3625,_3626,_3627); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3622,    int _3623,    std::shared_ptr< monty::ndarray< int,1 > > _3624,    std::shared_ptr< monty::ndarray< int,1 > > _3625,    std::shared_ptr< monty::ndarray< double,1 > > _3626,    monty::rc_ptr< ::mosek::fusion::Expression > _3627) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3622,_3623,_3624,_3625,_3626,_3627); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3622,    int _3623,    std::shared_ptr< monty::ndarray< int,1 > > _3624,    std::shared_ptr< monty::ndarray< int,1 > > _3625,    std::shared_ptr< monty::ndarray< double,1 > > _3626,    monty::rc_ptr< ::mosek::fusion::Expression > _3627){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3624(_3624 ? _3624->raw() : nullptr, _3624 ? _3624->size(0) : 0);
    _checked_ptr_1<int> _ptr__3625(_3625 ? _3625->raw() : nullptr, _3625 ? _3625->size(0) : 0);
    _checked_ptr_1<double> _ptr__3626(_3626 ? _3626->raw() : nullptr, _3626 ? _3626->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_3622,_3623,_3624,_3625,_3626,_3627,::mosek::fusion::p_ExprMulRight::validate(_3622,_3623,_3624,_3625,_3626,_3627));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3628,monty::rc_ptr< ::mosek::fusion::WorkStack > _3629,monty::rc_ptr< ::mosek::fusion::WorkStack > _3630) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_3628,_3629,_3630); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3628,monty::rc_ptr< ::mosek::fusion::WorkStack > _3629,monty::rc_ptr< ::mosek::fusion::WorkStack > _3630){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_3629,_3628,_3630);
  _3629->peek_expr();
  int _3631 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nd;
  bool _3632 = mosek::fusion::p_WorkStack::_get_impl(_3629)->hassp;
  int _3633 = (int)((mval)->size(0));
  bool _3634 = (_3633 < safe_mul( (long long)mdim0,(long long)mdim1 ));
  int _3635 = ((*mosek::fusion::p_WorkStack::_get_impl(_3629)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3629)->shape_base));
  if (_3634)
  {
    {
      int _3636 = _3630->alloci32(safe_add( mdim1,(int)1 ));
      int _3637 = _3630->alloci32(_3633);
      int _3638 = _3630->alloci32(safe_add( _3635,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3639 = mosek::fusion::p_WorkStack::_get_impl(_3630)->i32;
      _checked_ptr_1<int> _ptr__3639(_3639 ? _3639->raw() : nullptr,_3639 ? _3639->size(0) : 0);
      int _8511 = (int)0;
      int _8512 = safe_add( mdim1,(int)1 );
      for (int _3640 = _8511; _3640 < _8512; ++_3640)
      {
        {
          _ptr__3639[safe_add( _3636,_3640 )] = (int)0;
        }
      }
      int _8513 = (int)0;
      int _8514 = _3633;
      for (int _3641 = _8513; _3641 < _8514; ++_3641)
      {
        {
          ++ _ptr__3639[safe_add( safe_add( _3636,((*msubj)(_3641)) ),(int)1 )];
        }
      }
      int _8515 = (int)0;
      int _8516 = mdim1;
      for (int _3642 = _8515; _3642 < _8516; ++_3642)
      {
        {
          _ptr__3639[safe_add( safe_add( _3636,_3642 ),(int)1 )] += _ptr__3639[safe_add( _3636,_3642 )];
        }
      }
      int _8517 = (int)0;
      int _8518 = _3633;
      for (int _3643 = _8517; _3643 < _8518; ++_3643)
      {
        {
          _ptr__3639[safe_add( _3637,_3643 )] = _ptr__3639[safe_add( _3636,((*msubj)(_3643)) )];
          ++ _ptr__3639[safe_add( _3636,((*msubj)(_3643)) )];
        }
      }
      int _8519 = (int)0;
      int _8520 = mdim1;
      for (int _3644 = _8519; _3644 < _8520; ++_3644)
      {
        {
          _ptr__3639[(safe_add( _3636,mdim1 ) - _3644)] = _ptr__3639[((safe_add( _3636,mdim1 ) - _3644) - (int)1)];
        }
      }
      _ptr__3639[_3636] = (int)0;
      int _8521 = (int)0;
      int _8522 = safe_add( _3635,(int)1 );
      for (int _3645 = _8521; _3645 < _8522; ++_3645)
      {
        {
          _ptr__3639[safe_add( _3638,_3645 )] = (int)0;
        }
      }
      _3629->pop_expr();
      std::shared_ptr< monty::ndarray< int,1 > > _3646 = mosek::fusion::p_WorkStack::_get_impl(_3629)->i32;
      _checked_ptr_1<int> _ptr__3646(_3646 ? _3646->raw() : nullptr,_3646 ? _3646->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3647 = mosek::fusion::p_WorkStack::_get_impl(_3629)->i64;
      _checked_ptr_1<long long> _ptr__3647(_3647 ? _3647->raw() : nullptr,_3647 ? _3647->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3648 = mosek::fusion::p_WorkStack::_get_impl(_3629)->f64;
      _checked_ptr_1<double> _ptr__3648(_3648 ? _3648->raw() : nullptr,_3648 ? _3648->size(0) : 0);
      int _3649 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nd;
      if ((_3649 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3650 = ((*mosek::fusion::p_WorkStack::_get_impl(_3629)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3629)->shape_base));
      int _3651 = ((*mosek::fusion::p_WorkStack::_get_impl(_3629)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3629)->shape_base,(int)1 )));
      int _3652 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nelem;
      int _3653 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nnz;
      int _3654 = mosek::fusion::p_WorkStack::_get_impl(_3629)->ptr_base;
      int _3655 = mosek::fusion::p_WorkStack::_get_impl(_3629)->sp_base;
      int _3656 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nidxs_base;
      int _3657 = mosek::fusion::p_WorkStack::_get_impl(_3629)->bfix_base;
      int _3658 = mosek::fusion::p_WorkStack::_get_impl(_3629)->cof_base;
      if (_3632)
      {
        {
          int _8523 = (int)0;
          int _8524 = _3652;
          for (int _3659 = _8523; _3659 < _8524; ++_3659)
          {
            {
              ++ _ptr__3639[safe_add( safe_add( _3638,(_ptr__3647[safe_add( _3655,_3659 )] / _3651) ),(int)1 )];
            }
          }
          int _8525 = (int)0;
          int _8526 = _3650;
          for (int _3660 = _8525; _3660 < _8526; ++_3660)
          {
            {
              _ptr__3639[safe_add( safe_add( _3638,_3660 ),(int)1 )] += _ptr__3639[safe_add( _3638,_3660 )];
            }
          }
          int _3661 = (int)0;
          long long _3662 = (long long)0;
          int _8527 = (int)0;
          int _8528 = _3650;
          for (int _3663 = _8527; _3663 < _8528; ++_3663)
          {
            {
              int _8529 = (int)0;
              int _8530 = mdim1;
              for (int _3664 = _8529; _3664 < _8530; ++_3664)
              {
                {
                  bool _3665 = false;
                  int _3666 = _ptr__3639[safe_add( safe_add( _3638,_3663 ),(int)1 )];
                  int _3667 = _ptr__3639[safe_add( _3638,_3663 )];
                  int _3668 = _ptr__3639[safe_add( safe_add( _3636,_3664 ),(int)1 )];
                  int _3669 = _ptr__3639[safe_add( _3636,_3664 )];
                  while ( ((_3667 < _3666) && (_3669 < _3668)) )
                  {
                    {
                      int _3670 = _ptr__3639[safe_add( _3637,_3669 )];
                      if (((_ptr__3647[safe_add( _3655,_3667 )] % _3651) < ((*msubi)(_3670))))
                      {
                        {
                          ++ _3667;
                        }
                      }
                      else if(((_ptr__3647[safe_add( _3655,_3667 )] % _3651) > ((*msubi)(_3670))))
                      {
                        {
                          ++ _3669;
                        }
                      }
                      else
                      {
                        {
                          _3662 += (_ptr__3646[safe_add( safe_add( _3654,_3667 ),(int)1 )] - _ptr__3646[safe_add( _3654,_3667 )]);
                          ++ _3667;
                          ++ _3669;
                          _3665 = true;
                        }
                      }
                    }
                  }
                  if (_3665)
                  {
                    {
                      ++ _3661;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _3671 = (_3661 < safe_mul( _3650,mdim1 ));
          _3628->alloc_expr((int)2,_3661,(int)_3662,_3671);
          int _3672 = mosek::fusion::p_WorkStack::_get_impl(_3628)->ptr_base;
          int _3673 = mosek::fusion::p_WorkStack::_get_impl(_3628)->nidxs_base;
          int _8531;
          bool _8532 = _3671;
          if (_8532)
          {
            _8531 = mosek::fusion::p_WorkStack::_get_impl(_3628)->sp_base;
          }
          else
          {
            _8531 = _3628->alloci64(_3661);
          }
          int _3674 = _8531;
          int _3675 = mosek::fusion::p_WorkStack::_get_impl(_3628)->cof_base;
          int _3676 = mosek::fusion::p_WorkStack::_get_impl(_3628)->bfix_base;
          int _3677 = mosek::fusion::p_WorkStack::_get_impl(_3628)->shape_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3678 = mosek::fusion::p_WorkStack::_get_impl(_3628)->i32;
          _checked_ptr_1<int> _ptr__3678(_3678 ? _3678->raw() : nullptr,_3678 ? _3678->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3679 = mosek::fusion::p_WorkStack::_get_impl(_3628)->i64;
          _checked_ptr_1<long long> _ptr__3679(_3679 ? _3679->raw() : nullptr,_3679 ? _3679->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3680 = mosek::fusion::p_WorkStack::_get_impl(_3628)->f64;
          _checked_ptr_1<double> _ptr__3680(_3680 ? _3680->raw() : nullptr,_3680 ? _3680->size(0) : 0);
          _ptr__3678[_3677] = _3650;
          _ptr__3678[safe_add( _3677,(int)1 )] = mdim1;
          int _3681 = (int)0;
          int _3682 = (int)0;
          _ptr__3678[_3672] = (int)0;
          int _8533 = (int)0;
          int _8534 = _3650;
          for (int _3683 = _8533; _3683 < _8534; ++_3683)
          {
            {
              int _8535 = (int)0;
              int _8536 = mdim1;
              for (int _3684 = _8535; _3684 < _8536; ++_3684)
              {
                {
                  double _3685 = 0.0;
                  int _3686 = (int)0;
                  int _3687 = _ptr__3639[safe_add( safe_add( _3638,_3683 ),(int)1 )];
                  int _3688 = _ptr__3639[safe_add( _3638,_3683 )];
                  int _3689 = _ptr__3639[safe_add( safe_add( _3636,_3684 ),(int)1 )];
                  int _3690 = _ptr__3639[safe_add( _3636,_3684 )];
                  while ( ((_3688 < _3687) && (_3690 < _3689)) )
                  {
                    {
                      int _3691 = _ptr__3639[safe_add( _3637,_3690 )];
                      if (((_ptr__3647[safe_add( _3655,_3688 )] % _3651) < ((*msubi)(_3691))))
                      {
                        {
                          ++ _3688;
                        }
                      }
                      else if(((_ptr__3647[safe_add( _3655,_3688 )] % _3651) > ((*msubi)(_3691))))
                      {
                        {
                          ++ _3690;
                        }
                      }
                      else
                      {
                        {
                          int _3692 = (_ptr__3646[safe_add( safe_add( _3654,_3688 ),(int)1 )] - _ptr__3646[safe_add( _3654,_3688 )]);
                          _3685 += (((*mval)(_3691)) * _ptr__3648[safe_add( _3657,_3688 )]);
                          int _8537 = (int)0;
                          int _8538 = _3692;
                          for (int _3693 = _8537; _3693 < _8538; ++_3693)
                          {
                            {
                              _ptr__3679[safe_add( safe_add( _3673,_3682 ),_3693 )] = _ptr__3647[safe_add( safe_add( _3656,_ptr__3646[safe_add( _3654,_3688 )] ),_3693 )];
                            }
                          }
                          int _8539 = (int)0;
                          int _8540 = _3692;
                          for (int _3694 = _8539; _3694 < _8540; ++_3694)
                          {
                            {
                              _ptr__3680[safe_add( safe_add( _3675,_3682 ),_3694 )] = (_ptr__3648[safe_add( safe_add( _3658,_ptr__3646[safe_add( _3654,_3688 )] ),_3694 )] * ((*mval)(_3691)));
                            }
                          }
                          _3686 += _3692;
                          ++ _3688;
                          ++ _3690;
                        }
                      }
                    }
                  }
                  if ((_3686 > (int)0))
                  {
                    {
                      _3682 += _3686;
                      _ptr__3678[safe_add( safe_add( _3672,_3681 ),(int)1 )] = _3682;
                      _ptr__3680[safe_add( _3676,_3681 )] = _3685;
                      _ptr__3679[safe_add( _3674,_3681 )] = safe_add( safe_mul( _3683,mdim1 ),_3684 );
                      ++ _3681;
                    }
                  }
                  {}
                }
              }
            }
          }
          if ((!_3671))
          {
            {
              _3628->popi64(_3661);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _3695 = safe_mul( _3650,mdim1 );
          int _3696 = (int)0;
          int _8541 = (int)0;
          int _8542 = _3650;
          for (int _3697 = _8541; _3697 < _8542; ++_3697)
          {
            {
              int _8543 = (int)0;
              int _8544 = mdim1;
              for (int _3698 = _8543; _3698 < _8544; ++_3698)
              {
                {
                  int _8545 = _ptr__3639[safe_add( _3636,_3698 )];
                  int _8546 = _ptr__3639[safe_add( safe_add( _3636,_3698 ),(int)1 )];
                  for (int _3699 = _8545; _3699 < _8546; ++_3699)
                  {
                    {
                      int _3700 = _ptr__3639[safe_add( _3637,_3699 )];
                      int _3701 = safe_add( safe_mul( _3697,_3651 ),((*msubi)(_3700)) );
                      _3696 += (_ptr__3646[safe_add( safe_add( _3654,_3701 ),(int)1 )] - _ptr__3646[safe_add( _3654,_3701 )]);
                    }
                  }
                }
              }
            }
          }
          bool _3702 = (_3695 < safe_mul( _3650,mdim1 ));
          if ((!(_3696 <= (int)0x7fffffff)))
          {
            {
              throw ::mosek::fusion::LengthError(std::string ("Maximum number of nonzeros exceede in multiplication"));
            }
          }
          {}
          _3628->alloc_expr((int)2,_3695,(int)_3696,_3702);
          int _3703 = mosek::fusion::p_WorkStack::_get_impl(_3628)->ptr_base;
          int _3704 = mosek::fusion::p_WorkStack::_get_impl(_3628)->nidxs_base;
          int _8547;
          bool _8548 = _3702;
          if (_8548)
          {
            _8547 = mosek::fusion::p_WorkStack::_get_impl(_3628)->sp_base;
          }
          else
          {
            _8547 = _3628->alloci64(_3695);
          }
          int _3705 = _8547;
          int _3706 = mosek::fusion::p_WorkStack::_get_impl(_3628)->cof_base;
          int _3707 = mosek::fusion::p_WorkStack::_get_impl(_3628)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3708 = mosek::fusion::p_WorkStack::_get_impl(_3628)->i32;
          _checked_ptr_1<int> _ptr__3708(_3708 ? _3708->raw() : nullptr,_3708 ? _3708->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3709 = mosek::fusion::p_WorkStack::_get_impl(_3628)->i64;
          _checked_ptr_1<long long> _ptr__3709(_3709 ? _3709->raw() : nullptr,_3709 ? _3709->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3710 = mosek::fusion::p_WorkStack::_get_impl(_3628)->f64;
          _checked_ptr_1<double> _ptr__3710(_3710 ? _3710->raw() : nullptr,_3710 ? _3710->size(0) : 0);
          int _3711 = (int)0;
          int _3712 = (int)0;
          _ptr__3708[_3703] = (int)0;
          int _8549 = (int)0;
          int _8550 = _3650;
          for (int _3713 = _8549; _3713 < _8550; ++_3713)
          {
            {
              int _8551 = (int)0;
              int _8552 = mdim1;
              for (int _3714 = _8551; _3714 < _8552; ++_3714)
              {
                {
                  int _3715 = safe_mul( _3713,_3651 );
                  double _3716 = 0.0;
                  int _8553 = _ptr__3639[safe_add( _3636,_3714 )];
                  int _8554 = _ptr__3639[safe_add( safe_add( _3636,_3714 ),(int)1 )];
                  for (int _3717 = _8553; _3717 < _8554; ++_3717)
                  {
                    {
                      int _3718 = _ptr__3639[safe_add( _3637,_3717 )];
                      int _3719 = safe_add( _3715,((*msubi)(_3718)) );
                      int _3720 = _ptr__3646[safe_add( _3654,_3719 )];
                      int _3721 = (_ptr__3646[safe_add( safe_add( _3654,_3719 ),(int)1 )] - _ptr__3646[safe_add( _3654,_3719 )]);
                      int _8555 = (int)0;
                      int _8556 = _3721;
                      for (int _3722 = _8555; _3722 < _8556; ++_3722)
                      {
                        {
                          _ptr__3709[safe_add( safe_add( _3704,_3712 ),_3722 )] = _ptr__3647[safe_add( safe_add( _3656,_3720 ),_3722 )];
                        }
                      }
                      int _8557 = (int)0;
                      int _8558 = _3721;
                      for (int _3723 = _8557; _3723 < _8558; ++_3723)
                      {
                        {
                          _ptr__3710[safe_add( safe_add( _3706,_3712 ),_3723 )] = (_ptr__3648[safe_add( safe_add( _3658,_3720 ),_3723 )] * ((*mval)(_3718)));
                        }
                      }
                      _3716 += (_ptr__3648[safe_add( safe_add( _3657,_3715 ),((*msubi)(_3718)) )] * ((*mval)(_3718)));
                      _3712 += _3721;
                    }
                  }
                  _ptr__3708[safe_add( safe_add( _3703,_3711 ),(int)1 )] = _3712;
                  _ptr__3710[safe_add( _3707,_3711 )] = _3716;
                  _ptr__3709[safe_add( _3705,_3711 )] = safe_add( safe_mul( _3713,mdim1 ),_3714 );
                  ++ _3711;
                }
              }
            }
          }
          if ((!_3702))
          {
            {
              _3628->popi64(_3695);
            }
          }
          {}
        }
      }
      _3630->clear();
    }
  }
  else
  {
    {
      int _3724 = _3630->alloci32(safe_add( _3635,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3725 = mosek::fusion::p_WorkStack::_get_impl(_3630)->i32;
      _checked_ptr_1<int> _ptr__3725(_3725 ? _3725->raw() : nullptr,_3725 ? _3725->size(0) : 0);
      int _8559 = (int)0;
      int _8560 = safe_add( _3635,(int)1 );
      for (int _3726 = _8559; _3726 < _8560; ++_3726)
      {
        {
          _ptr__3725[safe_add( _3724,_3726 )] = (int)0;
        }
      }
      _3629->pop_expr();
      std::shared_ptr< monty::ndarray< int,1 > > _3727 = mosek::fusion::p_WorkStack::_get_impl(_3629)->i32;
      _checked_ptr_1<int> _ptr__3727(_3727 ? _3727->raw() : nullptr,_3727 ? _3727->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3728 = mosek::fusion::p_WorkStack::_get_impl(_3629)->i64;
      _checked_ptr_1<long long> _ptr__3728(_3728 ? _3728->raw() : nullptr,_3728 ? _3728->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3729 = mosek::fusion::p_WorkStack::_get_impl(_3629)->f64;
      _checked_ptr_1<double> _ptr__3729(_3729 ? _3729->raw() : nullptr,_3729 ? _3729->size(0) : 0);
      int _3730 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nd;
      int _3731 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nelem;
      int _3732 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nnz;
      bool _3733 = mosek::fusion::p_WorkStack::_get_impl(_3629)->hassp;
      int _3734 = _3732;
      int _3735 = _3731;
      int _3736 = mosek::fusion::p_WorkStack::_get_impl(_3629)->shape_base;
      int _3737 = mosek::fusion::p_WorkStack::_get_impl(_3629)->ptr_base;
      int _3738 = mosek::fusion::p_WorkStack::_get_impl(_3629)->sp_base;
      int _3739 = mosek::fusion::p_WorkStack::_get_impl(_3629)->nidxs_base;
      int _3740 = mosek::fusion::p_WorkStack::_get_impl(_3629)->bfix_base;
      int _3741 = mosek::fusion::p_WorkStack::_get_impl(_3629)->cof_base;
      int _3742 = _ptr__3727[_3736];
      int _3743 = _ptr__3727[safe_add( _3736,(int)1 )];
      if ((_3730 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,1 > > _3744 = mosek::fusion::p_WorkStack::_get_impl(_3629)->i32;
      _checked_ptr_1<int> _ptr__3744(_3744 ? _3744->raw() : nullptr,_3744 ? _3744->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3745 = mosek::fusion::p_WorkStack::_get_impl(_3629)->i64;
      _checked_ptr_1<long long> _ptr__3745(_3745 ? _3745->raw() : nullptr,_3745 ? _3745->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3746 = mosek::fusion::p_WorkStack::_get_impl(_3629)->f64;
      _checked_ptr_1<double> _ptr__3746(_3746 ? _3746->raw() : nullptr,_3746 ? _3746->size(0) : 0);
      int _3747 = safe_mul( _3742,mdim1 );
      long long _3748 = safe_mul( (long long)_3732,mdim1 );
      bool _3749 = false;
      int _3750 = (int)2;
      if ((!(_3748 <= (int)0x7fffffff)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Maximum number of nonzeros exceede in multiplication"));
        }
      }
      {}
      _3628->alloc_expr(_3750,_3747,(int)_3748,_3749);
      std::shared_ptr< monty::ndarray< int,1 > > _3751 = mosek::fusion::p_WorkStack::_get_impl(_3628)->i32;
      _checked_ptr_1<int> _ptr__3751(_3751 ? _3751->raw() : nullptr,_3751 ? _3751->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3752 = mosek::fusion::p_WorkStack::_get_impl(_3628)->i64;
      _checked_ptr_1<long long> _ptr__3752(_3752 ? _3752->raw() : nullptr,_3752 ? _3752->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3753 = mosek::fusion::p_WorkStack::_get_impl(_3628)->f64;
      _checked_ptr_1<double> _ptr__3753(_3753 ? _3753->raw() : nullptr,_3753 ? _3753->size(0) : 0);
      int _3754 = mosek::fusion::p_WorkStack::_get_impl(_3628)->shape_base;
      int _3755 = mosek::fusion::p_WorkStack::_get_impl(_3628)->ptr_base;
      int _3756 = mosek::fusion::p_WorkStack::_get_impl(_3628)->nidxs_base;
      int _3757 = mosek::fusion::p_WorkStack::_get_impl(_3628)->sp_base;
      int _3758 = mosek::fusion::p_WorkStack::_get_impl(_3628)->cof_base;
      int _3759 = mosek::fusion::p_WorkStack::_get_impl(_3628)->bfix_base;
      _ptr__3751[_3754] = _3742;
      _ptr__3751[safe_add( _3754,(int)1 )] = mdim1;
      int _3760 = (int)0;
      int _3761 = (int)0;
      _ptr__3751[_3755] = (int)0;
      if (_3733)
      {
        {
          int _8561 = (int)0;
          int _8562 = _3731;
          for (int _3762 = _8561; _3762 < _8562; ++_3762)
          {
            {
              ++ _ptr__3725[safe_add( safe_add( _3724,(_ptr__3745[safe_add( _3738,_3762 )] / _3743) ),(int)1 )];
            }
          }
          int _8563 = (int)0;
          int _8564 = _3742;
          for (int _3763 = _8563; _3763 < _8564; ++_3763)
          {
            {
              _ptr__3725[safe_add( safe_add( _3724,_3763 ),(int)1 )] += _ptr__3725[safe_add( _3724,_3763 )];
            }
          }
          int _8565 = (int)0;
          int _8566 = _3742;
          for (int _3764 = _8565; _3764 < _8566; ++_3764)
          {
            {
              int _8567 = (int)0;
              int _8568 = mdim1;
              for (int _3765 = _8567; _3765 < _8568; ++_3765)
              {
                {
                  double _3766 = 0.0;
                  int _3767 = (int)0;
                  int _8569 = _ptr__3725[safe_add( _3724,_3764 )];
                  int _8570 = _ptr__3725[safe_add( safe_add( _3724,_3764 ),(int)1 )];
                  for (int _3768 = _8569; _3768 < _8570; ++_3768)
                  {
                    {
                      long long _3769 = safe_add( _3765,safe_mul( (_ptr__3745[safe_add( _3738,_3768 )] % _3743),mdim1 ) );
                      _3766 += (_ptr__3746[safe_add( _3740,_3768 )] * ((*mval)(_3769)));
                      int _8571 = _ptr__3744[safe_add( _3737,_3768 )];
                      int _8572 = _ptr__3744[safe_add( safe_add( _3737,_3768 ),(int)1 )];
                      for (int _3770 = _8571; _3770 < _8572; ++_3770)
                      {
                        {
                          _ptr__3752[safe_add( safe_add( _3756,_3760 ),_3767 )] = _ptr__3745[safe_add( _3739,_3770 )];
                          _ptr__3753[safe_add( safe_add( _3758,_3760 ),_3767 )] = (_ptr__3746[safe_add( _3741,_3770 )] * ((*mval)(_3769)));
                          ++ _3767;
                        }
                      }
                    }
                  }
                  _3760 += _3767;
                  _ptr__3751[safe_add( safe_add( _3755,_3761 ),(int)1 )] = _3760;
                  _ptr__3753[safe_add( _3759,_3761 )] = _3766;
                  ++ _3761;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _8573 = (int)0;
          int _8574 = _3742;
          for (int _3771 = _8573; _3771 < _8574; ++_3771)
          {
            {
              int _8575 = (int)0;
              int _8576 = mdim1;
              for (int _3772 = _8575; _3772 < _8576; ++_3772)
              {
                {
                  double _3773 = 0.0;
                  int _3774 = (int)0;
                  int _8577 = (int)0;
                  int _8578 = _3743;
                  for (int _3775 = _8577; _3775 < _8578; ++_3775)
                  {
                    {
                      int _3776 = safe_add( safe_mul( _3771,_3743 ),_3775 );
                      int _3777 = safe_add( _3772,safe_mul( _3775,mdim1 ) );
                      _3773 += (_ptr__3746[safe_add( _3740,_3776 )] * ((*mval)(_3777)));
                      int _8579 = _ptr__3744[safe_add( _3737,_3776 )];
                      int _8580 = _ptr__3744[safe_add( safe_add( _3737,_3776 ),(int)1 )];
                      for (int _3778 = _8579; _3778 < _8580; ++_3778)
                      {
                        {
                          _ptr__3752[safe_add( safe_add( _3756,_3760 ),_3774 )] = _ptr__3745[safe_add( _3739,_3778 )];
                          _ptr__3753[safe_add( safe_add( _3758,_3760 ),_3774 )] = (_ptr__3746[safe_add( _3741,_3778 )] * ((*mval)(_3777)));
                          ++ _3774;
                        }
                      }
                    }
                  }
                  _3760 += _3774;
                  _ptr__3751[safe_add( safe_add( _3755,_3761 ),(int)1 )] = _3760;
                  _ptr__3753[safe_add( _3759,_3761 )] = _3773;
                  ++ _3761;
                }
              }
            }
          }
        }
      }
      _3630->clear();
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _3779,std::shared_ptr< monty::ndarray< int,1 > > _3780){
  _checked_ptr_1<int> _ptr__3780(_3780 ? _3780->raw() : nullptr, _3780 ? _3780->size(0) : 0);
  if (((int)((_3780)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_3779)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3780[(int)0]),(int)(_3779)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _3781,int _3782,std::shared_ptr< monty::ndarray< int,1 > > _3783,std::shared_ptr< monty::ndarray< int,1 > > _3784,std::shared_ptr< monty::ndarray< double,1 > > _3785,monty::rc_ptr< ::mosek::fusion::Expression > _3786){
  _checked_ptr_1<int> _ptr__3783(_3783 ? _3783->raw() : nullptr, _3783 ? _3783->size(0) : 0);
  _checked_ptr_1<int> _ptr__3784(_3784 ? _3784->raw() : nullptr, _3784 ? _3784->size(0) : 0);
  _checked_ptr_1<double> _ptr__3785(_3785 ? _3785->raw() : nullptr, _3785 ? _3785->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3787 = _3786->getShape();
  _checked_ptr_1<int> _ptr__3787(_3787 ? _3787->raw() : nullptr,_3787 ? _3787->size(0) : 0);
  if (((int)((_3787)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3788 = _ptr__3787[(int)0];
  int _3789 = _ptr__3787[(int)1];
  if (((_3781 < (int)0) || ((_3782 < (int)0) || ((_3788 < (int)0) || (_3789 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3781 != _3789))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3783)->size(0)) != (int)((_3784)->size(0))) || ((int)((_3783)->size(0)) != (int)((_3785)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3790 = (int)((_3783)->size(0));
  {
    bool _3791 = false;
    int _8581 = (int)0;
    int _8582 = _3790;
    for (int _3792 = _8581; _3792 < _8582; ++_3792)
    {
      {
        _3791 = (_3791 || ((_ptr__3783[_3792] < (int)0) || ((_ptr__3783[_3792] >= _3781) || ((_ptr__3784[_3792] < (int)0) || (_ptr__3784[_3792] >= _3782)))));
      }
    }
    if (_3791)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
      }
    }
    {}
  }
  {
    bool _3793 = false;
    int _8583 = (int)0;
    int _8584 = (_3790 - (int)1);
    for (int _3794 = _8583; _3794 < _8584; ++_3794)
    {
      {
        _3793 = (_3793 || ((_ptr__3783[_3794] > _ptr__3783[safe_add( _3794,(int)1 )]) || ((_ptr__3783[_3794] == _ptr__3783[safe_add( _3794,(int)1 )]) && (_ptr__3784[_3794] >= _ptr__3784[safe_add( _3794,(int)1 )]))));
      }
    }
    if (_3793)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
      }
    }
    {}
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3795,    int _3796,    std::shared_ptr< monty::ndarray< int,1 > > _3797,    std::shared_ptr< monty::ndarray< int,1 > > _3798,    std::shared_ptr< monty::ndarray< double,1 > > _3799,    monty::rc_ptr< ::mosek::fusion::Expression > _3800,    int _3801){ return new mosek::fusion::ExprMulLeft(_3795,_3796,_3797,_3798,_3799,_3800,_3801); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3795,    int _3796,    std::shared_ptr< monty::ndarray< int,1 > > _3797,    std::shared_ptr< monty::ndarray< int,1 > > _3798,    std::shared_ptr< monty::ndarray< double,1 > > _3799,    monty::rc_ptr< ::mosek::fusion::Expression > _3800,    int _3801) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3795,_3796,_3797,_3798,_3799,_3800,_3801); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3795,    int _3796,    std::shared_ptr< monty::ndarray< int,1 > > _3797,    std::shared_ptr< monty::ndarray< int,1 > > _3798,    std::shared_ptr< monty::ndarray< double,1 > > _3799,    monty::rc_ptr< ::mosek::fusion::Expression > _3800,    int _3801){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3797(_3797 ? _3797->raw() : nullptr, _3797 ? _3797->size(0) : 0);
    _checked_ptr_1<int> _ptr__3798(_3798 ? _3798->raw() : nullptr, _3798 ? _3798->size(0) : 0);
    _checked_ptr_1<double> _ptr__3799(_3799 ? _3799->raw() : nullptr, _3799 ? _3799->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_3795,_3796,_3800->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _3795;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _3796;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _3797;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _3798;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _3799;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _3800;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3802,    int _3803,    std::shared_ptr< monty::ndarray< int,1 > > _3804,    std::shared_ptr< monty::ndarray< int,1 > > _3805,    std::shared_ptr< monty::ndarray< double,1 > > _3806,    monty::rc_ptr< ::mosek::fusion::Expression > _3807){ return new mosek::fusion::ExprMulLeft(_3802,_3803,_3804,_3805,_3806,_3807); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3802,    int _3803,    std::shared_ptr< monty::ndarray< int,1 > > _3804,    std::shared_ptr< monty::ndarray< int,1 > > _3805,    std::shared_ptr< monty::ndarray< double,1 > > _3806,    monty::rc_ptr< ::mosek::fusion::Expression > _3807) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3802,_3803,_3804,_3805,_3806,_3807); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3802,    int _3803,    std::shared_ptr< monty::ndarray< int,1 > > _3804,    std::shared_ptr< monty::ndarray< int,1 > > _3805,    std::shared_ptr< monty::ndarray< double,1 > > _3806,    monty::rc_ptr< ::mosek::fusion::Expression > _3807){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3804(_3804 ? _3804->raw() : nullptr, _3804 ? _3804->size(0) : 0);
    _checked_ptr_1<int> _ptr__3805(_3805 ? _3805->raw() : nullptr, _3805 ? _3805->size(0) : 0);
    _checked_ptr_1<double> _ptr__3806(_3806 ? _3806->raw() : nullptr, _3806 ? _3806->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_3802,_3803,_3804,_3805,_3806,_3807,::mosek::fusion::p_ExprMulLeft::validate(_3802,_3803,_3804,_3805,_3806,_3807));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3808,monty::rc_ptr< ::mosek::fusion::WorkStack > _3809,monty::rc_ptr< ::mosek::fusion::WorkStack > _3810) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_3808,_3809,_3810); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3808,monty::rc_ptr< ::mosek::fusion::WorkStack > _3809,monty::rc_ptr< ::mosek::fusion::WorkStack > _3810){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_3809,_3808,_3810);
  _3809->pop_expr();
  int _3811 = mosek::fusion::p_WorkStack::_get_impl(_3809)->nd;
  int _3812 = mosek::fusion::p_WorkStack::_get_impl(_3809)->nnz;
  int _3813 = mosek::fusion::p_WorkStack::_get_impl(_3809)->nelem;
  bool _3814 = mosek::fusion::p_WorkStack::_get_impl(_3809)->hassp;
  int _3815 = mosek::fusion::p_WorkStack::_get_impl(_3809)->shape_base;
  int _3816 = mosek::fusion::p_WorkStack::_get_impl(_3809)->ptr_base;
  int _3817 = mosek::fusion::p_WorkStack::_get_impl(_3809)->sp_base;
  int _3818 = mosek::fusion::p_WorkStack::_get_impl(_3809)->nidxs_base;
  int _3819 = mosek::fusion::p_WorkStack::_get_impl(_3809)->bfix_base;
  int _3820 = mosek::fusion::p_WorkStack::_get_impl(_3809)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3821 = mosek::fusion::p_WorkStack::_get_impl(_3809)->i32;
  _checked_ptr_1<int> _ptr__3821(_3821 ? _3821->raw() : nullptr,_3821 ? _3821->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3822 = mosek::fusion::p_WorkStack::_get_impl(_3809)->i64;
  _checked_ptr_1<long long> _ptr__3822(_3822 ? _3822->raw() : nullptr,_3822 ? _3822->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3823 = mosek::fusion::p_WorkStack::_get_impl(_3809)->f64;
  _checked_ptr_1<double> _ptr__3823(_3823 ? _3823->raw() : nullptr,_3823 ? _3823->size(0) : 0);
  if ((_3811 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3824 = (int)9999;
  int _3825 = (int)9999;
  int _3826 = (int)9999;
  int _3827 = _ptr__3821[_3815];
  int _3828 = _ptr__3821[safe_add( _3815,(int)1 )];
  int _3829 = (int)((msubi)->size(0));
  bool _3830 = (_3829 < safe_mul( (long long)mdim0,(long long)mdim1 ));
  bool _3831 = false;
  int _3832 = (int)0;
  long long _3833 = (long long)0;
  if (_3814)
  {
    {
      _3824 = _3810->alloci32(_3813);
      _3825 = _3810->alloci32(_3813);
      _3826 = _3810->alloci32(safe_add( _3828,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3834 = mosek::fusion::p_WorkStack::_get_impl(_3810)->i32;
      _checked_ptr_1<int> _ptr__3834(_3834 ? _3834->raw() : nullptr,_3834 ? _3834->size(0) : 0);
      int _8585 = (int)0;
      int _8586 = safe_add( _3828,(int)1 );
      for (int _3835 = _8585; _3835 < _8586; ++_3835)
      {
        {
          _ptr__3834[safe_add( _3826,_3835 )] = (int)0;
        }
      }
      int _8587 = (int)0;
      int _8588 = _3813;
      for (int _3836 = _8587; _3836 < _8588; ++_3836)
      {
        {
          ++ _ptr__3834[safe_add( safe_add( _3826,(_ptr__3822[safe_add( _3817,_3836 )] % _3828) ),(int)1 )];
        }
      }
      int _8589 = (int)0;
      int _8590 = _3828;
      for (int _3837 = _8589; _3837 < _8590; ++_3837)
      {
        {
          _ptr__3834[safe_add( safe_add( _3826,_3837 ),(int)1 )] += _ptr__3834[safe_add( _3826,_3837 )];
        }
      }
      int _8591 = (int)0;
      int _8592 = _3813;
      for (int _3838 = _8591; _3838 < _8592; ++_3838)
      {
        {
          long long _3839 = (_ptr__3822[safe_add( _3817,_3838 )] % _3828);
          _ptr__3834[safe_add( _3824,_ptr__3834[safe_add( _3826,_3839 )] )] = _3838;
          ++ _ptr__3834[safe_add( _3826,_3839 )];
        }
      }
      int _8593 = (int)0;
      int _8594 = _3828;
      for (int _3840 = _8593; _3840 < _8594; ++_3840)
      {
        {
          _ptr__3834[(safe_add( _3826,_3828 ) - _3840)] = _ptr__3834[((safe_add( _3826,_3828 ) - _3840) - (int)1)];
        }
      }
      _ptr__3834[_3826] = (int)0;
      if (_3830)
      {
        {
          int _3841 = (int)0;
          while ( (_3841 < _3829) )
          {
            {
              int _3842 = ((*msubi)(_3841));
              int _3843 = safe_add( _3841,(int)1 );
              while ( ((_3843 < _3829) && (((*msubi)(_3843)) == ((*msubi)(_3841)))) )
              {
                {
                  ++ _3843;
                }
              }
              int _8595 = (int)0;
              int _8596 = _3828;
              for (int _3844 = _8595; _3844 < _8596; ++_3844)
              {
                {
                  bool _3845 = false;
                  int _3846 = _3843;
                  int _3847 = _3841;
                  int _3848 = _ptr__3834[safe_add( safe_add( _3826,_3844 ),(int)1 )];
                  int _3849 = _ptr__3834[safe_add( _3826,_3844 )];
                  while ( ((_3847 < _3846) && (_3849 < _3848)) )
                  {
                    {
                      int _3850 = _ptr__3834[safe_add( _3824,_3849 )];
                      if ((((*msubj)(_3847)) < (_ptr__3822[safe_add( _3817,_3850 )] / _3828)))
                      {
                        {
                          ++ _3847;
                        }
                      }
                      else if((((*msubj)(_3847)) > (_ptr__3822[safe_add( _3817,_3850 )] / _3828)))
                      {
                        {
                          ++ _3849;
                        }
                      }
                      else
                      {
                        {
                          _3845 = true;
                          _3833 += (_ptr__3821[safe_add( safe_add( _3816,_3850 ),(int)1 )] - _ptr__3821[safe_add( _3816,_3850 )]);
                          ++ _3849;
                          ++ _3847;
                        }
                      }
                    }
                  }
                  if (_3845)
                  {
                    {
                      ++ _3832;
                    }
                  }
                  {}
                }
              }
              _3841 = _3843;
            }
          }
        }
      }
      else
      {
        {
          _3832 = safe_mul( mdim0,_3828 );
          _3833 = safe_mul( (long long)_3812,mdim0 );
        }
      }
    }
  }
  else
  {
    {
      if (_3830)
      {
        {
          int _3851 = (int)0;
          while ( (_3851 < _3829) )
          {
            {
              int _3852 = safe_add( _3851,(int)1 );
              while ( ((_3852 < _3829) && (((*msubi)(_3851)) == ((*msubi)(_3852)))) )
              {
                {
                  ++ _3852;
                }
              }
              int _3853 = ((*msubi)(_3851));
              int _8597 = (int)0;
              int _8598 = _3828;
              for (int _3854 = _8597; _3854 < _8598; ++_3854)
              {
                {
                  bool _3855 = false;
                  int _8599 = _3851;
                  int _8600 = _3852;
                  for (int _3856 = _8599; _3856 < _8600; ++_3856)
                  {
                    {
                      int _3857 = safe_add( safe_mul( ((*msubj)(_3856)),_3828 ),_3854 );
                      _3833 += (_ptr__3821[safe_add( safe_add( _3816,_3857 ),(int)1 )] - _ptr__3821[safe_add( _3816,_3857 )]);
                      _3855 = true;
                    }
                  }
                  if (_3855)
                  {
                    {
                      ++ _3832;
                    }
                  }
                  {}
                }
              }
              _3851 = _3852;
            }
          }
        }
      }
      else
      {
        {
          _3833 = safe_mul( (long long)_3812,mdim0 );
          _3832 = safe_mul( mdim0,_3828 );
        }
      }
    }
  }
  if ((!(_3833 <= (int)0x7fffffff)))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Maximum number of nonzeros exceede in multiplication"));
    }
  }
  {}
  _3831 = (_3832 < safe_mul( mdim0,_3828 ));
  int _3858 = (int)2;
  _3808->alloc_expr(_3858,_3832,(int)_3833,_3831);
  int _3859 = mosek::fusion::p_WorkStack::_get_impl(_3808)->ptr_base;
  int _3860 = mosek::fusion::p_WorkStack::_get_impl(_3808)->nidxs_base;
  int _8601;
  bool _8602 = _3831;
  if (_8602)
  {
    _8601 = mosek::fusion::p_WorkStack::_get_impl(_3808)->sp_base;
  }
  else
  {
    _8601 = _3808->alloci64(_3832);
  }
  int _3861 = _8601;
  int _3862 = mosek::fusion::p_WorkStack::_get_impl(_3808)->cof_base;
  int _3863 = mosek::fusion::p_WorkStack::_get_impl(_3808)->bfix_base;
  int _3864 = mosek::fusion::p_WorkStack::_get_impl(_3808)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3865 = mosek::fusion::p_WorkStack::_get_impl(_3808)->i64;
  _checked_ptr_1<long long> _ptr__3865(_3865 ? _3865->raw() : nullptr,_3865 ? _3865->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3866 = mosek::fusion::p_WorkStack::_get_impl(_3808)->f64;
  _checked_ptr_1<double> _ptr__3866(_3866 ? _3866->raw() : nullptr,_3866 ? _3866->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3867 = mosek::fusion::p_WorkStack::_get_impl(_3808)->i32;
  _checked_ptr_1<int> _ptr__3867(_3867 ? _3867->raw() : nullptr,_3867 ? _3867->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3868 = mosek::fusion::p_WorkStack::_get_impl(_3810)->i32;
  _checked_ptr_1<int> _ptr__3868(_3868 ? _3868->raw() : nullptr,_3868 ? _3868->size(0) : 0);
  _ptr__3867[_3864] = mdim0;
  _ptr__3867[safe_add( _3864,(int)1 )] = _3828;
  if (_3814)
  {
    {
      _ptr__3867[_3859] = (int)0;
      if (_3830)
      {
        {
          int _3869 = (int)0;
          int _3870 = (int)0;
          int _3871 = (int)0;
          while ( (_3871 < _3829) )
          {
            {
              int _3872 = ((*msubi)(_3871));
              int _3873 = safe_add( _3871,(int)1 );
              while ( ((_3873 < _3829) && (((*msubi)(_3873)) == ((*msubi)(_3871)))) )
              {
                {
                  ++ _3873;
                }
              }
              int _8603 = (int)0;
              int _8604 = _3828;
              for (int _3874 = _8603; _3874 < _8604; ++_3874)
              {
                {
                  bool _3875 = false;
                  double _3876 = 0.0;
                  int _3877 = _3873;
                  int _3878 = _3871;
                  int _3879 = _ptr__3868[safe_add( safe_add( _3826,_3874 ),(int)1 )];
                  int _3880 = _ptr__3868[safe_add( _3826,_3874 )];
                  while ( ((_3878 < _3877) && (_3880 < _3879)) )
                  {
                    {
                      int _3881 = _ptr__3868[safe_add( _3824,_3880 )];
                      if ((((*msubj)(_3878)) < (_ptr__3822[safe_add( _3817,_3881 )] / _3828)))
                      {
                        {
                          ++ _3878;
                        }
                      }
                      else if((((*msubj)(_3878)) > (_ptr__3822[safe_add( _3817,_3881 )] / _3828)))
                      {
                        {
                          ++ _3880;
                        }
                      }
                      else
                      {
                        {
                          _3875 = true;
                          _3876 += (_ptr__3823[safe_add( _3819,_3881 )] * ((*mval)(_3878)));
                          int _3882 = (_ptr__3821[safe_add( safe_add( _3816,_3881 ),(int)1 )] - _ptr__3821[safe_add( _3816,_3881 )]);
                          int _8605 = (int)0;
                          int _8606 = _3882;
                          for (int _3883 = _8605; _3883 < _8606; ++_3883)
                          {
                            {
                              _ptr__3865[safe_add( safe_add( _3860,_3870 ),_3883 )] = _ptr__3822[safe_add( safe_add( _3818,_ptr__3821[safe_add( _3816,_3881 )] ),_3883 )];
                            }
                          }
                          int _8607 = (int)0;
                          int _8608 = _3882;
                          for (int _3884 = _8607; _3884 < _8608; ++_3884)
                          {
                            {
                              _ptr__3866[safe_add( safe_add( _3862,_3870 ),_3884 )] = (_ptr__3823[safe_add( safe_add( _3820,_ptr__3821[safe_add( _3816,_3881 )] ),_3884 )] * ((*mval)(_3878)));
                            }
                          }
                          ++ _3878;
                          ++ _3880;
                          _3870 += _3882;
                        }
                      }
                    }
                  }
                  if (_3875)
                  {
                    {
                      _ptr__3867[safe_add( safe_add( _3859,_3869 ),(int)1 )] = _3870;
                      _ptr__3865[safe_add( _3861,_3869 )] = safe_add( safe_mul( _3872,_3828 ),_3874 );
                      _ptr__3866[safe_add( _3863,_3869 )] = _3876;
                      ++ _3869;
                    }
                  }
                  {}
                }
              }
              _3871 = _3873;
            }
          }
        }
      }
      else
      {
        {
          int _3885 = (int)0;
          int _3886 = (int)0;
          int _8609 = (int)0;
          int _8610 = mdim0;
          for (int _3887 = _8609; _3887 < _8610; ++_3887)
          {
            {
              int _8611 = (int)0;
              int _8612 = _3828;
              for (int _3888 = _8611; _3888 < _8612; ++_3888)
              {
                {
                  double _3889 = 0.0;
                  int _8613 = _ptr__3868[safe_add( _3826,_3888 )];
                  int _8614 = _ptr__3868[safe_add( safe_add( _3826,_3888 ),(int)1 )];
                  for (int _3890 = _8613; _3890 < _8614; ++_3890)
                  {
                    {
                      int _3891 = _ptr__3868[safe_add( _3824,_3890 )];
                      long long _3892 = safe_add( safe_mul( _3887,mdim1 ),(_ptr__3822[safe_add( _3817,_3891 )] / _3828) );
                      _3889 += (_ptr__3823[safe_add( _3819,_3891 )] * ((*mval)(_3892)));
                      int _3893 = (_ptr__3821[safe_add( safe_add( _3816,_3891 ),(int)1 )] - _ptr__3821[safe_add( _3816,_3891 )]);
                      int _8615 = (int)0;
                      int _8616 = _3893;
                      for (int _3894 = _8615; _3894 < _8616; ++_3894)
                      {
                        {
                          _ptr__3865[safe_add( safe_add( _3860,_3886 ),_3894 )] = _ptr__3822[safe_add( safe_add( _3818,_ptr__3821[safe_add( _3816,_3891 )] ),_3894 )];
                          _ptr__3866[safe_add( safe_add( _3862,_3886 ),_3894 )] = (_ptr__3823[safe_add( safe_add( _3820,_ptr__3821[safe_add( _3816,_3891 )] ),_3894 )] * ((*mval)(_3892)));
                        }
                      }
                      _3886 += _3893;
                    }
                  }
                  _ptr__3867[safe_add( safe_add( _3859,_3885 ),(int)1 )] = _3886;
                  _ptr__3866[safe_add( _3863,_3885 )] = _3889;
                  ++ _3885;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _ptr__3867[_3859] = (int)0;
      int _3895 = (int)0;
      int _3896 = (int)0;
      int _3897 = (int)0;
      while ( (_3895 < _3829) )
      {
        {
          int _3898 = safe_add( _3895,(int)1 );
          while ( ((_3898 < _3829) && (((*msubi)(_3895)) == ((*msubi)(_3898)))) )
          {
            {
              ++ _3898;
            }
          }
          int _3899 = ((*msubi)(_3895));
          int _8617 = (int)0;
          int _8618 = _3828;
          for (int _3900 = _8617; _3900 < _8618; ++_3900)
          {
            {
              double _3901 = 0.0;
              bool _3902 = false;
              int _8619 = _3895;
              int _8620 = _3898;
              for (int _3903 = _8619; _3903 < _8620; ++_3903)
              {
                {
                  int _3904 = safe_add( safe_mul( ((*msubj)(_3903)),_3828 ),_3900 );
                  int _3905 = (_ptr__3821[safe_add( safe_add( _3816,_3904 ),(int)1 )] - _ptr__3821[safe_add( _3816,_3904 )]);
                  int _8621 = (int)0;
                  int _8622 = _3905;
                  for (int _3906 = _8621; _3906 < _8622; ++_3906)
                  {
                    {
                      _ptr__3865[safe_add( safe_add( _3860,_3897 ),_3906 )] = _ptr__3822[safe_add( safe_add( _3818,_ptr__3821[safe_add( _3816,_3904 )] ),_3906 )];
                    }
                  }
                  int _8623 = (int)0;
                  int _8624 = _3905;
                  for (int _3907 = _8623; _3907 < _8624; ++_3907)
                  {
                    {
                      _ptr__3866[safe_add( safe_add( _3862,_3897 ),_3907 )] = (_ptr__3823[safe_add( safe_add( _3820,_ptr__3821[safe_add( _3816,_3904 )] ),_3907 )] * ((*mval)(_3903)));
                    }
                  }
                  _3901 += (_ptr__3823[safe_add( _3819,_3904 )] * ((*mval)(_3903)));
                  _3902 = true;
                  _3897 += _3905;
                }
              }
              if (_3902)
              {
                {
                  _ptr__3865[safe_add( _3861,_3896 )] = safe_add( safe_mul( _3899,_3828 ),_3900 );
                  _ptr__3866[safe_add( _3863,_3896 )] = _3901;
                  _ptr__3867[safe_add( safe_add( _3859,_3896 ),(int)1 )] = _3897;
                  ++ _3896;
                }
              }
              {}
            }
          }
          _3895 = _3898;
        }
      }
    }
  }
  if ((!_3831))
  {
    {
      _3808->popi64(_3832);
    }
  }
  {}
  _3810->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _3908,int _3909,std::shared_ptr< monty::ndarray< int,1 > > _3910){
  _checked_ptr_1<int> _ptr__3910(_3910 ? _3910->raw() : nullptr, _3910 ? _3910->size(0) : 0);
  if (((int)((_3910)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_3909 != _ptr__3910[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3908),(int)(_ptr__3910[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _3911,int _3912,std::shared_ptr< monty::ndarray< int,1 > > _3913,std::shared_ptr< monty::ndarray< int,1 > > _3914,std::shared_ptr< monty::ndarray< double,1 > > _3915,monty::rc_ptr< ::mosek::fusion::Expression > _3916){
  _checked_ptr_1<int> _ptr__3913(_3913 ? _3913->raw() : nullptr, _3913 ? _3913->size(0) : 0);
  _checked_ptr_1<int> _ptr__3914(_3914 ? _3914->raw() : nullptr, _3914 ? _3914->size(0) : 0);
  _checked_ptr_1<double> _ptr__3915(_3915 ? _3915->raw() : nullptr, _3915 ? _3915->size(0) : 0);
  if ((_3916->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3917 = _3916->getDim((int)0);
  int _3918 = _3916->getDim((int)0);
  if (((_3911 < (int)0) || (_3912 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3912 != _3917))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3913)->size(0)) != (int)((_3914)->size(0))) || ((int)((_3913)->size(0)) != (int)((_3915)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3919 = (int)((_3913)->size(0));
  bool _3920 = false;
  bool _3921 = false;
  {
    int _8625 = (int)0;
    int _8626 = _3919;
    for (int _3922 = _8625; _3922 < _8626; ++_3922)
    {
      {
        _3920 = (_3920 || ((_ptr__3913[_3922] < (int)0) || ((_ptr__3913[_3922] >= _3911) || ((_ptr__3914[_3922] < (int)0) || (_ptr__3914[_3922] >= _3912)))));
      }
    }
    if ((!_3920))
    {
      {
        int _8627 = (int)0;
        int _8628 = (_3919 - (int)1);
        for (int _3923 = _8627; _3923 < _8628; ++_3923)
        {
          {
            _3921 = (_3921 || ((_ptr__3913[_3923] > _ptr__3913[safe_add( _3923,(int)1 )]) || ((_ptr__3913[_3923] == _ptr__3913[safe_add( _3923,(int)1 )]) && (_ptr__3914[_3923] >= _ptr__3914[safe_add( _3923,(int)1 )]))));
          }
        }
      }
    }
    {}
  }
  if (_3920)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_3921)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3924,    int _3925,    int _3926,    std::shared_ptr< monty::ndarray< int,1 > > _3927,    std::shared_ptr< monty::ndarray< int,1 > > _3928,    std::shared_ptr< monty::ndarray< double,1 > > _3929,    monty::rc_ptr< ::mosek::fusion::Variable > _3930){ return new mosek::fusion::ExprMulVar(_3924,_3925,_3926,_3927,_3928,_3929,_3930); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3924,    int _3925,    int _3926,    std::shared_ptr< monty::ndarray< int,1 > > _3927,    std::shared_ptr< monty::ndarray< int,1 > > _3928,    std::shared_ptr< monty::ndarray< double,1 > > _3929,    monty::rc_ptr< ::mosek::fusion::Variable > _3930) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3924,_3925,_3926,_3927,_3928,_3929,_3930); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3924,    int _3925,    int _3926,    std::shared_ptr< monty::ndarray< int,1 > > _3927,    std::shared_ptr< monty::ndarray< int,1 > > _3928,    std::shared_ptr< monty::ndarray< double,1 > > _3929,    monty::rc_ptr< ::mosek::fusion::Variable > _3930){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3927(_3927 ? _3927->raw() : nullptr, _3927 ? _3927->size(0) : 0);
    _checked_ptr_1<int> _ptr__3928(_3928 ? _3928->raw() : nullptr, _3928 ? _3928->size(0) : 0);
    _checked_ptr_1<double> _ptr__3929(_3929 ? _3929->raw() : nullptr, _3929 ? _3929->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_3924,_3925,_3926,_3927,_3928,_3929,_3930,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3931 = _3930->getShape();
    _checked_ptr_1<int> _ptr__3931(_3931 ? _3931->raw() : nullptr,_3931 ? _3931->size(0) : 0);
    int _3932 = (int)((_3931)->size(0));
    if ((_3932 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_3924 && (_ptr__3931[(int)0] != _3926)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_3924) && (_ptr__3931[(int)1] != _3925)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_3927)->size(0)) != (int)((_3928)->size(0))) || ((int)((_3927)->size(0)) != (int)((_3929)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_3925,_3926,_3927,_3928,_3929);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3933,    int _3934,    int _3935,    std::shared_ptr< monty::ndarray< int,1 > > _3936,    std::shared_ptr< monty::ndarray< int,1 > > _3937,    std::shared_ptr< monty::ndarray< double,1 > > _3938,    monty::rc_ptr< ::mosek::fusion::Variable > _3939,    int _3940){ return new mosek::fusion::ExprMulVar(_3933,_3934,_3935,_3936,_3937,_3938,_3939,_3940); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3933,    int _3934,    int _3935,    std::shared_ptr< monty::ndarray< int,1 > > _3936,    std::shared_ptr< monty::ndarray< int,1 > > _3937,    std::shared_ptr< monty::ndarray< double,1 > > _3938,    monty::rc_ptr< ::mosek::fusion::Variable > _3939,    int _3940) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3933,_3934,_3935,_3936,_3937,_3938,_3939,_3940); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3933,    int _3934,    int _3935,    std::shared_ptr< monty::ndarray< int,1 > > _3936,    std::shared_ptr< monty::ndarray< int,1 > > _3937,    std::shared_ptr< monty::ndarray< double,1 > > _3938,    monty::rc_ptr< ::mosek::fusion::Variable > _3939,    int _3940){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3936(_3936 ? _3936->raw() : nullptr, _3936 ? _3936->size(0) : 0);
    _checked_ptr_1<int> _ptr__3937(_3937 ? _3937->raw() : nullptr, _3937 ? _3937->size(0) : 0);
    _checked_ptr_1<double> _ptr__3938(_3938 ? _3938->raw() : nullptr, _3938 ? _3938->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_3934,_3935,_3939->getShape(),_3933));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _3933;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _3939;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _3934;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _3935;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_3936);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_3937);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_3938);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3941,monty::rc_ptr< ::mosek::fusion::WorkStack > _3942,monty::rc_ptr< ::mosek::fusion::WorkStack > _3943) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_3941,_3942,_3943); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3941,monty::rc_ptr< ::mosek::fusion::WorkStack > _3942,monty::rc_ptr< ::mosek::fusion::WorkStack > _3943){
  if (left)
  {
    {
      _pubthis->eval_left(_3941,_3942,_3943);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_3941,_3942,_3943);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3944,monty::rc_ptr< ::mosek::fusion::WorkStack > _3945,monty::rc_ptr< ::mosek::fusion::WorkStack > _3946) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_3944,_3945,_3946); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3944,monty::rc_ptr< ::mosek::fusion::WorkStack > _3945,monty::rc_ptr< ::mosek::fusion::WorkStack > _3946){
  int _3947 = mosek::fusion::p_WorkStack::_get_impl(_3945)->pi32;
  int _3948 = mosek::fusion::p_WorkStack::_get_impl(_3945)->pi64;
  int _3949 = x->numInst();
  int _3950 = _3945->alloci64(_3949);
  int _3951 = _3945->alloci64(_3949);
  int _3952 = _3945->alloci32(_3949);
  int _3953 = _3945->alloci32(_3949);
  std::shared_ptr< monty::ndarray< int,1 > > _3954 = x->getShape();
  _checked_ptr_1<int> _ptr__3954(_3954 ? _3954->raw() : nullptr,_3954 ? _3954->size(0) : 0);
  int _3955 = (int)((_3954)->size(0));
  long long _3956 = safe_mul( _ptr__3954[(int)0],_ptr__3954[(int)1] );
  int _3957 = _ptr__3954[(int)1];
  int _3958 = _ptr__3954[(int)0];
  int _3959 = _3945->alloci32(safe_add( _3958,(int)1 ));
  int _3960 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _3961 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3961(_3961 ? _3961->raw() : nullptr,_3961 ? _3961->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3962 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3962(_3962 ? _3962->raw() : nullptr,_3962 ? _3962->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3963 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3963(_3963 ? _3963->raw() : nullptr,_3963 ? _3963->size(0) : 0);
  int _3964 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3965 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _3966 = ((_3960 / _3964) == _3965);
  int _3967 = _3945->alloci32(_3960);
  int _3968 = _3945->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3969 = mosek::fusion::p_WorkStack::_get_impl(_3945)->i32;
  _checked_ptr_1<int> _ptr__3969(_3969 ? _3969->raw() : nullptr,_3969 ? _3969->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3970 = mosek::fusion::p_WorkStack::_get_impl(_3945)->i64;
  _checked_ptr_1<long long> _ptr__3970(_3970 ? _3970->raw() : nullptr,_3970 ? _3970->size(0) : 0);
  int _3971 = (int)0;
  int _3972 = (int)0;
  x->inst(_3951,_3970,_3950,_3970);
  if (_3966)
  {
    {
      int _3973 = (int)0;
      if ((_3949 > (int)0))
      {
        {
          _3973 = (int)1;
          if ((_3958 > (int)1))
          {
            {
              if ((_3957 == (int)1))
              {
                {
                  int _8629 = (int)1;
                  int _8630 = _3949;
                  for (int _3974 = _8629; _3974 < _8630; ++_3974)
                  {
                    {
                      if ((_ptr__3970[safe_add( _3951,_3974 )] > _ptr__3970[(safe_add( _3951,_3974 ) - (int)1)]))
                      {
                        {
                          ++ _3973;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _8631 = (int)1;
                  int _8632 = _3949;
                  for (int _3975 = _8631; _3975 < _8632; ++_3975)
                  {
                    {
                      if (((_ptr__3970[safe_add( _3951,_3975 )] / _3957) > (_ptr__3970[(safe_add( _3951,_3975 ) - (int)1)] / _3957)))
                      {
                        {
                          ++ _3973;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _3972 = safe_mul( _3973,_3965 );
      _3971 = safe_mul( _3949,_3965 );
      bool _3976 = (_3973 < _3958);
      int _3977 = _3944->alloci32(safe_add( _3972,(int)1 ));
      int _8633;
      bool _8634 = _3976;
      if (_8634)
      {
        _8633 = (int)1;
      }
      else
      {
        _8633 = (int)0;
      }
      _3944->pushi32(_8633);
      _3944->pushi32(_3971);
      _3944->pushi32(_3972);
      _3944->pushi32(_3958);
      _3944->pushi32(_3965);
      _3944->pushi32((int)2);
      int _3978 = _3944->alloci64(_3971);
      int _3979 = _3944->alloci64(_3972);
      int _3980 = _3944->allocf64(_3971);
      int _3981 = _3944->allocf64(_3972);
      std::shared_ptr< monty::ndarray< int,1 > > _3982 = mosek::fusion::p_WorkStack::_get_impl(_3944)->i32;
      _checked_ptr_1<int> _ptr__3982(_3982 ? _3982->raw() : nullptr,_3982 ? _3982->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3983 = mosek::fusion::p_WorkStack::_get_impl(_3944)->i64;
      _checked_ptr_1<long long> _ptr__3983(_3983 ? _3983->raw() : nullptr,_3983 ? _3983->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3984 = mosek::fusion::p_WorkStack::_get_impl(_3944)->f64;
      _checked_ptr_1<double> _ptr__3984(_3984 ? _3984->raw() : nullptr,_3984 ? _3984->size(0) : 0);
      {
        int _3985 = (int)0;
        int _3986 = (int)0;
        int _3987 = (int)0;
        _ptr__3982[_3977] = (int)0;
        while ( (_3985 < _3949) )
        {
          {
            int _3988 = _3985;
            ++ _3985;
            while ( ((_3985 < _3949) && ((_ptr__3970[safe_add( _3951,_3985 )] / _3957) == (_ptr__3970[safe_add( _3951,_3988 )] / _3957))) )
            {
              {
                ++ _3985;
              }
            }
            long long _3989 = (_ptr__3970[safe_add( _3951,_3988 )] / _3957);
            int _8635 = (int)0;
            int _8636 = _3965;
            for (int _3990 = _8635; _3990 < _8636; ++_3990)
            {
              {
                int _8637 = _3988;
                int _8638 = _3985;
                for (int _3991 = _8637; _3991 < _8638; ++_3991)
                {
                  {
                    long long _3992 = (_ptr__3970[safe_add( _3951,_3991 )] % _3957);
                    _ptr__3983[safe_add( _3978,_3987 )] = _ptr__3970[safe_add( _3950,_3991 )];
                    _ptr__3984[safe_add( _3980,_3987 )] = _ptr__3963[safe_add( safe_mul( _3992,_3965 ),_3990 )];
                    ++ _3987;
                  }
                }
                _ptr__3982[safe_add( safe_add( _3977,_3986 ),(int)1 )] = _3987;
                _ptr__3984[safe_add( _3981,_3986 )] = 0.0;
                _ptr__3983[safe_add( _3979,_3986 )] = safe_add( safe_mul( _3989,_3965 ),_3990 );
                ++ _3986;
              }
            }
          }
        }
      }
      if ((!_3976))
      {
        {
          _3944->popi64(_3972);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_3965 == (int)1))
        {
          {
            int _8639 = (int)0;
            int _8640 = _3960;
            for (int _3993 = _8639; _3993 < _8640; ++_3993)
            {
              {
                _ptr__3969[safe_add( _3967,_3993 )] = _3993;
              }
            }
            _ptr__3969[_3968] = (int)0;
            _ptr__3969[safe_add( _3968,(int)1 )] = _3960;
          }
        }
        else
        {
          {
            _ptr__3969[_3968] = (int)0;
            int _8641 = (int)0;
            int _8642 = safe_add( _3965,(int)1 );
            for (int _3994 = _8641; _3994 < _8642; ++_3994)
            {
              {
                _ptr__3969[safe_add( _3968,_3994 )] = (int)0;
              }
            }
            int _8643 = (int)0;
            int _8644 = _3960;
            for (int _3995 = _8643; _3995 < _8644; ++_3995)
            {
              {
                ++ _ptr__3969[safe_add( safe_add( _3968,_ptr__3962[_3995] ),(int)1 )];
              }
            }
            int _8645 = (int)0;
            int _8646 = mdimj;
            for (int _3996 = _8645; _3996 < _8646; ++_3996)
            {
              {
                _ptr__3969[safe_add( safe_add( _3968,_3996 ),(int)1 )] += _ptr__3969[safe_add( _3968,_3996 )];
              }
            }
            int _8647 = (int)0;
            int _8648 = _3960;
            for (int _3997 = _8647; _3997 < _8648; ++_3997)
            {
              {
                _ptr__3969[safe_add( _3967,_ptr__3969[safe_add( _3968,_ptr__3962[_3997] )] )] = _3997;
                ++ _ptr__3969[safe_add( _3968,_ptr__3962[_3997] )];
              }
            }
            int _8649 = (int)0;
            int _8650 = _3965;
            for (int _3998 = _8649; _3998 < _8650; ++_3998)
            {
              {
                _ptr__3969[(safe_add( _3968,_3965 ) - _3998)] = _ptr__3969[((safe_add( _3968,_3965 ) - _3998) - (int)1)];
              }
            }
            _ptr__3969[_3968] = (int)0;
          }
        }
      }
      if (((_3949 / _3958) == _3957))
      {
        {
          int _3999 = (int)0;
          {
            int _4000 = (int)0;
            while ( (_4000 < _3960) )
            {
              {
                ++ _4000;
                while ( ((_4000 < _3960) && (_ptr__3962[_ptr__3969[(safe_add( _3967,_4000 ) - (int)1)]] == _ptr__3962[_ptr__3969[safe_add( _3967,_4000 )]])) )
                {
                  {
                    ++ _4000;
                  }
                }
                ++ _3999;
              }
            }
          }
          _3972 = safe_mul( _3999,_3958 );
          _3971 = safe_mul( _3960,_3958 );
          bool _4001 = (_3999 < _3965);
          int _4002 = _3944->alloci32(safe_add( _3972,(int)1 ));
          int _8651;
          bool _8652 = _4001;
          if (_8652)
          {
            _8651 = (int)1;
          }
          else
          {
            _8651 = (int)0;
          }
          _3944->pushi32(_8651);
          _3944->pushi32(_3971);
          _3944->pushi32(_3972);
          _3944->pushi32(_3958);
          _3944->pushi32(_3965);
          _3944->pushi32((int)2);
          int _4003 = _3944->alloci64(_3971);
          int _4004 = _3944->alloci64(_3972);
          int _4005 = _3944->allocf64(_3971);
          int _4006 = _3944->allocf64(_3972);
          std::shared_ptr< monty::ndarray< int,1 > > _4007 = mosek::fusion::p_WorkStack::_get_impl(_3944)->i32;
          _checked_ptr_1<int> _ptr__4007(_4007 ? _4007->raw() : nullptr,_4007 ? _4007->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _4008 = mosek::fusion::p_WorkStack::_get_impl(_3944)->i64;
          _checked_ptr_1<long long> _ptr__4008(_4008 ? _4008->raw() : nullptr,_4008 ? _4008->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4009 = mosek::fusion::p_WorkStack::_get_impl(_3944)->f64;
          _checked_ptr_1<double> _ptr__4009(_4009 ? _4009->raw() : nullptr,_4009 ? _4009->size(0) : 0);
          _ptr__4007[_4002] = (int)0;
          int _4010 = (int)0;
          int _4011 = (int)0;
          int _8653 = (int)0;
          int _8654 = _3958;
          for (int _4012 = _8653; _4012 < _8654; ++_4012)
          {
            {
              int _4013 = (int)0;
              while ( (_4013 < _3960) )
              {
                {
                  int _4014 = _4013;
                  ++ _4013;
                  while ( ((_4013 < _3960) && (_ptr__3962[_ptr__3969[safe_add( _3967,_4014 )]] == _ptr__3962[_ptr__3969[safe_add( _3967,_4013 )]])) )
                  {
                    {
                      ++ _4013;
                    }
                  }
                  int _4015 = _ptr__3962[_ptr__3969[safe_add( _3967,_4014 )]];
                  int _8655 = _4014;
                  int _8656 = _4013;
                  for (int _4016 = _8655; _4016 < _8656; ++_4016)
                  {
                    {
                      int _4017 = _ptr__3961[_ptr__3969[safe_add( _3967,_4016 )]];
                      _ptr__4008[safe_add( _4003,_4011 )] = _ptr__3970[safe_add( safe_add( _3950,safe_mul( _4012,_3957 ) ),_4017 )];
                      _ptr__4009[safe_add( _4005,_4011 )] = _ptr__3963[_ptr__3969[safe_add( _3967,_4016 )]];
                      ++ _4011;
                    }
                  }
                  _ptr__4009[safe_add( _4006,_4010 )] = 0.0;
                  _ptr__4008[safe_add( _4004,_4010 )] = safe_add( safe_mul( _4012,_3965 ),_4015 );
                  _ptr__4007[safe_add( safe_add( _4002,_4010 ),(int)1 )] = _4011;
                  ++ _4010;
                }
              }
            }
          }
          if ((!_4001))
          {
            {
              _3944->popi64(_3972);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _8657 = (int)0;
          int _8658 = safe_add( _3958,(int)1 );
          for (int _4018 = _8657; _4018 < _8658; ++_4018)
          {
            {
              _ptr__3969[safe_add( _3959,_4018 )] = (int)0;
            }
          }
          if ((_3955 == (int)1))
          {
            {
              int _8659 = (int)0;
              int _8660 = _3949;
              for (int _4019 = _8659; _4019 < _8660; ++_4019)
              {
                {
                  _ptr__3969[safe_add( _3952,_4019 )] = (int)0;
                }
              }
              int _8661 = (int)0;
              int _8662 = _3949;
              for (int _4020 = _8661; _4020 < _8662; ++_4020)
              {
                {
                  _ptr__3969[safe_add( _3953,_4020 )] = (int)_ptr__3970[safe_add( _3951,_4020 )];
                }
              }
              _ptr__3969[_3959] = (int)0;
              _ptr__3969[safe_add( _3959,(int)1 )] = _3949;
            }
          }
          else
          {
            {
              int _8663 = (int)0;
              int _8664 = _3949;
              for (int _4021 = _8663; _4021 < _8664; ++_4021)
              {
                {
                  _ptr__3969[safe_add( _3952,_4021 )] = (int)(_ptr__3970[safe_add( _3951,_4021 )] / _ptr__3954[(int)1]);
                }
              }
              int _8665 = (int)0;
              int _8666 = _3949;
              for (int _4022 = _8665; _4022 < _8666; ++_4022)
              {
                {
                  _ptr__3969[safe_add( _3953,_4022 )] = (int)(_ptr__3970[safe_add( _3951,_4022 )] % _ptr__3954[(int)1]);
                }
              }
              _ptr__3969[_3959] = (int)0;
              int _8667 = (int)0;
              int _8668 = _3949;
              for (int _4023 = _8667; _4023 < _8668; ++_4023)
              {
                {
                  ++ _ptr__3969[safe_add( safe_add( _3959,_ptr__3969[safe_add( _3952,_4023 )] ),(int)1 )];
                }
              }
              int _8669 = (int)0;
              int _8670 = _3958;
              for (int _4024 = _8669; _4024 < _8670; ++_4024)
              {
                {
                  _ptr__3969[safe_add( safe_add( _3959,_4024 ),(int)1 )] += _ptr__3969[safe_add( _3959,_4024 )];
                }
              }
            }
          }
          int _8671 = (int)0;
          int _8672 = _3958;
          for (int _4025 = _8671; _4025 < _8672; ++_4025)
          {
            {
              int _8673 = (int)0;
              int _8674 = mdimj;
              for (int _4026 = _8673; _4026 < _8674; ++_4026)
              {
                {
                  int _4027 = (int)0;
                  int _4028 = _ptr__3969[safe_add( safe_add( _3959,_4025 ),(int)1 )];
                  int _4029 = _ptr__3969[safe_add( safe_add( _3968,_4026 ),(int)1 )];
                  int _4030 = _ptr__3969[safe_add( _3959,_4025 )];
                  int _4031 = _ptr__3969[safe_add( _3968,_4026 )];
                  while ( ((_4031 < _4029) && (_4030 < _4028)) )
                  {
                    {
                      if ((_ptr__3961[_ptr__3969[safe_add( _3967,_4031 )]] < _ptr__3969[safe_add( _3953,_4030 )]))
                      {
                        {
                          ++ _4031;
                        }
                      }
                      else if((_ptr__3961[_ptr__3969[safe_add( _3967,_4031 )]] > _ptr__3969[safe_add( _3953,_4030 )]))
                      {
                        {
                          ++ _4030;
                        }
                      }
                      else
                      {
                        {
                          ++ _4027;
                          ++ _4031;
                          ++ _4030;
                        }
                      }
                    }
                  }
                  if ((_4027 > (int)0))
                  {
                    {
                      _3971 += _4027;
                      ++ _3972;
                    }
                  }
                  {}
                }
              }
            }
          }
          int _4032 = _3944->alloci32(safe_add( _3972,(int)1 ));
          bool _8675;
          bool _8676 = (_3972 < safe_mul( _3957,mdimi ));
          if (_8676)
          {
            _8675 = true;
          }
          else
          {
            _8675 = false;
          }
          bool _4033 = _8675;
          int _8677;
          bool _8678 = _4033;
          if (_8678)
          {
            _8677 = (int)1;
          }
          else
          {
            _8677 = (int)0;
          }
          _3944->pushi32(_8677);
          _3944->pushi32(_3971);
          _3944->pushi32(_3972);
          _3944->pushi32(_3958);
          _3944->pushi32(mdimj);
          _3944->pushi32((int)2);
          int _4034 = _3944->alloci64(_3971);
          int _4035 = _3944->alloci64(_3972);
          int _4036 = _3944->allocf64(_3971);
          int _4037 = _3944->allocf64(_3972);
          std::shared_ptr< monty::ndarray< int,1 > > _4038 = mosek::fusion::p_WorkStack::_get_impl(_3944)->i32;
          _checked_ptr_1<int> _ptr__4038(_4038 ? _4038->raw() : nullptr,_4038 ? _4038->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _4039 = mosek::fusion::p_WorkStack::_get_impl(_3944)->i64;
          _checked_ptr_1<long long> _ptr__4039(_4039 ? _4039->raw() : nullptr,_4039 ? _4039->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4040 = mosek::fusion::p_WorkStack::_get_impl(_3944)->f64;
          _checked_ptr_1<double> _ptr__4040(_4040 ? _4040->raw() : nullptr,_4040 ? _4040->size(0) : 0);
          {
            int _4041 = (int)0;
            int _4042 = (int)0;
            int _4043 = (int)0;
            _ptr__4038[_4032] = (int)0;
            int _8679 = (int)0;
            int _8680 = _3972;
            for (int _4044 = _8679; _4044 < _8680; ++_4044)
            {
              {
                _ptr__4040[safe_add( _4037,_4044 )] = 0.0;
              }
            }
            int _8681 = (int)0;
            int _8682 = _3958;
            for (int _4045 = _8681; _4045 < _8682; ++_4045)
            {
              {
                int _8683 = (int)0;
                int _8684 = mdimj;
                for (int _4046 = _8683; _4046 < _8684; ++_4046)
                {
                  {
                    int _4047 = (int)0;
                    int _4048 = _ptr__3969[safe_add( safe_add( _3959,_4045 ),(int)1 )];
                    int _4049 = _ptr__3969[safe_add( safe_add( _3968,_4046 ),(int)1 )];
                    int _4050 = _ptr__3969[safe_add( _3959,_4045 )];
                    int _4051 = _ptr__3969[safe_add( _3968,_4046 )];
                    while ( ((_4051 < _4049) && (_4050 < _4048)) )
                    {
                      {
                        if ((_ptr__3961[_ptr__3969[safe_add( _3967,_4051 )]] < _ptr__3969[safe_add( _3953,_4050 )]))
                        {
                          {
                            ++ _4051;
                          }
                        }
                        else if((_ptr__3961[_ptr__3969[safe_add( _3967,_4051 )]] > _ptr__3969[safe_add( _3953,_4050 )]))
                        {
                          {
                            ++ _4050;
                          }
                        }
                        else
                        {
                          {
                            _ptr__4039[safe_add( _4034,_4043 )] = _ptr__3970[safe_add( _3950,_4050 )];
                            _ptr__4040[safe_add( _4036,_4043 )] = _ptr__3963[_ptr__3969[safe_add( _3967,_4051 )]];
                            ++ _4047;
                            ++ _4043;
                            ++ _4051;
                            ++ _4050;
                          }
                        }
                      }
                    }
                    if ((_4047 > (int)0))
                    {
                      {
                        _ptr__4038[safe_add( safe_add( _4032,_4042 ),(int)1 )] = _4043;
                        _ptr__4039[safe_add( _4035,_4042 )] = _4041;
                        ++ _4042;
                      }
                    }
                    {}
                    ++ _4041;
                  }
                }
              }
            }
          }
          if ((!_4033))
          {
            {
              _3944->popi64(_3972);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_3945)->pi32 = _3947;
  mosek::fusion::p_WorkStack::_get_impl(_3945)->pi64 = _3948;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _4052,monty::rc_ptr< ::mosek::fusion::WorkStack > _4053,monty::rc_ptr< ::mosek::fusion::WorkStack > _4054) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_4052,_4053,_4054); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _4052,monty::rc_ptr< ::mosek::fusion::WorkStack > _4053,monty::rc_ptr< ::mosek::fusion::WorkStack > _4054){
  int _4055 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _4056 = x->getShape();
  _checked_ptr_1<int> _ptr__4056(_4056 ? _4056->raw() : nullptr,_4056 ? _4056->size(0) : 0);
  int _4057 = (int)((_4056)->size(0));
  int _4058 = _4054->alloci64(_4055);
  int _4059 = _4054->alloci64(_4055);
  int _4060 = _4054->alloci32(_4055);
  int _4061 = _4054->alloci32(_4055);
  int _4062 = _4054->alloci32(_4055);
  int _4063 = _4054->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _4064 = x->getShape();
  _checked_ptr_1<int> _ptr__4064(_4064 ? _4064->raw() : nullptr,_4064 ? _4064->size(0) : 0);
  int _4065 = (int)((_4064)->size(0));
  int _8685;
  bool _8686 = (_4065 == (int)1);
  if (_8686)
  {
    _8685 = (int)1;
  }
  else
  {
    _8685 = _ptr__4064[(int)1];
  }
  int _4066 = _8685;
  int _4067 = _ptr__4064[(int)0];
  int _4068 = _4054->alloci32(safe_add( _4066,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _4069 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__4069(_4069 ? _4069->raw() : nullptr,_4069 ? _4069->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4070 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__4070(_4070 ? _4070->raw() : nullptr,_4070 ? _4070->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4071 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__4071(_4071 ? _4071->raw() : nullptr,_4071 ? _4071->size(0) : 0);
  int _4072 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _4073 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _4074 = (int)0;
  int _4075 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4076 = mosek::fusion::p_WorkStack::_get_impl(_4054)->i32;
  _checked_ptr_1<int> _ptr__4076(_4076 ? _4076->raw() : nullptr,_4076 ? _4076->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4077 = mosek::fusion::p_WorkStack::_get_impl(_4054)->i64;
  _checked_ptr_1<long long> _ptr__4077(_4077 ? _4077->raw() : nullptr,_4077 ? _4077->size(0) : 0);
  int _4078 = (int)((_4071)->size(0));
  x->inst(_4059,_4077,_4058,_4077);
  if ((x->numInst() < x->getSize()))
  {
    {
      {
        int _8687 = (int)0;
        int _8688 = safe_add( _4072,(int)1 );
        for (int _4079 = _8687; _4079 < _8688; ++_4079)
        {
          {
            _ptr__4076[safe_add( _4063,_4079 )] = (int)0;
          }
        }
        int _8689 = (int)0;
        int _8690 = (int)((_4069)->size(0));
        for (int _4080 = _8689; _4080 < _8690; ++_4080)
        {
          {
            ++ _ptr__4076[safe_add( safe_add( _4063,_ptr__4069[_4080] ),(int)1 )];
          }
        }
        int _8691 = (int)0;
        int _8692 = _4072;
        for (int _4081 = _8691; _4081 < _8692; ++_4081)
        {
          {
            _ptr__4076[safe_add( safe_add( _4063,_4081 ),(int)1 )] += _ptr__4076[safe_add( _4063,_4081 )];
          }
        }
        if ((_4065 == (int)1))
        {
          {
            int _8693 = (int)0;
            int _8694 = _4055;
            for (int _4082 = _8693; _4082 < _8694; ++_4082)
            {
              {
                _ptr__4076[safe_add( _4060,_4082 )] = (int)_ptr__4077[safe_add( _4059,_4082 )];
              }
            }
            int _8695 = (int)0;
            int _8696 = _4055;
            for (int _4083 = _8695; _4083 < _8696; ++_4083)
            {
              {
                _ptr__4076[safe_add( _4061,_4083 )] = (int)0;
              }
            }
          }
        }
        else
        {
          {
            int _8697 = (int)0;
            int _8698 = _4055;
            for (int _4084 = _8697; _4084 < _8698; ++_4084)
            {
              {
                _ptr__4076[safe_add( _4060,_4084 )] = (int)(_ptr__4077[safe_add( _4059,_4084 )] / _4066);
              }
            }
            int _8699 = (int)0;
            int _8700 = _4055;
            for (int _4085 = _8699; _4085 < _8700; ++_4085)
            {
              {
                _ptr__4076[safe_add( _4061,_4085 )] = (int)(_ptr__4077[safe_add( _4059,_4085 )] % _4066);
              }
            }
          }
        }
        if ((_4065 > (int)1))
        {
          {
            int _8701 = (int)0;
            int _8702 = safe_add( _4066,(int)1 );
            for (int _4086 = _8701; _4086 < _8702; ++_4086)
            {
              {
                _ptr__4076[safe_add( _4068,_4086 )] = (int)0;
              }
            }
            int _8703 = (int)0;
            int _8704 = _4055;
            for (int _4087 = _8703; _4087 < _8704; ++_4087)
            {
              {
                ++ _ptr__4076[safe_add( safe_add( _4068,_ptr__4076[safe_add( _4061,_4087 )] ),(int)1 )];
              }
            }
            int _8705 = (int)0;
            int _8706 = _4066;
            for (int _4088 = _8705; _4088 < _8706; ++_4088)
            {
              {
                _ptr__4076[safe_add( safe_add( _4068,_4088 ),(int)1 )] += _ptr__4076[safe_add( _4068,_4088 )];
              }
            }
            int _8707 = (int)0;
            int _8708 = _4055;
            for (int _4089 = _8707; _4089 < _8708; ++_4089)
            {
              {
                _ptr__4076[safe_add( _4062,_ptr__4076[safe_add( _4068,_ptr__4076[safe_add( _4061,_4089 )] )] )] = _4089;
                ++ _ptr__4076[safe_add( _4068,_ptr__4076[safe_add( _4061,_4089 )] )];
              }
            }
            int _8709 = (int)0;
            int _8710 = _4066;
            for (int _4090 = _8709; _4090 < _8710; ++_4090)
            {
              {
                _ptr__4076[(safe_add( _4068,_4066 ) - _4090)] = _ptr__4076[((safe_add( _4068,_4066 ) - _4090) - (int)1)];
              }
            }
            _ptr__4076[_4068] = (int)0;
          }
        }
        else
        {
          {
            _ptr__4076[_4068] = (int)0;
            _ptr__4076[safe_add( _4068,(int)1 )] = _4055;
            int _8711 = (int)0;
            int _8712 = _4055;
            for (int _4091 = _8711; _4091 < _8712; ++_4091)
            {
              {
                _ptr__4076[safe_add( _4062,_4091 )] = _4091;
              }
            }
          }
        }
        int _8713 = (int)0;
        int _8714 = _4072;
        for (int _4092 = _8713; _4092 < _8714; ++_4092)
        {
          {
            int _8715 = (int)0;
            int _8716 = _4066;
            for (int _4093 = _8715; _4093 < _8716; ++_4093)
            {
              {
                int _4094 = (int)0;
                int _4095 = _ptr__4076[safe_add( safe_add( _4068,_4093 ),(int)1 )];
                int _4096 = _ptr__4076[safe_add( safe_add( _4063,_4092 ),(int)1 )];
                int _4097 = _ptr__4076[safe_add( _4068,_4093 )];
                int _4098 = _ptr__4076[safe_add( _4063,_4092 )];
                while ( ((_4098 < _4096) && (_4097 < _4095)) )
                {
                  {
                    if ((_ptr__4070[_4098] < _ptr__4076[safe_add( _4060,_ptr__4076[safe_add( _4062,_4097 )] )]))
                    {
                      {
                        ++ _4098;
                      }
                    }
                    else if((_ptr__4070[_4098] > _ptr__4076[safe_add( _4060,_ptr__4076[safe_add( _4062,_4097 )] )]))
                    {
                      {
                        ++ _4097;
                      }
                    }
                    else
                    {
                      {
                        ++ _4094;
                        ++ _4098;
                        ++ _4097;
                      }
                    }
                  }
                }
                if ((_4094 > (int)0))
                {
                  {
                    _4074 += _4094;
                    ++ _4075;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _4074 = safe_mul( _4078,_4066 );
      int _4099 = (int)0;
      while ( (_4099 < _4078) )
      {
        {
          int _4100 = safe_add( _4099,(int)1 );
          while ( ((_4100 < _4078) && (_ptr__4069[_4099] == _ptr__4069[_4100])) )
          {
            {
              ++ _4100;
            }
          }
          ++ _4075;
          _4099 = _4100;
        }
      }
      _4075 *= _4066;
    }
  }
  bool _8717;
  bool _8718 = (_4075 < safe_mul( _4066,_4072 ));
  if (_8718)
  {
    _8717 = true;
  }
  else
  {
    _8717 = false;
  }
  bool _4101 = _8717;
  int _4102 = _4065;
  _4052->alloc_expr(_4102,_4075,_4074,_4101);
  int _4103 = mosek::fusion::p_WorkStack::_get_impl(_4052)->ptr_base;
  int _4104 = mosek::fusion::p_WorkStack::_get_impl(_4052)->shape_base;
  int _4105 = mosek::fusion::p_WorkStack::_get_impl(_4052)->nidxs_base;
  int _8719;
  bool _8720 = _4101;
  if (_8720)
  {
    _8719 = mosek::fusion::p_WorkStack::_get_impl(_4052)->sp_base;
  }
  else
  {
    _8719 = _4052->alloci64(_4075);
  }
  int _4106 = _8719;
  int _4107 = mosek::fusion::p_WorkStack::_get_impl(_4052)->cof_base;
  int _4108 = mosek::fusion::p_WorkStack::_get_impl(_4052)->bfix_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4109 = mosek::fusion::p_WorkStack::_get_impl(_4052)->i32;
  _checked_ptr_1<int> _ptr__4109(_4109 ? _4109->raw() : nullptr,_4109 ? _4109->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4110 = mosek::fusion::p_WorkStack::_get_impl(_4052)->i64;
  _checked_ptr_1<long long> _ptr__4110(_4110 ? _4110->raw() : nullptr,_4110 ? _4110->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4111 = mosek::fusion::p_WorkStack::_get_impl(_4052)->f64;
  _checked_ptr_1<double> _ptr__4111(_4111 ? _4111->raw() : nullptr,_4111 ? _4111->size(0) : 0);
  _ptr__4109[_4104] = _4072;
  if ((_4065 > (int)1))
  {
    {
      _ptr__4109[safe_add( _4104,(int)1 )] = _4066;
    }
  }
  {}
  if ((x->numInst() < x->getSize()))
  {
    {
      int _4112 = (int)0;
      int _4113 = (int)0;
      int _4114 = (int)0;
      _ptr__4109[_4103] = (int)0;
      int _8721 = (int)0;
      int _8722 = _4075;
      for (int _4115 = _8721; _4115 < _8722; ++_4115)
      {
        {
          _ptr__4111[safe_add( _4108,_4115 )] = 0.0;
        }
      }
      int _8723 = (int)0;
      int _8724 = _4072;
      for (int _4116 = _8723; _4116 < _8724; ++_4116)
      {
        {
          int _8725 = (int)0;
          int _8726 = _4066;
          for (int _4117 = _8725; _4117 < _8726; ++_4117)
          {
            {
              int _4118 = (int)0;
              int _4119 = _ptr__4076[safe_add( safe_add( _4068,_4117 ),(int)1 )];
              int _4120 = _ptr__4076[safe_add( safe_add( _4063,_4116 ),(int)1 )];
              int _4121 = _ptr__4076[safe_add( _4068,_4117 )];
              int _4122 = _ptr__4076[safe_add( _4063,_4116 )];
              while ( ((_4122 < _4120) && (_4121 < _4119)) )
              {
                {
                  if ((_ptr__4070[_4122] < _ptr__4076[safe_add( _4060,_ptr__4076[safe_add( _4062,_4121 )] )]))
                  {
                    {
                      ++ _4122;
                    }
                  }
                  else if((_ptr__4070[_4122] > _ptr__4076[safe_add( _4060,_ptr__4076[safe_add( _4062,_4121 )] )]))
                  {
                    {
                      ++ _4121;
                    }
                  }
                  else
                  {
                    {
                      _ptr__4110[safe_add( _4105,_4114 )] = _ptr__4077[safe_add( _4058,_ptr__4076[safe_add( _4062,_4121 )] )];
                      _ptr__4111[safe_add( _4107,_4114 )] = _ptr__4071[_4122];
                      ++ _4118;
                      ++ _4114;
                      ++ _4122;
                      ++ _4121;
                    }
                  }
                }
              }
              if ((_4118 > (int)0))
              {
                {
                  _ptr__4109[safe_add( safe_add( _4103,_4113 ),(int)1 )] = _4114;
                  _ptr__4110[safe_add( _4106,_4113 )] = _4112;
                  ++ _4113;
                }
              }
              {}
              ++ _4112;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4123 = (int)0;
      int _4124 = (int)0;
      _ptr__4109[_4103] = (int)0;
      int _4125 = (int)0;
      while ( (_4125 < _4078) )
      {
        {
          int _4126 = safe_add( _4125,(int)1 );
          while ( ((_4126 < _4078) && (_ptr__4069[_4126] == _ptr__4069[_4125])) )
          {
            {
              ++ _4126;
            }
          }
          int _8727 = (int)0;
          int _8728 = _4066;
          for (int _4127 = _8727; _4127 < _8728; ++_4127)
          {
            {
              int _8729 = _4125;
              int _8730 = _4126;
              for (int _4128 = _8729; _4128 < _8730; ++_4128)
              {
                {
                  _ptr__4110[safe_add( _4105,_4123 )] = _ptr__4077[safe_add( safe_add( _4058,safe_mul( _ptr__4070[_4128],_4066 ) ),_4127 )];
                  _ptr__4111[safe_add( _4107,_4123 )] = _ptr__4071[_4128];
                  ++ _4123;
                }
              }
              _ptr__4109[safe_add( safe_add( _4103,_4124 ),(int)1 )] = _4123;
              _ptr__4110[safe_add( _4106,_4124 )] = safe_add( safe_mul( _ptr__4069[_4125],_4066 ),_4127 );
              _ptr__4111[safe_add( _4108,_4124 )] = (int)0;
              ++ _4124;
            }
          }
          _4125 = _4126;
        }
      }
    }
  }
  if ((!_4101))
  {
    {
      _4052->popi64(_4075);
    }
  }
  {}
  _4054->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _4129,int _4130,std::shared_ptr< monty::ndarray< int,1 > > _4131,std::shared_ptr< monty::ndarray< int,1 > > _4132,std::shared_ptr< monty::ndarray< double,1 > > _4133){
  _checked_ptr_1<int> _ptr__4131(_4131 ? _4131->raw() : nullptr, _4131 ? _4131->size(0) : 0);
  _checked_ptr_1<int> _ptr__4132(_4132 ? _4132->raw() : nullptr, _4132 ? _4132->size(0) : 0);
  _checked_ptr_1<double> _ptr__4133(_4133 ? _4133->raw() : nullptr, _4133 ? _4133->size(0) : 0);
  bool _4134 = true;
  {
    int _8731 = (int)0;
    int _8732 = (int)((_4131)->size(0));
    for (int _4135 = _8731; _4135 < _8732; ++_4135)
    {
      {
        if (((_ptr__4131[_4135] < (int)0) || ((_ptr__4131[_4135] >= _4129) || ((_ptr__4132[_4135] < (int)0) || (_ptr__4132[_4135] >= _4130)))))
        {
          {
            _4134 = false;
          }
        }
        {}
      }
    }
    int _8733 = (int)1;
    int _8734 = (int)((_4131)->size(0));
    for (int _4136 = _8733; _4136 < _8734; ++_4136)
    {
      {
        if (((_ptr__4131[(_4136 - (int)1)] > _ptr__4131[_4136]) || ((_ptr__4131[(_4136 - (int)1)] == _ptr__4131[_4136]) && (_ptr__4132[(_4136 - (int)1)] >= _ptr__4132[_4136]))))
        {
          {
            _4134 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_4134))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _4137,int _4138,std::shared_ptr< monty::ndarray< int,1 > > _4139,bool _4140){
  _checked_ptr_1<int> _ptr__4139(_4139 ? _4139->raw() : nullptr, _4139 ? _4139->size(0) : 0);
  if (_4140)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4137),(int)(_ptr__4139[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4139[(int)0]),(int)(_4138)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4141,    int _4142,    std::shared_ptr< monty::ndarray< int,1 > > _4143,    std::shared_ptr< monty::ndarray< int,1 > > _4144,    std::shared_ptr< monty::ndarray< double,1 > > _4145,    monty::rc_ptr< ::mosek::fusion::Variable > _4146){ return new mosek::fusion::ExprMulScalarVar(_4141,_4142,_4143,_4144,_4145,_4146); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4141,    int _4142,    std::shared_ptr< monty::ndarray< int,1 > > _4143,    std::shared_ptr< monty::ndarray< int,1 > > _4144,    std::shared_ptr< monty::ndarray< double,1 > > _4145,    monty::rc_ptr< ::mosek::fusion::Variable > _4146) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4141,_4142,_4143,_4144,_4145,_4146); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4141,    int _4142,    std::shared_ptr< monty::ndarray< int,1 > > _4143,    std::shared_ptr< monty::ndarray< int,1 > > _4144,    std::shared_ptr< monty::ndarray< double,1 > > _4145,    monty::rc_ptr< ::mosek::fusion::Variable > _4146){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4143(_4143 ? _4143->raw() : nullptr, _4143 ? _4143->size(0) : 0);
    _checked_ptr_1<int> _ptr__4144(_4144 ? _4144->raw() : nullptr, _4144 ? _4144->size(0) : 0);
    _checked_ptr_1<double> _ptr__4145(_4145 ? _4145->raw() : nullptr, _4145 ? _4145->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_4141,_4142,::mosek::fusion::Utils::Tools::arraycopy(_4143),::mosek::fusion::Utils::Tools::arraycopy(_4144),::mosek::fusion::Utils::Tools::arraycopy(_4145),_4146,(int)1);
    if ((_4146->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_4141 < (int)0) || ((_4142 < (int)0) || (((int)((_4143)->size(0)) != (int)((_4144)->size(0))) || ((int)((_4143)->size(0)) != (int)((_4145)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    bool _4147 = false;
    int _8735 = (int)0;
    int _8736 = (int)((_4143)->size(0));
    for (int _4148 = _8735; _4148 < _8736; ++_4148)
    {
      {
        if (((_ptr__4143[_4148] < (int)0) || ((_ptr__4143[_4148] >= _4141) || ((_ptr__4144[_4148] < (int)0) || (_ptr__4144[_4148] >= _4142)))))
        {
          {
            _4147 = true;
          }
        }
        {}
      }
    }
    if (_4147)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    bool _4149 = false;
    int _8737 = (int)1;
    int _8738 = (int)((_4143)->size(0));
    for (int _4150 = _8737; _4150 < _8738; ++_4150)
    {
      {
        if (((_ptr__4143[_4150] < _ptr__4143[(_4150 - (int)1)]) || ((_ptr__4143[_4150] == _ptr__4143[(_4150 - (int)1)]) && (_ptr__4144[_4150] <= _ptr__4144[(_4150 - (int)1)]))))
        {
          {
            _4149 = true;
          }
        }
        {}
      }
    }
    if (_4149)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
      }
    }
    {}
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4151,    int _4152,    std::shared_ptr< monty::ndarray< int,1 > > _4153,    std::shared_ptr< monty::ndarray< int,1 > > _4154,    std::shared_ptr< monty::ndarray< double,1 > > _4155,    monty::rc_ptr< ::mosek::fusion::Variable > _4156,    int _4157){ return new mosek::fusion::ExprMulScalarVar(_4151,_4152,_4153,_4154,_4155,_4156,_4157); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4151,    int _4152,    std::shared_ptr< monty::ndarray< int,1 > > _4153,    std::shared_ptr< monty::ndarray< int,1 > > _4154,    std::shared_ptr< monty::ndarray< double,1 > > _4155,    monty::rc_ptr< ::mosek::fusion::Variable > _4156,    int _4157) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4151,_4152,_4153,_4154,_4155,_4156,_4157); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4151,    int _4152,    std::shared_ptr< monty::ndarray< int,1 > > _4153,    std::shared_ptr< monty::ndarray< int,1 > > _4154,    std::shared_ptr< monty::ndarray< double,1 > > _4155,    monty::rc_ptr< ::mosek::fusion::Variable > _4156,    int _4157){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4153(_4153 ? _4153->raw() : nullptr, _4153 ? _4153->size(0) : 0);
    _checked_ptr_1<int> _ptr__4154(_4154 ? _4154->raw() : nullptr, _4154 ? _4154->size(0) : 0);
    _checked_ptr_1<double> _ptr__4155(_4155 ? _4155->raw() : nullptr, _4155 ? _4155->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4151),(int)(_4152)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _4151;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _4152;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _4153;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _4154;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _4155;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _4156;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4158,monty::rc_ptr< ::mosek::fusion::WorkStack > _4159,monty::rc_ptr< ::mosek::fusion::WorkStack > _4160) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_4158,_4159,_4160); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4158,monty::rc_ptr< ::mosek::fusion::WorkStack > _4159,monty::rc_ptr< ::mosek::fusion::WorkStack > _4160){
  if ((x->numInst() == (int)0))
  {
    {
      _4158->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_4158)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4158)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4158)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4158)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4161 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__4161(_4161 ? _4161->raw() : nullptr,_4161 ? _4161->size(0) : 0);
      x->inst((int)0,_4161);
      long long _4162 = _ptr__4161[(int)0];
      int _4163 = (int)((msubi)->size(0));
      int _4164 = _4163;
      bool _4165 = (_4163 < safe_mul( mdimi,mdimj ));
      _4158->alloc_expr((int)2,_4163,_4164,_4165);
      int _4166 = mosek::fusion::p_WorkStack::_get_impl(_4158)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4158)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4158)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4158)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4158)->shape_base,(int)1 ))) = mdimj;
      int _4167 = mosek::fusion::p_WorkStack::_get_impl(_4158)->nidxs_base;
      int _4168 = mosek::fusion::p_WorkStack::_get_impl(_4158)->sp_base;
      int _4169 = mosek::fusion::p_WorkStack::_get_impl(_4158)->cof_base;
      int _4170 = mosek::fusion::p_WorkStack::_get_impl(_4158)->bfix_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4171 = mosek::fusion::p_WorkStack::_get_impl(_4158)->i32;
      _checked_ptr_1<int> _ptr__4171(_4171 ? _4171->raw() : nullptr,_4171 ? _4171->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4172 = mosek::fusion::p_WorkStack::_get_impl(_4158)->i64;
      _checked_ptr_1<long long> _ptr__4172(_4172 ? _4172->raw() : nullptr,_4172 ? _4172->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4173 = mosek::fusion::p_WorkStack::_get_impl(_4158)->f64;
      _checked_ptr_1<double> _ptr__4173(_4173 ? _4173->raw() : nullptr,_4173 ? _4173->size(0) : 0);
      {
        int _8739 = (int)0;
        int _8740 = _4163;
        for (int _4174 = _8739; _4174 < _8740; ++_4174)
        {
          {
            _ptr__4173[safe_add( _4170,_4174 )] = (int)0;
          }
        }
        int _8741 = (int)0;
        int _8742 = _4164;
        for (int _4175 = _8741; _4175 < _8742; ++_4175)
        {
          {
            _ptr__4173[safe_add( _4169,_4175 )] = ((*mcof)(_4175));
          }
        }
        int _8743 = (int)0;
        int _8744 = _4164;
        for (int _4176 = _8743; _4176 < _8744; ++_4176)
        {
          {
            _ptr__4172[safe_add( _4167,_4176 )] = _4162;
          }
        }
        if (_4165)
        {
          {
            int _8745 = (int)0;
            int _8746 = _4163;
            for (int _4177 = _8745; _4177 < _8746; ++_4177)
            {
              {
                _ptr__4172[safe_add( _4168,_4177 )] = safe_add( safe_mul( ((*msubi)(_4177)),mdimj ),((*msubj)(_4177)) );
              }
            }
          }
        }
        {}
        int _8747 = (int)0;
        int _8748 = safe_add( _4163,(int)1 );
        for (int _4178 = _8747; _4178 < _8748; ++_4178)
        {
          {
            _ptr__4171[safe_add( _4166,_4178 )] = _4178;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4179,    double _4180){ return new mosek::fusion::ExprMulVarScalarConst(_4179,_4180); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4179,    double _4180) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_4179,_4180); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4179,    double _4180){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4179->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _4179;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _4180;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4181,monty::rc_ptr< ::mosek::fusion::WorkStack > _4182,monty::rc_ptr< ::mosek::fusion::WorkStack > _4183) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_4181,_4182,_4183); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4181,monty::rc_ptr< ::mosek::fusion::WorkStack > _4182,monty::rc_ptr< ::mosek::fusion::WorkStack > _4183){
  int _4184 = x->numInst();
  int _4185 = _4184;
  std::shared_ptr< monty::ndarray< int,1 > > _4186 = x->getShape();
  _checked_ptr_1<int> _ptr__4186(_4186 ? _4186->raw() : nullptr,_4186 ? _4186->size(0) : 0);
  int _4187 = (int)((_4186)->size(0));
  int _4188 = _4181->alloci32(safe_add( _4185,(int)1 ));
  int _4189 = _4181->alloci64(_4184);
  bool _4190 = (::mosek::fusion::p_Set::size(_4186) > _4185);
  int _8749;
  bool _8750 = _4190;
  if (_8750)
  {
    _8749 = _4181->alloci64(_4185);
  }
  else
  {
    _8749 = (int)0;
  }
  int _4191 = _8749;
  int _4192 = _4181->allocf64(_4184);
  int _4193 = _4181->allocf64(_4185);
  if (_4190)
  {
    {
      x->inst(_4191,mosek::fusion::p_WorkStack::_get_impl(_4181)->i64,_4189,mosek::fusion::p_WorkStack::_get_impl(_4181)->i64);
    }
  }
  else
  {
    {
      x->inst(_4189,mosek::fusion::p_WorkStack::_get_impl(_4181)->i64);
    }
  }
  int _8751;
  bool _8752 = _4190;
  if (_8752)
  {
    _8751 = (int)1;
  }
  else
  {
    _8751 = (int)0;
  }
  _4181->pushi32(_8751);
  _4181->pushi32(_4185);
  _4181->pushi32(_4184);
  int _8753 = (int)0;
  int _8754 = _4187;
  for (int _4194 = _8753; _4194 < _8754; ++_4194)
  {
    {
      _4181->pushi32(_ptr__4186[_4194]);
    }
  }
  _4181->pushi32(_4187);
  std::shared_ptr< monty::ndarray< int,1 > > _4195 = mosek::fusion::p_WorkStack::_get_impl(_4181)->i32;
  _checked_ptr_1<int> _ptr__4195(_4195 ? _4195->raw() : nullptr,_4195 ? _4195->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4196 = mosek::fusion::p_WorkStack::_get_impl(_4181)->i64;
  _checked_ptr_1<long long> _ptr__4196(_4196 ? _4196->raw() : nullptr,_4196 ? _4196->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4197 = mosek::fusion::p_WorkStack::_get_impl(_4181)->f64;
  _checked_ptr_1<double> _ptr__4197(_4197 ? _4197->raw() : nullptr,_4197 ? _4197->size(0) : 0);
  {
    int _8755 = (int)0;
    int _8756 = safe_add( _4185,(int)1 );
    for (int _4198 = _8755; _4198 < _8756; ++_4198)
    {
      {
        _ptr__4195[safe_add( _4188,_4198 )] = _4198;
      }
    }
    int _8757 = (int)0;
    int _8758 = _4184;
    for (int _4199 = _8757; _4199 < _8758; ++_4199)
    {
      {
        _ptr__4197[safe_add( _4192,_4199 )] = 1.0;
      }
    }
    int _8759 = (int)0;
    int _8760 = _4185;
    for (int _4200 = _8759; _4200 < _8760; ++_4200)
    {
      {
        _ptr__4197[safe_add( _4193,_4200 )] = 0.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4201,    monty::rc_ptr< ::mosek::fusion::Expression > _4202,    double _4203,    double _4204){ return new mosek::fusion::ExprAdd(_4201,_4202,_4203,_4204); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4201,    monty::rc_ptr< ::mosek::fusion::Expression > _4202,    double _4203,    double _4204) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_4201,_4202,_4203,_4204); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4201,    monty::rc_ptr< ::mosek::fusion::Expression > _4202,    double _4203,    double _4204){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4201->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _4201;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _4202;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _4203;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _4204;
    if ((_4201->getND() != _4202->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _8761 = (int)0;
    int _8762 = _4201->getND();
    for (int _4205 = _8761; _4205 < _8762; ++_4205)
    {
      {
        if ((_4201->getDim(_4205) != _4202->getDim(_4205)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4206,monty::rc_ptr< ::mosek::fusion::WorkStack > _4207,monty::rc_ptr< ::mosek::fusion::WorkStack > _4208) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_4206,_4207,_4208); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4206,monty::rc_ptr< ::mosek::fusion::WorkStack > _4207,monty::rc_ptr< ::mosek::fusion::WorkStack > _4208){
  e1->eval(_4207,_4206,_4208);
  e2->eval(_4207,_4206,_4208);
  _4207->pop_expr();
  int _4209 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nd;
  int _4210 = mosek::fusion::p_WorkStack::_get_impl(_4207)->shape_base;
  int _4211 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nelem;
  int _4212 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nnz;
  bool _4213 = mosek::fusion::p_WorkStack::_get_impl(_4207)->hassp;
  int _4214 = mosek::fusion::p_WorkStack::_get_impl(_4207)->ptr_base;
  int _4215 = mosek::fusion::p_WorkStack::_get_impl(_4207)->sp_base;
  int _4216 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nidxs_base;
  int _4217 = mosek::fusion::p_WorkStack::_get_impl(_4207)->bfix_base;
  int _4218 = mosek::fusion::p_WorkStack::_get_impl(_4207)->cof_base;
  _4207->pop_expr();
  int _4219 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nd;
  int _4220 = mosek::fusion::p_WorkStack::_get_impl(_4207)->shape_base;
  int _4221 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nelem;
  int _4222 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nnz;
  bool _4223 = mosek::fusion::p_WorkStack::_get_impl(_4207)->hassp;
  int _4224 = mosek::fusion::p_WorkStack::_get_impl(_4207)->ptr_base;
  int _4225 = mosek::fusion::p_WorkStack::_get_impl(_4207)->sp_base;
  int _4226 = mosek::fusion::p_WorkStack::_get_impl(_4207)->nidxs_base;
  int _4227 = mosek::fusion::p_WorkStack::_get_impl(_4207)->bfix_base;
  int _4228 = mosek::fusion::p_WorkStack::_get_impl(_4207)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4229 = mosek::fusion::p_WorkStack::_get_impl(_4207)->i32;
  _checked_ptr_1<int> _ptr__4229(_4229 ? _4229->raw() : nullptr,_4229 ? _4229->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4230 = mosek::fusion::p_WorkStack::_get_impl(_4207)->i64;
  _checked_ptr_1<long long> _ptr__4230(_4230 ? _4230->raw() : nullptr,_4230 ? _4230->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4231 = mosek::fusion::p_WorkStack::_get_impl(_4207)->f64;
  _checked_ptr_1<double> _ptr__4231(_4231 ? _4231->raw() : nullptr,_4231 ? _4231->size(0) : 0);
  if ((_4219 != _4209))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _8763 = (int)0;
  int _8764 = _4219;
  for (int _4232 = _8763; _4232 < _8764; ++_4232)
  {
    {
      if ((_ptr__4229[safe_add( _4220,_4232 )] != _ptr__4229[safe_add( _4210,_4232 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_4223) && (!_4213)))
  {
    {
      int _4233 = _4221;
      int _4234 = safe_add( _4222,_4212 );
      int _4235 = _4219;
      _4206->alloc_expr(_4235,_4233,_4234,false);
      int _4236 = mosek::fusion::p_WorkStack::_get_impl(_4206)->shape_base;
      int _4237 = mosek::fusion::p_WorkStack::_get_impl(_4206)->ptr_base;
      int _4238 = mosek::fusion::p_WorkStack::_get_impl(_4206)->sp_base;
      int _4239 = mosek::fusion::p_WorkStack::_get_impl(_4206)->nidxs_base;
      int _4240 = mosek::fusion::p_WorkStack::_get_impl(_4206)->bfix_base;
      int _4241 = mosek::fusion::p_WorkStack::_get_impl(_4206)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4242 = mosek::fusion::p_WorkStack::_get_impl(_4206)->i32;
      _checked_ptr_1<int> _ptr__4242(_4242 ? _4242->raw() : nullptr,_4242 ? _4242->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4243 = mosek::fusion::p_WorkStack::_get_impl(_4206)->i64;
      _checked_ptr_1<long long> _ptr__4243(_4243 ? _4243->raw() : nullptr,_4243 ? _4243->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4244 = mosek::fusion::p_WorkStack::_get_impl(_4206)->f64;
      _checked_ptr_1<double> _ptr__4244(_4244 ? _4244->raw() : nullptr,_4244 ? _4244->size(0) : 0);
      int _8765 = (int)0;
      int _8766 = _4235;
      for (int _4245 = _8765; _4245 < _8766; ++_4245)
      {
        {
          _ptr__4242[safe_add( _4236,_4245 )] = _ptr__4229[safe_add( _4220,_4245 )];
        }
      }
      int _4246 = (int)0;
      _ptr__4242[_4237] = (int)0;
      int _8767 = (int)0;
      int _8768 = _4233;
      for (int _4247 = _8767; _4247 < _8768; ++_4247)
      {
        {
          int _8769 = _ptr__4229[safe_add( _4224,_4247 )];
          int _8770 = _ptr__4229[safe_add( safe_add( _4224,_4247 ),(int)1 )];
          for (int _4248 = _8769; _4248 < _8770; ++_4248)
          {
            {
              _ptr__4243[safe_add( _4239,_4246 )] = _ptr__4230[safe_add( _4226,_4248 )];
              _ptr__4244[safe_add( _4241,_4246 )] = (_ptr__4231[safe_add( _4228,_4248 )] * m1);
              ++ _4246;
            }
          }
          int _8771 = _ptr__4229[safe_add( _4214,_4247 )];
          int _8772 = _ptr__4229[safe_add( safe_add( _4214,_4247 ),(int)1 )];
          for (int _4249 = _8771; _4249 < _8772; ++_4249)
          {
            {
              _ptr__4243[safe_add( _4239,_4246 )] = _ptr__4230[safe_add( _4216,_4249 )];
              _ptr__4244[safe_add( _4241,_4246 )] = (_ptr__4231[safe_add( _4218,_4249 )] * m2);
              ++ _4246;
            }
          }
          _ptr__4242[safe_add( safe_add( _4237,_4247 ),(int)1 )] = _4246;
          _ptr__4244[safe_add( _4240,_4247 )] = ((_ptr__4231[safe_add( _4227,_4247 )] * m1) + (_ptr__4231[safe_add( _4217,_4247 )] * m2));
        }
      }
    }
  }
  else if(((!_4223) || (!_4213)))
  {
    {
      if ((!_4213))
      {
        {
          int _4250 = _4211;
          int _4251 = _4212;
          int _4252 = _4214;
          int _4253 = _4215;
          int _4254 = _4216;
          int _4255 = _4217;
          int _4256 = _4218;
          _4211 = _4221;
          _4212 = _4222;
          _4214 = _4224;
          _4215 = _4225;
          _4216 = _4226;
          _4217 = _4227;
          _4218 = _4228;
          _4221 = _4250;
          _4222 = _4251;
          _4224 = _4252;
          _4225 = _4253;
          _4226 = _4254;
          _4227 = _4255;
          _4228 = _4256;
        }
      }
      {}
      double _8773;
      bool _8774 = (!_4223);
      if (_8774)
      {
        _8773 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      else
      {
        _8773 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      double _4257 = _8773;
      double _8775;
      bool _8776 = (!_4223);
      if (_8776)
      {
        _8775 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      else
      {
        _8775 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      double _4258 = _8775;
      int _4259 = _4221;
      int _4260 = safe_add( _4222,_4212 );
      int _4261 = _4219;
      _4206->alloc_expr(_4261,_4259,_4260,false);
      int _4262 = mosek::fusion::p_WorkStack::_get_impl(_4206)->shape_base;
      int _4263 = mosek::fusion::p_WorkStack::_get_impl(_4206)->ptr_base;
      int _4264 = mosek::fusion::p_WorkStack::_get_impl(_4206)->sp_base;
      int _4265 = mosek::fusion::p_WorkStack::_get_impl(_4206)->nidxs_base;
      int _4266 = mosek::fusion::p_WorkStack::_get_impl(_4206)->bfix_base;
      int _4267 = mosek::fusion::p_WorkStack::_get_impl(_4206)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4268 = mosek::fusion::p_WorkStack::_get_impl(_4206)->i32;
      _checked_ptr_1<int> _ptr__4268(_4268 ? _4268->raw() : nullptr,_4268 ? _4268->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4269 = mosek::fusion::p_WorkStack::_get_impl(_4206)->i64;
      _checked_ptr_1<long long> _ptr__4269(_4269 ? _4269->raw() : nullptr,_4269 ? _4269->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4270 = mosek::fusion::p_WorkStack::_get_impl(_4206)->f64;
      _checked_ptr_1<double> _ptr__4270(_4270 ? _4270->raw() : nullptr,_4270 ? _4270->size(0) : 0);
      {
        int _4271 = (int)0;
        int _8777 = (int)0;
        int _8778 = _4261;
        for (int _4272 = _8777; _4272 < _8778; ++_4272)
        {
          {
            _ptr__4268[safe_add( _4262,_4272 )] = _ptr__4229[safe_add( _4220,_4272 )];
          }
        }
        int _8779 = (int)0;
        int _8780 = safe_add( _4259,(int)1 );
        for (int _4273 = _8779; _4273 < _8780; ++_4273)
        {
          {
            _ptr__4268[safe_add( _4263,_4273 )] = (int)0;
          }
        }
        int _8781 = (int)0;
        int _8782 = _4221;
        for (int _4274 = _8781; _4274 < _8782; ++_4274)
        {
          {
            _ptr__4268[safe_add( safe_add( _4263,_4274 ),(int)1 )] += (_ptr__4229[safe_add( safe_add( _4224,_4274 ),(int)1 )] - _ptr__4229[safe_add( _4224,_4274 )]);
          }
        }
        int _8783 = (int)0;
        int _8784 = _4211;
        for (int _4275 = _8783; _4275 < _8784; ++_4275)
        {
          {
            long long _4276 = _ptr__4230[safe_add( _4215,_4275 )];
            _ptr__4268[safe_add( safe_add( _4263,_4276 ),(int)1 )] += (_ptr__4229[safe_add( safe_add( _4214,_4275 ),(int)1 )] - _ptr__4229[safe_add( _4214,_4275 )]);
          }
        }
        int _8785 = (int)0;
        int _8786 = _4259;
        for (int _4277 = _8785; _4277 < _8786; ++_4277)
        {
          {
            _ptr__4268[safe_add( safe_add( _4263,_4277 ),(int)1 )] += _ptr__4268[safe_add( _4263,_4277 )];
          }
        }
        int _8787 = (int)0;
        int _8788 = _4221;
        for (int _4278 = _8787; _4278 < _8788; ++_4278)
        {
          {
            int _4279 = _ptr__4268[safe_add( _4263,_4278 )];
            int _4280 = _ptr__4229[safe_add( _4224,_4278 )];
            int _4281 = (_ptr__4229[safe_add( safe_add( _4224,_4278 ),(int)1 )] - _ptr__4229[safe_add( _4224,_4278 )]);
            int _8789 = (int)0;
            int _8790 = _4281;
            for (int _4282 = _8789; _4282 < _8790; ++_4282)
            {
              {
                _ptr__4269[safe_add( safe_add( _4265,_4279 ),_4282 )] = _ptr__4230[safe_add( safe_add( _4226,_4280 ),_4282 )];
                _ptr__4270[safe_add( safe_add( _4267,_4279 ),_4282 )] = (_ptr__4231[safe_add( safe_add( _4228,_4280 ),_4282 )] * _4257);
              }
            }
            _ptr__4268[safe_add( _4263,_4278 )] += _4281;
            _ptr__4270[safe_add( _4266,_4278 )] = (_ptr__4231[safe_add( _4227,_4278 )] * _4257);
          }
        }
        int _8791 = (int)0;
        int _8792 = _4211;
        for (int _4283 = _8791; _4283 < _8792; ++_4283)
        {
          {
            long long _4284 = _ptr__4230[safe_add( _4215,_4283 )];
            int _4285 = _ptr__4268[safe_add( _4263,_4284 )];
            int _4286 = _ptr__4229[safe_add( _4214,_4283 )];
            int _4287 = (_ptr__4229[safe_add( safe_add( _4214,_4283 ),(int)1 )] - _ptr__4229[safe_add( _4214,_4283 )]);
            int _8793 = (int)0;
            int _8794 = _4287;
            for (int _4288 = _8793; _4288 < _8794; ++_4288)
            {
              {
                _ptr__4269[safe_add( safe_add( _4265,_4285 ),_4288 )] = _ptr__4230[safe_add( safe_add( _4216,_4286 ),_4288 )];
                _ptr__4270[safe_add( safe_add( _4267,_4285 ),_4288 )] = (_ptr__4231[safe_add( safe_add( _4218,_4286 ),_4288 )] * _4258);
              }
            }
            _ptr__4268[safe_add( _4263,_4284 )] += _4287;
            _ptr__4270[safe_add( _4266,_4284 )] += (_ptr__4231[safe_add( _4217,_4283 )] * _4258);
          }
        }
        int _8795 = (int)0;
        int _8796 = _4259;
        for (int _4289 = _8795; _4289 < _8796; ++_4289)
        {
          {
            _ptr__4268[(safe_add( _4263,_4259 ) - _4289)] = _ptr__4268[((safe_add( _4263,_4259 ) - _4289) - (int)1)];
          }
        }
        _ptr__4268[_4263] = (int)0;
      }
    }
  }
  else
  {
    {
      int _4290 = safe_add( _4222,_4212 );
      int _4291 = (int)0;
      int _4292 = _4219;
      long long _4293 = (long long)1;
      int _8797 = (int)0;
      int _8798 = _4292;
      for (int _4294 = _8797; _4294 < _8798; ++_4294)
      {
        {
          _4293 *= _ptr__4229[safe_add( _4220,_4294 )];
        }
      }
      {
        int _4295 = (int)0;
        int _4296 = (int)0;
        while ( ((_4296 < _4221) && (_4295 < _4211)) )
        {
          {
            if ((_ptr__4230[safe_add( _4225,_4296 )] < _ptr__4230[safe_add( _4215,_4295 )]))
            {
              {
                ++ _4291;
                ++ _4296;
              }
            }
            else if((_ptr__4230[safe_add( _4225,_4296 )] > _ptr__4230[safe_add( _4215,_4295 )]))
            {
              {
                ++ _4291;
                ++ _4295;
              }
            }
            else
            {
              {
                ++ _4291;
                ++ _4296;
                ++ _4295;
              }
            }
          }
        }
        _4291 += (safe_add( (_4221 - _4296),_4211 ) - _4295);
      }
      bool _4297 = (_4291 < _4293);
      _4206->alloc_expr(_4292,_4291,_4290,_4297);
      int _4298 = mosek::fusion::p_WorkStack::_get_impl(_4206)->shape_base;
      int _4299 = mosek::fusion::p_WorkStack::_get_impl(_4206)->ptr_base;
      int _8799;
      bool _8800 = _4297;
      if (_8800)
      {
        _8799 = mosek::fusion::p_WorkStack::_get_impl(_4206)->sp_base;
      }
      else
      {
        _8799 = _4206->alloci64(_4291);
      }
      int _4300 = _8799;
      int _4301 = mosek::fusion::p_WorkStack::_get_impl(_4206)->nidxs_base;
      int _4302 = mosek::fusion::p_WorkStack::_get_impl(_4206)->bfix_base;
      int _4303 = mosek::fusion::p_WorkStack::_get_impl(_4206)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4304 = mosek::fusion::p_WorkStack::_get_impl(_4206)->i32;
      _checked_ptr_1<int> _ptr__4304(_4304 ? _4304->raw() : nullptr,_4304 ? _4304->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4305 = mosek::fusion::p_WorkStack::_get_impl(_4206)->i64;
      _checked_ptr_1<long long> _ptr__4305(_4305 ? _4305->raw() : nullptr,_4305 ? _4305->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4306 = mosek::fusion::p_WorkStack::_get_impl(_4206)->f64;
      _checked_ptr_1<double> _ptr__4306(_4306 ? _4306->raw() : nullptr,_4306 ? _4306->size(0) : 0);
      int _8801 = (int)0;
      int _8802 = _4292;
      for (int _4307 = _8801; _4307 < _8802; ++_4307)
      {
        {
          _ptr__4304[safe_add( _4298,_4307 )] = _ptr__4229[safe_add( _4220,_4307 )];
        }
      }
      {
        _ptr__4304[_4299] = (int)0;
        int _4308 = (int)0;
        int _4309 = (int)0;
        int _4310 = (int)0;
        int _4311 = (int)0;
        while ( ((_4311 < _4221) && (_4310 < _4211)) )
        {
          {
            if ((_ptr__4230[safe_add( _4225,_4311 )] < _ptr__4230[safe_add( _4215,_4310 )]))
            {
              {
                int _8803 = _ptr__4229[safe_add( _4224,_4311 )];
                int _8804 = _ptr__4229[safe_add( safe_add( _4224,_4311 ),(int)1 )];
                for (int _4312 = _8803; _4312 < _8804; ++_4312)
                {
                  {
                    _ptr__4305[safe_add( _4301,_4309 )] = _ptr__4230[safe_add( _4226,_4312 )];
                    _ptr__4306[safe_add( _4303,_4309 )] = (m1 * _ptr__4231[safe_add( _4228,_4312 )]);
                    ++ _4309;
                  }
                }
                _ptr__4306[safe_add( _4302,_4308 )] = (m1 * _ptr__4231[safe_add( _4227,_4311 )]);
                _ptr__4305[safe_add( _4300,_4308 )] = _ptr__4230[safe_add( _4225,_4311 )];
                _ptr__4304[safe_add( safe_add( _4299,_4308 ),(int)1 )] = _4309;
                ++ _4308;
                ++ _4311;
              }
            }
            else if((_ptr__4230[safe_add( _4215,_4310 )] < _ptr__4230[safe_add( _4225,_4311 )]))
            {
              {
                int _8805 = _ptr__4229[safe_add( _4214,_4310 )];
                int _8806 = _ptr__4229[safe_add( safe_add( _4214,_4310 ),(int)1 )];
                for (int _4313 = _8805; _4313 < _8806; ++_4313)
                {
                  {
                    _ptr__4305[safe_add( _4301,_4309 )] = _ptr__4230[safe_add( _4216,_4313 )];
                    _ptr__4306[safe_add( _4303,_4309 )] = (m2 * _ptr__4231[safe_add( _4218,_4313 )]);
                    ++ _4309;
                  }
                }
                _ptr__4306[safe_add( _4302,_4308 )] = (m1 * _ptr__4231[safe_add( _4217,_4311 )]);
                _ptr__4305[safe_add( _4300,_4308 )] = _ptr__4230[safe_add( _4215,_4310 )];
                _ptr__4304[safe_add( safe_add( _4299,_4308 ),(int)1 )] = _4309;
                ++ _4308;
                ++ _4310;
              }
            }
            else
            {
              {
                int _8807 = _ptr__4229[safe_add( _4224,_4311 )];
                int _8808 = _ptr__4229[safe_add( safe_add( _4224,_4311 ),(int)1 )];
                for (int _4314 = _8807; _4314 < _8808; ++_4314)
                {
                  {
                    _ptr__4305[safe_add( _4301,_4309 )] = _ptr__4230[safe_add( _4226,_4314 )];
                    _ptr__4306[safe_add( _4303,_4309 )] = (m1 * _ptr__4231[safe_add( _4228,_4314 )]);
                    ++ _4309;
                  }
                }
                int _8809 = _ptr__4229[safe_add( _4214,_4310 )];
                int _8810 = _ptr__4229[safe_add( safe_add( _4214,_4310 ),(int)1 )];
                for (int _4315 = _8809; _4315 < _8810; ++_4315)
                {
                  {
                    _ptr__4305[safe_add( _4301,_4309 )] = _ptr__4230[safe_add( _4216,_4315 )];
                    _ptr__4306[safe_add( _4303,_4309 )] = (m2 * _ptr__4231[safe_add( _4218,_4315 )]);
                    ++ _4309;
                  }
                }
                _ptr__4306[safe_add( _4302,_4308 )] = ((m1 * _ptr__4231[safe_add( _4227,_4311 )]) + (m2 * _ptr__4231[safe_add( _4217,_4310 )]));
                _ptr__4305[safe_add( _4300,_4308 )] = _ptr__4230[safe_add( _4225,_4311 )];
                _ptr__4304[safe_add( safe_add( _4299,_4308 ),(int)1 )] = _4309;
                ++ _4308;
                ++ _4311;
                ++ _4310;
              }
            }
          }
        }
        while ( (_4311 < _4221) )
        {
          {
            int _8811 = _ptr__4229[safe_add( _4224,_4311 )];
            int _8812 = _ptr__4229[safe_add( safe_add( _4224,_4311 ),(int)1 )];
            for (int _4316 = _8811; _4316 < _8812; ++_4316)
            {
              {
                _ptr__4305[safe_add( _4301,_4309 )] = _ptr__4230[safe_add( _4226,_4316 )];
                _ptr__4306[safe_add( _4303,_4309 )] = (m1 * _ptr__4231[safe_add( _4228,_4316 )]);
                ++ _4309;
              }
            }
            _ptr__4306[safe_add( _4302,_4308 )] = (m1 * _ptr__4231[safe_add( _4227,_4311 )]);
            _ptr__4305[safe_add( _4300,_4308 )] = _ptr__4230[safe_add( _4225,_4311 )];
            _ptr__4304[safe_add( safe_add( _4299,_4308 ),(int)1 )] = _4309;
            ++ _4308;
            ++ _4311;
          }
        }
        while ( (_4310 < _4211) )
        {
          {
            int _8813 = _ptr__4229[safe_add( _4214,_4310 )];
            int _8814 = _ptr__4229[safe_add( safe_add( _4214,_4310 ),(int)1 )];
            for (int _4317 = _8813; _4317 < _8814; ++_4317)
            {
              {
                _ptr__4305[safe_add( _4301,_4309 )] = _ptr__4230[safe_add( _4216,_4317 )];
                _ptr__4306[safe_add( _4303,_4309 )] = (m2 * _ptr__4231[safe_add( _4218,_4317 )]);
                ++ _4309;
              }
            }
            _ptr__4306[safe_add( _4302,_4308 )] = (m1 * _ptr__4231[safe_add( _4217,_4310 )]);
            _ptr__4305[safe_add( _4300,_4308 )] = _ptr__4230[safe_add( _4215,_4310 )];
            _ptr__4304[safe_add( safe_add( _4299,_4308 ),(int)1 )] = _4309;
            ++ _4308;
            ++ _4310;
          }
        }
      }
      if ((!_4297))
      {
        {
          _4206->popi64(_4291);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4318,    std::shared_ptr< monty::ndarray< double,1 > > _4319){ return new mosek::fusion::ExprWSum(_4318,_4319); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4318,    std::shared_ptr< monty::ndarray< double,1 > > _4319) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_4318,_4319); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4318,    std::shared_ptr< monty::ndarray< double,1 > > _4319){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__4319(_4319 ? _4319->raw() : nullptr, _4319 ? _4319->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_4318)((int)0))->getShape());
    if (((int)((_4319)->size(0)) != (int)((_4318)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_4319);
    std::shared_ptr< monty::ndarray< int,1 > > _4320 = ((*_4318)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__4320(_4320 ? _4320->raw() : nullptr,_4320 ? _4320->size(0) : 0);
    int _4321 = (int)((_4320)->size(0));
    int _8815 = (int)1;
    int _8816 = (int)((_4318)->size(0));
    for (int _4322 = _8815; _4322 < _8816; ++_4322)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4323 = ((*_4318)(_4322))->getShape();
        _checked_ptr_1<int> _ptr__4323(_4323 ? _4323->raw() : nullptr,_4323 ? _4323->size(0) : 0);
        if ((_4321 != (int)((_4323)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _8817 = (int)0;
            int _8818 = _4321;
            for (int _4324 = _8817; _4324 < _8818; ++_4324)
            {
              {
                if ((_ptr__4320[_4324] != _ptr__4323[_4324]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8819;
    for (int _4325 = (int)0, _8820 = (int)((_4318)->size(0)); _4325 < _8820 ; ++_4325)
    {
      _8819.push_back(((*_4318)(_4325)));
    }
    auto _8821 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8819.size()),_8819.begin(),_8819.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _8821;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4326,monty::rc_ptr< ::mosek::fusion::WorkStack > _4327,monty::rc_ptr< ::mosek::fusion::WorkStack > _4328) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_4326,_4327,_4328); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4326,monty::rc_ptr< ::mosek::fusion::WorkStack > _4327,monty::rc_ptr< ::mosek::fusion::WorkStack > _4328){
  int _4329 = (int)((es)->size(0));
  int _8822 = (int)0;
  int _8823 = _4329;
  for (int _4330 = _8822; _4330 < _8823; ++_4330)
  {
    {
      ((*es)(_4330))->eval(_4327,_4326,_4328);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4331 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4331(_4331 ? _4331->raw() : nullptr,_4331 ? _4331->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4332 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4332(_4332 ? _4332->raw() : nullptr,_4332 ? _4332->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4333 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4333(_4333 ? _4333->raw() : nullptr,_4333 ? _4333->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4334 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4334(_4334 ? _4334->raw() : nullptr,_4334 ? _4334->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4335 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4335(_4335 ? _4335->raw() : nullptr,_4335 ? _4335->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4336 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4336(_4336 ? _4336->raw() : nullptr,_4336 ? _4336->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4337 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
  _checked_ptr_1<int> _ptr__4337(_4337 ? _4337->raw() : nullptr,_4337 ? _4337->size(0) : 0);
  int _4338 = _4327->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4339 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4338)));
  _checked_ptr_1<int> _ptr__4339(_4339 ? _4339->raw() : nullptr,_4339 ? _4339->size(0) : 0);
  _4327->popi32(_4338,_4339,(int)0);
  {
    _ptr__4331[(_4329 - (int)1)] = _4327->popi32();
    _ptr__4332[(_4329 - (int)1)] = _4327->popi32();
    bool _4340 = (_4327->popi32() != (int)0);
    _ptr__4333[(_4329 - (int)1)] = _4327->popi32(safe_add( _ptr__4331[(_4329 - (int)1)],(int)1 ));
    int _8824;
    bool _8825 = _4340;
    if (_8825)
    {
      _8824 = _4327->popi64(_ptr__4331[(_4329 - (int)1)]);
    }
    else
    {
      _8824 = (-(int)1);
    }
    _ptr__4335[(_4329 - (int)1)] = _8824;
    _ptr__4334[(_4329 - (int)1)] = _4327->popi64(_ptr__4332[(_4329 - (int)1)]);
    _ptr__4337[(_4329 - (int)1)] = _4327->popf64(_ptr__4331[(_4329 - (int)1)]);
    _ptr__4336[(_4329 - (int)1)] = _4327->popf64(_ptr__4332[(_4329 - (int)1)]);
  }
  int _8826 = (int)1;
  int _8827 = _4329;
  for (int _4341 = _8826; _4341 < _8827; ++_4341)
  {
    {
      int _4342 = ((_4329 - _4341) - (int)1);
      _4327->popi32();
      _4327->popi32(_4338);
      _ptr__4331[_4342] = _4327->popi32();
      _ptr__4332[_4342] = _4327->popi32();
      bool _4343 = (_4327->popi32() != (int)0);
      _ptr__4333[_4342] = _4327->popi32(safe_add( _ptr__4331[_4342],(int)1 ));
      int _8828;
      bool _8829 = _4343;
      if (_8829)
      {
        _8828 = _4327->popi64(_ptr__4331[_4342]);
      }
      else
      {
        _8828 = (-(int)1);
      }
      _ptr__4335[_4342] = _8828;
      _ptr__4334[_4342] = _4327->popi64(_ptr__4332[_4342]);
      _ptr__4337[_4342] = _4327->popf64(_ptr__4331[_4342]);
      _ptr__4336[_4342] = _4327->popf64(_ptr__4332[_4342]);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4344 = mosek::fusion::p_WorkStack::_get_impl(_4327)->i32;
  _checked_ptr_1<int> _ptr__4344(_4344 ? _4344->raw() : nullptr,_4344 ? _4344->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4345 = mosek::fusion::p_WorkStack::_get_impl(_4327)->i64;
  _checked_ptr_1<long long> _ptr__4345(_4345 ? _4345->raw() : nullptr,_4345 ? _4345->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4346 = mosek::fusion::p_WorkStack::_get_impl(_4327)->f64;
  _checked_ptr_1<double> _ptr__4346(_4346 ? _4346->raw() : nullptr,_4346 ? _4346->size(0) : 0);
  bool _4347 = false;
  int _8830 = (int)0;
  int _8831 = _4329;
  for (int _4348 = _8830; _4348 < _8831; ++_4348)
  {
    {
      if ((_ptr__4335[_4348] < (int)0))
      {
        {
          _4347 = true;
        }
      }
      {}
    }
  }
  int _4349 = (int)0;
  int _4350 = (int)0;
  if (_4347)
  {
    {
      _4349 = (int)::mosek::fusion::p_Set::size(_4339);
      int _8832 = (int)0;
      int _8833 = _4329;
      for (int _4351 = _8832; _4351 < _8833; ++_4351)
      {
        {
          _4350 += _ptr__4332[_4351];
        }
      }
    }
  }
  else
  {
    {
      bool _4352 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4353 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
      _checked_ptr_1<int> _ptr__4353(_4353 ? _4353->raw() : nullptr,_4353 ? _4353->size(0) : 0);
      int _8834 = (int)0;
      int _8835 = _4329;
      for (int _4354 = _8834; _4354 < _8835; ++_4354)
      {
        {
          _4350 += _ptr__4332[_4354];
        }
      }
      while ( (!_4352) )
      {
        {
          long long _4355 = (-(int)1);
          int _8836 = (int)0;
          int _8837 = _4329;
          for (int _4356 = _8836; _4356 < _8837; ++_4356)
          {
            {
              if (((_ptr__4353[_4356] < _ptr__4331[_4356]) && ((_4355 < (int)0) || (_ptr__4345[safe_add( _ptr__4335[_4356],_ptr__4353[_4356] )] < _4355))))
              {
                {
                  _4355 = _ptr__4345[safe_add( _ptr__4335[_4356],_ptr__4353[_4356] )];
                }
              }
              {}
            }
          }
          if ((_4355 < (int)0))
          {
            {
              _4352 = true;
            }
          }
          else
          {
            {
              int _8838 = (int)0;
              int _8839 = _4329;
              for (int _4357 = _8838; _4357 < _8839; ++_4357)
              {
                {
                  if (((_ptr__4353[_4357] < _ptr__4331[_4357]) && (_4355 == _ptr__4345[safe_add( _ptr__4335[_4357],_ptr__4353[_4357] )])))
                  {
                    {
                      ++ _ptr__4353[_4357];
                    }
                  }
                  {}
                }
              }
              ++ _4349;
            }
          }
        }
      }
    }
  }
  int _4358 = _4326->alloci32(safe_add( _4349,(int)1 ));
  int _4359 = _4326->alloci64(_4350);
  int _8840;
  bool _8841 = (!_4347);
  if (_8841)
  {
    _8840 = _4326->alloci64(_4349);
  }
  else
  {
    _8840 = (-(int)1);
  }
  int _4360 = _8840;
  int _4361 = _4326->allocf64(_4350);
  int _4362 = _4326->allocf64(_4349);
  int _8842;
  bool _8843 = _4347;
  if (_8843)
  {
    _8842 = (int)0;
  }
  else
  {
    _8842 = (int)1;
  }
  _4326->pushi32(_8842);
  _4326->pushi32(_4350);
  _4326->pushi32(_4349);
  int _8844 = (int)0;
  int _8845 = _4338;
  for (int _4363 = _8844; _4363 < _8845; ++_4363)
  {
    {
      _4326->pushi32(_ptr__4339[_4363]);
    }
  }
  _4326->pushi32(_4338);
  std::shared_ptr< monty::ndarray< int,1 > > _4364 = mosek::fusion::p_WorkStack::_get_impl(_4326)->i32;
  _checked_ptr_1<int> _ptr__4364(_4364 ? _4364->raw() : nullptr,_4364 ? _4364->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4365 = mosek::fusion::p_WorkStack::_get_impl(_4326)->i64;
  _checked_ptr_1<long long> _ptr__4365(_4365 ? _4365->raw() : nullptr,_4365 ? _4365->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4366 = mosek::fusion::p_WorkStack::_get_impl(_4326)->f64;
  _checked_ptr_1<double> _ptr__4366(_4366 ? _4366->raw() : nullptr,_4366 ? _4366->size(0) : 0);
  _ptr__4364[_4358] = (int)0;
  int _8846 = (int)0;
  int _8847 = _4349;
  for (int _4367 = _8846; _4367 < _8847; ++_4367)
  {
    {
      _ptr__4366[safe_add( _4362,_4367 )] = 0.0;
    }
  }
  int _8848 = (int)0;
  int _8849 = safe_add( _4349,(int)1 );
  for (int _4368 = _8848; _4368 < _8849; ++_4368)
  {
    {
      _ptr__4364[safe_add( _4358,_4368 )] = (int)0;
    }
  }
  if (_4347)
  {
    {
      int _8850 = (int)0;
      int _8851 = _4329;
      for (int _4369 = _8850; _4369 < _8851; ++_4369)
      {
        {
          if ((_ptr__4335[_4369] >= (int)0))
          {
            {
              int _8852 = (int)0;
              int _8853 = _ptr__4331[_4369];
              for (int _4370 = _8852; _4370 < _8853; ++_4370)
              {
                {
                  _ptr__4364[safe_add( safe_add( _4358,_ptr__4345[safe_add( _ptr__4335[_4369],_4370 )] ),(int)1 )] += (_ptr__4344[safe_add( safe_add( _ptr__4333[_4369],_4370 ),(int)1 )] - _ptr__4344[safe_add( _ptr__4333[_4369],_4370 )]);
                }
              }
            }
          }
          else
          {
            {
              int _8854 = (int)0;
              int _8855 = _ptr__4331[_4369];
              for (int _4371 = _8854; _4371 < _8855; ++_4371)
              {
                {
                  _ptr__4364[safe_add( safe_add( _4358,_4371 ),(int)1 )] += (_ptr__4344[safe_add( safe_add( _ptr__4333[_4369],_4371 ),(int)1 )] - _ptr__4344[safe_add( _ptr__4333[_4369],_4371 )]);
                }
              }
            }
          }
        }
      }
      int _8856 = (int)0;
      int _8857 = _4349;
      for (int _4372 = _8856; _4372 < _8857; ++_4372)
      {
        {
          _ptr__4364[safe_add( safe_add( _4358,_4372 ),(int)1 )] += _ptr__4364[safe_add( _4358,_4372 )];
        }
      }
      int _8858 = (int)0;
      int _8859 = _4329;
      for (int _4373 = _8858; _4373 < _8859; ++_4373)
      {
        {
          if ((_ptr__4335[_4373] >= (int)0))
          {
            {
              int _8860 = (int)0;
              int _8861 = _ptr__4331[_4373];
              for (int _4374 = _8860; _4374 < _8861; ++_4374)
              {
                {
                  int _4375 = _ptr__4344[safe_add( _ptr__4333[_4373],_4374 )];
                  int _4376 = _ptr__4344[safe_add( safe_add( _ptr__4333[_4373],_4374 ),(int)1 )];
                  long long _4377 = _ptr__4345[safe_add( _ptr__4335[_4373],_4374 )];
                  int _4378 = _ptr__4364[safe_add( _4358,_4377 )];
                  int _8862 = _4375;
                  int _8863 = _4376;
                  for (int _4379 = _8862; _4379 < _8863; ++_4379)
                  {
                    {
                      _ptr__4365[safe_add( _4359,_4378 )] = _ptr__4345[safe_add( _ptr__4334[_4373],_4379 )];
                      _ptr__4366[safe_add( _4361,_4378 )] = (((*w)(_4373)) * _ptr__4346[safe_add( _ptr__4336[_4373],_4379 )]);
                      ++ _4378;
                    }
                  }
                  _ptr__4366[safe_add( _4362,_4377 )] += (((*w)(_4373)) * _ptr__4346[safe_add( _ptr__4337[_4373],_4374 )]);
                  _ptr__4364[safe_add( _4358,_4377 )] += (_4376 - _4375);
                }
              }
            }
          }
          else
          {
            {
              int _8864 = (int)0;
              int _8865 = _ptr__4331[_4373];
              for (int _4380 = _8864; _4380 < _8865; ++_4380)
              {
                {
                  int _4381 = _ptr__4344[safe_add( _ptr__4333[_4373],_4380 )];
                  int _4382 = _ptr__4344[safe_add( safe_add( _ptr__4333[_4373],_4380 ),(int)1 )];
                  int _4383 = _4380;
                  int _4384 = _ptr__4364[safe_add( _4358,_4383 )];
                  int _8866 = _4381;
                  int _8867 = _4382;
                  for (int _4385 = _8866; _4385 < _8867; ++_4385)
                  {
                    {
                      _ptr__4365[safe_add( _4359,_4384 )] = _ptr__4345[safe_add( _ptr__4334[_4373],_4385 )];
                      _ptr__4366[safe_add( _4361,_4384 )] = (((*w)(_4373)) * _ptr__4346[safe_add( _ptr__4336[_4373],_4385 )]);
                      ++ _4384;
                    }
                  }
                  _ptr__4366[safe_add( _4362,_4383 )] += (((*w)(_4373)) * _ptr__4346[safe_add( _ptr__4337[_4373],_4380 )]);
                  _ptr__4364[safe_add( _4358,_4383 )] += (_4382 - _4381);
                }
              }
            }
          }
        }
      }
      int _8868 = (int)0;
      int _8869 = _4349;
      for (int _4386 = _8868; _4386 < _8869; ++_4386)
      {
        {
          _ptr__4364[(safe_add( _4358,_4349 ) - _4386)] = _ptr__4364[((safe_add( _4358,_4349 ) - _4386) - (int)1)];
        }
      }
      _ptr__4364[_4358] = (int)0;
    }
  }
  else
  {
    {
      bool _4387 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4388 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4329)));
      _checked_ptr_1<int> _ptr__4388(_4388 ? _4388->raw() : nullptr,_4388 ? _4388->size(0) : 0);
      int _4389 = (int)0;
      int _4390 = (int)0;
      while ( (!_4387) )
      {
        {
          long long _4391 = (-(int)1);
          int _8870 = (int)0;
          int _8871 = _4329;
          for (int _4392 = _8870; _4392 < _8871; ++_4392)
          {
            {
              if (((_ptr__4388[_4392] < _ptr__4331[_4392]) && ((_4391 < (int)0) || (_ptr__4345[safe_add( _ptr__4335[_4392],_ptr__4388[_4392] )] < _4391))))
              {
                {
                  _4391 = _ptr__4345[safe_add( _ptr__4335[_4392],_ptr__4388[_4392] )];
                }
              }
              {}
            }
          }
          if ((_4391 < (int)0))
          {
            {
              _4387 = true;
            }
          }
          else
          {
            {
              int _8872 = (int)0;
              int _8873 = _4329;
              for (int _4393 = _8872; _4393 < _8873; ++_4393)
              {
                {
                  if (((_ptr__4388[_4393] < _ptr__4331[_4393]) && (_4391 == _ptr__4345[safe_add( _ptr__4335[_4393],_ptr__4388[_4393] )])))
                  {
                    {
                      int _8874 = _ptr__4344[safe_add( _ptr__4333[_4393],_ptr__4388[_4393] )];
                      int _8875 = _ptr__4344[safe_add( safe_add( _ptr__4333[_4393],_ptr__4388[_4393] ),(int)1 )];
                      for (int _4394 = _8874; _4394 < _8875; ++_4394)
                      {
                        {
                          _ptr__4365[safe_add( _4359,_4390 )] = _ptr__4345[safe_add( _ptr__4334[_4393],_4394 )];
                          _ptr__4366[safe_add( _4361,_4390 )] = (((*w)(_4393)) * _ptr__4346[safe_add( _ptr__4336[_4393],_4394 )]);
                          ++ _4390;
                        }
                      }
                      _ptr__4366[safe_add( _4362,_4389 )] += (((*w)(_4393)) * _ptr__4346[safe_add( _ptr__4337[_4393],_ptr__4388[_4393] )]);
                      ++ _ptr__4388[_4393];
                    }
                  }
                  {}
                }
              }
              _ptr__4364[safe_add( safe_add( _4358,_4389 ),(int)1 )] = _4390;
              _ptr__4365[safe_add( _4360,_4389 )] = _4391;
            }
          }
          ++ _4389;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  return std::string ("ExprWSum()");
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _4395,    monty::rc_ptr< ::mosek::fusion::Expression > _4396){ return new mosek::fusion::ExprSumReduce(_4395,_4396); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _4395,    monty::rc_ptr< ::mosek::fusion::Expression > _4396) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_4395,_4396); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _4395,    monty::rc_ptr< ::mosek::fusion::Expression > _4396){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_4395,_4396->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _4396;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _4395;
    std::shared_ptr< monty::ndarray< int,1 > > _4397 = _4396->getShape();
    _checked_ptr_1<int> _ptr__4397(_4397 ? _4397->raw() : nullptr,_4397 ? _4397->size(0) : 0);
    if (((int)((_4397)->size(0)) <= _4395))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4398,monty::rc_ptr< ::mosek::fusion::WorkStack > _4399,monty::rc_ptr< ::mosek::fusion::WorkStack > _4400) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_4398,_4399,_4400); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4398,monty::rc_ptr< ::mosek::fusion::WorkStack > _4399,monty::rc_ptr< ::mosek::fusion::WorkStack > _4400){
  expr->eval(_4399,_4398,_4400);
  _4399->pop_expr();
  int _4401 = mosek::fusion::p_WorkStack::_get_impl(_4399)->nd;
  int _4402 = mosek::fusion::p_WorkStack::_get_impl(_4399)->shape_base;
  int _4403 = mosek::fusion::p_WorkStack::_get_impl(_4399)->nelem;
  int _4404 = mosek::fusion::p_WorkStack::_get_impl(_4399)->nnz;
  bool _4405 = mosek::fusion::p_WorkStack::_get_impl(_4399)->hassp;
  int _4406 = mosek::fusion::p_WorkStack::_get_impl(_4399)->ptr_base;
  int _4407 = mosek::fusion::p_WorkStack::_get_impl(_4399)->sp_base;
  int _4408 = mosek::fusion::p_WorkStack::_get_impl(_4399)->nidxs_base;
  int _4409 = mosek::fusion::p_WorkStack::_get_impl(_4399)->bfix_base;
  int _4410 = mosek::fusion::p_WorkStack::_get_impl(_4399)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4411 = mosek::fusion::p_WorkStack::_get_impl(_4399)->i32;
  _checked_ptr_1<int> _ptr__4411(_4411 ? _4411->raw() : nullptr,_4411 ? _4411->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4412 = mosek::fusion::p_WorkStack::_get_impl(_4399)->i64;
  _checked_ptr_1<long long> _ptr__4412(_4412 ? _4412->raw() : nullptr,_4412 ? _4412->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4413 = mosek::fusion::p_WorkStack::_get_impl(_4399)->f64;
  _checked_ptr_1<double> _ptr__4413(_4413 ? _4413->raw() : nullptr,_4413 ? _4413->size(0) : 0);
  int _4414 = (int)99999;
  int _4415 = (int)99999;
  int _4416 = (int)99999;
  if (_4405)
  {
    {
      int _4417 = (int)0;
      int _8876 = (int)0;
      int _8877 = _4401;
      for (int _4418 = _8876; _4418 < _8877; ++_4418)
      {
        {
          if ((_4417 < _ptr__4411[safe_add( _4402,_4418 )]))
          {
            {
              _4417 = _ptr__4411[safe_add( _4402,_4418 )];
            }
          }
          {}
        }
      }
      _4414 = _4400->alloci32(safe_add( _4417,(int)1 ));
      _4415 = _4400->alloci32(_4403);
      _4416 = _4400->alloci32(_4403);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _4419 = mosek::fusion::p_WorkStack::_get_impl(_4400)->i32;
  _checked_ptr_1<int> _ptr__4419(_4419 ? _4419->raw() : nullptr,_4419 ? _4419->size(0) : 0);
  if (_4405)
  {
    {
      int _4420 = _4415;
      int _4421 = _4416;
      int _8878 = (int)0;
      int _8879 = _4403;
      for (int _4422 = _8878; _4422 < _8879; ++_4422)
      {
        {
          _ptr__4419[safe_add( _4420,_4422 )] = _4422;
        }
      }
      if ((dim < (_4401 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _4423 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4401)));
          _checked_ptr_1<long long> _ptr__4423(_4423 ? _4423->raw() : nullptr,_4423 ? _4423->size(0) : 0);
          _ptr__4423[(_4401 - (int)1)] = (int)1;
          int _8880 = (int)1;
          int _8881 = _4401;
          for (int _4424 = _8880; _4424 < _8881; ++_4424)
          {
            {
              _ptr__4423[((_4401 - _4424) - (int)1)] = safe_mul( _ptr__4423[(_4401 - _4424)],_ptr__4411[(safe_add( _4402,_4401 ) - _4424)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _4425 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_4401 - (int)1))));
          _checked_ptr_1<int> _ptr__4425(_4425 ? _4425->raw() : nullptr,_4425 ? _4425->size(0) : 0);
          int _8882 = (int)0;
          int _8883 = dim;
          for (int _4426 = _8882; _4426 < _8883; ++_4426)
          {
            {
              _ptr__4425[((_4401 - _4426) - (int)2)] = _4426;
            }
          }
          int _8884 = safe_add( dim,(int)1 );
          int _8885 = _4401;
          for (int _4427 = _8884; _4427 < _8885; ++_4427)
          {
            {
              _ptr__4425[((_4401 - _4427) - (int)1)] = _4427;
            }
          }
          int _8886 = (int)0;
          int _8887 = (_4401 - (int)1);
          for (int _4428 = _8886; _4428 < _8887; ++_4428)
          {
            {
              int _4429 = _ptr__4425[_4428];
              int _4430 = _ptr__4411[safe_add( _4402,_4429 )];
              int _8888 = (int)0;
              int _8889 = safe_add( _4430,(int)1 );
              for (int _4431 = _8888; _4431 < _8889; ++_4431)
              {
                {
                  _ptr__4419[safe_add( _4414,_4431 )] = (int)0;
                }
              }
              int _8890 = (int)0;
              int _8891 = _4403;
              for (int _4432 = _8890; _4432 < _8891; ++_4432)
              {
                {
                  ++ _ptr__4419[safe_add( safe_add( _4414,(int)1 ),((_ptr__4412[safe_add( _4407,_4432 )] / _ptr__4423[_4429]) % _4430) )];
                }
              }
              int _8892 = (int)0;
              int _8893 = _4430;
              for (int _4433 = _8892; _4433 < _8893; ++_4433)
              {
                {
                  _ptr__4419[safe_add( safe_add( _4414,_4433 ),(int)1 )] += _ptr__4419[safe_add( _4414,_4433 )];
                }
              }
              int _8894 = (int)0;
              int _8895 = _4403;
              for (int _4434 = _8894; _4434 < _8895; ++_4434)
              {
                {
                  int _4435 = _ptr__4419[safe_add( _4420,_4434 )];
                  long long _4436 = ((_ptr__4412[safe_add( _4407,_4435 )] / _ptr__4423[_4429]) % _4430);
                  _ptr__4419[safe_add( _4421,_ptr__4419[safe_add( _4414,_4436 )] )] = _4435;
                  ++ _ptr__4419[safe_add( _4414,_4436 )];
                }
              }
              int _4437 = _4421;
              _4421 = _4420;
              _4420 = _4437;
            }
          }
        }
      }
      {}
      int _4438 = (int)1;
      int _8896 = (int)0;
      int _8897 = dim;
      for (int _4439 = _8896; _4439 < _8897; ++_4439)
      {
        {
          _4438 *= _ptr__4411[safe_add( _4402,_4439 )];
        }
      }
      int _4440 = _ptr__4411[safe_add( _4402,dim )];
      int _4441 = (int)1;
      int _8898 = safe_add( dim,(int)1 );
      int _8899 = _4401;
      for (int _4442 = _8898; _4442 < _8899; ++_4442)
      {
        {
          _4441 *= _ptr__4411[safe_add( _4402,_4442 )];
        }
      }
      int _4443 = safe_mul( _4441,_4440 );
      int _4444 = _4441;
      int _4445 = (int)1;
      int _4446 = (int)0;
      long long _4447 = (-(int)1);
      long long _4448 = (-(int)1);
      int _8900 = (int)0;
      int _8901 = _4403;
      for (int _4449 = _8900; _4449 < _8901; ++_4449)
      {
        {
          int _4450 = _ptr__4419[safe_add( _4420,_4449 )];
          long long _4451 = ((_ptr__4412[safe_add( _4407,_4450 )] / _4443) % _4438);
          long long _4452 = (_ptr__4412[safe_add( _4407,_4450 )] % _4441);
          if (((_4448 != _4451) || (_4447 != _4452)))
          {
            {
              _4448 = _4451;
              _4447 = _4452;
              ++ _4446;
            }
          }
          {}
        }
      }
      int _4453 = (_4401 - (int)1);
      bool _4454 = (_4446 < safe_mul( _4438,_4441 ));
      int _4455 = _4404;
      _4398->alloc_expr(_4453,_4446,_4455,_4454);
      int _4456 = mosek::fusion::p_WorkStack::_get_impl(_4398)->ptr_base;
      int _4457 = mosek::fusion::p_WorkStack::_get_impl(_4398)->nidxs_base;
      int _8902;
      bool _8903 = _4454;
      if (_8903)
      {
        _8902 = mosek::fusion::p_WorkStack::_get_impl(_4398)->sp_base;
      }
      else
      {
        _8902 = _4398->alloci64(_4446);
      }
      int _4458 = _8902;
      int _4459 = mosek::fusion::p_WorkStack::_get_impl(_4398)->cof_base;
      int _4460 = mosek::fusion::p_WorkStack::_get_impl(_4398)->bfix_base;
      int _4461 = mosek::fusion::p_WorkStack::_get_impl(_4398)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4462 = mosek::fusion::p_WorkStack::_get_impl(_4398)->i32;
      _checked_ptr_1<int> _ptr__4462(_4462 ? _4462->raw() : nullptr,_4462 ? _4462->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4463 = mosek::fusion::p_WorkStack::_get_impl(_4398)->i64;
      _checked_ptr_1<long long> _ptr__4463(_4463 ? _4463->raw() : nullptr,_4463 ? _4463->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4464 = mosek::fusion::p_WorkStack::_get_impl(_4398)->f64;
      _checked_ptr_1<double> _ptr__4464(_4464 ? _4464->raw() : nullptr,_4464 ? _4464->size(0) : 0);
      int _8904 = (int)0;
      int _8905 = dim;
      for (int _4465 = _8904; _4465 < _8905; ++_4465)
      {
        {
          _ptr__4462[safe_add( _4461,_4465 )] = _ptr__4411[safe_add( _4402,_4465 )];
        }
      }
      int _8906 = safe_add( dim,(int)1 );
      int _8907 = _4401;
      for (int _4466 = _8906; _4466 < _8907; ++_4466)
      {
        {
          _ptr__4462[(safe_add( _4461,_4466 ) - (int)1)] = _ptr__4411[safe_add( _4402,_4466 )];
        }
      }
      _ptr__4462[_4456] = (int)0;
      int _4467 = (int)0;
      int _4468 = (int)0;
      int _4469 = (int)0;
      while ( (_4469 < _4403) )
      {
        {
          int _4470 = _4469;
          long long _4471 = ((_ptr__4412[safe_add( _4407,_ptr__4419[safe_add( _4420,_4470 )] )] / _4443) % _4438);
          long long _4472 = (_ptr__4412[safe_add( _4407,_ptr__4419[safe_add( _4420,_4470 )] )] % _4441);
          ++ _4469;
          while ( ((_4469 < _4403) && ((_4471 == ((_ptr__4412[safe_add( _4407,_ptr__4419[safe_add( _4420,_4469 )] )] / _4443) % _4438)) && (_4472 == (_ptr__4412[safe_add( _4407,_ptr__4419[safe_add( _4420,_4469 )] )] % _4441)))) )
          {
            {
              ++ _4469;
            }
          }
          double _4473 = 0.0;
          int _8908 = _4470;
          int _8909 = _4469;
          for (int _4474 = _8908; _4474 < _8909; ++_4474)
          {
            {
              int _4475 = _ptr__4419[safe_add( _4420,_4474 )];
              int _8910 = _ptr__4411[safe_add( _4406,_4475 )];
              int _8911 = _ptr__4411[safe_add( safe_add( _4406,_4475 ),(int)1 )];
              for (int _4476 = _8910; _4476 < _8911; ++_4476)
              {
                {
                  _ptr__4463[safe_add( _4457,_4468 )] = _ptr__4412[safe_add( _4408,_4476 )];
                  _ptr__4464[safe_add( _4459,_4468 )] = _ptr__4413[safe_add( _4410,_4476 )];
                  ++ _4468;
                }
              }
              _4473 += _ptr__4413[safe_add( _4409,_4475 )];
            }
          }
          _ptr__4463[safe_add( _4458,_4467 )] = safe_add( safe_mul( _4471,_4441 ),_4472 );
          _ptr__4462[safe_add( safe_add( _4456,_4467 ),(int)1 )] = _4468;
          _ptr__4464[safe_add( _4460,_4467 )] = _4473;
          ++ _4467;
        }
      }
      if ((!_4454))
      {
        {
          _4398->popi64(_4446);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4477 = (int)1;
      int _8912 = (int)0;
      int _8913 = dim;
      for (int _4478 = _8912; _4478 < _8913; ++_4478)
      {
        {
          _4477 *= _ptr__4411[safe_add( _4402,_4478 )];
        }
      }
      int _4479 = _ptr__4411[safe_add( _4402,dim )];
      int _4480 = (int)1;
      int _8914 = safe_add( dim,(int)1 );
      int _8915 = _4401;
      for (int _4481 = _8914; _4481 < _8915; ++_4481)
      {
        {
          _4480 *= _ptr__4411[safe_add( _4402,_4481 )];
        }
      }
      int _4482 = safe_mul( _4480,_4479 );
      int _4483 = _4480;
      int _4484 = (int)1;
      int _4485 = safe_mul( _4477,_4480 );
      int _4486 = _4398->alloci32(safe_add( _4485,(int)1 ));
      int _4487 = _4398->alloci64(_4404);
      int _4488 = _4398->allocf64(_4404);
      int _4489 = _4398->allocf64(_4485);
      _4398->pushi32((int)0);
      _4398->pushi32(_4404);
      _4398->pushi32(_4485);
      int _4490 = _4398->alloci32((_4401 - (int)1));
      _4398->pushi32((_4401 - (int)1));
      std::shared_ptr< monty::ndarray< int,1 > > _4491 = mosek::fusion::p_WorkStack::_get_impl(_4398)->i32;
      _checked_ptr_1<int> _ptr__4491(_4491 ? _4491->raw() : nullptr,_4491 ? _4491->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4492 = mosek::fusion::p_WorkStack::_get_impl(_4398)->i64;
      _checked_ptr_1<long long> _ptr__4492(_4492 ? _4492->raw() : nullptr,_4492 ? _4492->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4493 = mosek::fusion::p_WorkStack::_get_impl(_4398)->f64;
      _checked_ptr_1<double> _ptr__4493(_4493 ? _4493->raw() : nullptr,_4493 ? _4493->size(0) : 0);
      int _8916 = (int)0;
      int _8917 = dim;
      for (int _4494 = _8916; _4494 < _8917; ++_4494)
      {
        {
          _ptr__4491[safe_add( _4490,_4494 )] = _ptr__4411[safe_add( _4402,_4494 )];
        }
      }
      int _8918 = safe_add( dim,(int)1 );
      int _8919 = _4401;
      for (int _4495 = _8918; _4495 < _8919; ++_4495)
      {
        {
          _ptr__4491[(safe_add( _4490,_4495 ) - (int)1)] = _ptr__4411[safe_add( _4402,_4495 )];
        }
      }
      int _4496 = (int)0;
      int _4497 = (int)0;
      _ptr__4491[_4486] = (int)0;
      int _8920 = (int)0;
      int _8921 = _4477;
      for (int _4498 = _8920; _4498 < _8921; ++_4498)
      {
        {
          int _8922 = (int)0;
          int _8923 = _4480;
          for (int _4499 = _8922; _4499 < _8923; ++_4499)
          {
            {
              double _4500 = 0.0;
              int _8924 = (int)0;
              int _8925 = _4479;
              for (int _4501 = _8924; _4501 < _8925; ++_4501)
              {
                {
                  int _4502 = safe_add( safe_add( safe_mul( _4498,_4482 ),safe_mul( _4501,_4483 ) ),_4499 );
                  int _8926 = _ptr__4411[safe_add( _4406,_4502 )];
                  int _8927 = _ptr__4411[safe_add( safe_add( _4406,_4502 ),(int)1 )];
                  for (int _4503 = _8926; _4503 < _8927; ++_4503)
                  {
                    {
                      _ptr__4492[safe_add( _4487,_4497 )] = _ptr__4412[safe_add( _4408,_4503 )];
                      _ptr__4493[safe_add( _4488,_4497 )] = _ptr__4413[safe_add( _4410,_4503 )];
                      ++ _4497;
                    }
                  }
                  _4500 += _ptr__4413[safe_add( _4409,_4502 )];
                }
              }
              _ptr__4491[safe_add( safe_add( _4486,_4496 ),(int)1 )] = _4497;
              _ptr__4493[safe_add( _4489,_4496 )] = _4500;
              ++ _4496;
            }
          }
        }
      }
    }
  }
  _4400->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _4504,std::shared_ptr< monty::ndarray< int,1 > > _4505){
  _checked_ptr_1<int> _ptr__4505(_4505 ? _4505->raw() : nullptr, _4505 ? _4505->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4506 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_4505)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__4506(_4506 ? _4506->raw() : nullptr,_4506 ? _4506->size(0) : 0);
  int _8928 = (int)0;
  int _8929 = _4504;
  for (int _4507 = _8928; _4507 < _8929; ++_4507)
  {
    {
      _ptr__4506[_4507] = _ptr__4505[_4507];
    }
  }
  int _8930 = safe_add( _4504,(int)1 );
  int _8931 = (int)((_4505)->size(0));
  for (int _4508 = _8930; _4508 < _8931; ++_4508)
  {
    {
      _ptr__4506[(_4508 - (int)1)] = _ptr__4505[_4508];
    }
  }
  return _4506;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return std::string ("ExprSumReduce()");
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4509,    int _4510,    monty::rc_ptr< ::mosek::fusion::Expression > _4511,    int _4512){ return new mosek::fusion::ExprDenseTril(_4509,_4510,_4511,_4512); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4509,    int _4510,    monty::rc_ptr< ::mosek::fusion::Expression > _4511,    int _4512) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4509,_4510,_4511,_4512); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4509,    int _4510,    monty::rc_ptr< ::mosek::fusion::Expression > _4511,    int _4512){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4511->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _4511;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _4509;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _4510;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4513,    int _4514,    monty::rc_ptr< ::mosek::fusion::Expression > _4515){ return new mosek::fusion::ExprDenseTril(_4513,_4514,_4515); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4513,    int _4514,    monty::rc_ptr< ::mosek::fusion::Expression > _4515) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4513,_4514,_4515); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4513,    int _4514,    monty::rc_ptr< ::mosek::fusion::Expression > _4515){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_4513,_4514,_4515,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4516 = _4515->getShape();
    _checked_ptr_1<int> _ptr__4516(_4516 ? _4516->raw() : nullptr,_4516 ? _4516->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_4516)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_4516)->size(0))) || (_ptr__4516[dim0] != _ptr__4516[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4517,monty::rc_ptr< ::mosek::fusion::WorkStack > _4518,monty::rc_ptr< ::mosek::fusion::WorkStack > _4519) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_4517,_4518,_4519); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4517,monty::rc_ptr< ::mosek::fusion::WorkStack > _4518,monty::rc_ptr< ::mosek::fusion::WorkStack > _4519){
  expr->eval(_4518,_4517,_4519);
  std::shared_ptr< monty::ndarray< int,1 > > _4520 = mosek::fusion::p_WorkStack::_get_impl(_4518)->i32;
  _checked_ptr_1<int> _ptr__4520(_4520 ? _4520->raw() : nullptr,_4520 ? _4520->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4521 = mosek::fusion::p_WorkStack::_get_impl(_4518)->i64;
  _checked_ptr_1<long long> _ptr__4521(_4521 ? _4521->raw() : nullptr,_4521 ? _4521->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4522 = mosek::fusion::p_WorkStack::_get_impl(_4518)->f64;
  _checked_ptr_1<double> _ptr__4522(_4522 ? _4522->raw() : nullptr,_4522 ? _4522->size(0) : 0);
  int _8932;
  bool _8933 = (dim0 < dim1);
  if (_8933)
  {
    _8932 = dim0;
  }
  else
  {
    _8932 = dim1;
  }
  int _4523 = _8932;
  int _8934;
  bool _8935 = (dim0 > dim1);
  if (_8935)
  {
    _8934 = dim0;
  }
  else
  {
    _8934 = dim1;
  }
  int _4524 = _8934;
  bool _4525 = (dim0 < dim1);
  int _4526 = _4518->popi32();
  int _4527 = _4518->popi32(_4526);
  int _4528 = _4518->popi32();
  int _4529 = _4518->popi32();
  bool _4530 = (_4518->popi32() != (int)0);
  int _4531 = _4518->popi32(safe_add( _4528,(int)1 ));
  int _8936;
  bool _8937 = _4530;
  if (_8937)
  {
    _8936 = _4518->popi64(_4528);
  }
  else
  {
    _8936 = (-(int)1);
  }
  int _4532 = _8936;
  int _4533 = _4518->popi64(_4529);
  int _4534 = _4518->popf64(_4528);
  int _4535 = _4518->popf64(_4529);
  std::vector<int> _8938;
  for (int _4537 = (int)0, _8939 = (int)5; _4537 < _8939 ; ++_4537)
  {
    _8938.push_back((int)1);
  }
  auto _8940 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8938.size()),_8938.begin(),_8938.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4536 = _8940;
  _checked_ptr_1<int> _ptr__4536(_4536 ? _4536->raw() : nullptr,_4536 ? _4536->size(0) : 0);
  int _8941 = (int)0;
  int _8942 = _4523;
  for (int _4538 = _8941; _4538 < _8942; ++_4538)
  {
    {
      _ptr__4536[(int)0] *= _ptr__4520[safe_add( _4527,_4538 )];
    }
  }
  _ptr__4536[(int)1] = _ptr__4520[safe_add( _4527,_4523 )];
  int _8943 = safe_add( _4523,(int)1 );
  int _8944 = _4524;
  for (int _4539 = _8943; _4539 < _8944; ++_4539)
  {
    {
      _ptr__4536[(int)2] *= _ptr__4520[safe_add( _4527,_4539 )];
    }
  }
  _ptr__4536[(int)3] = _ptr__4520[safe_add( _4527,_4524 )];
  int _8945 = safe_add( _4524,(int)1 );
  int _8946 = _4526;
  for (int _4540 = _8945; _4540 < _8946; ++_4540)
  {
    {
      _ptr__4536[(int)4] *= _ptr__4520[safe_add( _4527,_4540 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4541 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__4541(_4541 ? _4541->raw() : nullptr,_4541 ? _4541->size(0) : 0);
  _ptr__4541[(int)4] = (int)1;
  int _8947 = (int)1;
  int _8948 = (int)5;
  for (int _4542 = _8947; _4542 < _8948; ++_4542)
  {
    {
      _ptr__4541[(((int)5 - _4542) - (int)1)] = safe_mul( _ptr__4541[((int)5 - _4542)],_ptr__4536[((int)5 - _4542)] );
    }
  }
  int _4543 = (int)0;
  int _4544 = (int)0;
  {
    if (_4530)
    {
      {
        if (_4525)
        {
          {
            int _8949 = (int)0;
            int _8950 = _4528;
            for (int _4545 = _8949; _4545 < _8950; ++_4545)
            {
              {
                long long _4546 = ((_ptr__4521[safe_add( _4532,_4545 )] / _ptr__4541[(int)1]) % _ptr__4536[(int)1]);
                long long _4547 = ((_ptr__4521[safe_add( _4532,_4545 )] / _ptr__4541[(int)3]) % _ptr__4536[(int)3]);
                if ((_4546 >= _4547))
                {
                  {
                    _4543 += (_ptr__4520[safe_add( safe_add( _4531,_4545 ),(int)1 )] - _ptr__4520[safe_add( _4531,_4545 )]);
                    ++ _4544;
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _8951 = (int)0;
            int _8952 = _4528;
            for (int _4548 = _8951; _4548 < _8952; ++_4548)
            {
              {
                long long _4549 = ((_ptr__4521[safe_add( _4532,_4548 )] / _ptr__4541[(int)1]) % _ptr__4536[(int)1]);
                long long _4550 = ((_ptr__4521[safe_add( _4532,_4548 )] / _ptr__4541[(int)3]) % _ptr__4536[(int)3]);
                if ((_4549 <= _4550))
                {
                  {
                    _4543 += (_ptr__4520[safe_add( safe_add( _4531,_4548 ),(int)1 )] - _ptr__4520[safe_add( _4531,_4548 )]);
                    ++ _4544;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        _4544 = safe_mul( safe_mul( safe_mul( _ptr__4536[(int)0],_ptr__4536[(int)2] ),_ptr__4536[(int)4] ),(safe_mul( _ptr__4536[(int)1],safe_add( _ptr__4536[(int)1],(int)1 ) ) / (int)2) );
        if (_4525)
        {
          {
            int _8953 = (int)0;
            int _8954 = _ptr__4536[(int)0];
            for (int _4551 = _8953; _4551 < _8954; ++_4551)
            {
              {
                int _8955 = (int)0;
                int _8956 = _ptr__4536[(int)1];
                for (int _4552 = _8955; _4552 < _8956; ++_4552)
                {
                  {
                    int _8957 = (int)0;
                    int _8958 = _ptr__4536[(int)2];
                    for (int _4553 = _8957; _4553 < _8958; ++_4553)
                    {
                      {
                        int _8959 = (int)0;
                        int _8960 = safe_add( _4552,(int)1 );
                        for (int _4554 = _8959; _4554 < _8960; ++_4554)
                        {
                          {
                            int _8961 = (int)0;
                            int _8962 = _ptr__4536[(int)4];
                            for (int _4555 = _8961; _4555 < _8962; ++_4555)
                            {
                              {
                                int _4556 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4551,_ptr__4541[(int)0] ),safe_mul( _4552,_ptr__4541[(int)1] ) ),safe_mul( _4553,_ptr__4541[(int)2] ) ),safe_mul( _4554,_ptr__4541[(int)3] ) ),safe_mul( _4555,_ptr__4541[(int)4] ) );
                                _4543 += (_ptr__4520[safe_add( safe_add( _4531,_4556 ),(int)1 )] - _ptr__4520[safe_add( _4531,_4556 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _8963 = (int)0;
            int _8964 = _ptr__4536[(int)0];
            for (int _4557 = _8963; _4557 < _8964; ++_4557)
            {
              {
                int _8965 = (int)0;
                int _8966 = _ptr__4536[(int)1];
                for (int _4558 = _8965; _4558 < _8966; ++_4558)
                {
                  {
                    int _8967 = (int)0;
                    int _8968 = _ptr__4536[(int)2];
                    for (int _4559 = _8967; _4559 < _8968; ++_4559)
                    {
                      {
                        int _8969 = _4558;
                        int _8970 = _ptr__4536[(int)3];
                        for (int _4560 = _8969; _4560 < _8970; ++_4560)
                        {
                          {
                            int _8971 = (int)0;
                            int _8972 = _ptr__4536[(int)4];
                            for (int _4561 = _8971; _4561 < _8972; ++_4561)
                            {
                              {
                                int _4562 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4557,_ptr__4541[(int)0] ),safe_mul( _4558,_ptr__4541[(int)1] ) ),safe_mul( _4559,_ptr__4541[(int)2] ) ),safe_mul( _4560,_ptr__4541[(int)3] ) ),safe_mul( _4561,_ptr__4541[(int)4] ) );
                                _4543 += (_ptr__4520[safe_add( safe_add( _4531,_4562 ),(int)1 )] - _ptr__4520[safe_add( _4531,_4562 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _4563 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__4536[(int)0],_ptr__4536[(int)2] ),_ptr__4536[(int)4] ),_ptr__4536[(int)1] ),safe_add( _ptr__4536[(int)1],(int)1 ) ) / (int)2);
  int _4564 = _4517->alloci32(safe_add( _4563,(int)1 ));
  _4517->pushi32((int)1);
  _4517->pushi32(_4543);
  _4517->pushi32(_4563);
  int _8973 = (int)0;
  int _8974 = _4526;
  for (int _4565 = _8973; _4565 < _8974; ++_4565)
  {
    {
      _4517->pushi32(_ptr__4520[safe_add( _4527,_4565 )]);
    }
  }
  _4517->pushi32(_4526);
  int _4566 = _4517->alloci64(_4543);
  int _4567 = _4517->alloci64(_4563);
  int _4568 = _4517->allocf64(_4543);
  int _4569 = _4517->allocf64(_4563);
  std::shared_ptr< monty::ndarray< int,1 > > _4570 = mosek::fusion::p_WorkStack::_get_impl(_4517)->i32;
  _checked_ptr_1<int> _ptr__4570(_4570 ? _4570->raw() : nullptr,_4570 ? _4570->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4571 = mosek::fusion::p_WorkStack::_get_impl(_4517)->i64;
  _checked_ptr_1<long long> _ptr__4571(_4571 ? _4571->raw() : nullptr,_4571 ? _4571->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4572 = mosek::fusion::p_WorkStack::_get_impl(_4517)->f64;
  _checked_ptr_1<double> _ptr__4572(_4572 ? _4572->raw() : nullptr,_4572 ? _4572->size(0) : 0);
  _ptr__4570[_4564] = (int)0;
  if (_4525)
  {
    {
      int _4573 = (int)0;
      int _8975 = (int)0;
      int _8976 = _ptr__4536[(int)0];
      for (int _4574 = _8975; _4574 < _8976; ++_4574)
      {
        {
          int _8977 = (int)0;
          int _8978 = _ptr__4536[(int)1];
          for (int _4575 = _8977; _4575 < _8978; ++_4575)
          {
            {
              int _8979 = (int)0;
              int _8980 = _ptr__4536[(int)2];
              for (int _4576 = _8979; _4576 < _8980; ++_4576)
              {
                {
                  int _8981 = (int)0;
                  int _8982 = safe_add( _4575,(int)1 );
                  for (int _4577 = _8981; _4577 < _8982; ++_4577)
                  {
                    {
                      int _8983 = (int)0;
                      int _8984 = _ptr__4536[(int)4];
                      for (int _4578 = _8983; _4578 < _8984; ++_4578)
                      {
                        {
                          _ptr__4571[safe_add( _4567,_4573 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4574,_ptr__4541[(int)0] ),safe_mul( _4575,_ptr__4541[(int)1] ) ),safe_mul( _4576,_ptr__4541[(int)2] ) ),safe_mul( _4577,_ptr__4541[(int)3] ) ),safe_mul( _4578,_ptr__4541[(int)4] ) );
                          ++ _4573;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4579 = (int)0;
      int _8985 = (int)0;
      int _8986 = _ptr__4536[(int)0];
      for (int _4580 = _8985; _4580 < _8986; ++_4580)
      {
        {
          int _8987 = (int)0;
          int _8988 = _ptr__4536[(int)1];
          for (int _4581 = _8987; _4581 < _8988; ++_4581)
          {
            {
              int _8989 = (int)0;
              int _8990 = _ptr__4536[(int)2];
              for (int _4582 = _8989; _4582 < _8990; ++_4582)
              {
                {
                  int _8991 = _4581;
                  int _8992 = _ptr__4536[(int)3];
                  for (int _4583 = _8991; _4583 < _8992; ++_4583)
                  {
                    {
                      int _8993 = (int)0;
                      int _8994 = _ptr__4536[(int)4];
                      for (int _4584 = _8993; _4584 < _8994; ++_4584)
                      {
                        {
                          _ptr__4571[safe_add( _4567,_4579 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4580,_ptr__4541[(int)0] ),safe_mul( _4581,_ptr__4541[(int)1] ) ),safe_mul( _4582,_ptr__4541[(int)2] ) ),safe_mul( _4583,_ptr__4541[(int)3] ) ),safe_mul( _4584,_ptr__4541[(int)4] ) );
                          ++ _4579;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  {
    int _4585 = (int)0;
    if (_4530)
    {
      {
        int _4586 = (int)0;
        int _4587 = (int)0;
        while ( ((_4587 < _4528) && (_4586 < _4563)) )
        {
          {
            if ((_ptr__4521[safe_add( _4532,_4587 )] < _ptr__4571[safe_add( _4567,_4586 )]))
            {
              {
                ++ _4587;
              }
            }
            else if((_ptr__4521[safe_add( _4532,_4587 )] > _ptr__4571[safe_add( _4567,_4586 )]))
            {
              {
                _ptr__4572[safe_add( _4569,_4586 )] = 0.0;
                _ptr__4570[safe_add( safe_add( _4564,_4586 ),(int)1 )] = _4585;
                ++ _4586;
              }
            }
            else
            {
              {
                int _8995 = _ptr__4520[safe_add( _4531,_4587 )];
                int _8996 = _ptr__4520[safe_add( safe_add( _4531,_4587 ),(int)1 )];
                for (int _4588 = _8995; _4588 < _8996; ++_4588)
                {
                  {
                    _ptr__4571[safe_add( _4566,_4585 )] = _ptr__4521[safe_add( _4533,_4588 )];
                    _ptr__4572[safe_add( _4568,_4585 )] = _ptr__4522[safe_add( _4535,_4588 )];
                    ++ _4585;
                  }
                }
                _ptr__4572[safe_add( _4569,_4586 )] = _ptr__4522[safe_add( _4534,_4587 )];
                _ptr__4570[safe_add( safe_add( _4564,_4586 ),(int)1 )] = _4585;
                ++ _4587;
                ++ _4586;
              }
            }
          }
        }
        while ( (_4586 < _4563) )
        {
          {
            _ptr__4570[safe_add( safe_add( _4564,_4586 ),(int)1 )] = _4585;
            _ptr__4572[safe_add( _4569,_4586 )] = 0.0;
            ++ _4586;
          }
        }
      }
    }
    else
    {
      {
        int _8997 = (int)0;
        int _8998 = _4563;
        for (int _4589 = _8997; _4589 < _8998; ++_4589)
        {
          {
            long long _4590 = _ptr__4571[safe_add( _4567,_4589 )];
            _ptr__4572[safe_add( _4569,_4589 )] = _ptr__4522[safe_add( _4534,_4590 )];
            int _8999 = _ptr__4520[safe_add( _4531,_4590 )];
            int _9000 = _ptr__4520[safe_add( safe_add( _4531,_4590 ),(int)1 )];
            for (int _4591 = _8999; _4591 < _9000; ++_4591)
            {
              {
                _ptr__4571[safe_add( _4566,_4585 )] = _ptr__4521[safe_add( _4533,_4591 )];
                _ptr__4572[safe_add( _4568,_4585 )] = _ptr__4522[safe_add( _4535,_4591 )];
                ++ _4585;
              }
            }
            _ptr__4570[safe_add( safe_add( _4564,_4589 ),(int)1 )] = _4585;
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4592){ return new mosek::fusion::ExprDense(_4592); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4592) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_4592); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4592){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4592->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _4592;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4593,monty::rc_ptr< ::mosek::fusion::WorkStack > _4594,monty::rc_ptr< ::mosek::fusion::WorkStack > _4595) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_4593,_4594,_4595); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4593,monty::rc_ptr< ::mosek::fusion::WorkStack > _4594,monty::rc_ptr< ::mosek::fusion::WorkStack > _4595){
  expr->eval(_4593,_4594,_4595);
  _4593->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_4593)->hassp)
  {
    {
      int _4596 = mosek::fusion::p_WorkStack::_get_impl(_4593)->nd;
      int _4597 = mosek::fusion::p_WorkStack::_get_impl(_4593)->nnz;
      int _4598 = mosek::fusion::p_WorkStack::_get_impl(_4593)->nelem;
      int _4599 = mosek::fusion::p_WorkStack::_get_impl(_4593)->sp_base;
      std::vector<int> _9001;
      for (int _4601 = (int)0, _9002 = _4596; _4601 < _9002 ; ++_4601)
      {
        _9001.push_back(((*mosek::fusion::p_WorkStack::_get_impl(_4593)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4593)->shape_base,_4601 ))));
      }
      auto _9003 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9001.size()),_9001.begin(),_9001.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _4600 = _9003;
      _checked_ptr_1<int> _ptr__4600(_4600 ? _4600->raw() : nullptr,_4600 ? _4600->size(0) : 0);
      int _4602 = (int)::mosek::fusion::p_Set::size(_4600);
      _4593->popi32(safe_add( (int)4,_4596 ));
      if ((_4602 == _4598))
      {
        {
          _4593->popi64(_4598);
          _4593->pushi32((int)0);
          _4593->pushi32(_4597);
          _4593->pushi32(_4598);
          int _4603 = _4593->alloci32(_4596);
          int _9004 = (int)0;
          int _9005 = _4596;
          for (int _4604 = _9004; _4604 < _9005; ++_4604)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4593)->i32)(safe_add( _4603,_4604 ))) = _ptr__4600[_4604];
            }
          }
          _4593->pushi32(_4596);
          _4593->peek_expr();
        }
      }
      else
      {
        {
          int _4605 = _4595->alloci32(safe_add( _4602,(int)1 ));
          int _4606 = _4595->allocf64(_4602);
          std::shared_ptr< monty::ndarray< int,1 > > _4607 = mosek::fusion::p_WorkStack::_get_impl(_4595)->i32;
          _checked_ptr_1<int> _ptr__4607(_4607 ? _4607->raw() : nullptr,_4607 ? _4607->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4608 = mosek::fusion::p_WorkStack::_get_impl(_4595)->f64;
          _checked_ptr_1<double> _ptr__4608(_4608 ? _4608->raw() : nullptr,_4608 ? _4608->size(0) : 0);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4593)->f64,mosek::fusion::p_WorkStack::_get_impl(_4593)->bfix_base,_4608,_4606,_4598);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4593)->i32,mosek::fusion::p_WorkStack::_get_impl(_4593)->ptr_base,_4607,_4605,safe_add( _4598,(int)1 ));
          _4593->popi32(safe_add( _4598,(int)1 ));
          _4593->popf64(_4598);
          int _4609 = _4593->alloci32(safe_add( _4602,(int)1 ));
          int _4610 = _4593->allocf64(_4602);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _4611 = mosek::fusion::p_WorkStack::_get_impl(_4593)->i32;
            _checked_ptr_1<int> _ptr__4611(_4611 ? _4611->raw() : nullptr,_4611 ? _4611->size(0) : 0);
            std::shared_ptr< monty::ndarray< long long,1 > > _4612 = mosek::fusion::p_WorkStack::_get_impl(_4593)->i64;
            _checked_ptr_1<long long> _ptr__4612(_4612 ? _4612->raw() : nullptr,_4612 ? _4612->size(0) : 0);
            std::shared_ptr< monty::ndarray< double,1 > > _4613 = mosek::fusion::p_WorkStack::_get_impl(_4593)->f64;
            _checked_ptr_1<double> _ptr__4613(_4613 ? _4613->raw() : nullptr,_4613 ? _4613->size(0) : 0);
            _ptr__4611[_4609] = (int)0;
            int _4614 = (int)0;
            if ((_4598 > (int)0))
            {
              {
                int _9006 = (int)0;
                int _9007 = _4602;
                for (int _4615 = _9006; _4615 < _9007; ++_4615)
                {
                  {
                    if (((_4614 < _4598) && (_ptr__4612[safe_add( _4599,_4614 )] == _4615)))
                    {
                      {
                        _ptr__4613[safe_add( _4610,_4615 )] = _ptr__4608[safe_add( _4606,_4614 )];
                        ++ _4614;
                      }
                    }
                    else
                    {
                      {
                        _ptr__4613[safe_add( _4610,_4615 )] = (int)0;
                      }
                    }
                    _ptr__4611[safe_add( safe_add( _4609,_4615 ),(int)1 )] = _ptr__4607[safe_add( _4605,_4614 )];
                  }
                }
              }
            }
            else
            {
              {
                int _9008 = (int)0;
                int _9009 = _4602;
                for (int _4616 = _9008; _4616 < _9009; ++_4616)
                {
                  {
                    _ptr__4613[safe_add( _4610,_4616 )] = (int)0;
                    _ptr__4611[safe_add( safe_add( _4609,_4616 ),(int)1 )] = (int)0;
                  }
                }
              }
            }
          }
          _4593->popi64(_4598);
          _4593->pushi32((int)0);
          _4593->pushi32(_4597);
          _4593->pushi32(_4602);
          int _9010 = (int)0;
          int _9011 = _4596;
          for (int _4617 = _9010; _4617 < _9011; ++_4617)
          {
            {
              _4593->pushi32(_ptr__4600[_4617]);
            }
          }
          _4593->pushi32(_4596);
          if ((((*mosek::fusion::p_WorkStack::_get_impl(_4593)->i32)(safe_add( _4609,_4602 ))) != _4597))
          {
            {
              throw ::mosek::fusion::FatalError(std::string ("Internal: Mismatching ptr and nnz"));
            }
          }
          {}
        }
      }
      _4593->peek_expr();
    }
  }
  {}
  _4595->clear();
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4618,    int _4619,    monty::rc_ptr< ::mosek::fusion::Expression > _4620,    int _4621){ return new mosek::fusion::ExprSymmetrize(_4618,_4619,_4620,_4621); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4618,    int _4619,    monty::rc_ptr< ::mosek::fusion::Expression > _4620,    int _4621) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4618,_4619,_4620,_4621); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4618,    int _4619,    monty::rc_ptr< ::mosek::fusion::Expression > _4620,    int _4621){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4620->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _4620;
    if ((_4618 < _4619))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4618;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4619;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4619;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4618;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4622,    int _4623,    monty::rc_ptr< ::mosek::fusion::Expression > _4624){ return new mosek::fusion::ExprSymmetrize(_4622,_4623,_4624); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4622,    int _4623,    monty::rc_ptr< ::mosek::fusion::Expression > _4624) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4622,_4623,_4624); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4622,    int _4623,    monty::rc_ptr< ::mosek::fusion::Expression > _4624){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_4622,_4623,_4624,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4625 = _4624->getShape();
    _checked_ptr_1<int> _ptr__4625(_4625 ? _4625->raw() : nullptr,_4625 ? _4625->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_4625)->size(0))) || (_ptr__4625[dim0] != _ptr__4625[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4626,monty::rc_ptr< ::mosek::fusion::WorkStack > _4627,monty::rc_ptr< ::mosek::fusion::WorkStack > _4628) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_4626,_4627,_4628); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4626,monty::rc_ptr< ::mosek::fusion::WorkStack > _4627,monty::rc_ptr< ::mosek::fusion::WorkStack > _4628){
  expr->eval(_4627,_4626,_4628);
  int _4629 = (int)0;
  int _4630 = _4627->peeki32();
  int _4631 = _4627->peeki32(safe_add( _4630,(int)3 ));
  int _4632 = _4627->peeki32(safe_add( _4630,(int)2 ));
  int _9012 = (int)0;
  int _9013 = _4630;
  for (int _4633 = _9012; _4633 < _9013; ++_4633)
  {
    {
      int _4634 = _4627->peeki32(safe_add( _4633,(int)1 ));
      if ((_4634 > _4629))
      {
        {
          _4634 = _4629;
        }
      }
      {}
    }
  }
  int _4635 = _4627->alloci32(_4632);
  int _4636 = _4627->alloci32(_4632);
  int _4637 = _4627->alloci32(safe_add( _4629,(int)1 ));
  int _4638 = _4627->alloci64(_4632);
  _4627->popi32(safe_add( safe_add( safe_mul( (int)2,_4632 ),_4629 ),(int)1 ));
  _4627->popi64(_4632);
  int _4639 = _4627->popi32();
  int _4640 = _4627->popi32(_4639);
  int _4641 = _4627->popi32();
  int _4642 = _4627->popi32();
  bool _4643 = (_4627->popi32() != (int)0);
  int _4644 = _4627->popi32(safe_add( _4641,(int)1 ));
  int _9014;
  bool _9015 = _4643;
  if (_9015)
  {
    _9014 = _4627->popi64(_4641);
  }
  else
  {
    _9014 = (-(int)1);
  }
  int _4645 = _9014;
  int _4646 = _4627->popi64(_4642);
  int _4647 = _4627->popf64(_4641);
  int _4648 = _4627->popf64(_4642);
  int _4649 = (int)0;
  int _4650 = (int)0;
  std::vector<int> _9016;
  for (int _4652 = (int)0, _9017 = (int)5; _4652 < _9017 ; ++_4652)
  {
    _9016.push_back((int)1);
  }
  auto _9018 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9016.size()),_9016.begin(),_9016.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4651 = _9018;
  _checked_ptr_1<int> _ptr__4651(_4651 ? _4651->raw() : nullptr,_4651 ? _4651->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4653 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__4653(_4653 ? _4653->raw() : nullptr,_4653 ? _4653->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4654 = mosek::fusion::p_WorkStack::_get_impl(_4627)->i32;
  _checked_ptr_1<int> _ptr__4654(_4654 ? _4654->raw() : nullptr,_4654 ? _4654->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4655 = mosek::fusion::p_WorkStack::_get_impl(_4627)->i64;
  _checked_ptr_1<long long> _ptr__4655(_4655 ? _4655->raw() : nullptr,_4655 ? _4655->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4656 = mosek::fusion::p_WorkStack::_get_impl(_4627)->f64;
  _checked_ptr_1<double> _ptr__4656(_4656 ? _4656->raw() : nullptr,_4656 ? _4656->size(0) : 0);
  int _9019 = (int)0;
  int _9020 = dim0;
  for (int _4657 = _9019; _4657 < _9020; ++_4657)
  {
    {
      _ptr__4651[(int)0] *= _ptr__4654[safe_add( _4640,_4657 )];
    }
  }
  _ptr__4651[(int)1] = _ptr__4654[safe_add( _4640,dim0 )];
  int _9021 = safe_add( dim0,(int)1 );
  int _9022 = dim1;
  for (int _4658 = _9021; _4658 < _9022; ++_4658)
  {
    {
      _ptr__4651[(int)2] *= _ptr__4654[safe_add( _4640,_4658 )];
    }
  }
  _ptr__4651[(int)3] = _ptr__4654[safe_add( _4640,dim1 )];
  int _9023 = safe_add( dim1,(int)1 );
  int _9024 = _4639;
  for (int _4659 = _9023; _4659 < _9024; ++_4659)
  {
    {
      _ptr__4651[(int)4] *= _ptr__4654[safe_add( _4640,_4659 )];
    }
  }
  _ptr__4653[(int)4] = (int)1;
  int _9025 = (int)1;
  int _9026 = (int)5;
  for (int _4660 = _9025; _4660 < _9026; ++_4660)
  {
    {
      _ptr__4653[(((int)5 - _4660) - (int)1)] = safe_mul( _ptr__4653[((int)5 - _4660)],_ptr__4651[((int)5 - _4660)] );
    }
  }
  if (_4643)
  {
    {
      int _4661 = _4635;
      int _9027 = (int)0;
      int _9028 = _4641;
      for (int _4662 = _9027; _4662 < _9028; ++_4662)
      {
        {
          _ptr__4654[safe_add( _4661,_4662 )] = _4662;
        }
      }
      int _4663 = _4636;
      std::shared_ptr< monty::ndarray< int,1 > > _4664 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__4664(_4664 ? _4664->raw() : nullptr,_4664 ? _4664->size(0) : 0);
      int _9029 = (int)0;
      int _9030 = (int)4;
      for (int _4665 = _9029; _4665 < _9030; ++_4665)
      {
        {
          long long _4666 = _ptr__4653[_ptr__4664[_4665]];
          int _4667 = _ptr__4651[_ptr__4664[_4665]];
          if ((_4667 > (int)1))
          {
            {
              int _9031 = (int)0;
              int _9032 = safe_add( _4667,(int)1 );
              for (int _4668 = _9031; _4668 < _9032; ++_4668)
              {
                {
                  _ptr__4654[safe_add( _4637,_4668 )] = (int)0;
                }
              }
              int _9033 = (int)0;
              int _9034 = _4641;
              for (int _4669 = _9033; _4669 < _9034; ++_4669)
              {
                {
                  ++ _ptr__4654[safe_add( safe_add( _4637,((_ptr__4655[safe_add( _4645,_ptr__4654[safe_add( _4661,_4669 )] )] / _4666) % _4667) ),(int)1 )];
                }
              }
              int _9035 = (int)0;
              int _9036 = _ptr__4651[(int)3];
              for (int _4670 = _9035; _4670 < _9036; ++_4670)
              {
                {
                  _ptr__4654[safe_add( safe_add( _4637,_4670 ),(int)1 )] += _ptr__4654[safe_add( _4637,_4670 )];
                }
              }
              int _9037 = (int)0;
              int _9038 = _4641;
              for (int _4671 = _9037; _4671 < _9038; ++_4671)
              {
                {
                  int _4672 = _ptr__4654[safe_add( _4661,_4671 )];
                  long long _4673 = ((_ptr__4655[safe_add( _4645,_4672 )] / _4666) % _4667);
                  _ptr__4654[safe_add( _4663,_ptr__4654[safe_add( _4637,_4673 )] )] = _4672;
                  ++ _ptr__4654[safe_add( _4637,_4673 )];
                }
              }
              int _4674 = _4661;
              _4661 = _4663;
              _4663 = _4674;
            }
          }
          {}
        }
      }
      int _9039 = (int)0;
      int _9040 = _4641;
      for (int _4675 = _9039; _4675 < _9040; ++_4675)
      {
        {
          _ptr__4655[safe_add( _4638,_4675 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__4655[safe_add( _4645,_4675 )] / _ptr__4653[(int)0]) % _ptr__4651[(int)0]),_ptr__4653[(int)0] ),safe_mul( ((_ptr__4655[safe_add( _4645,_4675 )] / _ptr__4653[(int)1]) % _ptr__4651[(int)1]),_ptr__4653[(int)3] ) ),safe_mul( ((_ptr__4655[safe_add( _4645,_4675 )] / _ptr__4653[(int)2]) % _ptr__4651[(int)2]),_ptr__4653[(int)2] ) ),safe_mul( ((_ptr__4655[safe_add( _4645,_4675 )] / _ptr__4653[(int)3]) % _ptr__4651[(int)3]),_ptr__4653[(int)1] ) ),safe_mul( ((_ptr__4655[safe_add( _4645,_4675 )] / _ptr__4653[(int)4]) % _ptr__4651[(int)4]),_ptr__4653[(int)4] ) );
        }
      }
      {
        int _4676 = (int)0;
        int _4677 = (int)0;
        while ( ((_4677 < _4641) && (_4676 < _4641)) )
        {
          {
            int _4678 = _ptr__4654[safe_add( _4661,_4676 )];
            if ((_ptr__4655[safe_add( _4645,_4677 )] < _ptr__4655[safe_add( _4638,_4678 )]))
            {
              {
                _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4677 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4677 )]);
                ++ _4649;
                ++ _4677;
              }
            }
            else if((_ptr__4655[safe_add( _4645,_4677 )] > _ptr__4655[safe_add( _4638,_4678 )]))
            {
              {
                _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4678 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4678 )]);
                ++ _4649;
                ++ _4676;
              }
            }
            else if((_ptr__4655[safe_add( _4645,_4677 )] != _ptr__4655[safe_add( _4645,_4678 )]))
            {
              {
                _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4677 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4677 )]);
                _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4678 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4678 )]);
                ++ _4649;
                ++ _4676;
                ++ _4677;
              }
            }
            else
            {
              {
                _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4677 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4677 )]);
                ++ _4649;
                ++ _4676;
                ++ _4677;
              }
            }
          }
        }
        while ( (_4677 < _4641) )
        {
          {
            _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4677 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4677 )]);
            ++ _4649;
            ++ _4677;
          }
        }
        while ( (_4676 < _4641) )
        {
          {
            int _4679 = _ptr__4654[safe_add( _4661,_4676 )];
            _4650 += (_ptr__4654[safe_add( safe_add( _4644,_4679 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4679 )]);
            ++ _4649;
            ++ _4676;
          }
        }
      }
      int _4680 = _4626->alloci32(safe_add( _4649,(int)1 ));
      _4626->pushi32((int)1);
      _4626->pushi32(_4650);
      _4626->pushi32(_4649);
      int _9041 = (int)0;
      int _9042 = _4639;
      for (int _4681 = _9041; _4681 < _9042; ++_4681)
      {
        {
          _4626->pushi32(_ptr__4654[safe_add( _4640,_4681 )]);
        }
      }
      _4626->pushi32(_4639);
      int _4682 = _4626->alloci64(_4650);
      int _4683 = _4626->alloci64(_4649);
      int _4684 = _4626->allocf64(_4650);
      int _4685 = _4626->allocf64(_4649);
      std::shared_ptr< monty::ndarray< int,1 > > _4686 = mosek::fusion::p_WorkStack::_get_impl(_4626)->i32;
      _checked_ptr_1<int> _ptr__4686(_4686 ? _4686->raw() : nullptr,_4686 ? _4686->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4687 = mosek::fusion::p_WorkStack::_get_impl(_4626)->i64;
      _checked_ptr_1<long long> _ptr__4687(_4687 ? _4687->raw() : nullptr,_4687 ? _4687->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4688 = mosek::fusion::p_WorkStack::_get_impl(_4626)->f64;
      _checked_ptr_1<double> _ptr__4688(_4688 ? _4688->raw() : nullptr,_4688 ? _4688->size(0) : 0);
      _ptr__4686[_4680] = (int)0;
      {
        int _4689 = (int)0;
        int _4690 = (int)0;
        int _4691 = (int)0;
        int _4692 = (int)0;
        _ptr__4654[_4680] = (int)0;
        while ( ((_4692 < _4641) && (_4691 < _4641)) )
        {
          {
            int _4693 = _ptr__4654[safe_add( _4661,_4691 )];
            if ((_ptr__4655[safe_add( _4645,_4692 )] < _ptr__4655[safe_add( _4638,_4693 )]))
            {
              {
                int _9043 = _ptr__4654[safe_add( _4644,_4692 )];
                int _9044 = _ptr__4654[safe_add( safe_add( _4644,_4692 ),(int)1 )];
                for (int _4694 = _9043; _4694 < _9044; ++_4694)
                {
                  {
                    _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4694 )];
                    _ptr__4688[safe_add( _4684,_4689 )] = (_ptr__4656[safe_add( _4648,_4694 )] * 0.5);
                    ++ _4689;
                  }
                }
                _ptr__4688[safe_add( _4685,_4690 )] = (_ptr__4656[safe_add( _4647,_4692 )] * 0.5);
                _ptr__4687[safe_add( _4683,_4690 )] = _ptr__4655[safe_add( _4645,_4692 )];
                _ptr__4686[safe_add( safe_add( _4680,_4690 ),(int)1 )] = _4689;
                ++ _4690;
                ++ _4692;
              }
            }
            else if((_ptr__4655[safe_add( _4645,_4692 )] > _ptr__4655[safe_add( _4638,_4693 )]))
            {
              {
                int _9045 = _ptr__4654[safe_add( _4644,_4693 )];
                int _9046 = _ptr__4654[safe_add( safe_add( _4644,_4693 ),(int)1 )];
                for (int _4695 = _9045; _4695 < _9046; ++_4695)
                {
                  {
                    _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4695 )];
                    _ptr__4688[safe_add( _4684,_4689 )] = (_ptr__4656[safe_add( _4648,_4695 )] * 0.5);
                    ++ _4689;
                  }
                }
                _ptr__4688[safe_add( _4685,_4690 )] = (_ptr__4656[safe_add( _4647,_4693 )] * 0.5);
                _ptr__4687[safe_add( _4683,_4690 )] = _ptr__4655[safe_add( _4638,_4693 )];
                _ptr__4686[safe_add( safe_add( _4680,_4690 ),(int)1 )] = _4689;
                ++ _4690;
                ++ _4691;
              }
            }
            else if((_ptr__4655[safe_add( _4645,_4692 )] != _ptr__4655[safe_add( _4645,_4693 )]))
            {
              {
                int _9047 = _ptr__4654[safe_add( _4644,_4692 )];
                int _9048 = _ptr__4654[safe_add( safe_add( _4644,_4692 ),(int)1 )];
                for (int _4696 = _9047; _4696 < _9048; ++_4696)
                {
                  {
                    _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4696 )];
                    _ptr__4688[safe_add( _4684,_4689 )] = (_ptr__4656[safe_add( _4648,_4696 )] * 0.5);
                    ++ _4689;
                  }
                }
                int _9049 = _ptr__4654[safe_add( _4644,_4693 )];
                int _9050 = _ptr__4654[safe_add( safe_add( _4644,_4693 ),(int)1 )];
                for (int _4697 = _9049; _4697 < _9050; ++_4697)
                {
                  {
                    _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4697 )];
                    _ptr__4688[safe_add( _4684,_4689 )] = (_ptr__4656[safe_add( _4648,_4697 )] * 0.5);
                    ++ _4689;
                  }
                }
                _ptr__4688[safe_add( _4685,_4690 )] = (0.5 * (_ptr__4656[safe_add( _4647,_4692 )] + _ptr__4656[safe_add( _4647,_4693 )]));
                _ptr__4687[safe_add( _4683,_4690 )] = _ptr__4655[safe_add( _4645,_4692 )];
                _ptr__4686[safe_add( safe_add( _4680,_4690 ),(int)1 )] = _4689;
                ++ _4690;
                ++ _4691;
                ++ _4692;
              }
            }
            else
            {
              {
                int _9051 = _ptr__4654[safe_add( _4644,_4692 )];
                int _9052 = _ptr__4654[safe_add( safe_add( _4644,_4692 ),(int)1 )];
                for (int _4698 = _9051; _4698 < _9052; ++_4698)
                {
                  {
                    _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4698 )];
                    _ptr__4688[safe_add( _4684,_4689 )] = _ptr__4656[safe_add( _4648,_4698 )];
                    ++ _4689;
                  }
                }
                _ptr__4688[safe_add( _4685,_4690 )] = _ptr__4656[safe_add( _4647,_4692 )];
                _ptr__4687[safe_add( _4683,_4690 )] = _ptr__4655[safe_add( _4645,_4692 )];
                _ptr__4686[safe_add( safe_add( _4680,_4690 ),(int)1 )] = _4689;
                ++ _4690;
                ++ _4691;
                ++ _4692;
              }
            }
          }
        }
        while ( (_4692 < _4641) )
        {
          {
            int _9053 = _ptr__4654[safe_add( _4644,_4692 )];
            int _9054 = _ptr__4654[safe_add( safe_add( _4644,_4692 ),(int)1 )];
            for (int _4699 = _9053; _4699 < _9054; ++_4699)
            {
              {
                _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4699 )];
                _ptr__4688[safe_add( _4684,_4689 )] = (_ptr__4656[safe_add( _4648,_4699 )] * 0.5);
                ++ _4689;
              }
            }
            _ptr__4688[safe_add( _4685,_4690 )] = (_ptr__4656[safe_add( _4647,_4692 )] * 0.5);
            _ptr__4687[safe_add( _4683,_4690 )] = _ptr__4655[safe_add( _4645,_4692 )];
            _ptr__4686[safe_add( safe_add( _4680,_4690 ),(int)1 )] = _4689;
            ++ _4690;
            ++ _4692;
          }
        }
        while ( (_4691 < _4641) )
        {
          {
            int _4700 = _ptr__4654[safe_add( _4661,_4691 )];
            int _9055 = _ptr__4654[safe_add( _4644,_4700 )];
            int _9056 = _ptr__4654[safe_add( safe_add( _4644,_4700 ),(int)1 )];
            for (int _4701 = _9055; _4701 < _9056; ++_4701)
            {
              {
                _ptr__4687[safe_add( _4682,_4689 )] = _ptr__4655[safe_add( _4646,_4701 )];
                _ptr__4688[safe_add( _4684,_4689 )] = (_ptr__4656[safe_add( _4648,_4701 )] * 0.5);
                ++ _4689;
              }
            }
            _ptr__4688[safe_add( _4685,_4690 )] = (_ptr__4656[safe_add( _4647,_4700 )] * 0.5);
            _ptr__4687[safe_add( _4683,_4690 )] = _ptr__4655[safe_add( _4638,_4700 )];
            _ptr__4686[safe_add( safe_add( _4680,_4690 ),(int)1 )] = _4689;
            ++ _4690;
            ++ _4691;
          }
        }
      }
    }
  }
  else
  {
    {
      _4649 = _4641;
      _4650 = safe_mul( _4642,(int)2 );
      int _9057 = (int)0;
      int _9058 = _ptr__4651[(int)0];
      for (int _4702 = _9057; _4702 < _9058; ++_4702)
      {
        {
          int _9059 = (int)0;
          int _9060 = _ptr__4651[(int)2];
          for (int _4703 = _9059; _4703 < _9060; ++_4703)
          {
            {
              int _9061 = (int)0;
              int _9062 = _ptr__4651[(int)4];
              for (int _4704 = _9061; _4704 < _9062; ++_4704)
              {
                {
                  int _9063 = (int)0;
                  int _9064 = _ptr__4651[(int)1];
                  for (int _4705 = _9063; _4705 < _9064; ++_4705)
                  {
                    {
                      long long _4706 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__4653[(int)0],_4702 ),safe_mul( _ptr__4653[(int)1],_4705 ) ),safe_mul( _ptr__4653[(int)2],_4703 ) ),safe_mul( _ptr__4653[(int)3],_4705 ) ),safe_mul( _ptr__4653[(int)4],_4704 ) );
                      _4650 -= (_ptr__4654[safe_add( safe_add( _4644,_4706 ),(int)1 )] - _ptr__4654[safe_add( _4644,_4706 )]);
                    }
                  }
                }
              }
            }
          }
        }
      }
      int _4707 = _4626->alloci32(safe_add( _4649,(int)1 ));
      _4626->pushi32((int)0);
      _4626->pushi32(_4650);
      _4626->pushi32(_4649);
      int _9065 = (int)0;
      int _9066 = _4639;
      for (int _4708 = _9065; _4708 < _9066; ++_4708)
      {
        {
          _4626->pushi32(_ptr__4654[safe_add( _4640,_4708 )]);
        }
      }
      _4626->pushi32(_4639);
      int _4709 = _4626->alloci64(_4650);
      int _4710 = _4626->allocf64(_4650);
      int _4711 = _4626->allocf64(_4649);
      std::shared_ptr< monty::ndarray< int,1 > > _4712 = mosek::fusion::p_WorkStack::_get_impl(_4626)->i32;
      _checked_ptr_1<int> _ptr__4712(_4712 ? _4712->raw() : nullptr,_4712 ? _4712->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4713 = mosek::fusion::p_WorkStack::_get_impl(_4626)->i64;
      _checked_ptr_1<long long> _ptr__4713(_4713 ? _4713->raw() : nullptr,_4713 ? _4713->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4714 = mosek::fusion::p_WorkStack::_get_impl(_4626)->f64;
      _checked_ptr_1<double> _ptr__4714(_4714 ? _4714->raw() : nullptr,_4714 ? _4714->size(0) : 0);
      int _4715 = (int)0;
      int _4716 = (int)0;
      _ptr__4712[_4707] = (int)0;
      int _4717 = (int)0;
      int _9067 = (int)0;
      int _9068 = _ptr__4651[(int)0];
      for (int _4718 = _9067; _4718 < _9068; ++_4718)
      {
        {
          int _9069 = (int)0;
          int _9070 = _ptr__4651[(int)1];
          for (int _4719 = _9069; _4719 < _9070; ++_4719)
          {
            {
              int _9071 = (int)0;
              int _9072 = _ptr__4651[(int)2];
              for (int _4720 = _9071; _4720 < _9072; ++_4720)
              {
                {
                  int _9073 = (int)0;
                  int _9074 = _ptr__4651[(int)3];
                  for (int _4721 = _9073; _4721 < _9074; ++_4721)
                  {
                    {
                      int _9075 = (int)0;
                      int _9076 = _ptr__4651[(int)4];
                      for (int _4722 = _9075; _4722 < _9076; ++_4722)
                      {
                        {
                          if ((_4719 == _4721))
                          {
                            {
                              int _9077 = _ptr__4654[safe_add( _4644,_4717 )];
                              int _9078 = _ptr__4654[safe_add( safe_add( _4644,_4717 ),(int)1 )];
                              for (int _4723 = _9077; _4723 < _9078; ++_4723)
                              {
                                {
                                  _ptr__4713[safe_add( _4709,_4715 )] = _ptr__4655[safe_add( _4646,_4723 )];
                                  _ptr__4714[safe_add( _4710,_4715 )] = _ptr__4656[safe_add( _4648,_4723 )];
                                  ++ _4715;
                                }
                              }
                              _ptr__4714[safe_add( _4711,_4716 )] = _ptr__4656[safe_add( _4647,_4718 )];
                              _ptr__4712[safe_add( safe_add( _4707,_4716 ),(int)1 )] = _4715;
                              ++ _4717;
                            }
                          }
                          else
                          {
                            {
                              long long _4724 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4718,_ptr__4653[(int)0] ),safe_mul( _4721,_ptr__4653[(int)1] ) ),safe_mul( _4720,_ptr__4653[(int)2] ) ),safe_mul( _4719,_ptr__4653[(int)3] ) ),_4722 );
                              int _9079 = _ptr__4654[safe_add( _4644,_4717 )];
                              int _9080 = _ptr__4654[safe_add( safe_add( _4644,_4717 ),(int)1 )];
                              for (int _4725 = _9079; _4725 < _9080; ++_4725)
                              {
                                {
                                  _ptr__4713[safe_add( _4709,_4715 )] = _ptr__4655[safe_add( _4646,_4725 )];
                                  _ptr__4714[safe_add( _4710,_4715 )] = (_ptr__4656[safe_add( _4648,_4725 )] * 0.5);
                                  ++ _4715;
                                }
                              }
                              int _9081 = _ptr__4654[safe_add( _4644,_4724 )];
                              int _9082 = _ptr__4654[safe_add( safe_add( _4644,_4724 ),(int)1 )];
                              for (int _4726 = _9081; _4726 < _9082; ++_4726)
                              {
                                {
                                  _ptr__4713[safe_add( _4709,_4715 )] = _ptr__4655[safe_add( _4646,_4726 )];
                                  _ptr__4714[safe_add( _4710,_4715 )] = (_ptr__4656[safe_add( _4648,_4726 )] * 0.5);
                                  ++ _4715;
                                }
                              }
                              _ptr__4714[safe_add( _4711,_4716 )] = (0.5 * (_ptr__4656[safe_add( _4647,_4717 )] + _ptr__4656[safe_add( _4647,_4724 )]));
                              _ptr__4712[safe_add( safe_add( _4707,_4716 ),(int)1 )] = _4715;
                              ++ _4717;
                            }
                          }
                          ++ _4716;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4727){ return new mosek::fusion::ExprCompress(_4727); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4727) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4727); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4727){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4727->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4727;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4728,    double _4729){ return new mosek::fusion::ExprCompress(_4728,_4729); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4728,    double _4729) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4728,_4729); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4728,    double _4729){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4728->getShape());
    eps = _4729;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4728;
  }
}void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4730,monty::rc_ptr< ::mosek::fusion::WorkStack > _4731,monty::rc_ptr< ::mosek::fusion::WorkStack > _4732) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4730,_4731,_4732); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4730,monty::rc_ptr< ::mosek::fusion::WorkStack > _4731,monty::rc_ptr< ::mosek::fusion::WorkStack > _4732){
  expr->eval(_4731,_4730,_4732);
  _4731->pop_expr();
  int _4733 = mosek::fusion::p_WorkStack::_get_impl(_4731)->nd;
  int _4734 = mosek::fusion::p_WorkStack::_get_impl(_4731)->shape_base;
  int _4735 = mosek::fusion::p_WorkStack::_get_impl(_4731)->nelem;
  int _4736 = mosek::fusion::p_WorkStack::_get_impl(_4731)->nnz;
  bool _4737 = mosek::fusion::p_WorkStack::_get_impl(_4731)->hassp;
  int _4738 = mosek::fusion::p_WorkStack::_get_impl(_4731)->ptr_base;
  int _4739 = mosek::fusion::p_WorkStack::_get_impl(_4731)->sp_base;
  int _4740 = mosek::fusion::p_WorkStack::_get_impl(_4731)->nidxs_base;
  int _4741 = mosek::fusion::p_WorkStack::_get_impl(_4731)->bfix_base;
  int _4742 = mosek::fusion::p_WorkStack::_get_impl(_4731)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4743 = mosek::fusion::p_WorkStack::_get_impl(_4731)->i32;
  _checked_ptr_1<int> _ptr__4743(_4743 ? _4743->raw() : nullptr,_4743 ? _4743->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4744 = mosek::fusion::p_WorkStack::_get_impl(_4731)->i64;
  _checked_ptr_1<long long> _ptr__4744(_4744 ? _4744->raw() : nullptr,_4744 ? _4744->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4745 = mosek::fusion::p_WorkStack::_get_impl(_4731)->f64;
  _checked_ptr_1<double> _ptr__4745(_4745 ? _4745->raw() : nullptr,_4745 ? _4745->size(0) : 0);
  std::vector<int> _9083;
  for (int _4747 = (int)0, _9084 = _4733; _4747 < _9084 ; ++_4747)
  {
    _9083.push_back(_ptr__4743[safe_add( _4734,_4747 )]);
  }
  auto _9085 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9083.size()),_9083.begin(),_9083.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4746 = _9085;
  _checked_ptr_1<int> _ptr__4746(_4746 ? _4746->raw() : nullptr,_4746 ? _4746->size(0) : 0);
  bool _4748 = true;
  {
    int _9086 = (int)0;
    int _9087 = _4735;
    for (int _4749 = _9086; _4749 < _9087; ++_4749)
    {
      {
        int _9088 = safe_add( _ptr__4743[safe_add( _4738,_4749 )],(int)1 );
        int _9089 = _ptr__4743[safe_add( safe_add( _4738,_4749 ),(int)1 )];
        for (int _4750 = _9088; _4750 < _9089; ++_4750)
        {
          {
            _4748 = (_4748 && ((_ptr__4744[safe_add( _4740,_4750 )] != (int)0) && (_ptr__4744[(safe_add( _4740,_4750 ) - (int)1)] < _ptr__4744[safe_add( _4740,_4750 )])));
          }
        }
      }
    }
    if (_4748)
    {
      {
        int _9090 = (int)0;
        int _9091 = _4736;
        for (int _4751 = _9090; _4751 < _9091; ++_4751)
        {
          {
            _4748 = (_4748 && ((_ptr__4745[safe_add( _4742,_4751 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4745[safe_add( _4742,_4751 )])));
          }
        }
      }
    }
    {}
  }
  if (_4748)
  {
    {
      _4730->alloc_expr(_4733,_4735,_4736,_4737);
      int _4752 = mosek::fusion::p_WorkStack::_get_impl(_4730)->ptr_base;
      int _4753 = mosek::fusion::p_WorkStack::_get_impl(_4730)->nidxs_base;
      int _4754 = mosek::fusion::p_WorkStack::_get_impl(_4730)->sp_base;
      int _4755 = mosek::fusion::p_WorkStack::_get_impl(_4730)->cof_base;
      int _4756 = mosek::fusion::p_WorkStack::_get_impl(_4730)->bfix_base;
      int _4757 = mosek::fusion::p_WorkStack::_get_impl(_4730)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4758 = mosek::fusion::p_WorkStack::_get_impl(_4730)->i32;
      _checked_ptr_1<int> _ptr__4758(_4758 ? _4758->raw() : nullptr,_4758 ? _4758->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4759 = mosek::fusion::p_WorkStack::_get_impl(_4730)->i64;
      _checked_ptr_1<long long> _ptr__4759(_4759 ? _4759->raw() : nullptr,_4759 ? _4759->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4760 = mosek::fusion::p_WorkStack::_get_impl(_4730)->f64;
      _checked_ptr_1<double> _ptr__4760(_4760 ? _4760->raw() : nullptr,_4760 ? _4760->size(0) : 0);
      {
        int _9092 = (int)0;
        int _9093 = _4733;
        for (int _4761 = _9092; _4761 < _9093; ++_4761)
        {
          {
            _ptr__4758[safe_add( _4757,_4761 )] = _ptr__4746[_4761];
          }
        }
        int _9094 = (int)0;
        int _9095 = safe_add( _4735,(int)1 );
        for (int _4762 = _9094; _4762 < _9095; ++_4762)
        {
          {
            _ptr__4758[safe_add( _4752,_4762 )] = _ptr__4743[safe_add( _4738,_4762 )];
          }
        }
        if (_4737)
        {
          {
            int _9096 = (int)0;
            int _9097 = _4735;
            for (int _4763 = _9096; _4763 < _9097; ++_4763)
            {
              {
                _ptr__4759[safe_add( _4754,_4763 )] = _ptr__4744[safe_add( _4739,_4763 )];
              }
            }
          }
        }
        {}
        int _9098 = (int)0;
        int _9099 = _4735;
        for (int _4764 = _9098; _4764 < _9099; ++_4764)
        {
          {
            _ptr__4760[safe_add( _4756,_4764 )] = _ptr__4745[safe_add( _4741,_4764 )];
          }
        }
        int _9100 = (int)0;
        int _9101 = _4736;
        for (int _4765 = _9100; _4765 < _9101; ++_4765)
        {
          {
            _ptr__4759[safe_add( _4753,_4765 )] = _ptr__4744[safe_add( _4740,_4765 )];
          }
        }
        int _9102 = (int)0;
        int _9103 = _4736;
        for (int _4766 = _9102; _4766 < _9103; ++_4766)
        {
          {
            _ptr__4760[safe_add( _4755,_4766 )] = _ptr__4745[safe_add( _4742,_4766 )];
          }
        }
      }
    }
  }
  else
  {
    {
      int _4767 = _4732->alloci32(_4736);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4731,_4732,_4767,_4735,_4736,_4738,_4740);
      std::shared_ptr< monty::ndarray< int,1 > > _4768 = mosek::fusion::p_WorkStack::_get_impl(_4732)->i32;
      _checked_ptr_1<int> _ptr__4768(_4768 ? _4768->raw() : nullptr,_4768 ? _4768->size(0) : 0);
      int _4769 = (int)0;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4770 = mosek::fusion::p_WorkStack::_get_impl(_4730)->i32;
        _checked_ptr_1<int> _ptr__4770(_4770 ? _4770->raw() : nullptr,_4770 ? _4770->size(0) : 0);
        int _9104 = (int)0;
        int _9105 = _4735;
        for (int _4771 = _9104; _4771 < _9105; ++_4771)
        {
          {
            int _4772 = _ptr__4743[safe_add( safe_add( _4738,_4771 ),(int)1 )];
            int _4773 = _ptr__4743[safe_add( _4738,_4771 )];
            if ((_4773 < _4772))
            {
              {
                int _4774 = _4773;
                while ( (_4774 < _4772) )
                {
                  {
                    double _4775 = 0.0;
                    long long _4776 = _ptr__4744[safe_add( _4740,_ptr__4768[safe_add( _4767,_4774 )] )];
                    if ((_4776 == (int)0))
                    {
                      {
                        ++ _4774;
                      }
                    }
                    else
                    {
                      {
                        while ( ((_4774 < _4772) && (_ptr__4744[safe_add( _4740,_ptr__4768[safe_add( _4767,_4774 )] )] == _4776)) )
                        {
                          {
                            _4775 += _ptr__4745[safe_add( _4742,_ptr__4768[safe_add( _4767,_4774 )] )];
                            ++ _4774;
                          }
                        }
                        {
                        }
                        if (((_4776 != (int)0) && ((_4775 < (-eps)) || (eps < _4775))))
                        {
                          {
                            ++ _4769;
                          }
                        }
                        {}
                      }
                    }
                  }
                }
              }
            }
            {}
          }
        }
      }
      _4730->alloc_expr(_4733,_4735,_4769,_4737);
      int _4777 = mosek::fusion::p_WorkStack::_get_impl(_4730)->nidxs_base;
      int _4778 = mosek::fusion::p_WorkStack::_get_impl(_4730)->shape_base;
      int _4779 = mosek::fusion::p_WorkStack::_get_impl(_4730)->sp_base;
      int _4780 = mosek::fusion::p_WorkStack::_get_impl(_4730)->cof_base;
      int _4781 = mosek::fusion::p_WorkStack::_get_impl(_4730)->bfix_base;
      int _4782 = mosek::fusion::p_WorkStack::_get_impl(_4730)->ptr_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4783 = mosek::fusion::p_WorkStack::_get_impl(_4730)->i32;
      _checked_ptr_1<int> _ptr__4783(_4783 ? _4783->raw() : nullptr,_4783 ? _4783->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4784 = mosek::fusion::p_WorkStack::_get_impl(_4730)->i64;
      _checked_ptr_1<long long> _ptr__4784(_4784 ? _4784->raw() : nullptr,_4784 ? _4784->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4785 = mosek::fusion::p_WorkStack::_get_impl(_4730)->f64;
      _checked_ptr_1<double> _ptr__4785(_4785 ? _4785->raw() : nullptr,_4785 ? _4785->size(0) : 0);
      {
        int _9106 = (int)0;
        int _9107 = _4733;
        for (int _4786 = _9106; _4786 < _9107; ++_4786)
        {
          {
            _ptr__4783[safe_add( _4778,_4786 )] = _ptr__4746[_4786];
          }
        }
        int _9108 = (int)0;
        int _9109 = _4735;
        for (int _4787 = _9108; _4787 < _9109; ++_4787)
        {
          {
            _ptr__4785[safe_add( _4780,_4787 )] = 0.0;
          }
        }
        int _9110 = (int)0;
        int _9111 = _4735;
        for (int _4788 = _9110; _4788 < _9111; ++_4788)
        {
          {
            _ptr__4785[safe_add( _4781,_4788 )] = _ptr__4745[safe_add( _4741,_4788 )];
          }
        }
        if (_4737)
        {
          {
            int _9112 = (int)0;
            int _9113 = _4735;
            for (int _4789 = _9112; _4789 < _9113; ++_4789)
            {
              {
                _ptr__4784[safe_add( _4779,_4789 )] = _ptr__4744[safe_add( _4779,_4789 )];
              }
            }
          }
        }
        {}
        int _4790 = (int)0;
        {
          int _4791 = (_4780 - _4777);
          _ptr__4783[_4782] = (int)0;
          int _9114 = (int)0;
          int _9115 = _4735;
          for (int _4792 = _9114; _4792 < _9115; ++_4792)
          {
            {
              int _4793 = _ptr__4743[safe_add( safe_add( _4738,_4792 ),(int)1 )];
              int _4794 = _ptr__4743[safe_add( _4738,_4792 )];
              if ((_4794 < _4793))
              {
                {
                  int _4795 = _4794;
                  while ( (_4795 < _4793) )
                  {
                    {
                      double _4796 = 0.0;
                      long long _4797 = _ptr__4744[safe_add( _4740,_ptr__4768[safe_add( _4767,_4795 )] )];
                      while ( ((_4795 < _4793) && (_ptr__4744[safe_add( _4740,_ptr__4768[safe_add( _4767,_4795 )] )] == _4797)) )
                      {
                        {
                          _4796 += _ptr__4745[safe_add( _4742,_ptr__4768[safe_add( _4767,_4795 )] )];
                          ++ _4795;
                        }
                      }
                      {
                      }
                      if (((_4797 != (int)0) && ((_4796 < (-eps)) || (eps < _4796))))
                      {
                        {
                          _ptr__4784[safe_add( _4777,_4790 )] = _4797;
                          _ptr__4785[safe_add( _4780,_4790 )] = _4796;
                          ++ _4790;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
              _ptr__4783[safe_add( safe_add( _4782,_4792 ),(int)1 )] = _4790;
            }
          }
        }
      }
    }
  }
  _4732->clear();
}
void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4798,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4799,    int _4800,    int _4801,    int _4802,    int _4803,    int _4804) { mosek::fusion::p_ExprCompress::arg_sort(_4798,_4799,_4800,_4801,_4802,_4803,_4804); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4798,monty::rc_ptr< ::mosek::fusion::WorkStack > _4799,int _4800,int _4801,int _4802,int _4803,int _4804){
  int _4805 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4806 = mosek::fusion::p_WorkStack::_get_impl(_4798)->i32;
  _checked_ptr_1<int> _ptr__4806(_4806 ? _4806->raw() : nullptr,_4806 ? _4806->size(0) : 0);
  int _9116 = (int)0;
  int _9117 = _4801;
  for (int _4807 = _9116; _4807 < _9117; ++_4807)
  {
    {
      if (((_ptr__4806[safe_add( safe_add( _4803,_4807 ),(int)1 )] - _ptr__4806[safe_add( _4803,_4807 )]) > _4805))
      {
        {
          _4805 = (_ptr__4806[safe_add( safe_add( _4803,_4807 ),(int)1 )] - _ptr__4806[safe_add( _4803,_4807 )]);
        }
      }
      {}
    }
  }
  int _9118;
  bool _9119 = (_4805 > (int)2);
  if (_9119)
  {
    _9118 = _4799->alloci32(safe_mul( _4805,(int)2 ));
  }
  else
  {
    _9118 = (int)99999;
  }
  int _4808 = _9118;
  std::shared_ptr< monty::ndarray< int,1 > > _4809 = mosek::fusion::p_WorkStack::_get_impl(_4799)->i32;
  _checked_ptr_1<int> _ptr__4809(_4809 ? _4809->raw() : nullptr,_4809 ? _4809->size(0) : 0);
  _4806 = mosek::fusion::p_WorkStack::_get_impl(_4798)->i32;
  _ptr__4806.update(_4806 ? _4806->raw() : nullptr, _4806 ? _4806->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4810 = mosek::fusion::p_WorkStack::_get_impl(_4798)->i64;
  _checked_ptr_1<long long> _ptr__4810(_4810 ? _4810->raw() : nullptr,_4810 ? _4810->size(0) : 0);
  int _9120 = (int)0;
  int _9121 = _4801;
  for (int _4811 = _9120; _4811 < _9121; ++_4811)
  {
    {
      int _4812 = _ptr__4806[safe_add( _4803,_4811 )];
      int _4813 = _ptr__4806[safe_add( safe_add( _4803,_4811 ),(int)1 )];
      int _4814 = (_4813 - _4812);
      if ((_4814 == (int)0))
      {
        {
        }
      }
      else if((_4814 == (int)1))
      {
        {
          _ptr__4809[safe_add( _4800,_4812 )] = _4812;
        }
      }
      else if((_4814 == (int)2))
      {
        {
          if ((_ptr__4810[safe_add( _4804,_4812 )] <= _ptr__4810[safe_add( safe_add( _4804,_4812 ),(int)1 )]))
          {
            {
              _ptr__4809[safe_add( _4800,_4812 )] = _4812;
              _ptr__4809[safe_add( safe_add( _4800,_4812 ),(int)1 )] = safe_add( _4812,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4809[safe_add( _4800,_4812 )] = safe_add( _4812,(int)1 );
              _ptr__4809[safe_add( safe_add( _4800,_4812 ),(int)1 )] = _4812;
            }
          }
        }
      }
      else
      {
        {
          long long _4815 = _ptr__4810[safe_add( _4804,_4812 )];
          long long _4816 = _ptr__4810[safe_add( _4804,_4812 )];
          bool _4817 = false;
          int _9122 = safe_add( _4812,(int)1 );
          int _9123 = _4813;
          for (int _4818 = _9122; _4818 < _9123; ++_4818)
          {
            {
              _4817 = (_4817 && (_ptr__4810[(safe_add( _4804,_4818 ) - (int)1)] <= _ptr__4810[safe_add( _4804,_4818 )]));
              if ((_4815 > _ptr__4810[safe_add( _4804,_4818 )]))
              {
                {
                  _4815 = _ptr__4810[safe_add( _4804,_4818 )];
                }
              }
              {}
              if ((_4816 < _ptr__4810[safe_add( _4804,_4818 )]))
              {
                {
                  _4816 = _ptr__4810[safe_add( _4804,_4818 )];
                }
              }
              {}
            }
          }
          if (_4817)
          {
            {
              int _9124 = _4812;
              int _9125 = _4813;
              for (int _4819 = _9124; _4819 < _9125; ++_4819)
              {
                {
                  _ptr__4809[safe_add( _4800,_4819 )] = _4819;
                }
              }
            }
          }
          else if((safe_add( (_4816 - _4815),(int)1 ) <= _4814))
          {
            {
              long long _4820 = safe_add( (_4816 - _4815),(int)1 );
              int _9126 = (int)0;
              long long _9127 = safe_add( _4820,(int)1 );
              for (long long _4821 = _9126; _4821 < _9127; ++_4821)
              {
                {
                  _ptr__4809[safe_add( _4808,_4821 )] = (int)0;
                }
              }
              int _9128 = _4812;
              int _9129 = _4813;
              for (int _4822 = _9128; _4822 < _9129; ++_4822)
              {
                {
                  ++ _ptr__4809[safe_add( (safe_add( _4808,_ptr__4810[safe_add( _4804,_4822 )] ) - _4815),(int)1 )];
                }
              }
              int _9130 = (int)0;
              long long _9131 = _4820;
              for (long long _4823 = _9130; _4823 < _9131; ++_4823)
              {
                {
                  _ptr__4809[safe_add( safe_add( _4808,_4823 ),(int)1 )] += _ptr__4809[safe_add( _4808,_4823 )];
                }
              }
              int _9132 = _4812;
              int _9133 = _4813;
              for (int _4824 = _9132; _4824 < _9133; ++_4824)
              {
                {
                  _ptr__4809[safe_add( safe_add( _4800,_4812 ),_ptr__4809[(safe_add( _4808,_ptr__4810[safe_add( _4804,_4824 )] ) - _4815)] )] = _4824;
                  ++ _ptr__4809[(safe_add( _4808,_ptr__4810[safe_add( _4804,_4824 )] ) - _4815)];
                }
              }
            }
          }
          else
          {
            {
              int _4825 = (int)1;
              int _4826 = _4808;
              int _4827 = safe_add( _4808,_4814 );
              int _9134 = (int)0;
              int _9135 = _4814;
              for (int _4828 = _9134; _4828 < _9135; ++_4828)
              {
                {
                  _ptr__4809[safe_add( _4826,_4828 )] = _4828;
                }
              }
              while ( (_4825 < _4814) )
              {
                {
                  int _4829 = safe_mul( _4825,(int)2 );
                  int _4830 = (_4814 / _4829);
                  if ((safe_add( safe_mul( _4830,_4829 ),_4825 ) < _4814))
                  {
                    {
                      ++ _4830;
                    }
                  }
                  {}
                  int _4831 = (int)0;
                  int _9136 = (int)0;
                  int _9137 = _4830;
                  for (int _4832 = _9136; _4832 < _9137; ++_4832)
                  {
                    {
                      int _4833 = safe_mul( _4832,_4829 );
                      int _4834 = safe_add( _4833,_4825 );
                      int _4835 = _4834;
                      int _4836 = safe_add( _4835,_4825 );
                      if ((_4836 > _4814))
                      {
                        {
                          _4836 = _4814;
                        }
                      }
                      {}
                      while ( ((_4833 < _4834) && (_4835 < _4836)) )
                      {
                        {
                          if ((_ptr__4810[safe_add( safe_add( _4804,_ptr__4809[safe_add( _4826,_4833 )] ),_4812 )] <= _ptr__4810[safe_add( safe_add( _4804,_ptr__4809[safe_add( _4826,_4835 )] ),_4812 )]))
                          {
                            {
                              _ptr__4809[safe_add( _4827,_4831 )] = _ptr__4809[safe_add( _4826,_4833 )];
                              ++ _4831;
                              ++ _4833;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4809[safe_add( _4827,_4831 )] = _ptr__4809[safe_add( _4826,_4835 )];
                              ++ _4831;
                              ++ _4835;
                            }
                          }
                        }
                      }
                      while ( (_4833 < _4834) )
                      {
                        {
                          _ptr__4809[safe_add( _4827,_4831 )] = _ptr__4809[safe_add( _4826,_4833 )];
                          ++ _4831;
                          ++ _4833;
                        }
                      }
                      while ( (_4835 < _4836) )
                      {
                        {
                          _ptr__4809[safe_add( _4827,_4831 )] = _ptr__4809[safe_add( _4826,_4835 )];
                          ++ _4831;
                          ++ _4835;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4830,_4829 ) < _4814))
                  {
                    {
                      int _4837 = safe_mul( _4830,_4829 );
                      while ( (_4837 < _4814) )
                      {
                        {
                          _ptr__4809[safe_add( _4827,_4831 )] = _ptr__4809[safe_add( _4826,_4837 )];
                          ++ _4837;
                          ++ _4831;
                        }
                      }
                    }
                  }
                  {}
                  int _4838 = _4826;
                  _4826 = _4827;
                  _4827 = _4838;
                  _4825 *= (int)2;
                }
              }
              int _9138 = (int)0;
              int _9139 = _4814;
              for (int _4839 = _9138; _4839 < _9139; ++_4839)
              {
                {
                  _ptr__4809[safe_add( safe_add( _4800,_4812 ),_4839 )] = safe_add( _ptr__4809[safe_add( _4826,_4839 )],_4812 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4840,    int _4841,    int _4842,    int _4843,    int _4844,    int _4845,    std::shared_ptr< monty::ndarray< int,1 > > _4846,    std::shared_ptr< monty::ndarray< long long,1 > > _4847) { mosek::fusion::p_ExprCompress::merge_sort(_4840,_4841,_4842,_4843,_4844,_4845,_4846,_4847); }void mosek::fusion::p_ExprCompress::merge_sort(int _4840,int _4841,int _4842,int _4843,int _4844,int _4845,std::shared_ptr< monty::ndarray< int,1 > > _4846,std::shared_ptr< monty::ndarray< long long,1 > > _4847){
  _checked_ptr_1<int> _ptr__4846(_4846 ? _4846->raw() : nullptr, _4846 ? _4846->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4847(_4847 ? _4847->raw() : nullptr, _4847 ? _4847->size(0) : 0);
  int _4848 = _4840;
  int _4849 = _4841;
  int _9140 = (int)0;
  int _9141 = _4843;
  for (int _4850 = _9140; _4850 < _9141; ++_4850)
  {
    {
      _ptr__4846[safe_add( _4848,_4850 )] = _4850;
    }
  }
  int _9142 = (int)0;
  int _9143 = _4842;
  for (int _4851 = _9142; _4851 < _9143; ++_4851)
  {
    {
      _4848 = _4840;
      _4849 = _4841;
      int _4852 = _ptr__4846[safe_add( safe_add( _4844,_4851 ),(int)1 )];
      int _4853 = _ptr__4846[safe_add( _4844,_4851 )];
      if ((safe_add( _4853,(int)1 ) < _4852))
      {
        {
          int _4854 = (_4852 - _4853);
          int _4855 = (int)0;
          while ( (_4854 > (int)1) )
          {
            {
              ++ _4855;
              _4854 /= (int)2;
            }
          }
          _4854 = (_4852 - _4853);
          int _4856 = (int)1;
          int _9144 = (int)0;
          int _9145 = safe_add( _4855,(int)1 );
          for (int _4857 = _9144; _4857 < _9145; ++_4857)
          {
            {
              int _4858 = ((safe_add( _4854,_4856 ) - (int)1) / _4856);
              int _4859 = (_4858 / (int)2);
              int _4860 = _4853;
              int _9146 = (int)0;
              int _9147 = _4859;
              for (int _4861 = _9146; _4861 < _9147; ++_4861)
              {
                {
                  int _4862 = safe_mul( safe_mul( _4861,_4856 ),(int)2 );
                  int _9148;
                  bool _9149 = (safe_add( safe_add( _4853,_4862 ),safe_mul( (int)2,_4856 ) ) < _4852);
                  if (_9149)
                  {
                    _9148 = safe_add( safe_add( _4853,_4862 ),safe_mul( (int)2,_4856 ) );
                  }
                  else
                  {
                    _9148 = _4852;
                  }
                  int _4863 = _9148;
                  int _4864 = safe_add( safe_add( _4853,_4862 ),_4856 );
                  int _4865 = safe_add( safe_add( _4853,_4862 ),_4856 );
                  int _4866 = safe_add( _4853,_4862 );
                  while ( ((_4866 < _4865) && (_4864 < _4863)) )
                  {
                    {
                      if ((_ptr__4847[safe_add( _4845,_ptr__4846[safe_add( _4848,_4866 )] )] <= _ptr__4847[safe_add( _4845,_ptr__4846[safe_add( _4848,_4864 )] )]))
                      {
                        {
                          _ptr__4846[safe_add( _4849,_4860 )] = _ptr__4846[safe_add( _4848,_4866 )];
                          ++ _4860;
                          ++ _4866;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4846[safe_add( _4849,_4860 )] = _ptr__4846[safe_add( _4848,_4864 )];
                          ++ _4860;
                          ++ _4864;
                        }
                      }
                    }
                  }
                  while ( (_4866 < _4865) )
                  {
                    {
                      _ptr__4846[safe_add( _4849,_4860 )] = _ptr__4846[safe_add( _4848,_4866 )];
                      ++ _4860;
                      ++ _4866;
                    }
                  }
                  while ( (_4864 < _4863) )
                  {
                    {
                      _ptr__4846[safe_add( _4849,_4860 )] = _ptr__4846[safe_add( _4848,_4864 )];
                      ++ _4860;
                      ++ _4864;
                    }
                  }
                }
              }
              int _9150 = _4860;
              int _9151 = _4852;
              for (int _4867 = _9150; _4867 < _9151; ++_4867)
              {
                {
                  _ptr__4846[safe_add( _4849,_4867 )] = _ptr__4846[safe_add( _4848,_4867 )];
                }
              }
              int _4868 = _4848;
              _4848 = _4849;
              _4849 = _4868;
              _4856 *= (int)2;
            }
          }
        }
      }
      {}
      int _9152 = _4853;
      int _9153 = _4852;
      for (int _4869 = _9152; _4869 < _9153; ++_4869)
      {
        {
          _ptr__4846[safe_add( _4840,_4869 )] = _ptr__4846[safe_add( _4848,_4869 )];
        }
      }
    }
  }
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4870){ return new mosek::fusion::ExprCondense(_4870); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4870) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_4870); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4870){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4870->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _4870;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4871,monty::rc_ptr< ::mosek::fusion::WorkStack > _4872,monty::rc_ptr< ::mosek::fusion::WorkStack > _4873) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_4871,_4872,_4873); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4871,monty::rc_ptr< ::mosek::fusion::WorkStack > _4872,monty::rc_ptr< ::mosek::fusion::WorkStack > _4873){
  expr->eval(_4871,_4872,_4873);
  int _4874 = _4871->popi32();
  long long _4875 = (int)1;
  int _9154 = (int)0;
  int _9155 = _4874;
  for (int _4876 = _9154; _4876 < _9155; ++_4876)
  {
    {
      _4875 *= _4871->popi32();
    }
  }
  int _4877 = _4871->popi32();
  int _4878 = _4871->popi32();
  bool _4879 = (_4871->popi32() != (int)0);
  if (_4879)
  {
    {
      _4871->popi64(_4877);
    }
  }
  {}
  _4871->pushi32((int)0);
  _4871->pushi32(_4878);
  _4871->pushi32(_4877);
  _4871->pushi32(_4877);
  _4871->pushi32((int)1);
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4880){ return new mosek::fusion::ExprFromVar(_4880); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4880) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_4880); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4880){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4880->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _4880;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4881,monty::rc_ptr< ::mosek::fusion::WorkStack > _4882,monty::rc_ptr< ::mosek::fusion::WorkStack > _4883) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_4881,_4882,_4883); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4881,monty::rc_ptr< ::mosek::fusion::WorkStack > _4882,monty::rc_ptr< ::mosek::fusion::WorkStack > _4883){
  std::shared_ptr< monty::ndarray< int,1 > > _4884 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4884(_4884 ? _4884->raw() : nullptr,_4884 ? _4884->size(0) : 0);
  long long _4885 = ::mosek::fusion::p_Set::size(_4884);
  int _4886 = x->numInst();
  int _4887 = _4886;
  bool _4888 = (_4885 > _4886);
  int _4889 = _4881->alloci32(safe_add( _4886,(int)1 ));
  int _4890 = _4881->alloci64(_4887);
  int _9156;
  bool _9157 = _4888;
  if (_9157)
  {
    _9156 = _4881->alloci64(_4886);
  }
  else
  {
    _9156 = (-(int)1);
  }
  int _4891 = _9156;
  int _4892 = _4881->allocf64(_4887);
  int _4893 = _4881->allocf64(_4886);
  int _9158;
  bool _9159 = _4888;
  if (_9159)
  {
    _9158 = (int)1;
  }
  else
  {
    _9158 = (int)0;
  }
  _4881->pushi32(_9158);
  _4881->pushi32(_4887);
  _4881->pushi32(_4886);
  int _9160 = (int)0;
  int _9161 = (int)((_4884)->size(0));
  for (int _4894 = _9160; _4894 < _9161; ++_4894)
  {
    {
      _4881->pushi32(_ptr__4884[_4894]);
    }
  }
  _4881->pushi32((int)((_4884)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4895 = mosek::fusion::p_WorkStack::_get_impl(_4881)->i32;
  _checked_ptr_1<int> _ptr__4895(_4895 ? _4895->raw() : nullptr,_4895 ? _4895->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4896 = mosek::fusion::p_WorkStack::_get_impl(_4881)->i64;
  _checked_ptr_1<long long> _ptr__4896(_4896 ? _4896->raw() : nullptr,_4896 ? _4896->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4897 = mosek::fusion::p_WorkStack::_get_impl(_4881)->f64;
  _checked_ptr_1<double> _ptr__4897(_4897 ? _4897->raw() : nullptr,_4897 ? _4897->size(0) : 0);
  {
    int _9162 = (int)0;
    int _9163 = safe_add( _4886,(int)1 );
    for (int _4898 = _9162; _4898 < _9163; ++_4898)
    {
      {
        _ptr__4895[safe_add( _4889,_4898 )] = _4898;
      }
    }
    int _9164 = (int)0;
    int _9165 = _4886;
    for (int _4899 = _9164; _4899 < _9165; ++_4899)
    {
      {
        _ptr__4897[safe_add( _4893,_4899 )] = 0.0;
      }
    }
    int _9166 = (int)0;
    int _9167 = _4887;
    for (int _4900 = _9166; _4900 < _9167; ++_4900)
    {
      {
        _ptr__4897[safe_add( _4892,_4900 )] = 1.0;
      }
    }
  }
  if (_4888)
  {
    {
      x->inst(_4891,_4896,_4890,_4896);
    }
  }
  else
  {
    {
      x->inst(_4890,_4896);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4901,    monty::rc_ptr< ::mosek::fusion::Expression > _4902){ return new mosek::fusion::ExprReshape(_4901,_4902); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4901,    monty::rc_ptr< ::mosek::fusion::Expression > _4902) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_4901,_4902); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4901,    monty::rc_ptr< ::mosek::fusion::Expression > _4902){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4901(_4901 ? _4901->raw() : nullptr, _4901 ? _4901->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4901));
    long long _4903 = _4902->getSize();
    if ((::mosek::fusion::p_Set::size(_4901) != _4902->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _4902;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4904,monty::rc_ptr< ::mosek::fusion::WorkStack > _4905,monty::rc_ptr< ::mosek::fusion::WorkStack > _4906) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_4904,_4905,_4906); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4904,monty::rc_ptr< ::mosek::fusion::WorkStack > _4905,monty::rc_ptr< ::mosek::fusion::WorkStack > _4906){
  std::shared_ptr< monty::ndarray< int,1 > > _4907 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4907(_4907 ? _4907->raw() : nullptr,_4907 ? _4907->size(0) : 0);
  e->eval(_4904,_4905,_4906);
  _4904->peek_expr();
  int _4908 = _4904->popi32();
  long long _4909 = (int)1;
  int _9168 = (int)0;
  int _9169 = _4908;
  for (int _4910 = _9168; _4910 < _9169; ++_4910)
  {
    {
      _4909 *= _4904->popi32();
    }
  }
  if ((_4909 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _9170 = (int)0;
  int _9171 = (int)((_4907)->size(0));
  for (int _4911 = _9170; _4911 < _9171; ++_4911)
  {
    {
      _4904->pushi32(_ptr__4907[_4911]);
    }
  }
  _4904->pushi32((int)((_4907)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4912 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _4912->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _9172 = (int)1;
      int _9173 = _pubthis->getND();
      for (int _4913 = _9172; _4913 < _9173; ++_4913)
      {
        {
          _4912->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_4913));
        }
      }
    }
  }
  {}
  _4912->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4912->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4914){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4914(_4914 ? _4914->raw() : nullptr, _4914 ? _4914->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _4914;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__eval() { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::eval() { return __mosek_2fusion_2BaseExpression__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__eval(){
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4915 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4916 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4917 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  _pubthis->eval(_4915,_4916,_4917);
  int _4918 = _4915->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4919 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4918)));
  _checked_ptr_1<int> _ptr__4919(_4919 ? _4919->raw() : nullptr,_4919 ? _4919->size(0) : 0);
  _4915->popi32(_4918,_4919,(int)0);
  int _4920 = _4915->popi32();
  int _4921 = _4915->popi32();
  int _4922 = (int)1;
  int _9174 = (int)0;
  int _9175 = _4918;
  for (int _4923 = _9174; _4923 < _9175; ++_4923)
  {
    {
      _4922 *= _ptr__4919[_4923];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4924 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4921)));
  _checked_ptr_1<long long> _ptr__4924(_4924 ? _4924->raw() : nullptr,_4924 ? _4924->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4925 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4920,(int)1 ))));
  _checked_ptr_1<int> _ptr__4925(_4925 ? _4925->raw() : nullptr,_4925 ? _4925->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4926 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4920)));
  _checked_ptr_1<double> _ptr__4926(_4926 ? _4926->raw() : nullptr,_4926 ? _4926->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4927 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4921)));
  _checked_ptr_1<double> _ptr__4927(_4927 ? _4927->raw() : nullptr,_4927 ? _4927->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4928 = nullptr;
  _checked_ptr_1<long long> _ptr__4928(_4928 ? _4928->raw() : nullptr,_4928 ? _4928->size(0) : 0);
  if ((_4922 < _4920))
  {
    {
      _4928 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4920)));
      _ptr__4928.update(_4928 ? _4928->raw() : nullptr, _4928 ? _4928->size(0) : 0);
      _4915->popi64(_4920,_4928,(int)0);
    }
  }
  {}
  _4915->popi32(_4920,_4925,(int)1);
  _4915->popi64(_4921,_4924,(int)0);
  _4915->popf64(_4920,_4926,(int)0);
  _4915->popf64(_4921,_4927,(int)0);
  std::vector<long long> _9176;
  for (int _4929 = (int)0, _9177 = safe_add( _4920,(int)1 ); _4929 < _9177 ; ++_4929)
  {
    _9176.push_back(_ptr__4925[_4929]);
  }
  auto _9178 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9176.size()),_9176.begin(),_9176.end()));
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4926,_9178,_4924,_4927,_4919,_4928);
}
void mosek::fusion::BaseExpression::storeexpr  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4930,    std::shared_ptr< monty::ndarray< int,1 > > _4931,    std::shared_ptr< monty::ndarray< int,1 > > _4932,    std::shared_ptr< monty::ndarray< long long,1 > > _4933,    std::shared_ptr< monty::ndarray< long long,1 > > _4934,    std::shared_ptr< monty::ndarray< double,1 > > _4935,    std::shared_ptr< monty::ndarray< double,1 > > _4936) { mosek::fusion::p_BaseExpression::storeexpr(_4930,_4931,_4932,_4933,_4934,_4935,_4936); }void mosek::fusion::p_BaseExpression::storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4930,std::shared_ptr< monty::ndarray< int,1 > > _4931,std::shared_ptr< monty::ndarray< int,1 > > _4932,std::shared_ptr< monty::ndarray< long long,1 > > _4933,std::shared_ptr< monty::ndarray< long long,1 > > _4934,std::shared_ptr< monty::ndarray< double,1 > > _4935,std::shared_ptr< monty::ndarray< double,1 > > _4936){
  _checked_ptr_1<int> _ptr__4931(_4931 ? _4931->raw() : nullptr, _4931 ? _4931->size(0) : 0);
  _checked_ptr_1<int> _ptr__4932(_4932 ? _4932->raw() : nullptr, _4932 ? _4932->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4933(_4933 ? _4933->raw() : nullptr, _4933 ? _4933->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4934(_4934 ? _4934->raw() : nullptr, _4934 ? _4934->size(0) : 0);
  _checked_ptr_1<double> _ptr__4935(_4935 ? _4935->raw() : nullptr, _4935 ? _4935->size(0) : 0);
  _checked_ptr_1<double> _ptr__4936(_4936 ? _4936->raw() : nullptr, _4936 ? _4936->size(0) : 0);
  int _4937 = _ptr__4932[((int)((_4932)->size(0)) - (int)1)];
  int _4938 = ((int)((_4932)->size(0)) - (int)1);
  int _4939 = (int)((_4931)->size(0));
  {
    int _4940 = _4930->alloci32(safe_add( _4938,(int)1 ));
    ::mosek::fusion::Utils::Tools::arraycopy(_4932,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4930)->i32,_4940,safe_add( _4938,(int)1 ));
  }
  int _9179;
  bool _9180 = (NULL != _4933.get());
  if (_9180)
  {
    _9179 = (int)1;
  }
  else
  {
    _9179 = (int)0;
  }
  _4930->pushi32(_9179);
  _4930->pushi32(_4937);
  _4930->pushi32(_4938);
  {
    int _4941 = _4930->alloci32(_4939);
    ::mosek::fusion::Utils::Tools::arraycopy(_4931,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4930)->i32,_4941,_4939);
  }
  _4930->pushi32(_4939);
  {
    int _4942 = _4930->alloci64(_4937);
    ::mosek::fusion::Utils::Tools::arraycopy(_4934,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4930)->i64,_4942,_4937);
  }
  if ((NULL != _4933.get()))
  {
    {
      int _4943 = _4930->alloci64(_4938);
      ::mosek::fusion::Utils::Tools::arraycopy(_4933,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4930)->i64,_4943,_4938);
    }
  }
  {}
  {
    int _4944 = _4930->allocf64(_4937);
    ::mosek::fusion::Utils::Tools::arraycopy(_4935,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4930)->f64,_4944,_4937);
  }
  {
    int _4945 = _4930->allocf64(_4938);
    if ((NULL != _4936.get()))
    {
      {
        ::mosek::fusion::Utils::Tools::arraycopy(_4936,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4930)->f64,_4945,_4938);
      }
    }
    else
    {
      {
        int _9181 = (int)0;
        int _9182 = _4938;
        for (int _4946 = _9181; _4946 < _9182; ++_4946)
        {
          {
            ((*mosek::fusion::p_WorkStack::_get_impl(_4930)->f64)(safe_add( _4945,_4946 ))) = (int)0;
          }
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4950) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4950); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _4950) { return __mosek_2fusion_2BaseExpression__pick(_4950); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4950) { return __mosek_2fusion_2BaseExpression__pick(_4950); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4950){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4950)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4951) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4951); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _4951) { return __mosek_2fusion_2BaseExpression__pick(_4951); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4951) { return __mosek_2fusion_2BaseExpression__pick(_4951); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4951){
  _checked_ptr_1<int> _ptr__4951(_4951 ? _4951->raw() : nullptr, _4951 ? _4951->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4952 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_4951)->size(0)),(int)1)));
  int _9183 = (int)0;
  int _9184 = (int)((_4951)->size(0));
  for (int _4953 = _9183; _4953 < _9184; ++_4953)
  {
    {
      ((*_4952)(_4953,(int)0)) = _ptr__4951[_4953];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4952)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4954) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4954); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _4954) { return __mosek_2fusion_2BaseExpression__index(_4954); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4954) { return __mosek_2fusion_2BaseExpression__index(_4954); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4954){
  _checked_ptr_1<int> _ptr__4954(_4954 ? _4954->raw() : nullptr, _4954 ? _4954->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4955 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_4954)->size(0)))));
  int _9185 = (int)0;
  int _9186 = (int)((_4954)->size(0));
  for (int _4956 = _9185; _4956 < _9186; ++_4956)
  {
    {
      ((*_4955)((int)0,_4956)) = _ptr__4954[_4956];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4955)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _4957) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4957); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _4957) { return __mosek_2fusion_2BaseExpression__index(_4957); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _4957) { return __mosek_2fusion_2BaseExpression__index(_4957); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _4957){
  std::shared_ptr< monty::ndarray< int,2 > > _4958 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_4958)((int)0,(int)0)) = _4957;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4958)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4959,std::shared_ptr< monty::ndarray< int,1 > > _4960) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4959,_4960); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _4959,std::shared_ptr< monty::ndarray< int,1 > > _4960) { return __mosek_2fusion_2BaseExpression__slice(_4959,_4960); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4959,std::shared_ptr< monty::ndarray< int,1 > > _4960) { return __mosek_2fusion_2BaseExpression__slice(_4959,_4960); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4959,std::shared_ptr< monty::ndarray< int,1 > > _4960){
  _checked_ptr_1<int> _ptr__4959(_4959 ? _4959->raw() : nullptr, _4959 ? _4959->size(0) : 0);
  _checked_ptr_1<int> _ptr__4960(_4960 ? _4960->raw() : nullptr, _4960 ? _4960->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4959,_4960)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _4961,int _4962) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4961,_4962); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _4961,int _4962) { return __mosek_2fusion_2BaseExpression__slice(_4961,_4962); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _4961,int _4962) { return __mosek_2fusion_2BaseExpression__slice(_4961,_4962); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _4961,int _4962){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4961)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4962)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _4963) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_4963); }int mosek::fusion::p_BaseExpression::getDim(int _4963){
  return ((*shape)(_4963));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_bfix_base() { return _impl->bfix_base; }
void mosek::fusion::WorkStack::set_bfix_base(int _val) { _impl->bfix_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    bfix_base = (int)0;
    cof_base = (int)0;
  }
}bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _4964) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_4964); }int mosek::fusion::p_WorkStack::peek_dim(int _4964){
  return _pubthis->peeki32(safe_add( _4964,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _4965,int _4966,int _4967,bool _4968) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_4965,_4966,_4967,_4968); }void mosek::fusion::p_WorkStack::alloc_expr(int _4965,int _4966,int _4967,bool _4968){
  cof_base = _pubthis->allocf64(_4967);
  bfix_base = _pubthis->allocf64(_4966);
  nidxs_base = _pubthis->alloci64(_4967);
  int _9187;
  bool _9188 = _4968;
  if (_9188)
  {
    _9187 = _pubthis->alloci64(_4966);
  }
  else
  {
    _9187 = (-(int)9999);
  }
  sp_base = _9187;
  ptr_base = _pubthis->alloci32(safe_add( _4966,(int)1 ));
  int _9189;
  bool _9190 = _4968;
  if (_9190)
  {
    _9189 = (int)1;
  }
  else
  {
    _9189 = (int)0;
  }
  _pubthis->pushi32(_9189);
  _pubthis->pushi32(_4967);
  _pubthis->pushi32(_4966);
  shape_base = _pubthis->alloci32(_4965);
  _pubthis->pushi32(_4965);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _4965;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _4966;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _4967;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _4968;
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4969) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_4969); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4969){
  int _4970 = pi32;
  int _4971 = pi64;
  int _4972 = pf64;
  _pubthis->pop_expr();
  int _4973 = _4969->alloci32((_4970 - pi32));
  int _4974 = _4969->alloci64((_4971 - pi64));
  int _4975 = _4969->allocf64((_4972 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_4969)->i32,_4973,(_4970 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_4969)->i64,_4974,(_4971 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_4969)->f64,_4975,(_4972 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _4976 = pi32;
  int _4977 = pi64;
  int _4978 = pf64;
  _pubthis->pop_expr();
  pi32 = _4976;
  pi64 = _4977;
  pf64 = _4978;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _9191;
  bool _9192 = hassp;
  if (_9192)
  {
    _9191 = _pubthis->popi64(nelem);
  }
  else
  {
    _9191 = (-(int)9999);
  }
  sp_base = _9191;
  nidxs_base = _pubthis->popi64(nnz);
  bfix_base = _pubthis->popf64(nelem);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _4979 = ((*i32)((pi32 - (int)1)));
  bool _4980 = (((*i32)(((pi32 - _4979) - (int)3))) != (int)0);
  int _4981 = ((*i32)(((pi32 - _4979) - (int)1)));
  if ((!_4980))
  {
    {
      ((*i32)(((pi32 - _4979) - (int)3))) = (int)1;
      int _4982 = _pubthis->alloci64(_4981);
      int _9193 = (int)0;
      int _9194 = _4981;
      for (int _4983 = _9193; _4983 < _9194; ++_4983)
      {
        {
          ((*i64)(_4982)) = _4983;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _4984) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_4984); }int mosek::fusion::p_WorkStack::allocf64(int _4984){
  _pubthis->ensuref64(_4984);
  int _4985 = pf64;
  pf64 += _4984;
  return _4985;
}
int mosek::fusion::WorkStack :: alloci64(int _4986) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_4986); }int mosek::fusion::p_WorkStack::alloci64(int _4986){
  _pubthis->ensurei64(_4986);
  int _4987 = pi64;
  pi64 += _4986;
  return _4987;
}
int mosek::fusion::WorkStack :: alloci32(int _4988) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_4988); }int mosek::fusion::p_WorkStack::alloci32(int _4988){
  if ((_4988 > (int)0))
  {
    {
      _pubthis->ensurei32(_4988);
      int _4989 = pi32;
      pi32 += _4988;
      return _4989;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _4990) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_4990); }void mosek::fusion::p_WorkStack::pushf64(double _4990){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _4990;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _4991) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_4991); }void mosek::fusion::p_WorkStack::pushi64(long long _4991){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _4991;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _4992) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_4992); }void mosek::fusion::p_WorkStack::pushi32(int _4992){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _4992;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _4993) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_4993); }void mosek::fusion::p_WorkStack::ensuref64(int _4993){
  if ((safe_add( pf64,_4993 ) > (int)((f64)->size(0))))
  {
    {
      int _9195;
      bool _9196 = (_4993 < (int)((f64)->size(0)));
      if (_9196)
      {
        _9195 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _9195 = safe_add( (int)((f64)->size(0)),_4993 );
      }
      int _4994 = _9195;
      std::shared_ptr< monty::ndarray< double,1 > > _4995 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4994)));
      _checked_ptr_1<double> _ptr__4995(_4995 ? _4995->raw() : nullptr,_4995 ? _4995->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_4995,(int)0,pf64);
      f64 = _4995;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _4996) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_4996); }void mosek::fusion::p_WorkStack::ensurei64(int _4996){
  if ((safe_add( pi64,_4996 ) > (int)((i64)->size(0))))
  {
    {
      int _9197;
      bool _9198 = (_4996 < (int)((i64)->size(0)));
      if (_9198)
      {
        _9197 = (int)((i64)->size(0));
      }
      else
      {
        _9197 = _4996;
      }
      int _4997 = safe_add( (int)((i64)->size(0)),_9197 );
      std::shared_ptr< monty::ndarray< long long,1 > > _4998 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4997)));
      _checked_ptr_1<long long> _ptr__4998(_4998 ? _4998->raw() : nullptr,_4998 ? _4998->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_4998,(int)0,pi64);
      i64 = _4998;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _4999) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_4999); }void mosek::fusion::p_WorkStack::ensurei32(int _4999){
  if ((safe_add( pi32,_4999 ) > (int)((i32)->size(0))))
  {
    {
      int _9199;
      bool _9200 = (_4999 < (int)((i32)->size(0)));
      if (_9200)
      {
        _9199 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _9199 = safe_add( (int)((i32)->size(0)),_4999 );
      }
      int _5000 = _9199;
      std::shared_ptr< monty::ndarray< int,1 > > _5001 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5000)));
      _checked_ptr_1<int> _ptr__5001(_5001 ? _5001->raw() : nullptr,_5001 ? _5001->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_5001,(int)0,pi32);
      i32 = _5001;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _5002) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_5002); }int mosek::fusion::p_WorkStack::popf64(int _5002){
  pf64 -= _5002;
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _5003) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_5003); }int mosek::fusion::p_WorkStack::popi64(int _5003){
  pi64 -= _5003;
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _5004) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_5004); }int mosek::fusion::p_WorkStack::popi32(int _5004){
  pi32 -= _5004;
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _5005,std::shared_ptr< monty::ndarray< double,1 > > _5006,int _5007) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_5005,_5006,_5007); }void mosek::fusion::p_WorkStack::popf64(int _5005,std::shared_ptr< monty::ndarray< double,1 > > _5006,int _5007){
  _checked_ptr_1<double> _ptr__5006(_5006 ? _5006->raw() : nullptr, _5006 ? _5006->size(0) : 0);
  pf64 -= _5005;
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_5006,_5007,_5005);
}
void mosek::fusion::WorkStack :: popi64(int _5008,std::shared_ptr< monty::ndarray< long long,1 > > _5009,int _5010) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_5008,_5009,_5010); }void mosek::fusion::p_WorkStack::popi64(int _5008,std::shared_ptr< monty::ndarray< long long,1 > > _5009,int _5010){
  _checked_ptr_1<long long> _ptr__5009(_5009 ? _5009->raw() : nullptr, _5009 ? _5009->size(0) : 0);
  pi64 -= _5008;
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_5009,_5010,_5008);
}
void mosek::fusion::WorkStack :: popi32(int _5011,std::shared_ptr< monty::ndarray< int,1 > > _5012,int _5013) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_5011,_5012,_5013); }void mosek::fusion::p_WorkStack::popi32(int _5011,std::shared_ptr< monty::ndarray< int,1 > > _5012,int _5013){
  _checked_ptr_1<int> _ptr__5012(_5012 ? _5012->raw() : nullptr, _5012 ? _5012->size(0) : 0);
  pi32 -= _5011;
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_5012,_5013,_5011);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _5014) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_5014); }double mosek::fusion::p_WorkStack::peekf64(int _5014){
  return ((*f64)(((pf64 - _5014) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _5015) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_5015); }long long mosek::fusion::p_WorkStack::peeki64(int _5015){
  return ((*i64)(((pi64 - _5015) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _5016) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_5016); }int mosek::fusion::p_WorkStack::peeki32(int _5016){
  return ((*i32)(((pi32 - _5016) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _5017,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _5018,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5019,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5020){ return new mosek::fusion::SymmetricExpr(_5017,_5018,_5019,_5020); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _5017,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _5018,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5019,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5020) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_5017,_5018,_5019,_5020); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _5017,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _5018,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5019,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5020){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _5017;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _5018;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _5019;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _5020;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _5021,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5022){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_5021)->n != _5022->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9201;
  bool _9202 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_5021)->b.get());
  if (_9202)
  {
    _9201 = mosek::fusion::p_SymmetricExpr::_get_impl(_5021)->b->__mosek_2fusion_2SymmetricMatrix__add(_5022);
  }
  else
  {
    _9201 = _5022;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_5021)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_5021)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_5021)->xs,_9201);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _5023,double _5024){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _9203;
  for (int _5025 = (int)0, _9204 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5023)->Ms)->size(0)); _5025 < _9204 ; ++_5025)
  {
    _9203.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_5023)->Ms)(_5025))->__mosek_2fusion_2SymmetricMatrix__mul(_5024));
  }
  auto _9205 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_9203.size()),_9203.begin(),_9203.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9206;
  bool _9207 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_5023)->b.get());
  if (_9207)
  {
    _9206 = mosek::fusion::p_SymmetricExpr::_get_impl(_5023)->b->__mosek_2fusion_2SymmetricMatrix__mul(_5024);
  }
  else
  {
    _9206 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_5023)->n,_9205,mosek::fusion::p_SymmetricExpr::_get_impl(_5023)->xs,_9206);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _5026,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _5027){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _5028 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5029 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->xs)->size(0)) ))));
  int _5030 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->Ms)->size(0));
  int _9208 = (int)0;
  int _9209 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->Ms)->size(0));
  for (int _5031 = _9208; _5031 < _9209; ++_5031)
  {
    {
      ((*_5028)(_5031)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->Ms)(_5031));
    }
  }
  int _9210 = (int)0;
  int _9211 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->Ms)->size(0));
  for (int _5032 = _9210; _5032 < _9211; ++_5032)
  {
    {
      ((*_5028)(safe_add( _5032,_5030 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->Ms)(_5032));
    }
  }
  int _5033 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->xs)->size(0));
  int _9212 = (int)0;
  int _9213 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->xs)->size(0));
  for (int _5034 = _9212; _5034 < _9213; ++_5034)
  {
    {
      ((*_5029)(_5034)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->xs)(_5034));
    }
  }
  int _9214 = (int)0;
  int _9215 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->xs)->size(0));
  for (int _5035 = _9214; _5035 < _9215; ++_5035)
  {
    {
      ((*_5029)(safe_add( _5035,_5033 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->xs)(_5035));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9216;
  bool _9217 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->b.get()));
  if (_9217)
  {
    _9216 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9218;
    bool _9219 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->b.get()));
    if (_9219)
    {
      _9218 = mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9220;
      bool _9221 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->b.get());
      if (_9221)
      {
        _9220 = mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->b;
      }
      else
      {
        _9220 = mosek::fusion::p_SymmetricExpr::_get_impl(_5027)->b;
      }
      _9218 = _9220;
    }
    _9216 = _9218;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5036 = _9216;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_5026)->n,_5028,_5029,_5036);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5037 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5037->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _5037->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _5038,    std::shared_ptr< monty::ndarray< long long,1 > > _5039,    std::shared_ptr< monty::ndarray< double,1 > > _5040,    std::shared_ptr< monty::ndarray< double,1 > > _5041,    std::shared_ptr< monty::ndarray< int,1 > > _5042,    std::shared_ptr< monty::ndarray< long long,1 > > _5043){ return new mosek::fusion::Expr(_5038,_5039,_5040,_5041,_5042,_5043); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _5038,    std::shared_ptr< monty::ndarray< long long,1 > > _5039,    std::shared_ptr< monty::ndarray< double,1 > > _5040,    std::shared_ptr< monty::ndarray< double,1 > > _5041,    std::shared_ptr< monty::ndarray< int,1 > > _5042,    std::shared_ptr< monty::ndarray< long long,1 > > _5043) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_5038,_5039,_5040,_5041,_5042,_5043); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _5038,    std::shared_ptr< monty::ndarray< long long,1 > > _5039,    std::shared_ptr< monty::ndarray< double,1 > > _5040,    std::shared_ptr< monty::ndarray< double,1 > > _5041,    std::shared_ptr< monty::ndarray< int,1 > > _5042,    std::shared_ptr< monty::ndarray< long long,1 > > _5043){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__5038(_5038 ? _5038->raw() : nullptr, _5038 ? _5038->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5039(_5039 ? _5039->raw() : nullptr, _5039 ? _5039->size(0) : 0);
    _checked_ptr_1<double> _ptr__5040(_5040 ? _5040->raw() : nullptr, _5040 ? _5040->size(0) : 0);
    _checked_ptr_1<double> _ptr__5041(_5041 ? _5041->raw() : nullptr, _5041 ? _5041->size(0) : 0);
    _checked_ptr_1<int> _ptr__5042(_5042 ? _5042->raw() : nullptr, _5042 ? _5042->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5043(_5043 ? _5043->raw() : nullptr, _5043 ? _5043->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _9222;
    bool _9223 = (NULL != _5042.get());
    if (_9223)
    {
      _9222 = ::mosek::fusion::Utils::Tools::arraycopy(_5042);
    }
    else
    {
      _9222 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_5038)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _9224;
    bool _9225 = (NULL != _5043.get());
    if (_9225)
    {
      _9224 = ::mosek::fusion::Utils::Tools::arraycopy(_5043);
    }
    else
    {
      _9224 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_5038),::mosek::fusion::Utils::Tools::arraycopy(_5039),::mosek::fusion::Utils::Tools::arraycopy(_5040),::mosek::fusion::Utils::Tools::arraycopy(_5041),_9222,_9224,(int)1);
    int _5044 = ((int)((_5038)->size(0)) - (int)1);
    if ((_5044 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _5045 = _ptr__5038[_5044];
    if (((_5045 < (int)0) || ((_5045 != (int)((_5040)->size(0))) || (_5045 != (int)((_5039)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _5046 = true;
    bool _5047 = true;
    bool _5048 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _5049 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__5049(_5049 ? _5049->raw() : nullptr,_5049 ? _5049->size(0) : 0);
    long long _5050 = ::mosek::fusion::p_Set::size(_5049);
    {
      int _9226 = (int)0;
      int _9227 = (int)((_5049)->size(0));
      for (int _5051 = _9226; _5051 < _9227; ++_5051)
      {
        {
          _5047 = (_5047 && (_ptr__5049[_5051] >= (int)0));
        }
      }
      int _9228 = (int)0;
      int _9229 = _5044;
      for (int _5052 = _9228; _5052 < _9229; ++_5052)
      {
        {
          _5046 = (_5046 && (_ptr__5038[_5052] <= _ptr__5038[safe_add( _5052,(int)1 )]));
        }
      }
      if (((NULL != _5043.get()) && ((int)((_5043)->size(0)) > (int)0)))
      {
        {
          _5048 = ((_ptr__5043[(int)0] >= (int)0) && (_ptr__5043[(_5044 - (int)1)] < _5050));
          int _9230 = (int)0;
          int _9231 = (_5044 - (int)1);
          for (int _5053 = _9230; _5053 < _9231; ++_5053)
          {
            {
              _5048 = (_5048 && (_ptr__5043[_5053] < _ptr__5043[safe_add( _5053,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_5047))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_5046))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_5048))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _5054,    std::shared_ptr< monty::ndarray< long long,1 > > _5055,    std::shared_ptr< monty::ndarray< double,1 > > _5056,    std::shared_ptr< monty::ndarray< double,1 > > _5057,    std::shared_ptr< monty::ndarray< int,1 > > _5058,    std::shared_ptr< monty::ndarray< long long,1 > > _5059,    int _5060){ return new mosek::fusion::Expr(_5054,_5055,_5056,_5057,_5058,_5059,_5060); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _5054,    std::shared_ptr< monty::ndarray< long long,1 > > _5055,    std::shared_ptr< monty::ndarray< double,1 > > _5056,    std::shared_ptr< monty::ndarray< double,1 > > _5057,    std::shared_ptr< monty::ndarray< int,1 > > _5058,    std::shared_ptr< monty::ndarray< long long,1 > > _5059,    int _5060) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_5054,_5055,_5056,_5057,_5058,_5059,_5060); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _5054,    std::shared_ptr< monty::ndarray< long long,1 > > _5055,    std::shared_ptr< monty::ndarray< double,1 > > _5056,    std::shared_ptr< monty::ndarray< double,1 > > _5057,    std::shared_ptr< monty::ndarray< int,1 > > _5058,    std::shared_ptr< monty::ndarray< long long,1 > > _5059,    int _5060){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__5054(_5054 ? _5054->raw() : nullptr, _5054 ? _5054->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5055(_5055 ? _5055->raw() : nullptr, _5055 ? _5055->size(0) : 0);
    _checked_ptr_1<double> _ptr__5056(_5056 ? _5056->raw() : nullptr, _5056 ? _5056->size(0) : 0);
    _checked_ptr_1<double> _ptr__5057(_5057 ? _5057->raw() : nullptr, _5057 ? _5057->size(0) : 0);
    _checked_ptr_1<int> _ptr__5058(_5058 ? _5058->raw() : nullptr, _5058 ? _5058->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5059(_5059 ? _5059->raw() : nullptr, _5059 ? _5059->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_5058);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _5058;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _5054;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _5055;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _5056;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _5057;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _5059;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _5061){ return new mosek::fusion::Expr(_5061); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _5061) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_5061); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _5061){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_5061->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _9232 = _5061;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_9232.get()))
    {
      ::mosek::fusion::Expr::t _5062 (dynamic_cast<::mosek::fusion::Expr*>(_9232.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_5062)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_5062)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_5062)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_5062)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_5062)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_5062)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _5063 = _9232;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _5064 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _5065 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _5066 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _5063->eval(_5066,_5065,_5064);
        int _5067 = _5066->popi32();
        int _5068 = _5066->popi32(_5067);
        int _5069 = _5066->popi32();
        int _5070 = _5066->popi32();
        bool _5071 = (_5066->popi32() != (int)0);
        int _5072 = _5066->popi32(safe_add( _5069,(int)1 ));
        int _9233;
        bool _9234 = _5071;
        if (_9234)
        {
          _9233 = _5066->popi64(_5069);
        }
        else
        {
          _9233 = (int)0;
        }
        int _5073 = _9233;
        int _5074 = _5066->popi64(_5070);
        int _5075 = _5066->popf64(_5069);
        int _5076 = _5066->popf64(_5070);
        std::shared_ptr< monty::ndarray< int,1 > > _5077 = mosek::fusion::p_WorkStack::_get_impl(_5066)->i32;
        _checked_ptr_1<int> _ptr__5077(_5077 ? _5077->raw() : nullptr,_5077 ? _5077->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _5078 = mosek::fusion::p_WorkStack::_get_impl(_5066)->i64;
        _checked_ptr_1<long long> _ptr__5078(_5078 ? _5078->raw() : nullptr,_5078 ? _5078->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _5079 = mosek::fusion::p_WorkStack::_get_impl(_5066)->f64;
        _checked_ptr_1<double> _ptr__5079(_5079 ? _5079->raw() : nullptr,_5079 ? _5079->size(0) : 0);
        std::vector<int> _9235;
        for (int _5080 = (int)0, _9236 = _5067; _5080 < _9236 ; ++_5080)
        {
          _9235.push_back(_ptr__5077[safe_add( _5068,_5080 )]);
        }
        auto _9237 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9235.size()),_9235.begin(),_9235.end()));
        shape = _9237;
        std::vector<long long> _9238;
        for (int _5081 = (int)0, _9239 = safe_add( _5069,(int)1 ); _5081 < _9239 ; ++_5081)
        {
          _9238.push_back(_ptr__5077[safe_add( _5072,_5081 )]);
        }
        auto _9240 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9238.size()),_9238.begin(),_9238.end()));
        ptrb = _9240;
        std::vector<long long> _9241;
        for (int _5082 = (int)0, _9242 = _5070; _5082 < _9242 ; ++_5082)
        {
          _9241.push_back(_ptr__5078[safe_add( _5074,_5082 )]);
        }
        auto _9243 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9241.size()),_9241.begin(),_9241.end()));
        subj = _9243;
        std::vector<double> _9244;
        for (int _5083 = (int)0, _9245 = _5070; _5083 < _9245 ; ++_5083)
        {
          _9244.push_back(_ptr__5079[safe_add( _5076,_5083 )]);
        }
        auto _9246 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9244.size()),_9244.begin(),_9244.end()));
        cof_v = _9246;
        std::vector<double> _9247;
        for (int _5084 = (int)0, _9248 = _5070; _5084 < _9248 ; ++_5084)
        {
          _9247.push_back(_ptr__5079[safe_add( _5075,_5084 )]);
        }
        auto _9249 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9247.size()),_9247.begin(),_9247.end()));
        bfix = _9249;
        std::shared_ptr< monty::ndarray< long long,1 > > _9250;
        bool _9251 = _5071;
        if (_9251)
        {
          std::vector<long long> _9252;
          for (int _5085 = (int)0, _9253 = _5070; _5085 < _9253 ; ++_5085)
          {
            _9252.push_back(_ptr__5078[safe_add( _5073,_5085 )]);
          }
          auto _9254 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9252.size()),_9252.begin(),_9252.end()));
          _9250 = _9254;
        }
        else
        {
          _9250 = nullptr;
        }
        inst = _9250;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _5086){
  _checked_ptr_1<int> _ptr__5086(_5086 ? _5086->raw() : nullptr, _5086 ? _5086->size(0) : 0);
  int _5087 = (int)1;
  int _9255 = (int)0;
  int _9256 = (int)((_5086)->size(0));
  for (int _5088 = _9255; _5088 < _9256; ++_5088)
  {
    {
      _5087 *= _ptr__5086[_5088];
    }
  }
  return _5087;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _5089){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9257;
  for (int _5090 = (int)0, _9258 = (int)((_5089)->size(0)); _5090 < _9258 ; ++_5090)
  {
    for (int _5091 = (int)0, _9259 = (int)((((*_5089)(_5090)))->size(0)); _5091 < _9259 ; ++_5091)
    {
      _9257.push_back(((*((*_5089)(_5090)))(_5091)));
    }
  }
  auto _9260 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9257.size()),_9257.begin(),_9257.end()));
  return _9260;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5092,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5093){
  if ((NULL == _5092.get()))
  {
    {
      return _5093;
    }
  }
  else if((NULL == _5093.get()))
  {
    {
      return _5092;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5094 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_5092)->size(0)),(int)((_5093)->size(0)) ))));
      int _9261 = (int)0;
      int _9262 = (int)((_5092)->size(0));
      for (int _5095 = _9261; _5095 < _9262; ++_5095)
      {
        {
          ((*_5094)(_5095)) = ((*_5092)(_5095));
        }
      }
      int _9263 = (int)0;
      int _9264 = (int)((_5093)->size(0));
      for (int _5096 = _9263; _5096 < _9264; ++_5096)
      {
        {
          ((*_5094)(safe_add( _5096,(int)((_5092)->size(0)) ))) = ((*_5093)(_5096));
        }
      }
      return _5094;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _5097) { return mosek::fusion::p_Expr::condense(_5097); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _5097){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_5097)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _5098) { return mosek::fusion::p_Expr::flatten(_5098); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5098){
  if ((NULL == _5098.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5098,(int)_5098->getSize());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5099,    int _5100,    int _5101) { return mosek::fusion::p_Expr::reshape(_5099,_5100,_5101); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5099,int _5100,int _5101){
  if ((NULL == _5099.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5099,::mosek::fusion::p_Set::make(_5100,_5101));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5102,    int _5103) { return mosek::fusion::p_Expr::reshape(_5102,_5103); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5102,int _5103){
  if ((NULL == _5102.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5102,::mosek::fusion::p_Set::make(_5103));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5104,    std::shared_ptr< monty::ndarray< int,1 > > _5105) { return mosek::fusion::p_Expr::reshape(_5104,_5105); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5104,std::shared_ptr< monty::ndarray< int,1 > > _5105){
  _checked_ptr_1<int> _ptr__5105(_5105 ? _5105->raw() : nullptr, _5105 ? _5105->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5105,_5104)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr :: __mosek_2fusion_2Expr__eval() { return mosek::fusion::p_Expr::_get_impl(this)->__mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::eval() { return __mosek_2fusion_2Expr__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::__mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_Expr::__mosek_2fusion_2Expr__eval(){
  std::shared_ptr< monty::ndarray< double,1 > > _9265;
  bool _9266 = (NULL == bfix.get());
  if (_9266)
  {
    _9265 = nullptr;
  }
  else
  {
    _9265 = ::mosek::fusion::Utils::Tools::arraycopy(bfix);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5106 = _9265;
  _checked_ptr_1<double> _ptr__5106(_5106 ? _5106->raw() : nullptr,_5106 ? _5106->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9267;
  bool _9268 = (NULL == inst.get());
  if (_9268)
  {
    _9267 = nullptr;
  }
  else
  {
    _9267 = ::mosek::fusion::Utils::Tools::arraycopy(inst);
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5107 = _9267;
  _checked_ptr_1<long long> _ptr__5107(_5107 ? _5107->raw() : nullptr,_5107 ? _5107->size(0) : 0);
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_5106,::mosek::fusion::Utils::Tools::arraycopy(ptrb),::mosek::fusion::Utils::Tools::arraycopy(subj),::mosek::fusion::Utils::Tools::arraycopy(cof_v),shape,inst);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _5108) { return mosek::fusion::p_Expr::zeros(_5108); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _5108){
  _checked_ptr_1<int> _ptr__5108(_5108 ? _5108->raw() : nullptr, _5108 ? _5108->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5108,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _5109) { return mosek::fusion::p_Expr::zeros(_5109); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _5109){
  return ::mosek::fusion::p_Expr::constTerm(_5109,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5110,    std::shared_ptr< monty::ndarray< int,2 > > _5111) { return mosek::fusion::p_Expr::ones(_5110,_5111); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5110,std::shared_ptr< monty::ndarray< int,2 > > _5111){
  _checked_ptr_1<int> _ptr__5110(_5110 ? _5110->raw() : nullptr, _5110 ? _5110->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5110,_5111,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5112) { return mosek::fusion::p_Expr::ones(_5112); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5112){
  _checked_ptr_1<int> _ptr__5112(_5112 ? _5112->raw() : nullptr, _5112 ? _5112->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5112,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _5113) { return mosek::fusion::p_Expr::ones(_5113); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _5113){
  return ::mosek::fusion::p_Expr::constTerm(_5113,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5114) { return mosek::fusion::p_Expr::constTerm(_5114); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5114){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_5114)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_5114)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5114)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5115) { return mosek::fusion::p_Expr::constTerm(_5115); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5115){
  int _5116 = _5115->numRows();
  int _5117 = _5115->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _5118 = ::mosek::fusion::p_Set::make(_5116,_5117);
  _checked_ptr_1<int> _ptr__5118(_5118 ? _5118->raw() : nullptr,_5118 ? _5118->size(0) : 0);
  if (_5115->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5119 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5115->numNonzeros())));
      _checked_ptr_1<double> _ptr__5119(_5119 ? _5119->raw() : nullptr,_5119 ? _5119->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5120 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5115->numNonzeros())));
      _checked_ptr_1<int> _ptr__5120(_5120 ? _5120->raw() : nullptr,_5120 ? _5120->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5121 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5115->numNonzeros())));
      _checked_ptr_1<int> _ptr__5121(_5121 ? _5121->raw() : nullptr,_5121 ? _5121->size(0) : 0);
      _5115->getDataAsTriplets(_5121,_5120,_5119);
      std::vector<long long> _9269;
      for (int _5123 = (int)0, _9270 = (int)((_5120)->size(0)); _5123 < _9270 ; ++_5123)
      {
        _9269.push_back(safe_add( safe_mul( _ptr__5121[_5123],_5117 ),_ptr__5120[_5123] ));
      }
      auto _9271 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9269.size()),_9269.begin(),_9269.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _5122 = _9271;
      _checked_ptr_1<long long> _ptr__5122(_5122 ? _5122->raw() : nullptr,_5122 ? _5122->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5118,_5122,_5119)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5118,nullptr,_5115->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _5124) { return mosek::fusion::p_Expr::constTerm(_5124); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _5124){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_5124)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5125,    std::shared_ptr< monty::ndarray< int,2 > > _5126,    double _5127) { return mosek::fusion::p_Expr::constTerm(_5125,_5126,_5127); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5125,std::shared_ptr< monty::ndarray< int,2 > > _5126,double _5127){
  _checked_ptr_1<int> _ptr__5125(_5125 ? _5125->raw() : nullptr, _5125 ? _5125->size(0) : 0);
  int _5128 = (int)((_5126)->size(0));
  int _5129 = (int)((_5125)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5130 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5128)));
  _checked_ptr_1<long long> _ptr__5130(_5130 ? _5130->raw() : nullptr,_5130 ? _5130->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5131 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5129)));
  _checked_ptr_1<long long> _ptr__5131(_5131 ? _5131->raw() : nullptr,_5131 ? _5131->size(0) : 0);
  _ptr__5131[(_5129 - (int)1)] = (int)1;
  int _9272 = (int)1;
  int _9273 = _5129;
  for (int _5132 = _9272; _5132 < _9273; ++_5132)
  {
    {
      _ptr__5131[((_5129 - _5132) - (int)1)] = safe_mul( _ptr__5131[(_5129 - _5132)],_ptr__5125[(_5129 - _5132)] );
    }
  }
  int _9274 = (int)0;
  int _9275 = _5128;
  for (int _5133 = _9274; _5133 < _9275; ++_5133)
  {
    {
      int _9276 = (int)0;
      int _9277 = _5129;
      for (int _5134 = _9276; _5134 < _9277; ++_5134)
      {
        {
          _ptr__5130[_5133] += safe_mul( _ptr__5131[_5134],((*_5126)(_5133,_5134)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5125,_5130,_5127)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5135,    std::shared_ptr< monty::ndarray< int,2 > > _5136,    std::shared_ptr< monty::ndarray< double,1 > > _5137) { return mosek::fusion::p_Expr::constTerm(_5135,_5136,_5137); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5135,std::shared_ptr< monty::ndarray< int,2 > > _5136,std::shared_ptr< monty::ndarray< double,1 > > _5137){
  _checked_ptr_1<int> _ptr__5135(_5135 ? _5135->raw() : nullptr, _5135 ? _5135->size(0) : 0);
  _checked_ptr_1<double> _ptr__5137(_5137 ? _5137->raw() : nullptr, _5137 ? _5137->size(0) : 0);
  int _5138 = (int)((_5136)->size(0));
  int _5139 = (int)((_5135)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5140 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5138)));
  _checked_ptr_1<long long> _ptr__5140(_5140 ? _5140->raw() : nullptr,_5140 ? _5140->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5141 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5139)));
  _checked_ptr_1<long long> _ptr__5141(_5141 ? _5141->raw() : nullptr,_5141 ? _5141->size(0) : 0);
  _ptr__5141[(_5139 - (int)1)] = (int)1;
  int _9278 = (int)1;
  int _9279 = _5139;
  for (int _5142 = _9278; _5142 < _9279; ++_5142)
  {
    {
      _ptr__5141[((_5139 - _5142) - (int)1)] = safe_mul( _ptr__5141[(_5139 - _5142)],_ptr__5135[(_5139 - _5142)] );
    }
  }
  int _9280 = (int)0;
  int _9281 = _5138;
  for (int _5143 = _9280; _5143 < _9281; ++_5143)
  {
    {
      int _9282 = (int)0;
      int _9283 = _5139;
      for (int _5144 = _9282; _5144 < _9283; ++_5144)
      {
        {
          _ptr__5140[_5143] += safe_mul( _ptr__5141[_5144],((*_5136)(_5143,_5144)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5135,_5140,_5137)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5145,    double _5146) { return mosek::fusion::p_Expr::constTerm(_5145,_5146); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5145,double _5146){
  _checked_ptr_1<int> _ptr__5145(_5145 ? _5145->raw() : nullptr, _5145 ? _5145->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5145,nullptr,_5146)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _5147,    double _5148) { return mosek::fusion::p_Expr::constTerm(_5147,_5148); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _5147,double _5148){
  std::vector<double> _9284;
  for (int _5149 = (int)0, _9285 = _5147; _5149 < _9285 ; ++_5149)
  {
    _9284.push_back(_5148);
  }
  auto _9286 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9284.size()),_9284.begin(),_9284.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5147)}),nullptr,_9286)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _5150) { return mosek::fusion::p_Expr::constTerm(_5150); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5150){
  std::vector<double> _9287;
  for (int _5151 = (int)0, _9288 = (int)((_5150)->size(0)); _5151 < _9288 ; ++_5151)
  {
    for (int _5152 = (int)0, _9289 = (int)((_5150)->size(1)); _5152 < _9289 ; ++_5152)
    {
      _9287.push_back(((*_5150)(_5151,_5152)));
    }
  }
  auto _9290 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9287.size()),_9287.begin(),_9287.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5150)->size(0))),(int)((int)((_5150)->size(1)))}),nullptr,_9290)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _5153) { return mosek::fusion::p_Expr::constTerm(_5153); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5153){
  _checked_ptr_1<double> _ptr__5153(_5153 ? _5153->raw() : nullptr, _5153 ? _5153->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5153)->size(0)))}),nullptr,_5153)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5154,    int _5155) { return mosek::fusion::p_Expr::sum(_5154,_5155); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5154,int _5155){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_5155,_5154)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5156) { return mosek::fusion::p_Expr::sum(_5156); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5156){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_5156))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _5157) { return mosek::fusion::p_Expr::neg(_5157); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _5157){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_5157)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _5158,monty::rc_ptr< ::mosek::fusion::Matrix > _5159,monty::rc_ptr< ::mosek::fusion::Expression > _5160){
  long long _5161 = _5159->numNonzeros();
  int _5162 = _5159->numRows();
  int _5163 = _5159->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5164 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5161)));
  _checked_ptr_1<double> _ptr__5164(_5164 ? _5164->raw() : nullptr,_5164 ? _5164->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5165 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5161)));
  _checked_ptr_1<int> _ptr__5165(_5165 ? _5165->raw() : nullptr,_5165 ? _5165->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5166 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5161)));
  _checked_ptr_1<int> _ptr__5166(_5166 ? _5166->raw() : nullptr,_5166 ? _5166->size(0) : 0);
  _5159->getDataAsTriplets(_5166,_5165,_5164);
  if (_5158)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_5162,_5163,_5166,_5165,_5164,_5160)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_5162,_5163,_5166,_5165,_5164,_5160)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5167,    monty::rc_ptr< ::mosek::fusion::Matrix > _5168) { return mosek::fusion::p_Expr::mulDiag(_5167,_5168); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5167,monty::rc_ptr< ::mosek::fusion::Matrix > _5168){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5168,_5167->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5169,    monty::rc_ptr< ::mosek::fusion::Variable > _5170) { return mosek::fusion::p_Expr::mulDiag(_5169,_5170); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5169,monty::rc_ptr< ::mosek::fusion::Variable > _5170){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5169,_5170->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5171,    monty::rc_ptr< ::mosek::fusion::Matrix > _5172) { return mosek::fusion::p_Expr::mulDiag(_5171,_5172); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5171,monty::rc_ptr< ::mosek::fusion::Matrix > _5172){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5172,_5171);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5173,    monty::rc_ptr< ::mosek::fusion::Expression > _5174) { return mosek::fusion::p_Expr::mulDiag(_5173,_5174); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5173,monty::rc_ptr< ::mosek::fusion::Expression > _5174){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5173,_5174);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5175,    std::shared_ptr< monty::ndarray< double,2 > > _5176) { return mosek::fusion::p_Expr::mulDiag(_5175,_5176); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5175,std::shared_ptr< monty::ndarray< double,2 > > _5176){
  std::vector<int> _9291;
  for (int _5177 = (int)0, _9292 = (int)((_5176)->size(0)); _5177 < _9292 ; ++_5177)
  {
    for (int _5178 = (int)0, _9293 = (int)((_5176)->size(1)); _5178 < _9293 ; ++_5178)
    {
      _9291.push_back(_5177);
    }
  }
  auto _9294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9291.size()),_9291.begin(),_9291.end()));
  std::vector<int> _9295;
  for (int _5179 = (int)0, _9296 = (int)((_5176)->size(0)); _5179 < _9296 ; ++_5179)
  {
    for (int _5180 = (int)0, _9297 = (int)((_5176)->size(1)); _5180 < _9297 ; ++_5180)
    {
      _9295.push_back(_5180);
    }
  }
  auto _9298 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9295.size()),_9295.begin(),_9295.end()));
  std::vector<double> _9299;
  for (int _5181 = (int)0, _9300 = (int)((_5176)->size(0)); _5181 < _9300 ; ++_5181)
  {
    for (int _5182 = (int)0, _9301 = (int)((_5176)->size(1)); _5182 < _9301 ; ++_5182)
    {
      _9299.push_back(((*_5176)(_5181,_5182)));
    }
  }
  auto _9302 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9299.size()),_9299.begin(),_9299.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5176)->size(0)),(int)((_5176)->size(1)),_9294,_9298,_9302,_5175->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5183,    std::shared_ptr< monty::ndarray< double,2 > > _5184) { return mosek::fusion::p_Expr::mulDiag(_5183,_5184); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5183,std::shared_ptr< monty::ndarray< double,2 > > _5184){
  std::vector<int> _9303;
  for (int _5185 = (int)0, _9304 = (int)((_5184)->size(0)); _5185 < _9304 ; ++_5185)
  {
    for (int _5186 = (int)0, _9305 = (int)((_5184)->size(1)); _5186 < _9305 ; ++_5186)
    {
      _9303.push_back(_5185);
    }
  }
  auto _9306 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9303.size()),_9303.begin(),_9303.end()));
  std::vector<int> _9307;
  for (int _5187 = (int)0, _9308 = (int)((_5184)->size(0)); _5187 < _9308 ; ++_5187)
  {
    for (int _5188 = (int)0, _9309 = (int)((_5184)->size(1)); _5188 < _9309 ; ++_5188)
    {
      _9307.push_back(_5188);
    }
  }
  auto _9310 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9307.size()),_9307.begin(),_9307.end()));
  std::vector<double> _9311;
  for (int _5189 = (int)0, _9312 = (int)((_5184)->size(0)); _5189 < _9312 ; ++_5189)
  {
    for (int _5190 = (int)0, _9313 = (int)((_5184)->size(1)); _5190 < _9313 ; ++_5190)
    {
      _9311.push_back(((*_5184)(_5189,_5190)));
    }
  }
  auto _9314 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9311.size()),_9311.begin(),_9311.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5184)->size(0)),(int)((_5184)->size(1)),_9306,_9310,_9314,_5183)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5191,    monty::rc_ptr< ::mosek::fusion::Variable > _5192) { return mosek::fusion::p_Expr::mulDiag(_5191,_5192); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5191,monty::rc_ptr< ::mosek::fusion::Variable > _5192){
  std::vector<int> _9315;
  for (int _5193 = (int)0, _9316 = (int)((_5191)->size(0)); _5193 < _9316 ; ++_5193)
  {
    for (int _5194 = (int)0, _9317 = (int)((_5191)->size(1)); _5194 < _9317 ; ++_5194)
    {
      _9315.push_back(_5193);
    }
  }
  auto _9318 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9315.size()),_9315.begin(),_9315.end()));
  std::vector<int> _9319;
  for (int _5195 = (int)0, _9320 = (int)((_5191)->size(0)); _5195 < _9320 ; ++_5195)
  {
    for (int _5196 = (int)0, _9321 = (int)((_5191)->size(1)); _5196 < _9321 ; ++_5196)
    {
      _9319.push_back(_5196);
    }
  }
  auto _9322 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9319.size()),_9319.begin(),_9319.end()));
  std::vector<double> _9323;
  for (int _5197 = (int)0, _9324 = (int)((_5191)->size(0)); _5197 < _9324 ; ++_5197)
  {
    for (int _5198 = (int)0, _9325 = (int)((_5191)->size(1)); _5198 < _9325 ; ++_5198)
    {
      _9323.push_back(((*_5191)(_5197,_5198)));
    }
  }
  auto _9326 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9323.size()),_9323.begin(),_9323.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5191)->size(0)),(int)((_5191)->size(1)),_9318,_9322,_9326,_5192->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5199,    monty::rc_ptr< ::mosek::fusion::Expression > _5200) { return mosek::fusion::p_Expr::mulDiag(_5199,_5200); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5199,monty::rc_ptr< ::mosek::fusion::Expression > _5200){
  std::vector<int> _9327;
  for (int _5201 = (int)0, _9328 = (int)((_5199)->size(0)); _5201 < _9328 ; ++_5201)
  {
    for (int _5202 = (int)0, _9329 = (int)((_5199)->size(1)); _5202 < _9329 ; ++_5202)
    {
      _9327.push_back(_5201);
    }
  }
  auto _9330 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9327.size()),_9327.begin(),_9327.end()));
  std::vector<int> _9331;
  for (int _5203 = (int)0, _9332 = (int)((_5199)->size(0)); _5203 < _9332 ; ++_5203)
  {
    for (int _5204 = (int)0, _9333 = (int)((_5199)->size(1)); _5204 < _9333 ; ++_5204)
    {
      _9331.push_back(_5204);
    }
  }
  auto _9334 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9331.size()),_9331.begin(),_9331.end()));
  std::vector<double> _9335;
  for (int _5205 = (int)0, _9336 = (int)((_5199)->size(0)); _5205 < _9336 ; ++_5205)
  {
    for (int _5206 = (int)0, _9337 = (int)((_5199)->size(1)); _5206 < _9337 ; ++_5206)
    {
      _9335.push_back(((*_5199)(_5205,_5206)));
    }
  }
  auto _9338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9335.size()),_9335.begin(),_9335.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5199)->size(0)),(int)((_5199)->size(1)),_9330,_9334,_9338,_5200)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5207,monty::rc_ptr< ::mosek::fusion::Expression > _5208){
  std::shared_ptr< monty::ndarray< int,1 > > _5209 = _5208->getShape();
  _checked_ptr_1<int> _ptr__5209(_5209 ? _5209->raw() : nullptr,_5209 ? _5209->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _5210 = _5208;
  if (((int)((_5209)->size(0)) == (int)1))
  {
    {
      _5209 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5209[(int)0]),(int)((int)1)});
      _ptr__5209.update(_5209 ? _5209->raw() : nullptr, _5209 ? _5209->size(0) : 0);
      _5210 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5209,_5208)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5209)->size(0)) != (int)2) || ((_5207->numRows() != _ptr__5209[(int)0]) || (_5207->numColumns() != _ptr__5209[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _5211 = _5207->numColumns();
  long long _5212 = _5207->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5213 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5212)));
  _checked_ptr_1<int> _ptr__5213(_5213 ? _5213->raw() : nullptr,_5213 ? _5213->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5214 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5212)));
  _checked_ptr_1<int> _ptr__5214(_5214 ? _5214->raw() : nullptr,_5214 ? _5214->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5215 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5212)));
  _checked_ptr_1<double> _ptr__5215(_5215 ? _5215->raw() : nullptr,_5215 ? _5215->size(0) : 0);
  _5207->getDataAsTriplets(_5213,_5214,_5215);
  std::vector<long long> _9339;
  for (long long _5216 = (int)0, _9340 = _5212; _5216 < _9340 ; ++_5216)
  {
    _9339.push_back(safe_add( safe_mul( _ptr__5213[_5216],_5211 ),_ptr__5214[_5216] ));
  }
  auto _9341 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9339.size()),_9339.begin(),_9339.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5215,_9341,_5210,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5217,monty::rc_ptr< ::mosek::fusion::Expression > _5218){
  _checked_ptr_1<double> _ptr__5217(_5217 ? _5217->raw() : nullptr, _5217 ? _5217->size(0) : 0);
  if (((NULL == _5217.get()) || (NULL == _5218.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_5218->getND() == (int)0) && ((int)((_5217)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__5217[(int)0],_5218)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_5218->getND() != (int)1) || (_5218->getDim((int)0) != (int)((_5217)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _9342;
      for (int _5219 = (int)0, _9343 = (int)((_5217)->size(0)); _5219 < _9343 ; ++_5219)
      {
        _9342.push_back(_5219);
      }
      auto _9344 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9342.size()),_9342.begin(),_9342.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5217,_9344,_5218)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5220,monty::rc_ptr< ::mosek::fusion::Expression > _5221){
  if (((NULL == _5220.get()) || (NULL == _5221.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _5222 = _5221->getShape();
  _checked_ptr_1<int> _ptr__5222(_5222 ? _5222->raw() : nullptr,_5222 ? _5222->size(0) : 0);
  if (((int)((_5222)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5220)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _9345 = (int)0;
  int _9346 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5220)->dims)->size(0));
  for (int _5223 = _9345; _5223 < _9346; ++_5223)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_5220)->dims)(_5223)) != _ptr__5222[_5223]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_5220)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_5220)->inst,_5221)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5224,    double _5225) { return mosek::fusion::p_Expr::mul(_5224,_5225); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5224,double _5225){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5225,_5224)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _5226,    monty::rc_ptr< ::mosek::fusion::Expression > _5227) { return mosek::fusion::p_Expr::mul(_5226,_5227); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _5226,monty::rc_ptr< ::mosek::fusion::Expression > _5227){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5226,_5227)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5228,    std::shared_ptr< monty::ndarray< double,1 > > _5229) { return mosek::fusion::p_Expr::mul(_5228,_5229); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5228,std::shared_ptr< monty::ndarray< double,1 > > _5229){
  _checked_ptr_1<double> _ptr__5229(_5229 ? _5229->raw() : nullptr, _5229 ? _5229->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_5229,_5228);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _5230,    monty::rc_ptr< ::mosek::fusion::Expression > _5231) { return mosek::fusion::p_Expr::mul(_5230,_5231); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _5230,monty::rc_ptr< ::mosek::fusion::Expression > _5231){
  _checked_ptr_1<double> _ptr__5230(_5230 ? _5230->raw() : nullptr, _5230 ? _5230->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_5230,_5231);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5232,    std::shared_ptr< monty::ndarray< double,2 > > _5233) { return mosek::fusion::p_Expr::mul(_5232,_5233); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5232,std::shared_ptr< monty::ndarray< double,2 > > _5233){
  return ::mosek::fusion::p_Expr::mul(false,_5233,_5232);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _5234,    monty::rc_ptr< ::mosek::fusion::Expression > _5235) { return mosek::fusion::p_Expr::mul(_5234,_5235); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _5234,monty::rc_ptr< ::mosek::fusion::Expression > _5235){
  return ::mosek::fusion::p_Expr::mul(true,_5234,_5235);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5236,    monty::rc_ptr< ::mosek::fusion::Matrix > _5237) { return mosek::fusion::p_Expr::mul(_5236,_5237); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5236,monty::rc_ptr< ::mosek::fusion::Matrix > _5237){
  return ::mosek::fusion::p_Expr::mul(false,_5237,_5236);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5238,    monty::rc_ptr< ::mosek::fusion::Expression > _5239) { return mosek::fusion::p_Expr::mul(_5238,_5239); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5238,monty::rc_ptr< ::mosek::fusion::Expression > _5239){
  return ::mosek::fusion::p_Expr::mul(true,_5238,_5239);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5240,std::shared_ptr< monty::ndarray< double,1 > > _5241,monty::rc_ptr< ::mosek::fusion::Expression > _5242){
  _checked_ptr_1<double> _ptr__5241(_5241 ? _5241->raw() : nullptr, _5241 ? _5241->size(0) : 0);
  int _5243 = (int)((_5241)->size(0));
  int _5244 = _5243;
  std::shared_ptr< monty::ndarray< double,1 > > _5245 = ::mosek::fusion::Utils::Tools::arraycopy(_5241);
  _checked_ptr_1<double> _ptr__5245(_5245 ? _5245->raw() : nullptr,_5245 ? _5245->size(0) : 0);
  int _5246 = _5242->getND();
  if ((_5246 == (int)0))
  {
    {
      std::vector<int> _9347;
      for (int _5247 = (int)0, _9348 = _5243; _5247 < _9348 ; ++_5247)
      {
        _9347.push_back(_5247);
      }
      auto _9349 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9347.size()),_9347.begin(),_9347.end()));
      std::vector<int> _9350;
      for (int _5248 = (int)0, _9351 = _5243; _5248 < _9351 ; ++_5248)
      {
        _9350.push_back((int)0);
      }
      auto _9352 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9350.size()),_9350.begin(),_9350.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5243)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5243,(int)1,_9349,_9352,_5245,_5242,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5246 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_5240 && (_5242->getDim((int)0) == (int)((_5241)->size(0)))))
  {
    {
      std::vector<int> _9353;
      for (int _5249 = (int)0, _9354 = _5243; _5249 < _9354 ; ++_5249)
      {
        _9353.push_back((int)0);
      }
      auto _9355 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9353.size()),_9353.begin(),_9353.end()));
      std::vector<int> _9356;
      for (int _5250 = (int)0, _9357 = _5243; _5250 < _9357 ; ++_5250)
      {
        _9356.push_back(_5250);
      }
      auto _9358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9356.size()),_9356.begin(),_9356.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5242->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_5243,_9355,_9358,_5245,_5242)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5240 && (_5242->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _9359;
      for (int _5251 = (int)0, _9360 = _5243; _5251 < _9360 ; ++_5251)
      {
        _9359.push_back(_5251);
      }
      auto _9361 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9359.size()),_9359.begin(),_9359.end()));
      std::vector<int> _9362;
      for (int _5252 = (int)0, _9363 = _5243; _5252 < _9363 ; ++_5252)
      {
        _9362.push_back((int)0);
      }
      auto _9364 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9362.size()),_9362.begin(),_9362.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5243,(int)1,_9361,_9364,_5245,_5242,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5240) && (_5242->getDim((int)1) == _5243)))
  {
    {
      std::vector<int> _9365;
      for (int _5253 = (int)0, _9366 = _5243; _5253 < _9366 ; ++_5253)
      {
        _9365.push_back(_5253);
      }
      auto _9367 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9365.size()),_9365.begin(),_9365.end()));
      std::vector<int> _9368;
      for (int _5254 = (int)0, _9369 = _5243; _5254 < _9369 ; ++_5254)
      {
        _9368.push_back((int)0);
      }
      auto _9370 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9368.size()),_9368.begin(),_9368.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5242->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5243,(int)1,_9367,_9370,_5245,_5242)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5240) && (_5242->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _9371;
      for (int _5255 = (int)0, _9372 = _5243; _5255 < _9372 ; ++_5255)
      {
        _9371.push_back((int)0);
      }
      auto _9373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9371.size()),_9371.begin(),_9371.end()));
      std::vector<int> _9374;
      for (int _5256 = (int)0, _9375 = _5243; _5256 < _9375 ; ++_5256)
      {
        _9374.push_back(_5256);
      }
      auto _9376 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9374.size()),_9374.begin(),_9374.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_5243,_9373,_9376,_5245,_5242,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5257,std::shared_ptr< monty::ndarray< double,2 > > _5258,monty::rc_ptr< ::mosek::fusion::Expression > _5259){
  int _5260 = (int)((_5258)->size(0));
  int _5261 = (int)((_5258)->size(1));
  int _5262 = safe_mul( _5260,_5261 );
  std::vector<int> _9377;
  for (int _5264 = (int)0, _9378 = _5260; _5264 < _9378 ; ++_5264)
  {
    for (int _5265 = (int)0, _9379 = _5261; _5265 < _9379 ; ++_5265)
    {
      _9377.push_back(_5264);
    }
  }
  auto _9380 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9377.size()),_9377.begin(),_9377.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5263 = _9380;
  _checked_ptr_1<int> _ptr__5263(_5263 ? _5263->raw() : nullptr,_5263 ? _5263->size(0) : 0);
  std::vector<int> _9381;
  for (int _5267 = (int)0, _9382 = _5260; _5267 < _9382 ; ++_5267)
  {
    for (int _5268 = (int)0, _9383 = _5261; _5268 < _9383 ; ++_5268)
    {
      _9381.push_back(_5268);
    }
  }
  auto _9384 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9381.size()),_9381.begin(),_9381.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5266 = _9384;
  _checked_ptr_1<int> _ptr__5266(_5266 ? _5266->raw() : nullptr,_5266 ? _5266->size(0) : 0);
  std::vector<double> _9385;
  for (int _5270 = (int)0, _9386 = _5260; _5270 < _9386 ; ++_5270)
  {
    for (int _5271 = (int)0, _9387 = _5261; _5271 < _9387 ; ++_5271)
    {
      _9385.push_back(((*_5258)(_5270,_5271)));
    }
  }
  auto _9388 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9385.size()),_9385.begin(),_9385.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5269 = _9388;
  _checked_ptr_1<double> _ptr__5269(_5269 ? _5269->raw() : nullptr,_5269 ? _5269->size(0) : 0);
  long long _5272 = _5259->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _5273 = _5259->getShape();
  _checked_ptr_1<int> _ptr__5273(_5273 ? _5273->raw() : nullptr,_5273 ? _5273->size(0) : 0);
  if (((int)((_5273)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5260,_5261,_5263,_5266,_5269,_5259,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_5257)
  {
    {
      if (((int)((_5273)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5258)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5260,_5261,_5263,_5266,_5269,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5273[(int)0]),(int)((int)1)}),_5259)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5273)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5260,_5261,_5263,_5266,_5269,_5259)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_5273)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5258)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5260,_5261,_5263,_5266,_5269,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5273[(int)0])}),_5259)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5273)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5260,_5261,_5263,_5266,_5269,_5259)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5274,monty::rc_ptr< ::mosek::fusion::Matrix > _5275,monty::rc_ptr< ::mosek::fusion::Expression > _5276){
  long long _5277 = _5275->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5278 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5277)));
  _checked_ptr_1<int> _ptr__5278(_5278 ? _5278->raw() : nullptr,_5278 ? _5278->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5279 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5277)));
  _checked_ptr_1<int> _ptr__5279(_5279 ? _5279->raw() : nullptr,_5279 ? _5279->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5280 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5277)));
  _checked_ptr_1<double> _ptr__5280(_5280 ? _5280->raw() : nullptr,_5280 ? _5280->size(0) : 0);
  int _5281 = _5275->numRows();
  int _5282 = _5275->numColumns();
  _5275->getDataAsTriplets(_5278,_5279,_5280);
  int _5283 = _5276->getND();
  if ((_5283 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5281,_5282,_5278,_5279,_5280,_5276)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5283 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5284 = _5276->getShape();
      _checked_ptr_1<int> _ptr__5284(_5284 ? _5284->raw() : nullptr,_5284 ? _5284->size(0) : 0);
      if (_5274)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5281)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5281,_5282,_5278,_5279,_5280,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5284[(int)0]),(int)((int)1)}),_5276)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5282)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5281,_5282,_5278,_5279,_5280,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5284[(int)0])}),_5276)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_5283 == (int)2))
  {
    {
      if (_5274)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5281,_5282,_5278,_5279,_5280,_5276)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5281,_5282,_5278,_5279,_5280,_5276)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _5285,    monty::rc_ptr< ::mosek::fusion::Matrix > _5286) { return mosek::fusion::p_Expr::mul(_5285,_5286); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _5285,monty::rc_ptr< ::mosek::fusion::Matrix > _5286){
  int _5287 = _5286->numRows();
  int _5288 = _5286->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5289 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5286->numNonzeros())));
  _checked_ptr_1<double> _ptr__5289(_5289 ? _5289->raw() : nullptr,_5289 ? _5289->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5290 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5286->numNonzeros())));
  _checked_ptr_1<int> _ptr__5290(_5290 ? _5290->raw() : nullptr,_5290 ? _5290->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5291 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5286->numNonzeros())));
  _checked_ptr_1<int> _ptr__5291(_5291 ? _5291->raw() : nullptr,_5291 ? _5291->size(0) : 0);
  _5286->getDataAsTriplets(_5291,_5290,_5289);
  return ::mosek::fusion::p_Expr::mul(false,_5287,_5288,_5291,_5290,_5289,_5285);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5292,    monty::rc_ptr< ::mosek::fusion::Variable > _5293) { return mosek::fusion::p_Expr::mul(_5292,_5293); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5292,monty::rc_ptr< ::mosek::fusion::Variable > _5293){
  int _5294 = _5292->numRows();
  int _5295 = _5292->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5296 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5292->numNonzeros())));
  _checked_ptr_1<double> _ptr__5296(_5296 ? _5296->raw() : nullptr,_5296 ? _5296->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5297 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5292->numNonzeros())));
  _checked_ptr_1<int> _ptr__5297(_5297 ? _5297->raw() : nullptr,_5297 ? _5297->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5298 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5292->numNonzeros())));
  _checked_ptr_1<int> _ptr__5298(_5298 ? _5298->raw() : nullptr,_5298 ? _5298->size(0) : 0);
  _5292->getDataAsTriplets(_5298,_5297,_5296);
  return ::mosek::fusion::p_Expr::mul(true,_5294,_5295,_5298,_5297,_5296,_5293);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5299,int _5300,int _5301,std::shared_ptr< monty::ndarray< int,1 > > _5302,std::shared_ptr< monty::ndarray< int,1 > > _5303,std::shared_ptr< monty::ndarray< double,1 > > _5304,monty::rc_ptr< ::mosek::fusion::Variable > _5305){
  _checked_ptr_1<int> _ptr__5302(_5302 ? _5302->raw() : nullptr, _5302 ? _5302->size(0) : 0);
  _checked_ptr_1<int> _ptr__5303(_5303 ? _5303->raw() : nullptr, _5303 ? _5303->size(0) : 0);
  _checked_ptr_1<double> _ptr__5304(_5304 ? _5304->raw() : nullptr, _5304 ? _5304->size(0) : 0);
  if ((_5305->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_5300,_5301,_5302,_5303,_5304,_5305)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5305->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5306 = _5305->getShape();
      _checked_ptr_1<int> _ptr__5306(_5306 ? _5306->raw() : nullptr,_5306 ? _5306->size(0) : 0);
      int _9389;
      bool _9390 = _5299;
      if (_9390)
      {
        _9389 = _5300;
      }
      else
      {
        _9389 = _5301;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _9391;
      bool _9392 = _5299;
      if (_9392)
      {
        _9391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5306[(int)0]),(int)((int)1)});
      }
      else
      {
        _9391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5306[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_9389)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5299,_5300,_5301,_5302,_5303,_5304,::mosek::fusion::p_Var::reshape(_5305,_9391))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5299,_5300,_5301,_5302,_5303,_5304,_5305)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5307,    monty::rc_ptr< ::mosek::fusion::Matrix > _5308) { return mosek::fusion::p_Expr::dot(_5307,_5308); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5307,monty::rc_ptr< ::mosek::fusion::Matrix > _5308){
  long long _5309 = _5308->numNonzeros();
  if ((!_5308->isSparse()))
  {
    {
      std::vector<long long> _9393;
      for (long long _5310 = (int)0, _9394 = _5309; _5310 < _9394 ; ++_5310)
      {
        _9393.push_back(_5310);
      }
      auto _9395 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9393.size()),_9393.begin(),_9393.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5307,_9395,_5308->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5311 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5309)));
      _checked_ptr_1<int> _ptr__5311(_5311 ? _5311->raw() : nullptr,_5311 ? _5311->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5312 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5309)));
      _checked_ptr_1<int> _ptr__5312(_5312 ? _5312->raw() : nullptr,_5312 ? _5312->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5313 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5309)));
      _checked_ptr_1<double> _ptr__5313(_5313 ? _5313->raw() : nullptr,_5313 ? _5313->size(0) : 0);
      int _5314 = _5308->numColumns();
      _5308->getDataAsTriplets(_5311,_5312,_5313);
      std::vector<long long> _9396;
      for (int _5315 = (int)0, _9397 = (int)((_5311)->size(0)); _5315 < _9397 ; ++_5315)
      {
        _9396.push_back(safe_add( safe_mul( _ptr__5311[_5315],_5314 ),_ptr__5312[_5315] ));
      }
      auto _9398 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9396.size()),_9396.begin(),_9396.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5307,_9398,_5313)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5316,    std::shared_ptr< monty::ndarray< double,2 > > _5317) { return mosek::fusion::p_Expr::dot(_5316,_5317); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5316,std::shared_ptr< monty::ndarray< double,2 > > _5317){
  std::vector<long long> _9399;
  for (int _5318 = (int)0, _9400 = safe_mul( (int)((_5317)->size(0)),(int)((_5317)->size(1)) ); _5318 < _9400 ; ++_5318)
  {
    _9399.push_back(_5318);
  }
  auto _9401 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9399.size()),_9399.begin(),_9399.end()));
  std::vector<double> _9402;
  for (int _5319 = (int)0, _9403 = (int)((_5317)->size(0)); _5319 < _9403 ; ++_5319)
  {
    for (int _5320 = (int)0, _9404 = (int)((_5317)->size(1)); _5320 < _9404 ; ++_5320)
    {
      _9402.push_back(((*_5317)(_5319,_5320)));
    }
  }
  auto _9405 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9402.size()),_9402.begin(),_9402.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5316,_9401,_9405)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5321,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5322) { return mosek::fusion::p_Expr::dot(_5321,_5322); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5321,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5322){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5321,mosek::fusion::p_NDSparseArray::_get_impl(_5322)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5322)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5323,    std::shared_ptr< monty::ndarray< double,1 > > _5324) { return mosek::fusion::p_Expr::dot(_5323,_5324); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5323,std::shared_ptr< monty::ndarray< double,1 > > _5324){
  _checked_ptr_1<double> _ptr__5324(_5324 ? _5324->raw() : nullptr, _5324 ? _5324->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5325 = _5323->getShape();
  _checked_ptr_1<int> _ptr__5325(_5325 ? _5325->raw() : nullptr,_5325 ? _5325->size(0) : 0);
  if (((_5323->getSize() == (int)((_5324)->size(0))) && ((int)((_5325)->size(0)) > (int)1)))
  {
    {
      int _5326 = (int)0;
      int _9406 = (int)0;
      int _9407 = (int)((_5325)->size(0));
      for (int _5327 = _9406; _5327 < _9407; ++_5327)
      {
        {
          if ((_ptr__5325[_5327] > (int)1))
          {
            {
              ++ _5326;
            }
          }
          {}
        }
      }
      if ((_5326 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5328 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_5323->getSize())});
          _checked_ptr_1<int> _ptr__5328(_5328 ? _5328->raw() : nullptr,_5328 ? _5328->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5328,_5323)).as<::mosek::fusion::Expression>(),_5324)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5323,_5324)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5329,    monty::rc_ptr< ::mosek::fusion::Expression > _5330) { return mosek::fusion::p_Expr::dot(_5329,_5330); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5329,monty::rc_ptr< ::mosek::fusion::Expression > _5330){
  return ::mosek::fusion::p_Expr::dot(_5330,_5329);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5331,    monty::rc_ptr< ::mosek::fusion::Expression > _5332) { return mosek::fusion::p_Expr::dot(_5331,_5332); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5331,monty::rc_ptr< ::mosek::fusion::Expression > _5332){
  return ::mosek::fusion::p_Expr::dot(_5332,_5331);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _5333,    monty::rc_ptr< ::mosek::fusion::Expression > _5334) { return mosek::fusion::p_Expr::dot(_5333,_5334); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _5333,monty::rc_ptr< ::mosek::fusion::Expression > _5334){
  return ::mosek::fusion::p_Expr::dot(_5334,_5333);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _5335,    monty::rc_ptr< ::mosek::fusion::Expression > _5336) { return mosek::fusion::p_Expr::dot(_5335,_5336); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _5335,monty::rc_ptr< ::mosek::fusion::Expression > _5336){
  _checked_ptr_1<double> _ptr__5335(_5335 ? _5335->raw() : nullptr, _5335 ? _5335->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_5336,_5335);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5337,    monty::rc_ptr< ::mosek::fusion::Expression > _5338) { return mosek::fusion::p_Expr::outer(_5337,_5338); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5337,monty::rc_ptr< ::mosek::fusion::Expression > _5338){
  _checked_ptr_1<double> _ptr__5337(_5337 ? _5337->raw() : nullptr, _5337 ? _5337->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5339 = _5338->getShape();
  _checked_ptr_1<int> _ptr__5339(_5339 ? _5339->raw() : nullptr,_5339 ? _5339->size(0) : 0);
  if (((int)((_5339)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  if ((_ptr__5339[(int)0] != (int)((_5337)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Argument lengths do not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5340 = _5338->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9408;
  for (int _5341 = (int)0, _9409 = (int)((_5337)->size(0)); _5341 < _9409 ; ++_5341)
  {
    _9408.push_back(_5341);
  }
  auto _9410 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9408.size()),_9408.begin(),_9408.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5340)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5340)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5340)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5340)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5340)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5340)->inst,_5337,_9410,(int)((_5337)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Expression > _5342,    std::shared_ptr< monty::ndarray< double,1 > > _5343) { return mosek::fusion::p_Expr::outer(_5342,_5343); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Expression > _5342,std::shared_ptr< monty::ndarray< double,1 > > _5343){
  _checked_ptr_1<double> _ptr__5343(_5343 ? _5343->raw() : nullptr, _5343 ? _5343->size(0) : 0);
  if (((_5342->getND() != (int)1) || (_5342->getND() != (int)1)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5344 = _5342->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9411;
  for (int _5345 = (int)0, _9412 = (int)((_5343)->size(0)); _5345 < _9412 ; ++_5345)
  {
    _9411.push_back(_5345);
  }
  auto _9413 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9411.size()),_9411.begin(),_9411.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5344)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5344)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5344)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5344)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5344)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5344)->inst,_5343,_9413,(int)((_5343)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5346,    monty::rc_ptr< ::mosek::fusion::Variable > _5347) { return mosek::fusion::p_Expr::outer(_5346,_5347); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5346,monty::rc_ptr< ::mosek::fusion::Variable > _5347){
  std::shared_ptr< monty::ndarray< int,1 > > _5348 = _5347->getShape();
  _checked_ptr_1<int> _ptr__5348(_5348 ? _5348->raw() : nullptr,_5348 ? _5348->size(0) : 0);
  if ((!(((int)((_5348)->size(0)) == (int)1) || (((int)((_5348)->size(0)) == (int)2) && (_ptr__5348[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5346)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9414 = _5346;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9414.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5349 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9414.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5347,_ptr__5348[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5349)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5349)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5350 = _9414;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5351 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5350->numNonzeros())));
      _checked_ptr_1<double> _ptr__5351(_5351 ? _5351->raw() : nullptr,_5351 ? _5351->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5352 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5350->numNonzeros())));
      _checked_ptr_1<int> _ptr__5352(_5352 ? _5352->raw() : nullptr,_5352 ? _5352->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5353 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5350->numNonzeros())));
      _checked_ptr_1<int> _ptr__5353(_5353 ? _5353->raw() : nullptr,_5353 ? _5353->size(0) : 0);
      _5350->getDataAsTriplets(_5353,_5352,_5351);
      return ::mosek::fusion::p_Expr::outer_(_5347,_ptr__5348[(int)0],_5351,_5353,mosek::fusion::p_Matrix::_get_impl(_5350)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5354,    monty::rc_ptr< ::mosek::fusion::Matrix > _5355) { return mosek::fusion::p_Expr::outer(_5354,_5355); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5354,monty::rc_ptr< ::mosek::fusion::Matrix > _5355){
  std::shared_ptr< monty::ndarray< int,1 > > _5356 = _5354->getShape();
  _checked_ptr_1<int> _ptr__5356(_5356 ? _5356->raw() : nullptr,_5356 ? _5356->size(0) : 0);
  if ((!((_5354->getND() == (int)1) || ((_5354->getND() == (int)2) && (_ptr__5356[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5355)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9415 = _5355;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9415.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5357 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9415.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5354,_ptr__5356[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5357)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5357)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5358 = _9415;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5359 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5358->numNonzeros())));
      _checked_ptr_1<double> _ptr__5359(_5359 ? _5359->raw() : nullptr,_5359 ? _5359->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5360 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5358->numNonzeros())));
      _checked_ptr_1<int> _ptr__5360(_5360 ? _5360->raw() : nullptr,_5360 ? _5360->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5361 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5355->numNonzeros())));
      _checked_ptr_1<int> _ptr__5361(_5361 ? _5361->raw() : nullptr,_5361 ? _5361->size(0) : 0);
      _5358->getDataAsTriplets(_5361,_5360,_5359);
      return ::mosek::fusion::p_Expr::outer_(_5354,((*_5354->getShape())((int)0)),_5359,_5361,mosek::fusion::p_Matrix::_get_impl(_5358)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5362,    monty::rc_ptr< ::mosek::fusion::Variable > _5363) { return mosek::fusion::p_Expr::outer(_5362,_5363); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5362,monty::rc_ptr< ::mosek::fusion::Variable > _5363){
  _checked_ptr_1<double> _ptr__5362(_5362 ? _5362->raw() : nullptr, _5362 ? _5362->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5364 = _5363->getShape();
  _checked_ptr_1<int> _ptr__5364(_5364 ? _5364->raw() : nullptr,_5364 ? _5364->size(0) : 0);
  if ((!((_5363->getND() == (int)1) || ((_5363->getND() == (int)2) && (_ptr__5364[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5363,_ptr__5364[(int)0],_5362,nullptr,(int)((_5362)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5365,    std::shared_ptr< monty::ndarray< double,1 > > _5366) { return mosek::fusion::p_Expr::outer(_5365,_5366); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5365,std::shared_ptr< monty::ndarray< double,1 > > _5366){
  _checked_ptr_1<double> _ptr__5366(_5366 ? _5366->raw() : nullptr, _5366 ? _5366->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5367 = _5365->getShape();
  _checked_ptr_1<int> _ptr__5367(_5367 ? _5367->raw() : nullptr,_5367 ? _5367->size(0) : 0);
  if ((!((_5365->getND() == (int)1) || ((_5365->getND() == (int)2) && (_ptr__5367[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5365,_ptr__5367[(int)0],_5366,nullptr,(int)((_5366)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _5368,std::shared_ptr< monty::ndarray< long long,1 > > _5369,std::shared_ptr< monty::ndarray< long long,1 > > _5370,std::shared_ptr< monty::ndarray< double,1 > > _5371,std::shared_ptr< monty::ndarray< double,1 > > _5372,std::shared_ptr< monty::ndarray< long long,1 > > _5373,std::shared_ptr< monty::ndarray< double,1 > > _5374,std::shared_ptr< monty::ndarray< int,1 > > _5375,int _5376,bool _5377){
  _checked_ptr_1<long long> _ptr__5369(_5369 ? _5369->raw() : nullptr, _5369 ? _5369->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5370(_5370 ? _5370->raw() : nullptr, _5370 ? _5370->size(0) : 0);
  _checked_ptr_1<double> _ptr__5371(_5371 ? _5371->raw() : nullptr, _5371 ? _5371->size(0) : 0);
  _checked_ptr_1<double> _ptr__5372(_5372 ? _5372->raw() : nullptr, _5372 ? _5372->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5373(_5373 ? _5373->raw() : nullptr, _5373 ? _5373->size(0) : 0);
  _checked_ptr_1<double> _ptr__5374(_5374 ? _5374->raw() : nullptr, _5374 ? _5374->size(0) : 0);
  _checked_ptr_1<int> _ptr__5375(_5375 ? _5375->raw() : nullptr, _5375 ? _5375->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9416;
  bool _9417 = (!_5377);
  if (_9417)
  {
    _9416 = ::mosek::fusion::p_Set::make(_5368,_5376);
  }
  else
  {
    _9416 = ::mosek::fusion::p_Set::make(_5376,_5368);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5378 = _9416;
  _checked_ptr_1<int> _ptr__5378(_5378 ? _5378->raw() : nullptr,_5378 ? _5378->size(0) : 0);
  int _5379 = safe_mul( (int)((_5374)->size(0)),(int)((_5373)->size(0)) );
  int _5380 = safe_mul( (int)((_5374)->size(0)),(int)((_5370)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _5381 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5379)));
  _checked_ptr_1<long long> _ptr__5381(_5381 ? _5381->raw() : nullptr,_5381 ? _5381->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9418;
  bool _9419 = (NULL != _5372.get());
  if (_9419)
  {
    _9418 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5379)));
  }
  else
  {
    _9418 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5382 = _9418;
  _checked_ptr_1<double> _ptr__5382(_5382 ? _5382->raw() : nullptr,_5382 ? _5382->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5383 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5380)));
  _checked_ptr_1<double> _ptr__5383(_5383 ? _5383->raw() : nullptr,_5383 ? _5383->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5384 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5380)));
  _checked_ptr_1<long long> _ptr__5384(_5384 ? _5384->raw() : nullptr,_5384 ? _5384->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5385 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5379,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5385(_5385 ? _5385->raw() : nullptr,_5385 ? _5385->size(0) : 0);
  int _5386 = (int)_ptr__5385[((int)((_5385)->size(0)) - (int)1)];
  if ((!_5377))
  {
    {
      long long _5387 = (long long)0;
      long long _5388 = (long long)0;
      int _9420 = (int)0;
      int _9421 = (int)((_5373)->size(0));
      for (int _5389 = _9420; _5389 < _9421; ++_5389)
      {
        {
          long long _5390 = (_ptr__5369[safe_add( _5389,(int)1 )] - _ptr__5369[_5389]);
          int _9422 = (int)0;
          int _9423 = (int)((_5374)->size(0));
          for (int _5391 = _9422; _5391 < _9423; ++_5391)
          {
            {
              _ptr__5373[_5387] = safe_add( safe_mul( _ptr__5373[_5389],_5376 ),_ptr__5375[_5391] );
              _ptr__5385[safe_add( _5387,(int)1 )] = safe_add( _ptr__5385[_5387],_5390 );
              ++ _5387;
              long long _9424 = _ptr__5369[_5389];
              long long _9425 = _ptr__5369[safe_add( _5389,(int)1 )];
              for (long long _5392 = _9424; _5392 < _9425; ++_5392)
              {
                {
                  _ptr__5384[_5388] = _ptr__5370[_5392];
                  _ptr__5383[_5388] = (_ptr__5371[_5392] * _ptr__5374[_5391]);
                  ++ _5388;
                }
              }
            }
          }
        }
      }
      if ((NULL != _5382.get()))
      {
        {
          int _5393 = (int)0;
          int _9426 = (int)0;
          int _9427 = (int)((_5373)->size(0));
          for (int _5394 = _9426; _5394 < _9427; ++_5394)
          {
            {
              int _9428 = (int)0;
              int _9429 = (int)((_5374)->size(0));
              for (int _5395 = _9428; _5395 < _9429; ++_5395)
              {
                {
                  _ptr__5382[_5393] = (_ptr__5374[_5395] * _ptr__5372[_5394]);
                  ++ _5393;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _5396 = (long long)0;
      long long _5397 = (long long)0;
      int _9430 = (int)0;
      int _9431 = (int)((_5374)->size(0));
      for (int _5398 = _9430; _5398 < _9431; ++_5398)
      {
        {
          double _5399 = _ptr__5374[_5398];
          ::mosek::fusion::Utils::Tools::arraycopy(_5370,(long long)((int)0),_5384,_5397,(long long)(_5386));
          int _9432 = (int)0;
          int _9433 = _5386;
          for (int _5400 = _9432; _5400 < _9433; ++_5400)
          {
            {
              _ptr__5383[safe_add( _5397,_5400 )] = (_ptr__5371[_5400] * _ptr__5374[_5398]);
            }
          }
          int _9434 = (int)0;
          int _9435 = (int)((_5373)->size(0));
          for (int _5401 = _9434; _5401 < _9435; ++_5401)
          {
            {
              long long _5402 = (_ptr__5369[safe_add( _5401,(int)1 )] - _ptr__5369[_5401]);
              _ptr__5373[_5396] = safe_add( safe_mul( _ptr__5373[_5401],_5376 ),_ptr__5375[_5398] );
              _ptr__5385[safe_add( _5396,(int)1 )] = safe_add( _ptr__5385[_5396],_5402 );
              ++ _5396;
            }
          }
          _5397 += _5386;
        }
      }
      if ((NULL != _5382.get()))
      {
        {
          int _5403 = (int)0;
          int _9436 = (int)0;
          int _9437 = (int)((_5374)->size(0));
          for (int _5404 = _9436; _5404 < _9437; ++_5404)
          {
            {
              double _5405 = _ptr__5374[_5404];
              int _9438 = (int)0;
              int _9439 = (int)((_5373)->size(0));
              for (int _5406 = _9438; _5406 < _9439; ++_5406)
              {
                {
                  _ptr__5382[_5403] = (_ptr__5372[_5406] * _5405);
                  ++ _5403;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5385,_5384,_5383,_5382,_5378,_5381)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5407,int _5408,std::shared_ptr< monty::ndarray< double,1 > > _5409,std::shared_ptr< monty::ndarray< int,1 > > _5410,int _5411,bool _5412){
  _checked_ptr_1<double> _ptr__5409(_5409 ? _5409->raw() : nullptr, _5409 ? _5409->size(0) : 0);
  _checked_ptr_1<int> _ptr__5410(_5410 ? _5410->raw() : nullptr, _5410 ? _5410->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9440;
  bool _9441 = (!_5412);
  if (_9441)
  {
    _9440 = ::mosek::fusion::p_Set::make(_5408,_5411);
  }
  else
  {
    _9440 = ::mosek::fusion::p_Set::make(_5411,_5408);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5413 = _9440;
  _checked_ptr_1<int> _ptr__5413(_5413 ? _5413->raw() : nullptr,_5413 ? _5413->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9442;
  bool _9443 = (_5411 == (int)((_5409)->size(0)));
  if (_9443)
  {
    _9442 = nullptr;
  }
  else
  {
    _9442 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5409)->size(0)),_5408 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5414 = _9442;
  _checked_ptr_1<long long> _ptr__5414(_5414 ? _5414->raw() : nullptr,_5414 ? _5414->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5415 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5409)->size(0)),_5408 ))));
  _checked_ptr_1<double> _ptr__5415(_5415 ? _5415->raw() : nullptr,_5415 ? _5415->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5416 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5409)->size(0)),_5408 ))));
  _checked_ptr_1<double> _ptr__5416(_5416 ? _5416->raw() : nullptr,_5416 ? _5416->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5417 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5409)->size(0)),_5408 ))));
  _checked_ptr_1<long long> _ptr__5417(_5417 ? _5417->raw() : nullptr,_5417 ? _5417->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5418 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_5409)->size(0)),_5408 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__5418(_5418 ? _5418->raw() : nullptr,_5418 ? _5418->size(0) : 0);
  if ((_5411 == (int)((_5409)->size(0))))
  {
    {
      long long _5419 = (long long)0;
      if ((!_5412))
      {
        {
          int _9444 = (int)0;
          int _9445 = _5408;
          for (int _5420 = _9444; _5420 < _9445; ++_5420)
          {
            {
              int _9446 = (int)0;
              int _9447 = _5411;
              for (int _5421 = _9446; _5421 < _9447; ++_5421)
              {
                {
                  _ptr__5418[safe_add( _5419,(int)1 )] = safe_add( _5419,(int)1 );
                  _ptr__5417[_5419] = (long long)_5420;
                  _ptr__5416[_5419] = _ptr__5409[_5421];
                  ++ _5419;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9448 = (int)0;
          int _9449 = _5411;
          for (int _5422 = _9448; _5422 < _9449; ++_5422)
          {
            {
              int _9450 = (int)0;
              int _9451 = _5408;
              for (int _5423 = _9450; _5423 < _9451; ++_5423)
              {
                {
                  _ptr__5418[safe_add( _5419,(int)1 )] = safe_add( _5419,(int)1 );
                  _ptr__5417[_5419] = (long long)_5423;
                  _ptr__5416[_5419] = _ptr__5409[_5422];
                  ++ _5419;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _5424 = (long long)0;
      if ((!_5412))
      {
        {
          int _9452 = (int)0;
          int _9453 = _5408;
          for (int _5425 = _9452; _5425 < _9453; ++_5425)
          {
            {
              int _9454 = (int)0;
              int _9455 = (int)((_5409)->size(0));
              for (int _5426 = _9454; _5426 < _9455; ++_5426)
              {
                {
                  _ptr__5418[safe_add( _5424,(int)1 )] = safe_add( _5424,(int)1 );
                  _ptr__5417[_5424] = (long long)_5425;
                  _ptr__5416[_5424] = _ptr__5409[_5426];
                  _ptr__5414[_5424] = safe_add( safe_mul( _5425,_5411 ),_ptr__5410[_5426] );
                  ++ _5424;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9456 = (int)0;
          int _9457 = (int)((_5409)->size(0));
          for (int _5427 = _9456; _5427 < _9457; ++_5427)
          {
            {
              int _9458 = (int)0;
              int _9459 = _5408;
              for (int _5428 = _9458; _5428 < _9459; ++_5428)
              {
                {
                  _ptr__5418[safe_add( _5424,(int)1 )] = safe_add( _5424,(int)1 );
                  _ptr__5417[_5424] = (long long)_5428;
                  _ptr__5416[_5424] = _ptr__5409[_5427];
                  _ptr__5414[_5424] = safe_add( safe_mul( _ptr__5410[_5427],_5408 ),_5428 );
                  ++ _5424;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5418,_5417,_5416,_5415,_5413,_5414)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5429) { return mosek::fusion::p_Expr::stack(_5429); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5429){
  if ((NULL == _5429.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9460 = (int)0;
  int _9461 = (int)((_5429)->size(0));
  for (int _5430 = _9460; _5430 < _9461; ++_5430)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5431 = ((*_5429)(_5430));
      if ((NULL == _5431.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _9462 = (int)0;
      int _9463 = (int)((_5431)->size(0));
      for (int _5432 = _9462; _5432 < _9463; ++_5432)
      {
        {
          if ((NULL == ((*_5431)(_5432)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9464;
  for (int _5434 = (int)0, _9465 = (int)((_5429)->size(0)); _5434 < _9465 ; ++_5434)
  {
    _9464.push_back(::mosek::fusion::p_Expr::stack_(((*_5429)(_5434)),(int)1));
  }
  auto _9466 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9464.size()),_9464.begin(),_9464.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5433 = _9466;
  return ::mosek::fusion::p_Expr::stack_(_5433,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5435,    double _5436,    double _5437) { return mosek::fusion::p_Expr::vstack(_5435,_5436,_5437); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5435,double _5436,double _5437){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5435).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5436).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5437).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5438,    double _5439,    monty::rc_ptr< ::mosek::fusion::Expression > _5440) { return mosek::fusion::p_Expr::vstack(_5438,_5439,_5440); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5438,double _5439,monty::rc_ptr< ::mosek::fusion::Expression > _5440){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5438).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5439).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5440.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5441,    monty::rc_ptr< ::mosek::fusion::Expression > _5442,    double _5443) { return mosek::fusion::p_Expr::vstack(_5441,_5442,_5443); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5441,monty::rc_ptr< ::mosek::fusion::Expression > _5442,double _5443){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5441).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5442.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5443).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5444,    monty::rc_ptr< ::mosek::fusion::Expression > _5445,    monty::rc_ptr< ::mosek::fusion::Expression > _5446) { return mosek::fusion::p_Expr::vstack(_5444,_5445,_5446); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5444,monty::rc_ptr< ::mosek::fusion::Expression > _5445,monty::rc_ptr< ::mosek::fusion::Expression > _5446){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5444).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5445.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5446.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5447,    double _5448,    double _5449) { return mosek::fusion::p_Expr::vstack(_5447,_5448,_5449); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5447,double _5448,double _5449){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5447.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5448).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5449).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5450,    double _5451,    monty::rc_ptr< ::mosek::fusion::Expression > _5452) { return mosek::fusion::p_Expr::vstack(_5450,_5451,_5452); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5450,double _5451,monty::rc_ptr< ::mosek::fusion::Expression > _5452){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5450.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5451).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5452.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5453,    monty::rc_ptr< ::mosek::fusion::Expression > _5454,    double _5455) { return mosek::fusion::p_Expr::vstack(_5453,_5454,_5455); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5453,monty::rc_ptr< ::mosek::fusion::Expression > _5454,double _5455){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5453.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5454.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5455).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5456,    monty::rc_ptr< ::mosek::fusion::Expression > _5457,    monty::rc_ptr< ::mosek::fusion::Expression > _5458) { return mosek::fusion::p_Expr::vstack(_5456,_5457,_5458); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5456,monty::rc_ptr< ::mosek::fusion::Expression > _5457,monty::rc_ptr< ::mosek::fusion::Expression > _5458){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5456.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5457.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5458.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5459,    monty::rc_ptr< ::mosek::fusion::Expression > _5460) { return mosek::fusion::p_Expr::vstack(_5459,_5460); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5459,monty::rc_ptr< ::mosek::fusion::Expression > _5460){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5459).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5460.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5461,    double _5462) { return mosek::fusion::p_Expr::vstack(_5461,_5462); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5461,double _5462){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5461.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5462).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5463,    monty::rc_ptr< ::mosek::fusion::Expression > _5464) { return mosek::fusion::p_Expr::vstack(_5463,_5464); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5463,monty::rc_ptr< ::mosek::fusion::Expression > _5464){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5463.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5464.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5465) { return mosek::fusion::p_Expr::vstack(_5465); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5465){
  if ((NULL == _5465.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9467 = (int)0;
  int _9468 = (int)((_5465)->size(0));
  for (int _5466 = _9467; _5466 < _9468; ++_5466)
  {
    {
      if ((NULL == ((*_5465)(_5466)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5465,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5467,    monty::rc_ptr< ::mosek::fusion::Expression > _5468,    monty::rc_ptr< ::mosek::fusion::Expression > _5469) { return mosek::fusion::p_Expr::hstack(_5467,_5468,_5469); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5467,monty::rc_ptr< ::mosek::fusion::Expression > _5468,monty::rc_ptr< ::mosek::fusion::Expression > _5469){
  if (((NULL == _5467.get()) || ((NULL == _5468.get()) || (NULL == _5469.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5467.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5468.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5469.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5470,    monty::rc_ptr< ::mosek::fusion::Expression > _5471,    double _5472) { return mosek::fusion::p_Expr::hstack(_5470,_5471,_5472); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5470,monty::rc_ptr< ::mosek::fusion::Expression > _5471,double _5472){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5470.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5471.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5472).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5473,    double _5474,    monty::rc_ptr< ::mosek::fusion::Expression > _5475) { return mosek::fusion::p_Expr::hstack(_5473,_5474,_5475); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5473,double _5474,monty::rc_ptr< ::mosek::fusion::Expression > _5475){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5473.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5474).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5475.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5476,    double _5477,    double _5478) { return mosek::fusion::p_Expr::hstack(_5476,_5477,_5478); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5476,double _5477,double _5478){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5476.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5477).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5478).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5479,    monty::rc_ptr< ::mosek::fusion::Expression > _5480,    monty::rc_ptr< ::mosek::fusion::Expression > _5481) { return mosek::fusion::p_Expr::hstack(_5479,_5480,_5481); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5479,monty::rc_ptr< ::mosek::fusion::Expression > _5480,monty::rc_ptr< ::mosek::fusion::Expression > _5481){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5479).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5480.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5481.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5482,    monty::rc_ptr< ::mosek::fusion::Expression > _5483,    double _5484) { return mosek::fusion::p_Expr::hstack(_5482,_5483,_5484); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5482,monty::rc_ptr< ::mosek::fusion::Expression > _5483,double _5484){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5482).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5483.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5484).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5485,    double _5486,    monty::rc_ptr< ::mosek::fusion::Expression > _5487) { return mosek::fusion::p_Expr::hstack(_5485,_5486,_5487); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5485,double _5486,monty::rc_ptr< ::mosek::fusion::Expression > _5487){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5485).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5486).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5487.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5488,    monty::rc_ptr< ::mosek::fusion::Expression > _5489) { return mosek::fusion::p_Expr::hstack(_5488,_5489); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5488,monty::rc_ptr< ::mosek::fusion::Expression > _5489){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5488).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5489.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5490,    double _5491) { return mosek::fusion::p_Expr::hstack(_5490,_5491); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5490,double _5491){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5490.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5491).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5492,    monty::rc_ptr< ::mosek::fusion::Expression > _5493) { return mosek::fusion::p_Expr::hstack(_5492,_5493); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5492,monty::rc_ptr< ::mosek::fusion::Expression > _5493){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5492.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5493.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5494) { return mosek::fusion::p_Expr::hstack(_5494); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5494){
  if ((NULL == _5494.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9469 = (int)0;
  int _9470 = (int)((_5494)->size(0));
  for (int _5495 = _9469; _5495 < _9470; ++_5495)
  {
    {
      if ((NULL == ((*_5494)(_5495)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5494,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5496,    monty::rc_ptr< ::mosek::fusion::Expression > _5497,    monty::rc_ptr< ::mosek::fusion::Expression > _5498,    monty::rc_ptr< ::mosek::fusion::Expression > _5499) { return mosek::fusion::p_Expr::stack(_5496,_5497,_5498,_5499); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5496,monty::rc_ptr< ::mosek::fusion::Expression > _5497,monty::rc_ptr< ::mosek::fusion::Expression > _5498,monty::rc_ptr< ::mosek::fusion::Expression > _5499){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5497.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5498.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5499.get())}),_5496);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5500,    monty::rc_ptr< ::mosek::fusion::Expression > _5501,    monty::rc_ptr< ::mosek::fusion::Expression > _5502,    double _5503) { return mosek::fusion::p_Expr::stack(_5500,_5501,_5502,_5503); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5500,monty::rc_ptr< ::mosek::fusion::Expression > _5501,monty::rc_ptr< ::mosek::fusion::Expression > _5502,double _5503){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5501.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5502.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5503).get())}),_5500);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5504,    monty::rc_ptr< ::mosek::fusion::Expression > _5505,    double _5506,    monty::rc_ptr< ::mosek::fusion::Expression > _5507) { return mosek::fusion::p_Expr::stack(_5504,_5505,_5506,_5507); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5504,monty::rc_ptr< ::mosek::fusion::Expression > _5505,double _5506,monty::rc_ptr< ::mosek::fusion::Expression > _5507){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5505.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5506).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5507.get())}),_5504);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5508,    monty::rc_ptr< ::mosek::fusion::Expression > _5509,    double _5510,    double _5511) { return mosek::fusion::p_Expr::stack(_5508,_5509,_5510,_5511); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5508,monty::rc_ptr< ::mosek::fusion::Expression > _5509,double _5510,double _5511){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5509.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5510).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5511).get())}),_5508);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5512,    double _5513,    monty::rc_ptr< ::mosek::fusion::Expression > _5514,    monty::rc_ptr< ::mosek::fusion::Expression > _5515) { return mosek::fusion::p_Expr::stack(_5512,_5513,_5514,_5515); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5512,double _5513,monty::rc_ptr< ::mosek::fusion::Expression > _5514,monty::rc_ptr< ::mosek::fusion::Expression > _5515){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5513).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5514.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5515.get())}),_5512);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5516,    double _5517,    monty::rc_ptr< ::mosek::fusion::Expression > _5518,    double _5519) { return mosek::fusion::p_Expr::stack(_5516,_5517,_5518,_5519); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5516,double _5517,monty::rc_ptr< ::mosek::fusion::Expression > _5518,double _5519){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5517).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5518.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5519).get())}),_5516);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5520,    double _5521,    double _5522,    monty::rc_ptr< ::mosek::fusion::Expression > _5523) { return mosek::fusion::p_Expr::stack(_5520,_5521,_5522,_5523); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5520,double _5521,double _5522,monty::rc_ptr< ::mosek::fusion::Expression > _5523){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5521).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5522).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5523.get())}),_5520);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5524,    double _5525,    monty::rc_ptr< ::mosek::fusion::Expression > _5526) { return mosek::fusion::p_Expr::stack(_5524,_5525,_5526); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5524,double _5525,monty::rc_ptr< ::mosek::fusion::Expression > _5526){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5525).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5526.get())}),_5524);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5527,    monty::rc_ptr< ::mosek::fusion::Expression > _5528,    double _5529) { return mosek::fusion::p_Expr::stack(_5527,_5528,_5529); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5527,monty::rc_ptr< ::mosek::fusion::Expression > _5528,double _5529){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5528.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5529).get())}),_5527);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5530,    monty::rc_ptr< ::mosek::fusion::Expression > _5531,    monty::rc_ptr< ::mosek::fusion::Expression > _5532) { return mosek::fusion::p_Expr::stack(_5530,_5531,_5532); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5530,monty::rc_ptr< ::mosek::fusion::Expression > _5531,monty::rc_ptr< ::mosek::fusion::Expression > _5532){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5531.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5532.get())}),_5530);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5533,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5534) { return mosek::fusion::p_Expr::stack(_5533,_5534); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5533,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5534){
  return ::mosek::fusion::p_Expr::stack_(_5534,_5533);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5535,int _5536){
  if (((int)((_5535)->size(0)) == (int)1))
  {
    {
      return ((*_5535)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_5535,_5536),_5536)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5537,int _5538){
  int _5539 = (int)((_5537)->size(0));
  std::vector<int> _9471;
  for (int _5541 = (int)0, _9472 = _5539; _5541 < _9472 ; ++_5541)
  {
    _9471.push_back(((*_5537)(_5541))->getND());
  }
  auto _9473 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9471.size()),_9471.begin(),_9471.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5540 = _9473;
  _checked_ptr_1<int> _ptr__5540(_5540 ? _5540->raw() : nullptr,_5540 ? _5540->size(0) : 0);
  int _5542 = _ptr__5540[(int)0];
  int _5543 = _ptr__5540[(int)0];
  int _9474 = (int)1;
  int _9475 = _5539;
  for (int _5544 = _9474; _5544 < _9475; ++_5544)
  {
    {
      if ((_ptr__5540[_5544] < _5543))
      {
        {
          _5543 = _ptr__5540[_5544];
        }
      }
      {}
      if ((_ptr__5540[_5544] > _5542))
      {
        {
          _5542 = _ptr__5540[_5544];
        }
      }
      {}
    }
  }
  if ((_5542 < _5538))
  {
    {
      _5542 = _5538;
    }
  }
  {}
  if ((_5543 < _5542))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5545 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_5539)));
      std::shared_ptr< monty::ndarray< int,1 > > _5546 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5542)));
      _checked_ptr_1<int> _ptr__5546(_5546 ? _5546->raw() : nullptr,_5546 ? _5546->size(0) : 0);
      int _9476 = (int)0;
      int _9477 = _5539;
      for (int _5547 = _9476; _5547 < _9477; ++_5547)
      {
        {
          if ((((*_5537)(_5547))->getND() == _5542))
          {
            {
              ((*_5545)(_5547)) = ((*_5537)(_5547));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _5548 = ((*_5537)(_5547))->getShape();
              _checked_ptr_1<int> _ptr__5548(_5548 ? _5548->raw() : nullptr,_5548 ? _5548->size(0) : 0);
              int _9478 = (int)0;
              int _9479 = (int)((_5548)->size(0));
              for (int _5549 = _9478; _5549 < _9479; ++_5549)
              {
                {
                  _ptr__5546[_5549] = _ptr__5548[_5549];
                }
              }
              int _9480 = (int)((_5548)->size(0));
              int _9481 = _5542;
              for (int _5550 = _9480; _5550 < _9481; ++_5550)
              {
                {
                  _ptr__5546[_5550] = (int)1;
                }
              }
              ((*_5545)(_5547)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5546,((*_5537)(_5547)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _5545;
    }
  }
  else
  {
    {
      return _5537;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _5551,    int _5552,    int _5553) { return mosek::fusion::p_Expr::repeat(_5551,_5552,_5553); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5551,int _5552,int _5553){
  if ((_5552 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9482;
  for (int _5554 = (int)0, _9483 = _5552; _5554 < _9483 ; ++_5554)
  {
    _9482.push_back(_5551);
  }
  auto _9484 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9482.size()),_9482.begin(),_9482.end()));
  return ::mosek::fusion::p_Expr::stack_(_9484,_5553);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5555) { return mosek::fusion::p_Expr::add(_5555); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5555){
  std::vector<double> _9485;
  for (int _5556 = (int)0, _9486 = (int)((_5555)->size(0)); _5556 < _9486 ; ++_5556)
  {
    _9485.push_back(1.0);
  }
  auto _9487 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9485.size()),_9485.begin(),_9485.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_5555,_9487)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5557) { return mosek::fusion::p_Expr::add(_5557); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5557){
  if ((NULL == _5557.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_5557)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5557)->size(0)) > (int)0) && (NULL == ((*_5557)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _5558 = ((*_5557)((int)0))->getND();
  int _9488 = (int)1;
  int _9489 = (int)((_5557)->size(0));
  for (int _5559 = _9488; _5559 < _9489; ++_5559)
  {
    {
      if ((_5558 < ((*_5557)(_5559))->getND()))
      {
        {
          _5558 = ((*_5557)(_5559))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _5560 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_5557)->size(0)),_5558)));
  int _9490 = (int)0;
  int _9491 = (int)((_5557)->size(0));
  for (int _5561 = _9490; _5561 < _9491; ++_5561)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5562 = ((*_5557)(_5561))->getShape();
      _checked_ptr_1<int> _ptr__5562(_5562 ? _5562->raw() : nullptr,_5562 ? _5562->size(0) : 0);
      int _9492 = (int)0;
      int _9493 = (int)((_5562)->size(0));
      for (int _5563 = _9492; _5563 < _9493; ++_5563)
      {
        {
          ((*_5560)(_5561,_5563)) = _ptr__5562[_5563];
        }
      }
      int _9494 = (int)((_5562)->size(0));
      int _9495 = _5558;
      for (int _5564 = _9494; _5564 < _9495; ++_5564)
      {
        {
          ((*_5560)(_5561,_5564)) = (int)1;
        }
      }
    }
  }
  int _9496 = (int)1;
  int _9497 = (int)((_5557)->size(0));
  for (int _5565 = _9496; _5565 < _9497; ++_5565)
  {
    {
      int _9498 = (int)0;
      int _9499 = _5558;
      for (int _5566 = _9498; _5566 < _9499; ++_5566)
      {
        {
          if ((((*_5560)((int)0,_5566)) != ((*_5560)(_5565,_5566))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _9500;
  for (int _5568 = (int)0, _9501 = _5558; _5568 < _9501 ; ++_5568)
  {
    _9500.push_back(((*_5560)((int)0,_5568)));
  }
  auto _9502 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9500.size()),_9500.begin(),_9500.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5567 = _9502;
  _checked_ptr_1<int> _ptr__5567(_5567 ? _5567->raw() : nullptr,_5567 ? _5567->size(0) : 0);
  int _5569 = (int)1;
  int _9503 = (int)0;
  int _9504 = _5558;
  for (int _5570 = _9503; _5570 < _9504; ++_5570)
  {
    {
      _5569 *= _ptr__5567[_5570];
    }
  }
  int _5571 = (int)0;
  int _5572 = (int)0;
  int _9505 = (int)0;
  int _9506 = (int)((_5557)->size(0));
  for (int _5573 = _9505; _5573 < _9506; ++_5573)
  {
    {
      int _5574 = ((*_5557)(_5573))->numInst();
      _5571 += _5574;
      int _9507;
      bool _9508 = (_5572 > _5574);
      if (_9508)
      {
        _9507 = _5572;
      }
      else
      {
        _9507 = _5574;
      }
      _5572 = _9507;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5575 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5569,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5575(_5575 ? _5575->raw() : nullptr,_5575 ? _5575->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5576 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5571)));
  _checked_ptr_1<long long> _ptr__5576(_5576 ? _5576->raw() : nullptr,_5576 ? _5576->size(0) : 0);
  std::vector<double> _9509;
  for (int _5578 = (int)0, _9510 = _5571; _5578 < _9510 ; ++_5578)
  {
    _9509.push_back(1.0);
  }
  auto _9511 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9509.size()),_9509.begin(),_9509.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5577 = _9511;
  _checked_ptr_1<double> _ptr__5577(_5577 ? _5577->raw() : nullptr,_5577 ? _5577->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _5579 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5572)));
    _checked_ptr_1<long long> _ptr__5579(_5579 ? _5579->raw() : nullptr,_5579 ? _5579->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5580 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5572)));
    _checked_ptr_1<long long> _ptr__5580(_5580 ? _5580->raw() : nullptr,_5580 ? _5580->size(0) : 0);
    int _9512 = (int)0;
    int _9513 = (int)((_5557)->size(0));
    for (int _5581 = _9512; _5581 < _9513; ++_5581)
    {
      {
        int _5582 = ((*_5557)(_5581))->inst((int)0,_5579,(int)0,_5580);
        int _9514 = (int)0;
        int _9515 = _5582;
        for (int _5583 = _9514; _5583 < _9515; ++_5583)
        {
          {
            _ptr__5575[safe_add( _ptr__5579[_5583],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _9516 = (int)0;
    int _9517 = _5569;
    for (int _5584 = _9516; _5584 < _9517; ++_5584)
    {
      {
        _ptr__5575[safe_add( _5584,(int)1 )] += _ptr__5575[_5584];
      }
    }
    int _9518 = (int)0;
    int _9519 = (int)((_5557)->size(0));
    for (int _5585 = _9518; _5585 < _9519; ++_5585)
    {
      {
        int _5586 = ((*_5557)(_5585))->inst((int)0,_5579,(int)0,_5580);
        int _9520 = (int)0;
        int _9521 = _5586;
        for (int _5587 = _9520; _5587 < _9521; ++_5587)
        {
          {
            _ptr__5576[_ptr__5575[_ptr__5579[_5587]]] = _ptr__5580[_5587];
            ++ _ptr__5575[_ptr__5579[_5587]];
          }
        }
      }
    }
    int _9522 = (int)0;
    int _9523 = _5569;
    for (int _5588 = _9522; _5588 < _9523; ++_5588)
    {
      {
        _ptr__5575[(_5569 - _5588)] = _ptr__5575[((_5569 - _5588) - (int)1)];
      }
    }
    _ptr__5575[(int)0] = (int)0;
  }
  std::vector<double> _9524;
  for (int _5589 = (int)0, _9525 = _5569; _5589 < _9525 ; ++_5589)
  {
    _9524.push_back(0.0);
  }
  auto _9526 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9524.size()),_9524.begin(),_9524.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_5575,_5576,_5577,_9526,_5567,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _5590,double _5591,monty::rc_ptr< ::mosek::fusion::Expression > _5592,double _5593){
  int _5594 = _5590->getND();
  int _5595 = _5592->getND();
  if ((_5594 == _5595))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5590,_5592,_5591,_5593)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _9527;
      bool _9528 = (_5594 > _5595);
      if (_9528)
      {
        _9527 = _5594;
      }
      else
      {
        _9527 = _5595;
      }
      int _5596 = _9527;
      std::shared_ptr< monty::ndarray< int,1 > > _5597 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5596)));
      _checked_ptr_1<int> _ptr__5597(_5597 ? _5597->raw() : nullptr,_5597 ? _5597->size(0) : 0);
      if ((_5594 < _5595))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5598 = _5590->getShape();
          _checked_ptr_1<int> _ptr__5598(_5598 ? _5598->raw() : nullptr,_5598 ? _5598->size(0) : 0);
          int _9529 = (int)0;
          int _9530 = _5594;
          for (int _5599 = _9529; _5599 < _9530; ++_5599)
          {
            {
              _ptr__5597[_5599] = _ptr__5598[_5599];
            }
          }
          int _9531 = _5594;
          int _9532 = _5596;
          for (int _5600 = _9531; _5600 < _9532; ++_5600)
          {
            {
              _ptr__5597[_5600] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5597,_5590)).as<::mosek::fusion::Expression>(),_5592,_5591,_5593)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5601 = _5592->getShape();
          _checked_ptr_1<int> _ptr__5601(_5601 ? _5601->raw() : nullptr,_5601 ? _5601->size(0) : 0);
          int _9533 = (int)0;
          int _9534 = _5595;
          for (int _5602 = _9533; _5602 < _9534; ++_5602)
          {
            {
              _ptr__5597[_5602] = _ptr__5601[_5602];
            }
          }
          int _9535 = _5595;
          int _9536 = _5596;
          for (int _5603 = _9535; _5603 < _9536; ++_5603)
          {
            {
              _ptr__5597[_5603] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5590,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5597,_5592)).as<::mosek::fusion::Expression>(),_5591,_5593)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _5604) { return mosek::fusion::p_Expr::transpose(_5604); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5604){
  if ((_5604->getND() == (int)0))
  {
    {
      return _5604;
    }
  }
  else if((_5604->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5604->getDim((int)0))}),_5604)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5604->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_5604)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5605,    monty::rc_ptr< ::mosek::fusion::Expression > _5606) { return mosek::fusion::p_Expr::mulElm(_5605,_5606); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5605,monty::rc_ptr< ::mosek::fusion::Expression > _5606){
  return ::mosek::fusion::p_Expr::mulElm_(_5605,_5606);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5607,    monty::rc_ptr< ::mosek::fusion::Expression > _5608) { return mosek::fusion::p_Expr::mulElm(_5607,_5608); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5607,monty::rc_ptr< ::mosek::fusion::Expression > _5608){
  return ::mosek::fusion::p_Expr::mulElm_(_5607,_5608);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _5609,    monty::rc_ptr< ::mosek::fusion::Expression > _5610) { return mosek::fusion::p_Expr::mulElm(_5609,_5610); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5609,monty::rc_ptr< ::mosek::fusion::Expression > _5610){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5609),_5610);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _5611,    monty::rc_ptr< ::mosek::fusion::Expression > _5612) { return mosek::fusion::p_Expr::mulElm(_5611,_5612); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5611,monty::rc_ptr< ::mosek::fusion::Expression > _5612){
  _checked_ptr_1<double> _ptr__5611(_5611 ? _5611->raw() : nullptr, _5611 ? _5611->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5611,_5612);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5613,    monty::rc_ptr< ::mosek::fusion::Matrix > _5614) { return mosek::fusion::p_Expr::mulElm(_5613,_5614); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5613,monty::rc_ptr< ::mosek::fusion::Matrix > _5614){
  return ::mosek::fusion::p_Expr::mulElm_(_5614,_5613);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5615,    std::shared_ptr< monty::ndarray< double,2 > > _5616) { return mosek::fusion::p_Expr::mulElm(_5615,_5616); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5615,std::shared_ptr< monty::ndarray< double,2 > > _5616){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5616),_5615);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5617,    std::shared_ptr< monty::ndarray< double,1 > > _5618) { return mosek::fusion::p_Expr::mulElm(_5617,_5618); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5617,std::shared_ptr< monty::ndarray< double,1 > > _5618){
  _checked_ptr_1<double> _ptr__5618(_5618 ? _5618->raw() : nullptr, _5618 ? _5618->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5618,_5617);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5619,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5620) { return mosek::fusion::p_Expr::mulElm(_5619,_5620); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5619,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5620){
  return ::mosek::fusion::p_Expr::mulElm_(_5620,_5619);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5621,    monty::rc_ptr< ::mosek::fusion::Expression > _5622) { return mosek::fusion::p_Expr::sub(_5621,_5622); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5621,monty::rc_ptr< ::mosek::fusion::Expression > _5622){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5621),1.0,_5622,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5623,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5624) { return mosek::fusion::p_Expr::sub(_5623,_5624); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5623,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5624){
  return ::mosek::fusion::p_Expr::add_(_5623,1.0,::mosek::fusion::p_Expr::constTerm(_5624),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5625,    monty::rc_ptr< ::mosek::fusion::Expression > _5626) { return mosek::fusion::p_Expr::sub(_5625,_5626); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5625,monty::rc_ptr< ::mosek::fusion::Expression > _5626){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5625),1.0,_5626,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5627,    monty::rc_ptr< ::mosek::fusion::Matrix > _5628) { return mosek::fusion::p_Expr::sub(_5627,_5628); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5627,monty::rc_ptr< ::mosek::fusion::Matrix > _5628){
  return ::mosek::fusion::p_Expr::add_(_5627,1.0,::mosek::fusion::p_Expr::constTerm(_5628),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _5629,    monty::rc_ptr< ::mosek::fusion::Expression > _5630) { return mosek::fusion::p_Expr::sub(_5629,_5630); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _5629,monty::rc_ptr< ::mosek::fusion::Expression > _5630){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5630->getShape(),_5629),1.0,_5630,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5631,    double _5632) { return mosek::fusion::p_Expr::sub(_5631,_5632); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5631,double _5632){
  return ::mosek::fusion::p_Expr::add_(_5631,1.0,::mosek::fusion::p_Expr::constTerm(_5631->getShape(),_5632),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _5633,    monty::rc_ptr< ::mosek::fusion::Expression > _5634) { return mosek::fusion::p_Expr::sub(_5633,_5634); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _5633,monty::rc_ptr< ::mosek::fusion::Expression > _5634){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5633),1.0,_5634,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _5635,    monty::rc_ptr< ::mosek::fusion::Expression > _5636) { return mosek::fusion::p_Expr::sub(_5635,_5636); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _5635,monty::rc_ptr< ::mosek::fusion::Expression > _5636){
  _checked_ptr_1<double> _ptr__5635(_5635 ? _5635->raw() : nullptr, _5635 ? _5635->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5635),1.0,_5636,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5637,    std::shared_ptr< monty::ndarray< double,2 > > _5638) { return mosek::fusion::p_Expr::sub(_5637,_5638); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5637,std::shared_ptr< monty::ndarray< double,2 > > _5638){
  return ::mosek::fusion::p_Expr::add_(_5637,1.0,::mosek::fusion::p_Expr::constTerm(_5638),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5639,    std::shared_ptr< monty::ndarray< double,1 > > _5640) { return mosek::fusion::p_Expr::sub(_5639,_5640); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5639,std::shared_ptr< monty::ndarray< double,1 > > _5640){
  _checked_ptr_1<double> _ptr__5640(_5640 ? _5640->raw() : nullptr, _5640 ? _5640->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5639,1.0,::mosek::fusion::p_Expr::constTerm(_5640),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5641,    monty::rc_ptr< ::mosek::fusion::Expression > _5642) { return mosek::fusion::p_Expr::sub(_5641,_5642); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5641,monty::rc_ptr< ::mosek::fusion::Expression > _5642){
  return ::mosek::fusion::p_Expr::add_(_5641,1.0,_5642,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5643,    monty::rc_ptr< ::mosek::fusion::Expression > _5644) { return mosek::fusion::p_Expr::add(_5643,_5644); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5643,monty::rc_ptr< ::mosek::fusion::Expression > _5644){
  return ::mosek::fusion::p_Expr::add_(_5644,1.0,::mosek::fusion::p_Expr::constTerm(_5643),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5645,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5646) { return mosek::fusion::p_Expr::add(_5645,_5646); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5645,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5646){
  return ::mosek::fusion::p_Expr::add_(_5645,1.0,::mosek::fusion::p_Expr::constTerm(_5646),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5647,    monty::rc_ptr< ::mosek::fusion::Expression > _5648) { return mosek::fusion::p_Expr::add(_5647,_5648); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _5647,monty::rc_ptr< ::mosek::fusion::Expression > _5648){
  return ::mosek::fusion::p_Expr::add_(_5648,1.0,::mosek::fusion::p_Expr::constTerm(_5647),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5649,    monty::rc_ptr< ::mosek::fusion::Matrix > _5650) { return mosek::fusion::p_Expr::add(_5649,_5650); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5649,monty::rc_ptr< ::mosek::fusion::Matrix > _5650){
  return ::mosek::fusion::p_Expr::add_(_5649,1.0,::mosek::fusion::p_Expr::constTerm(_5650),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _5651,    monty::rc_ptr< ::mosek::fusion::Expression > _5652) { return mosek::fusion::p_Expr::add(_5651,_5652); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _5651,monty::rc_ptr< ::mosek::fusion::Expression > _5652){
  return ::mosek::fusion::p_Expr::add_(_5652,1.0,::mosek::fusion::p_Expr::constTerm(_5652->getShape(),_5651),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5653,    double _5654) { return mosek::fusion::p_Expr::add(_5653,_5654); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5653,double _5654){
  return ::mosek::fusion::p_Expr::add_(_5653,1.0,::mosek::fusion::p_Expr::constTerm(_5653->getShape(),_5654),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _5655,    monty::rc_ptr< ::mosek::fusion::Expression > _5656) { return mosek::fusion::p_Expr::add(_5655,_5656); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _5655,monty::rc_ptr< ::mosek::fusion::Expression > _5656){
  return ::mosek::fusion::p_Expr::add_(_5656,1.0,::mosek::fusion::p_Expr::constTerm(_5655),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _5657,    monty::rc_ptr< ::mosek::fusion::Expression > _5658) { return mosek::fusion::p_Expr::add(_5657,_5658); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _5657,monty::rc_ptr< ::mosek::fusion::Expression > _5658){
  _checked_ptr_1<double> _ptr__5657(_5657 ? _5657->raw() : nullptr, _5657 ? _5657->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5658,1.0,::mosek::fusion::p_Expr::constTerm(_5657),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5659,    std::shared_ptr< monty::ndarray< double,2 > > _5660) { return mosek::fusion::p_Expr::add(_5659,_5660); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5659,std::shared_ptr< monty::ndarray< double,2 > > _5660){
  return ::mosek::fusion::p_Expr::add_(_5659,1.0,::mosek::fusion::p_Expr::constTerm(_5660),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5661,    std::shared_ptr< monty::ndarray< double,1 > > _5662) { return mosek::fusion::p_Expr::add(_5661,_5662); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5661,std::shared_ptr< monty::ndarray< double,1 > > _5662){
  _checked_ptr_1<double> _ptr__5662(_5662 ? _5662->raw() : nullptr, _5662 ? _5662->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5661,1.0,::mosek::fusion::p_Expr::constTerm(_5662),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5663,    monty::rc_ptr< ::mosek::fusion::Expression > _5664) { return mosek::fusion::p_Expr::add(_5663,_5664); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5663,monty::rc_ptr< ::mosek::fusion::Expression > _5664){
  return ::mosek::fusion::p_Expr::add_(_5663,1.0,_5664,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5665,monty::rc_ptr< ::mosek::fusion::WorkStack > _5666,monty::rc_ptr< ::mosek::fusion::WorkStack > _5667) { mosek::fusion::p_Expr::_get_impl(this)->eval(_5665,_5666,_5667); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5665,monty::rc_ptr< ::mosek::fusion::WorkStack > _5666,monty::rc_ptr< ::mosek::fusion::WorkStack > _5667){
  std::vector<int> _9537;
  for (int _5668 = (int)0, _9538 = (int)((ptrb)->size(0)); _5668 < _9538 ; ++_5668)
  {
    _9537.push_back((int)((*ptrb)(_5668)));
  }
  auto _9539 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9537.size()),_9537.begin(),_9537.end()));
  ::mosek::fusion::p_BaseExpression::storeexpr(_5665,shape,_9539,inst,subj,cof_v,bfix);
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5669,std::shared_ptr< monty::ndarray< long long,1 > > _5670,std::shared_ptr< monty::ndarray< double,1 > > _5671,std::shared_ptr< monty::ndarray< double,1 > > _5672,std::shared_ptr< monty::ndarray< int,1 > > _5673,std::shared_ptr< monty::ndarray< long long,1 > > _5674){
  _checked_ptr_1<long long> _ptr__5669(_5669 ? _5669->raw() : nullptr, _5669 ? _5669->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5670(_5670 ? _5670->raw() : nullptr, _5670 ? _5670->size(0) : 0);
  _checked_ptr_1<double> _ptr__5671(_5671 ? _5671->raw() : nullptr, _5671 ? _5671->size(0) : 0);
  _checked_ptr_1<double> _ptr__5672(_5672 ? _5672->raw() : nullptr, _5672 ? _5672->size(0) : 0);
  _checked_ptr_1<int> _ptr__5673(_5673 ? _5673->raw() : nullptr, _5673 ? _5673->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5674(_5674 ? _5674->raw() : nullptr, _5674 ? _5674->size(0) : 0);
  if ((NULL == _5673.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _5675 = ((int)((_5669)->size(0)) - (int)1);
  long long _5676 = _ptr__5669[((int)((_5669)->size(0)) - (int)1)];
  int _5677 = (int)((_5673)->size(0));
  long long _5678 = (long long)1;
  int _9540 = (int)0;
  int _9541 = _5677;
  for (int _5679 = _9540; _5679 < _9541; ++_5679)
  {
    {
      _5678 *= _ptr__5673[_5679];
    }
  }
  if (((int)((_5669)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_5676 != (int)((_5670)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_5676 != (int)((_5671)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _5672.get()) || (_5675 != (int)((_5672)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _5674.get()) && ((int)((_5674)->size(0)) < _5678)))
  {
    {
      if (((int)((_5674)->size(0)) != ((int)((_5669)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_5674)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5674[(int)0] < (int)0) || (_ptr__5674[(int)0] >= _5678)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _5680 = true;
          long long _5681 = _5678;
          int _9542 = (int)1;
          int _9543 = (int)((_5674)->size(0));
          for (int _5682 = _9542; _5682 < _9543; ++_5682)
          {
            {
              _5680 = (_5680 && ((_ptr__5674[_5682] >= (int)0) && ((_ptr__5674[_5682] < _5681) && (_ptr__5674[_5682] > _ptr__5674[(_5682 - (int)1)]))));
            }
          }
          if ((!_5680))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_5678 != ((long long)((_5669)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _5683 = false;
  bool _5684 = false;
  if ((_ptr__5669[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _5685 = true;
  int _9544 = (int)0;
  int _9545 = _5675;
  for (int _5686 = _9544; _5686 < _9545; ++_5686)
  {
    {
      _5685 = (_5685 && (_ptr__5669[_5686] <= _ptr__5669[safe_add( _5686,(int)1 )]));
    }
  }
  if ((!_5685))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5687){
  monty::rc_ptr< ::mosek::fusion::Model > _9546;
  bool _9547 = ((NULL == _5687.get()) || ((int)((_5687)->size(0)) == (int)0));
  if (_9547)
  {
    _9546 = nullptr;
  }
  else
  {
    _9546 = ((*_5687)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _9546;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _5688) { return __mosek_2fusion_2Expression__pick(_5688); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _5689) { return __mosek_2fusion_2Expression__pick(_5689); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _5690) { return __mosek_2fusion_2Expression__index(_5690); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _5691) { return __mosek_2fusion_2Expression__index(_5691); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _5692,std::shared_ptr< monty::ndarray< int,1 > > _5693) { return __mosek_2fusion_2Expression__slice(_5692,_5693); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _5694,int _5695) { return __mosek_2fusion_2Expression__slice(_5694,_5695); }
monty::rc_ptr< mosek::fusion::FlatExpr > mosek::fusion::Expression::eval() { return __mosek_2fusion_2Expression__eval(); }
mosek::fusion::FlatExpr::FlatExpr(mosek::fusion::p_FlatExpr *_impl) : _impl(_impl) { /*std::cout << "FlatExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::FlatExpr::~FlatExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_FlatExpr::p_FlatExpr  (::mosek::fusion::FlatExpr * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_inst() { return _impl->inst; }
void mosek::fusion::FlatExpr::set_inst(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->inst = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::FlatExpr::get_shape() { return _impl->shape; }
void mosek::fusion::FlatExpr::set_shape(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->shape = _val; }
long long mosek::fusion::FlatExpr::get_nnz() { return _impl->nnz; }
void mosek::fusion::FlatExpr::set_nnz(long long _val) { _impl->nnz = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_cof() { return _impl->cof; }
void mosek::fusion::FlatExpr::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_subj() { return _impl->subj; }
void mosek::fusion::FlatExpr::set_subj(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::FlatExpr::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_bfix() { return _impl->bfix; }
void mosek::fusion::FlatExpr::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5700){ return new mosek::fusion::FlatExpr(_5700); }mosek::fusion::FlatExpr::FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5700) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5700); }void mosek::fusion::p_FlatExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5700){monty::rc_reserve __reserve_this(_pubthis);   {
    bfix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5700)->bfix);
    ptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5700)->ptrb);
    subj = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5700)->subj);
    cof = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5700)->cof);
    nnz = mosek::fusion::p_FlatExpr::_get_impl(_5700)->nnz;
    shape = mosek::fusion::p_FlatExpr::_get_impl(_5700)->shape;
    inst = mosek::fusion::p_FlatExpr::_get_impl(_5700)->inst;
  }
}mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5701,    std::shared_ptr< monty::ndarray< long long,1 > > _5702,    std::shared_ptr< monty::ndarray< long long,1 > > _5703,    std::shared_ptr< monty::ndarray< double,1 > > _5704,    std::shared_ptr< monty::ndarray< int,1 > > _5705,    std::shared_ptr< monty::ndarray< long long,1 > > _5706){ return new mosek::fusion::FlatExpr(_5701,_5702,_5703,_5704,_5705,_5706); }mosek::fusion::FlatExpr::FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5701,    std::shared_ptr< monty::ndarray< long long,1 > > _5702,    std::shared_ptr< monty::ndarray< long long,1 > > _5703,    std::shared_ptr< monty::ndarray< double,1 > > _5704,    std::shared_ptr< monty::ndarray< int,1 > > _5705,    std::shared_ptr< monty::ndarray< long long,1 > > _5706) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5701,_5702,_5703,_5704,_5705,_5706); }void mosek::fusion::p_FlatExpr::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5701,    std::shared_ptr< monty::ndarray< long long,1 > > _5702,    std::shared_ptr< monty::ndarray< long long,1 > > _5703,    std::shared_ptr< monty::ndarray< double,1 > > _5704,    std::shared_ptr< monty::ndarray< int,1 > > _5705,    std::shared_ptr< monty::ndarray< long long,1 > > _5706){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5701(_5701 ? _5701->raw() : nullptr, _5701 ? _5701->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5702(_5702 ? _5702->raw() : nullptr, _5702 ? _5702->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5703(_5703 ? _5703->raw() : nullptr, _5703 ? _5703->size(0) : 0);
    _checked_ptr_1<double> _ptr__5704(_5704 ? _5704->raw() : nullptr, _5704 ? _5704->size(0) : 0);
    _checked_ptr_1<int> _ptr__5705(_5705 ? _5705->raw() : nullptr, _5705 ? _5705->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5706(_5706 ? _5706->raw() : nullptr, _5706 ? _5706->size(0) : 0);
    if (((NULL != _5701.get()) && ((int)((_5701)->size(0)) != ((int)((_5702)->size(0)) - (int)1))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of bfix and ptrb"));
      }
    }
    {}
    if (((NULL == _5704.get()) || ((NULL == _5703.get()) || ((int)((_5703)->size(0)) != (int)((_5704)->size(0))))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of subj and cof"));
      }
    }
    {}
    if ((NULL != _5705.get()))
    {
      {
        if ((NULL != _5706.get()))
        {
          {
            if (((int)((_5706)->size(0)) != ((int)((_5702)->size(0)) - (int)1)))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of inst and ptrb"));
              }
            }
            {}
          }
        }
        else if((::mosek::fusion::p_Set::size(_5705) != ((long long)((_5702)->size(0)) - (int)1)))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching shape and ptrb"));
          }
        }
        {}
      }
    }
    {}
    bfix = _5701;
    ptrb = _5702;
    subj = _5703;
    cof = _5704;
    nnz = ((*ptrb)(((int)((ptrb)->size(0)) - (int)1)));
    shape = _5705;
    inst = _5706;
  }
}std::string mosek::fusion::FlatExpr :: toString() { return mosek::fusion::p_FlatExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_FlatExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5707 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5707->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("FlatExpr:"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| ptrb["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((ptrb)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(ptrb)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| subj["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((subj)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(subj)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| cof ["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((cof)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(cof)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| bfix["));
  if ((NULL != bfix.get()))
  {
    {
      _5707->__mosek_2fusion_2Utils_2StringBuffer__a((int)((bfix)->size(0)));
    }
  }
  {}
  _5707->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(bfix)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| inst["));
  if ((NULL != inst.get()))
  {
    {
      _5707->__mosek_2fusion_2Utils_2StringBuffer__a((int)((inst)->size(0)));
    }
  }
  {}
  _5707->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(inst)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"));
  return _5707->toString();
}
int mosek::fusion::FlatExpr :: size() { return mosek::fusion::p_FlatExpr::_get_impl(this)->size(); }int mosek::fusion::p_FlatExpr::size(){
  return ((int)((ptrb)->size(0)) - (int)1);
}
void mosek::fusion::p_FlatExpr::destroy(){inst.reset();shape.reset();cof.reset();subj.reset();ptrb.reset();bfix.reset();}void mosek::fusion::FlatExpr::destroy() { mosek::fusion::p_FlatExpr::_get_impl(this)->destroy(); }mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _5708,    int _5709,    std::shared_ptr< monty::ndarray< int,1 > > _5710,    std::shared_ptr< monty::ndarray< int,1 > > _5711,    std::shared_ptr< monty::ndarray< double,1 > > _5712,    std::shared_ptr< monty::ndarray< int,1 > > _5713,    std::shared_ptr< monty::ndarray< int,1 > > _5714,    std::shared_ptr< monty::ndarray< double,1 > > _5715,    double _5716){ return new mosek::fusion::SymmetricMatrix(_5708,_5709,_5710,_5711,_5712,_5713,_5714,_5715,_5716); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _5708,    int _5709,    std::shared_ptr< monty::ndarray< int,1 > > _5710,    std::shared_ptr< monty::ndarray< int,1 > > _5711,    std::shared_ptr< monty::ndarray< double,1 > > _5712,    std::shared_ptr< monty::ndarray< int,1 > > _5713,    std::shared_ptr< monty::ndarray< int,1 > > _5714,    std::shared_ptr< monty::ndarray< double,1 > > _5715,    double _5716) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_5708,_5709,_5710,_5711,_5712,_5713,_5714,_5715,_5716); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _5708,    int _5709,    std::shared_ptr< monty::ndarray< int,1 > > _5710,    std::shared_ptr< monty::ndarray< int,1 > > _5711,    std::shared_ptr< monty::ndarray< double,1 > > _5712,    std::shared_ptr< monty::ndarray< int,1 > > _5713,    std::shared_ptr< monty::ndarray< int,1 > > _5714,    std::shared_ptr< monty::ndarray< double,1 > > _5715,    double _5716){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5710(_5710 ? _5710->raw() : nullptr, _5710 ? _5710->size(0) : 0);
    _checked_ptr_1<int> _ptr__5711(_5711 ? _5711->raw() : nullptr, _5711 ? _5711->size(0) : 0);
    _checked_ptr_1<double> _ptr__5712(_5712 ? _5712->raw() : nullptr, _5712 ? _5712->size(0) : 0);
    _checked_ptr_1<int> _ptr__5713(_5713 ? _5713->raw() : nullptr, _5713 ? _5713->size(0) : 0);
    _checked_ptr_1<int> _ptr__5714(_5714 ? _5714->raw() : nullptr, _5714 ? _5714->size(0) : 0);
    _checked_ptr_1<double> _ptr__5715(_5715 ? _5715->raw() : nullptr, _5715 ? _5715->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _5708;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _5709;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _5710;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _5711;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _5712;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _5713;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _5714;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _5715;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _5716;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _5717,    std::shared_ptr< monty::ndarray< int,1 > > _5718,    std::shared_ptr< monty::ndarray< double,1 > > _5719) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5717,_5718,_5719); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _5717,std::shared_ptr< monty::ndarray< int,1 > > _5718,std::shared_ptr< monty::ndarray< double,1 > > _5719){
  _checked_ptr_1<int> _ptr__5718(_5718 ? _5718->raw() : nullptr, _5718 ? _5718->size(0) : 0);
  _checked_ptr_1<double> _ptr__5719(_5719 ? _5719->raw() : nullptr, _5719 ? _5719->size(0) : 0);
  if (((int)((_5718)->size(0)) != (int)((_5719)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _9548 = (int)0;
  int _9549 = (int)((_5718)->size(0));
  for (int _5720 = _9548; _5720 < _9549; ++_5720)
  {
    {
      if (((_ptr__5718[_5720] < (int)0) || (_ptr__5718[_5720] >= _5717)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _9550;
  for (int _5722 = (int)0, _9551 = (int)((_5718)->size(0)); _5722 < _9551 ; ++_5722)
  {
    _9550.push_back(_ptr__5718[_5722]);
  }
  auto _9552 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9550.size()),_9550.begin(),_9550.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5721 = _9552;
  _checked_ptr_1<int> _ptr__5721(_5721 ? _5721->raw() : nullptr,_5721 ? _5721->size(0) : 0);
  std::vector<int> _9553;
  for (int _5724 = (int)0, _9554 = (int)((_5718)->size(0)); _5724 < _9554 ; ++_5724)
  {
    _9553.push_back((int)1);
  }
  auto _9555 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9553.size()),_9553.begin(),_9553.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5723 = _9555;
  _checked_ptr_1<int> _ptr__5723(_5723 ? _5723->raw() : nullptr,_5723 ? _5723->size(0) : 0);
  std::vector<double> _9556;
  for (int _5726 = (int)0, _9557 = (int)((_5719)->size(0)); _5726 < _9557 ; ++_5726)
  {
    _9556.push_back(_ptr__5719[_5726]);
  }
  auto _9558 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9556.size()),_9556.begin(),_9556.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5725 = _9558;
  _checked_ptr_1<double> _ptr__5725(_5725 ? _5725->raw() : nullptr,_5725 ? _5725->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5717,(int)1,_5721,_5723,_5725,_5721,_5723,_5725,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _5727) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5727); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5727){
  _checked_ptr_1<double> _ptr__5727(_5727 ? _5727->raw() : nullptr, _5727 ? _5727->size(0) : 0);
  int _5728 = (int)((_5727)->size(0));
  std::vector<int> _9559;
  for (int _5730 = (int)0, _9560 = _5728; _5730 < _9560 ; ++_5730)
  {
    _9559.push_back(_5730);
  }
  auto _9561 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9559.size()),_9559.begin(),_9559.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5729 = _9561;
  _checked_ptr_1<int> _ptr__5729(_5729 ? _5729->raw() : nullptr,_5729 ? _5729->size(0) : 0);
  std::vector<int> _9562;
  for (int _5732 = (int)0, _9563 = _5728; _5732 < _9563 ; ++_5732)
  {
    _9562.push_back((int)1);
  }
  auto _9564 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9562.size()),_9562.begin(),_9562.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5731 = _9564;
  _checked_ptr_1<int> _ptr__5731(_5731 ? _5731->raw() : nullptr,_5731 ? _5731->size(0) : 0);
  std::vector<double> _9565;
  for (int _5734 = (int)0, _9566 = _5728; _5734 < _9566 ; ++_5734)
  {
    _9565.push_back(_ptr__5727[_5734]);
  }
  auto _9567 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9565.size()),_9565.begin(),_9565.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5733 = _9567;
  _checked_ptr_1<double> _ptr__5733(_5733 ? _5733->raw() : nullptr,_5733 ? _5733->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5728,(int)1,_5729,_5731,_5733,_5729,_5731,_5733,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5735) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_5735); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5735){
  _checked_ptr_1<double> _ptr__5735(_5735 ? _5735->raw() : nullptr, _5735 ? _5735->size(0) : 0);
  int _5736 = (int)((_5735)->size(0));
  std::vector<int> _9568;
  for (int _5738 = (int)0, _9569 = _5736; _5738 < _9569 ; ++_5738)
  {
    _9568.push_back(_5738);
  }
  auto _9570 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9568.size()),_9568.begin(),_9568.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5737 = _9570;
  _checked_ptr_1<int> _ptr__5737(_5737 ? _5737->raw() : nullptr,_5737 ? _5737->size(0) : 0);
  std::vector<int> _9571;
  for (int _5739 = (int)0, _9572 = _5736; _5739 < _9572 ; ++_5739)
  {
    _9571.push_back((_5736 - _5739));
  }
  auto _9573 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9571.size()),_9571.begin(),_9571.end()));
  std::vector<double> _9574;
  for (int _5740 = (int)0, _9575 = _5736; _5740 < _9575 ; ++_5740)
  {
    _9574.push_back(_ptr__5735[_5740]);
  }
  auto _9576 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9574.size()),_9574.begin(),_9574.end()));
  std::vector<double> _9577;
  for (int _5741 = (int)0, _9578 = _5736; _5741 < _9578 ; ++_5741)
  {
    _9577.push_back(1.0);
  }
  auto _9579 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9577.size()),_9577.begin(),_9577.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5736,_5736,_5737,_9573,_9576,_5737,_5737,_9579,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5742) { return mosek::fusion::p_SymmetricMatrix::diag(_5742); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5742){
  _checked_ptr_1<double> _ptr__5742(_5742 ? _5742->raw() : nullptr, _5742 ? _5742->size(0) : 0);
  int _5743 = (int)((_5742)->size(0));
  std::vector<int> _9580;
  for (int _5745 = (int)0, _9581 = _5743; _5745 < _9581 ; ++_5745)
  {
    _9580.push_back(_5745);
  }
  auto _9582 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9580.size()),_9580.begin(),_9580.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5744 = _9582;
  _checked_ptr_1<int> _ptr__5744(_5744 ? _5744->raw() : nullptr,_5744 ? _5744->size(0) : 0);
  std::vector<double> _9583;
  for (int _5746 = (int)0, _9584 = _5743; _5746 < _9584 ; ++_5746)
  {
    _9583.push_back(_ptr__5742[_5746]);
  }
  auto _9585 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9583.size()),_9583.begin(),_9583.end()));
  std::vector<double> _9586;
  for (int _5747 = (int)0, _9587 = _5743; _5747 < _9587 ; ++_5747)
  {
    _9586.push_back(1.0);
  }
  auto _9588 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9586.size()),_9586.begin(),_9586.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5743,_5743,_5744,_5744,_9585,_5744,_5744,_9588,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5748) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_5748); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5748) { return __mosek_2fusion_2SymmetricMatrix__add(_5748); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5748){
  int _5749 = _pubthis->getdim();
  if ((_5748->getdim() != _5749))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _5750 = (int)((usubi)->size(0));
  int _5751 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->usubi)->size(0));
  int _5752 = safe_add( _5750,_5751 );
  int _5753 = (int)((vsubi)->size(0));
  int _5754 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->vsubi)->size(0));
  int _5755 = safe_add( _5753,_5754 );
  std::shared_ptr< monty::ndarray< double,1 > > _5756 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5755)));
  _checked_ptr_1<double> _ptr__5756(_5756 ? _5756->raw() : nullptr,_5756 ? _5756->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5757 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5755)));
  _checked_ptr_1<int> _ptr__5757(_5757 ? _5757->raw() : nullptr,_5757 ? _5757->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5758 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5755)));
  _checked_ptr_1<int> _ptr__5758(_5758 ? _5758->raw() : nullptr,_5758 ? _5758->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5759 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5752)));
  _checked_ptr_1<double> _ptr__5759(_5759 ? _5759->raw() : nullptr,_5759 ? _5759->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5760 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5752)));
  _checked_ptr_1<int> _ptr__5760(_5760 ? _5760->raw() : nullptr,_5760 ? _5760->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5761 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5752)));
  _checked_ptr_1<int> _ptr__5761(_5761 ? _5761->raw() : nullptr,_5761 ? _5761->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5761,(int)0,_5750);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->usubi,(int)0,_5761,_5750,_5751);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_5760,(int)0,_5750);
  int _9589 = (int)0;
  int _9590 = _5751;
  for (int _5762 = _9589; _5762 < _9590; ++_5762)
  {
    {
      _ptr__5760[safe_add( _5762,_5750 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->usubj)(_5762)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_5759,(int)0,_5750);
    }
  }
  else
  {
    {
      int _9591 = (int)0;
      int _9592 = _5750;
      for (int _5763 = _9591; _5763 < _9592; ++_5763)
      {
        {
          _ptr__5759[_5763] = (scale * ((*uval)(_5763)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->uval,(int)0,_5759,_5750,_5751);
    }
  }
  else
  {
    {
      int _9593 = (int)0;
      int _9594 = _5751;
      for (int _5764 = _9593; _5764 < _9594; ++_5764)
      {
        {
          _ptr__5759[safe_add( _5764,_5750 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->uval)(_5764)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5761,(int)0,_5750);
  int _9595 = (int)0;
  int _9596 = _5754;
  for (int _5765 = _9595; _5765 < _9596; ++_5765)
  {
    {
      _ptr__5758[safe_add( _5765,_5753 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->vsubi)(_5765)),mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_5757,(int)0,_5753);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->vsubj,_5753,_5757,_5753,_5754);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_5756,(int)0,_5753);
    }
  }
  else
  {
    {
      int _9597 = (int)0;
      int _9598 = _5753;
      for (int _5766 = _9597; _5766 < _9598; ++_5766)
      {
        {
          _ptr__5756[_5766] = (scale * ((*vval)(_5766)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->vval,(int)0,_5756,_5753,_5754);
    }
  }
  else
  {
    {
      int _9599 = (int)0;
      int _9600 = _5754;
      for (int _5767 = _9599; _5767 < _9600; ++_5767)
      {
        {
          _ptr__5756[safe_add( _5767,_5753 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->vval)(_5767)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_5748)->d1 ),_5761,_5760,_5759,_5758,_5757,_5756,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5768) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_5768); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5768) { return __mosek_2fusion_2SymmetricMatrix__sub(_5768); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5768){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_5768->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _5769) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_5769); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _5769) { return __mosek_2fusion_2SymmetricMatrix__mul(_5769); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _5769){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _5769));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5770,    std::shared_ptr< monty::ndarray< int,2 > > _5771,    std::shared_ptr< monty::ndarray< double,1 > > _5772){ return new mosek::fusion::NDSparseArray(_5770,_5771,_5772); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5770,    std::shared_ptr< monty::ndarray< int,2 > > _5771,    std::shared_ptr< monty::ndarray< double,1 > > _5772) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5770,_5771,_5772); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5770,    std::shared_ptr< monty::ndarray< int,2 > > _5771,    std::shared_ptr< monty::ndarray< double,1 > > _5772){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5770(_5770 ? _5770->raw() : nullptr, _5770 ? _5770->size(0) : 0);
    _checked_ptr_1<double> _ptr__5772(_5772 ? _5772->raw() : nullptr, _5772 ? _5772->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5773 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5771)->size(0)))));
    _checked_ptr_1<long long> _ptr__5773(_5773 ? _5773->raw() : nullptr,_5773 ? _5773->size(0) : 0);
    size = (long long)1;
    int _9601 = (int)0;
    int _9602 = (int)((_5770)->size(0));
    for (int _5774 = _9601; _5774 < _9602; ++_5774)
    {
      {
        size = safe_mul( size,_ptr__5770[_5774] );
      }
    }
    int _5775 = (int)((_5770)->size(0));
    if (((int)((_5771)->size(0)) != (int)((_5772)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_5771)->size(1)) != _5775))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    bool _5776 = false;
    int _9603 = (int)0;
    int _9604 = (int)((_5771)->size(0));
    for (int _5777 = _9603; _5777 < _9604; ++_5777)
    {
      {
        int _9605 = (int)0;
        int _9606 = (int)((_5771)->size(1));
        for (int _5778 = _9605; _5778 < _9606; ++_5778)
        {
          {
            if (((((*_5771)(_5777,_5778)) < (int)0) || (((*_5771)(_5777,_5778)) >= _ptr__5770[_5778])))
            {
              {
                _5776 = true;
              }
            }
            {}
          }
        }
      }
    }
    if (_5776)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
      }
    }
    {}
    int _9607 = (int)0;
    int _9608 = (int)((_5771)->size(0));
    for (int _5779 = _9607; _5779 < _9608; ++_5779)
    {
      {
        long long _5780 = (long long)0;
        int _9609 = (int)0;
        int _9610 = (int)((_5771)->size(1));
        for (int _5781 = _9609; _5781 < _9610; ++_5781)
        {
          {
            _5780 = safe_add( safe_mul( _5780,_ptr__5770[_5781] ),((*_5771)(_5779,_5781)) );
          }
        }
        _ptr__5773[_5779] = _5780;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5770);
    bool _5782 = true;
    int _9611 = (int)1;
    int _9612 = (int)((_5773)->size(0));
    for (int _5783 = _9611; _5783 < _9612; ++_5783)
    {
      {
        _5782 = (_5782 && (_ptr__5773[_5783] >= _ptr__5773[(_5783 - (int)1)]));
      }
    }
    if (_5782)
    {
      {
        int _5784 = (int)1;
        int _9613 = (int)1;
        int _9614 = (int)((_5773)->size(0));
        for (int _5785 = _9613; _5785 < _9614; ++_5785)
        {
          {
            if ((_ptr__5773[(_5785 - (int)1)] < _ptr__5773[_5785]))
            {
              {
                ++ _5784;
              }
            }
            {}
          }
        }
        if ((_5784 == (int)((_5773)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5773);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5772);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5784)));
            ((*inst)((int)0)) = _ptr__5773[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5784)));
            ((*cof)((int)0)) = _ptr__5772[(int)0];
            int _5786 = (int)0;
            int _9615 = (int)1;
            int _9616 = (int)((_5773)->size(0));
            for (int _5787 = _9615; _5787 < _9616; ++_5787)
            {
              {
                if ((_ptr__5773[_5787] > _ptr__5773[(_5787 - (int)1)]))
                {
                  {
                    ++ _5786;
                    ((*inst)(_5786)) = _ptr__5773[_5787];
                    ((*cof)(_5786)) = _ptr__5772[_5787];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5786)) = (((*cof)(_5786)) + _ptr__5772[_5787]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5788 = ::mosek::fusion::Utils::Tools::range((long long)((_5773)->size(0)));
        _checked_ptr_1<long long> _ptr__5788(_5788 ? _5788->raw() : nullptr,_5788 ? _5788->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5788,_5773,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5773)->size(0)));
        int _5789 = (int)1;
        int _9617 = (int)1;
        int _9618 = (int)((_5773)->size(0));
        for (int _5790 = _9617; _5790 < _9618; ++_5790)
        {
          {
            if ((_ptr__5773[_ptr__5788[(_5790 - (int)1)]] < _ptr__5773[_ptr__5788[_5790]]))
            {
              {
                ++ _5789;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5789)));
        ((*inst)((int)0)) = _ptr__5773[_ptr__5788[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5789)));
        ((*cof)((int)0)) = _ptr__5772[_ptr__5788[(int)0]];
        int _5791 = (int)0;
        int _9619 = (int)1;
        int _9620 = (int)((_5773)->size(0));
        for (int _5792 = _9619; _5792 < _9620; ++_5792)
        {
          {
            if ((_ptr__5773[_ptr__5788[_5792]] > _ptr__5773[_ptr__5788[(_5792 - (int)1)]]))
            {
              {
                ++ _5791;
                ((*inst)(_5791)) = _ptr__5773[_ptr__5788[_5792]];
                ((*cof)(_5791)) = _ptr__5772[_ptr__5788[_5792]];
              }
            }
            else
            {
              {
                ((*cof)(_5791)) = (((*cof)(_5791)) + _ptr__5772[_ptr__5788[_5792]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5793,    std::shared_ptr< monty::ndarray< long long,1 > > _5794,    std::shared_ptr< monty::ndarray< double,1 > > _5795){ return new mosek::fusion::NDSparseArray(_5793,_5794,_5795); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5793,    std::shared_ptr< monty::ndarray< long long,1 > > _5794,    std::shared_ptr< monty::ndarray< double,1 > > _5795) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5793,_5794,_5795); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5793,    std::shared_ptr< monty::ndarray< long long,1 > > _5794,    std::shared_ptr< monty::ndarray< double,1 > > _5795){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5793(_5793 ? _5793->raw() : nullptr, _5793 ? _5793->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5794(_5794 ? _5794->raw() : nullptr, _5794 ? _5794->size(0) : 0);
    _checked_ptr_1<double> _ptr__5795(_5795 ? _5795->raw() : nullptr, _5795 ? _5795->size(0) : 0);
    size = (long long)1;
    int _9621 = (int)0;
    int _9622 = (int)((_5793)->size(0));
    for (int _5796 = _9621; _5796 < _9622; ++_5796)
    {
      {
        size = safe_mul( size,_ptr__5793[_5796] );
      }
    }
    if (((int)((_5794)->size(0)) != (int)((_5795)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    {
      bool _5797 = false;
      int _9623 = (int)0;
      int _9624 = (int)((_5794)->size(0));
      for (int _5798 = _9623; _5798 < _9624; ++_5798)
      {
        {
          _5797 = (_5797 || ((_ptr__5794[_5798] < (int)0) || (_ptr__5794[_5798] >= size)));
        }
      }
      if (_5797)
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
        }
      }
      {}
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5793);
    bool _5799 = true;
    int _9625 = (int)1;
    int _9626 = (int)((_5794)->size(0));
    for (int _5800 = _9625; _5800 < _9626; ++_5800)
    {
      {
        _5799 = (_5799 && (_ptr__5794[_5800] >= _ptr__5794[(_5800 - (int)1)]));
      }
    }
    if (_5799)
    {
      {
        int _5801 = (int)1;
        int _9627 = (int)1;
        int _9628 = (int)((_5794)->size(0));
        for (int _5802 = _9627; _5802 < _9628; ++_5802)
        {
          {
            if ((_ptr__5794[(_5802 - (int)1)] < _ptr__5794[_5802]))
            {
              {
                ++ _5801;
              }
            }
            {}
          }
        }
        if ((_5801 == (int)((_5794)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5794);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5795);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5801)));
            ((*inst)((int)0)) = _ptr__5794[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5801)));
            ((*cof)((int)0)) = _ptr__5795[(int)0];
            int _5803 = (int)0;
            int _9629 = (int)1;
            int _9630 = (int)((_5794)->size(0));
            for (int _5804 = _9629; _5804 < _9630; ++_5804)
            {
              {
                if ((_ptr__5794[_5804] > _ptr__5794[(_5804 - (int)1)]))
                {
                  {
                    ++ _5803;
                    ((*inst)(_5803)) = _ptr__5794[_5804];
                    ((*cof)(_5803)) = _ptr__5795[_5804];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5803)) = (((*cof)(_5803)) + _ptr__5795[_5804]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5805 = ::mosek::fusion::Utils::Tools::range((long long)((_5794)->size(0)));
        _checked_ptr_1<long long> _ptr__5805(_5805 ? _5805->raw() : nullptr,_5805 ? _5805->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5805,_5794,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5794)->size(0)));
        int _5806 = (int)1;
        int _9631 = (int)1;
        int _9632 = (int)((_5794)->size(0));
        for (int _5807 = _9631; _5807 < _9632; ++_5807)
        {
          {
            if ((_ptr__5794[_ptr__5805[(_5807 - (int)1)]] < _ptr__5794[_ptr__5805[_5807]]))
            {
              {
                ++ _5806;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5806)));
        ((*inst)((int)0)) = _ptr__5794[_ptr__5805[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5806)));
        ((*cof)((int)0)) = _ptr__5795[_ptr__5805[(int)0]];
        int _5808 = (int)0;
        int _9633 = (int)1;
        int _9634 = (int)((_5794)->size(0));
        for (int _5809 = _9633; _5809 < _9634; ++_5809)
        {
          {
            if ((_ptr__5794[_ptr__5805[_5809]] > ((*inst)(_ptr__5805[(_5809 - (int)1)]))))
            {
              {
                ++ _5808;
                ((*inst)(_5808)) = _ptr__5794[_ptr__5805[_5809]];
                ((*cof)(_5808)) = _ptr__5795[_ptr__5805[_5809]];
              }
            }
            else
            {
              {
                ((*cof)(_5808)) = (((*cof)(_5808)) + _ptr__5795[_ptr__5805[_5809]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5810){ return new mosek::fusion::NDSparseArray(_5810); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5810) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5810); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5810){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _5811 = _5810->numNonzeros();
    int _5812 = _5810->numColumns();
    int _5813 = _5810->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _5814 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5811)));
    _checked_ptr_1<double> _ptr__5814(_5814 ? _5814->raw() : nullptr,_5814 ? _5814->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5815 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5811)));
    _checked_ptr_1<int> _ptr__5815(_5815 ? _5815->raw() : nullptr,_5815 ? _5815->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5816 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5811)));
    _checked_ptr_1<int> _ptr__5816(_5816 ? _5816->raw() : nullptr,_5816 ? _5816->size(0) : 0);
    _5810->getDataAsTriplets(_5816,_5815,_5814);
    size = safe_mul( (long long)_5810->numRows(),(long long)_5810->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5813),(int)(_5812)});
    std::vector<long long> _9635;
    for (long long _5817 = (long long)0, _9636 = _5811; _5817 < _9636 ; ++_5817)
    {
      _9635.push_back(safe_add( safe_mul( (long long)_ptr__5816[_5817],_5812 ),(long long)_ptr__5815[_5817] ));
    }
    auto _9637 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9635.size()),_9635.begin(),_9635.end()));
    inst = _9637;
    cof = _5814;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5818) { return mosek::fusion::p_NDSparseArray::make(_5818); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _5818){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5818);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5819,    std::shared_ptr< monty::ndarray< long long,1 > > _5820,    std::shared_ptr< monty::ndarray< double,1 > > _5821) { return mosek::fusion::p_NDSparseArray::make(_5819,_5820,_5821); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5819,std::shared_ptr< monty::ndarray< long long,1 > > _5820,std::shared_ptr< monty::ndarray< double,1 > > _5821){
  _checked_ptr_1<int> _ptr__5819(_5819 ? _5819->raw() : nullptr, _5819 ? _5819->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5820(_5820 ? _5820->raw() : nullptr, _5820 ? _5820->size(0) : 0);
  _checked_ptr_1<double> _ptr__5821(_5821 ? _5821->raw() : nullptr, _5821 ? _5821->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5819,_5820,_5821);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5822,    std::shared_ptr< monty::ndarray< int,2 > > _5823,    std::shared_ptr< monty::ndarray< double,1 > > _5824) { return mosek::fusion::p_NDSparseArray::make(_5822,_5823,_5824); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5822,std::shared_ptr< monty::ndarray< int,2 > > _5823,std::shared_ptr< monty::ndarray< double,1 > > _5824){
  _checked_ptr_1<int> _ptr__5822(_5822 ? _5822->raw() : nullptr, _5822 ? _5822->size(0) : 0);
  _checked_ptr_1<double> _ptr__5824(_5824 ? _5824->raw() : nullptr, _5824 ? _5824->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5822,_5823,_5824);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5825,    int _5826,    std::shared_ptr< monty::ndarray< double,1 > > _5827){ return new mosek::fusion::DenseMatrix(_5825,_5826,_5827); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5825,    int _5826,    std::shared_ptr< monty::ndarray< double,1 > > _5827) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5825,_5826,_5827); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5825,    int _5826,    std::shared_ptr< monty::ndarray< double,1 > > _5827){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5827(_5827 ? _5827->raw() : nullptr, _5827 ? _5827->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5825,_5826);
    nnz = (long long)safe_mul( _5825,_5826 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _5825,_5826 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_5827,(int)0,data,(int)0,safe_mul( _5825,_5826 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5828){ return new mosek::fusion::DenseMatrix(_5828); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5828) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5828); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5828){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_5828)->dimi,mosek::fusion::p_Matrix::_get_impl(_5828)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _9638 = _5828;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9638.get()))
    {
      ::mosek::fusion::DenseMatrix::t _5829 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9638.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_5829)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9638.get()))
    {
      ::mosek::fusion::SparseMatrix::t _5830 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9638.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_5830)->dimi,mosek::fusion::p_Matrix::_get_impl(_5830)->dimj ));
        long long _9639 = (long long)0;
        long long _9640 = mosek::fusion::p_SparseMatrix::_get_impl(_5830)->nnz;
        for (long long _5832 = _9639; _5832 < _9640; ++_5832)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5830)->subi)(_5832)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_5830)->subj)(_5832)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5830)->val)(_5832));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _5831 = _9638;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5833){ return new mosek::fusion::DenseMatrix(_5833); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5833) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5833); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _5833){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_5833)->size(0)),(int)((_5833)->size(1)));
    std::vector<double> _9641;
    for (int _5834 = (int)0, _9642 = dimi; _5834 < _9642 ; ++_5834)
    {
      for (int _5835 = (int)0, _9643 = dimj; _5835 < _9643 ; ++_5835)
      {
        _9641.push_back(((*_5833)(_5834,_5835)));
      }
    }
    auto _9644 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9641.size()),_9641.begin(),_9641.end()));
    data = _9644;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5836,    int _5837,    double _5838){ return new mosek::fusion::DenseMatrix(_5836,_5837,_5838); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5836,    int _5837,    double _5838) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5836,_5837,_5838); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5836,    int _5837,    double _5838){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_5836,_5837);
    std::vector<double> _9645;
    for (int _5839 = (int)0, _9646 = _5836; _5839 < _9646 ; ++_5839)
    {
      for (int _5840 = (int)0, _9647 = _5837; _5840 < _9647 ; ++_5840)
      {
        _9645.push_back(_5838);
      }
    }
    auto _9648 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9645.size()),_9645.begin(),_9645.end()));
    data = _9648;
    nnz = (long long)safe_mul( _5836,_5837 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5841 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _5841->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _5841->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _5842 = (int)0;
  {
    int _5843 = (int)0;
    for(;(_5843 < dimi);++ _5843)
    {
      {
        if ((_5843 > (int)0))
        {
          {
            _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _5841->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5842)));
        ++ _5842;
        {
          int _5844 = (int)1;
          for(;(_5844 < dimj);++ _5844)
          {
            {
              _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _5841->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5842)));
              ++ _5842;
            }
          }
        }
        _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _5841->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _5841->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _5845 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5845(_5845 ? _5845->raw() : nullptr,_5845 ? _5845->size(0) : 0);
  int _5846 = (int)0;
  int _5847 = dimi;
  int _9649 = (int)0;
  int _9650 = dimi;
  for (int _5848 = _9649; _5848 < _9650; ++_5848)
  {
    {
      int _5849 = _5848;
      int _9651 = (int)0;
      int _9652 = dimj;
      for (int _5850 = _9651; _5850 < _9652; ++_5850)
      {
        {
          _ptr__5845[_5849] = ((*data)(_5846));
          _5849 = safe_add( _5849,_5847 );
          ++ _5846;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_5845)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5851,std::shared_ptr< monty::ndarray< int,1 > > _5852,std::shared_ptr< monty::ndarray< double,1 > > _5853) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_5851,_5852,_5853); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5851,std::shared_ptr< monty::ndarray< int,1 > > _5852,std::shared_ptr< monty::ndarray< double,1 > > _5853){
  _checked_ptr_1<int> _ptr__5851(_5851 ? _5851->raw() : nullptr, _5851 ? _5851->size(0) : 0);
  _checked_ptr_1<int> _ptr__5852(_5852 ? _5852->raw() : nullptr, _5852 ? _5852->size(0) : 0);
  _checked_ptr_1<double> _ptr__5853(_5853 ? _5853->raw() : nullptr, _5853 ? _5853->size(0) : 0);
  if ((((int)((_5851)->size(0)) < nnz) || (((int)((_5852)->size(0)) < nnz) || ((int)((_5853)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_5853,(int)0,(int)((data)->size(0)));
  int _5854 = (int)0;
  int _9653 = (int)0;
  int _9654 = dimi;
  for (int _5855 = _9653; _5855 < _9654; ++_5855)
  {
    {
      int _9655 = (int)0;
      int _9656 = dimj;
      for (int _5856 = _9655; _5856 < _9656; ++_5856)
      {
        {
          _ptr__5851[_5854] = _5855;
          _ptr__5852[_5854] = _5856;
          ++ _5854;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _5857,int _5858) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_5857,_5858); }double mosek::fusion::p_DenseMatrix::get(int _5857,int _5858){
  return ((*data)(safe_add( safe_mul( _5857,dimj ),_5858 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5859,    int _5860,    std::shared_ptr< monty::ndarray< int,1 > > _5861,    std::shared_ptr< monty::ndarray< int,1 > > _5862,    std::shared_ptr< monty::ndarray< double,1 > > _5863,    long long _5864){ return new mosek::fusion::SparseMatrix(_5859,_5860,_5861,_5862,_5863,_5864); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5859,    int _5860,    std::shared_ptr< monty::ndarray< int,1 > > _5861,    std::shared_ptr< monty::ndarray< int,1 > > _5862,    std::shared_ptr< monty::ndarray< double,1 > > _5863,    long long _5864) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5859,_5860,_5861,_5862,_5863,_5864); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5859,    int _5860,    std::shared_ptr< monty::ndarray< int,1 > > _5861,    std::shared_ptr< monty::ndarray< int,1 > > _5862,    std::shared_ptr< monty::ndarray< double,1 > > _5863,    long long _5864){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5861(_5861 ? _5861->raw() : nullptr, _5861 ? _5861->size(0) : 0);
    _checked_ptr_1<int> _ptr__5862(_5862 ? _5862->raw() : nullptr, _5862 ? _5862->size(0) : 0);
    _checked_ptr_1<double> _ptr__5863(_5863 ? _5863->raw() : nullptr, _5863 ? _5863->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5859,_5860);
    if ((_5864 > (int)0))
    {
      {
        if ((((int)((_5861)->size(0)) < _5864) || (((int)((_5862)->size(0)) < _5864) || ((int)((_5863)->size(0)) < _5864))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        bool _5865 = false;
        long long _9657 = (long long)0;
        long long _9658 = _5864;
        for (long long _5866 = _9657; _5866 < _9658; ++_5866)
        {
          {
            if (((_ptr__5861[_5866] < (int)0) || ((_ptr__5861[_5866] >= dimi) || ((_ptr__5862[_5866] < (int)0) || (_ptr__5862[_5866] >= dimj)))))
            {
              {
                _5865 = true;
              }
            }
            {}
          }
        }
        if (_5865)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
          }
        }
        {}
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5867 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5868 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _5869 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_5861,_5862,_5863,_5867,_5868,_5869,_5864,dimi,dimj);
        subi = ((*_5867)((int)0));
        subj = ((*_5868)((int)0));
        val = ((*_5869)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5870,    int _5871,    std::shared_ptr< monty::ndarray< int,1 > > _5872,    std::shared_ptr< monty::ndarray< int,1 > > _5873,    std::shared_ptr< monty::ndarray< double,1 > > _5874){ return new mosek::fusion::SparseMatrix(_5870,_5871,_5872,_5873,_5874); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5870,    int _5871,    std::shared_ptr< monty::ndarray< int,1 > > _5872,    std::shared_ptr< monty::ndarray< int,1 > > _5873,    std::shared_ptr< monty::ndarray< double,1 > > _5874) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5870,_5871,_5872,_5873,_5874); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5870,    int _5871,    std::shared_ptr< monty::ndarray< int,1 > > _5872,    std::shared_ptr< monty::ndarray< int,1 > > _5873,    std::shared_ptr< monty::ndarray< double,1 > > _5874){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5872(_5872 ? _5872->raw() : nullptr, _5872 ? _5872->size(0) : 0);
    _checked_ptr_1<int> _ptr__5873(_5873 ? _5873->raw() : nullptr, _5873 ? _5873->size(0) : 0);
    _checked_ptr_1<double> _ptr__5874(_5874 ? _5874->raw() : nullptr, _5874 ? _5874->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5870,_5871);
    int _5875 = (int)0;
    int _9659 = (int)0;
    int _9660 = (int)((_5874)->size(0));
    for (int _5876 = _9659; _5876 < _9660; ++_5876)
    {
      {
        if (((_ptr__5874[_5876] > (int)0) || (_ptr__5874[_5876] < (int)0)))
        {
          {
            ++ _5875;
          }
        }
        {}
      }
    }
    if (((_5875 > (int)0) && (_5875 < (int)((_5872)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5875)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5875)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5875)));
        nnz = _5875;
        int _5877 = (int)0;
        int _9661 = (int)0;
        int _9662 = (int)((_5874)->size(0));
        for (int _5878 = _9661; _5878 < _9662; ++_5878)
        {
          {
            if (((_ptr__5874[_5878] < (int)0) || (_ptr__5874[_5878] > (int)0)))
            {
              {
                ((*val)(_5877)) = _ptr__5874[_5878];
                ((*subj)(_5877)) = _ptr__5873[_5878];
                ((*subi)(_5877)) = _ptr__5872[_5878];
                ++ _5877;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _5872;
        subj = _5873;
        val = _5874;
        if ((NULL == _5872.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _5879 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5879(_5879 ? _5879->raw() : nullptr,_5879 ? _5879->size(0) : 0);
  long long _5880 = (long long)0;
  int _9663 = (int)0;
  int _9664 = dimi;
  for (int _5881 = _9663; _5881 < _9664; ++_5881)
  {
    {
      _ptr__5879[_5881] = _5880;
      {
        for(;((_5880 < nnz) && (((*subi)(_5880)) == _5881));++ _5880)
        {
          {
          }
        }
      }
    }
  }
  _ptr__5879[dimi] = _5880;
  return _5879;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5882 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5882->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _5882->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _9665 = (int)1;
      int _9666 = (int)((subi)->size(0));
      for (int _5883 = _9665; _5883 < _9666; ++_5883)
      {
        {
          _5882->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_5883)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_5883)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_5883)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _5882->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _5882->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _5884 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5884(_5884 ? _5884->raw() : nullptr,_5884 ? _5884->size(0) : 0);
  int _9667 = (int)0;
  int _9668 = (int)((subi)->size(0));
  for (int _5885 = _9667; _5885 < _9668; ++_5885)
  {
    {
      _ptr__5884[safe_add( safe_mul( ((*subi)(_5885)),dimj ),((*subj)(_5885)) )] = ((*val)(_5885));
    }
  }
  return _5884;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5886,std::shared_ptr< monty::ndarray< int,1 > > _5887,std::shared_ptr< monty::ndarray< double,1 > > _5888) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_5886,_5887,_5888); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5886,std::shared_ptr< monty::ndarray< int,1 > > _5887,std::shared_ptr< monty::ndarray< double,1 > > _5888){
  _checked_ptr_1<int> _ptr__5886(_5886 ? _5886->raw() : nullptr, _5886 ? _5886->size(0) : 0);
  _checked_ptr_1<int> _ptr__5887(_5887 ? _5887->raw() : nullptr, _5887 ? _5887->size(0) : 0);
  _checked_ptr_1<double> _ptr__5888(_5888 ? _5888->raw() : nullptr, _5888 ? _5888->size(0) : 0);
  if ((((long long)((_5886)->size(0)) < nnz) || (((long long)((_5887)->size(0)) < nnz) || ((long long)((_5888)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_5886,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_5887,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_5888,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _5889,int _5890) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_5889,_5890); }double mosek::fusion::p_SparseMatrix::get(int _5889,int _5890){
  if (((_5889 < (int)0) || ((_5889 >= dimi) || ((_5890 < (int)0) || (_5890 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _5891 = (int)((subi)->size(0));
  int _5892 = (int)0;
  while ( ((_5891 - _5892) > (int)1) )
  {
    {
      int _5893 = (safe_add( _5892,_5891 ) / (int)2);
      if (((((*subi)(_5893)) < _5889) || ((((*subi)(_5893)) == _5889) && (((*subj)(_5893)) < _5890))))
      {
        {
          _5892 = _5893;
        }
      }
      else if(((((*subi)(_5893)) > _5889) || ((((*subi)(_5893)) == _5889) && (((*subj)(_5893)) > _5890))))
      {
        {
          _5891 = _5893;
        }
      }
      else
      {
        {
          return ((*val)(_5893));
        }
      }
    }
  }
  if (((((*subi)(_5892)) == _5889) && (((*subj)(_5892)) == _5890)))
  {
    {
      return ((*val)(_5892));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _5894,    int _5895){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_5894 < (int)0) || (_5895 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _5894;
    dimj = _5895;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _5896 = dimi;
  dimi = dimj;
  dimj = _5896;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5897,    monty::rc_ptr< ::mosek::fusion::Matrix > _5898) { return mosek::fusion::p_Matrix::diag(_5897,_5898); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5897,monty::rc_ptr< ::mosek::fusion::Matrix > _5898){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _9669;
  for (int _5899 = (int)0, _9670 = _5897; _5899 < _9670 ; ++_5899)
  {
    _9669.push_back(_5898);
  }
  auto _9671 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_9669.size()),_9669.begin(),_9669.end()));
  return ::mosek::fusion::p_Matrix::diag(_9671);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5900) { return mosek::fusion::p_Matrix::diag(_5900); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5900){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5901 = _5900;
  long long _5902 = (long long)0;
  int _5903 = (int)0;
  int _5904 = (int)0;
  int _9672 = (int)0;
  int _9673 = (int)((_5900)->size(0));
  for (int _5905 = _9672; _5905 < _9673; ++_5905)
  {
    {
      _5904 = safe_add( _5904,mosek::fusion::p_Matrix::_get_impl(((*_5900)(_5905)))->dimi );
      _5903 = safe_add( _5903,mosek::fusion::p_Matrix::_get_impl(((*_5900)(_5905)))->dimj );
      _5902 = safe_add( _5902,((*_5900)(_5905))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5906 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5902)));
  _checked_ptr_1<int> _ptr__5906(_5906 ? _5906->raw() : nullptr,_5906 ? _5906->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5907 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5902)));
  _checked_ptr_1<int> _ptr__5907(_5907 ? _5907->raw() : nullptr,_5907 ? _5907->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5908 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5902)));
  _checked_ptr_1<double> _ptr__5908(_5908 ? _5908->raw() : nullptr,_5908 ? _5908->size(0) : 0);
  {
    int _5909 = (int)0;
    int _5910 = (int)0;
    long long _5911 = (long long)0;
    int _9674 = (int)0;
    int _9675 = (int)((_5900)->size(0));
    for (int _5912 = _9674; _5912 < _9675; ++_5912)
    {
      {
        long long _5913 = ((*_5900)(_5912))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _5914 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5913)));
        _checked_ptr_1<double> _ptr__5914(_5914 ? _5914->raw() : nullptr,_5914 ? _5914->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5915 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5913)));
        _checked_ptr_1<int> _ptr__5915(_5915 ? _5915->raw() : nullptr,_5915 ? _5915->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5916 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5913)));
        _checked_ptr_1<int> _ptr__5916(_5916 ? _5916->raw() : nullptr,_5916 ? _5916->size(0) : 0);
        ((*_5900)(_5912))->getDataAsTriplets(_5916,_5915,_5914);
        ::mosek::fusion::Utils::Tools::arraycopy(_5914,(long long)0,_5908,_5911,_5913);
        long long _9676 = (long long)0;
        long long _9677 = _5913;
        for (long long _5917 = _9676; _5917 < _9677; ++_5917)
        {
          {
            _ptr__5906[safe_add( _5911,_5917 )] = safe_add( _ptr__5916[_5917],_5910 );
            _ptr__5907[safe_add( _5911,_5917 )] = safe_add( _ptr__5916[_5917],_5909 );
          }
        }
        _5911 = safe_add( _5911,_5913 );
        _5910 = safe_add( _5910,mosek::fusion::p_Matrix::_get_impl(((*_5900)(_5912)))->dimi );
        _5909 = safe_add( _5909,mosek::fusion::p_Matrix::_get_impl(((*_5900)(_5912)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5904,_5903,_5906,_5907,_5908)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5918,    double _5919,    int _5920) { return mosek::fusion::p_Matrix::antidiag(_5918,_5919,_5920); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5918,double _5919,int _5920){
  if (((_5920 < _5918) && (_5920 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5919,(_5918 - _5920)),_5920);
    }
  }
  else if(((_5920 > (-_5918)) && (_5920 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5919,safe_add( _5918,_5920 )),_5920);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5921,    double _5922) { return mosek::fusion::p_Matrix::antidiag(_5921,_5922); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5921,double _5922){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5922,_5921),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5923,    double _5924,    int _5925) { return mosek::fusion::p_Matrix::diag(_5923,_5924,_5925); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5923,double _5924,int _5925){
  if (((_5925 < _5923) && (_5925 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5924,(_5923 - _5925)),_5925);
    }
  }
  else if(((_5925 > (-_5923)) && (_5925 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5924,safe_add( _5923,_5925 )),_5925);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5926,    double _5927) { return mosek::fusion::p_Matrix::diag(_5926,_5927); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5926,double _5927){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5927,_5926),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5928,    int _5929) { return mosek::fusion::p_Matrix::antidiag(_5928,_5929); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5928,int _5929){
  _checked_ptr_1<double> _ptr__5928(_5928 ? _5928->raw() : nullptr, _5928 ? _5928->size(0) : 0);
  int _9678;
  bool _9679 = (_5929 > (int)0);
  if (_9679)
  {
    _9678 = _5929;
  }
  else
  {
    _9678 = (-_5929);
  }
  int _5930 = _9678;
  int _5931 = safe_add( (int)((_5928)->size(0)),_5930 );
  int _5932 = (int)((_5928)->size(0));
  if ((_5929 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5933 = ::mosek::fusion::Utils::Tools::range(_5929,safe_add( _5932,_5929 ));
      _checked_ptr_1<int> _ptr__5933(_5933 ? _5933->raw() : nullptr,_5933 ? _5933->size(0) : 0);
      std::vector<int> _9680;
      for (int _5935 = (int)1, _9681 = safe_add( _5932,(int)1 ); _5935 < _9681 ; ++_5935)
      {
        _9680.push_back((safe_add( _5932,_5929 ) - _5935));
      }
      auto _9682 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9680.size()),_9680.begin(),_9680.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5934 = _9682;
      _checked_ptr_1<int> _ptr__5934(_5934 ? _5934->raw() : nullptr,_5934 ? _5934->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5931,_5931,_5933,_5934,_5928)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5936 = ::mosek::fusion::Utils::Tools::range((int)0,_5932);
      _checked_ptr_1<int> _ptr__5936(_5936 ? _5936->raw() : nullptr,_5936 ? _5936->size(0) : 0);
      std::vector<int> _9683;
      for (int _5938 = (int)1, _9684 = safe_add( _5932,(int)1 ); _5938 < _9684 ; ++_5938)
      {
        _9683.push_back((_5932 - _5938));
      }
      auto _9685 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9683.size()),_9683.begin(),_9683.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5937 = _9685;
      _checked_ptr_1<int> _ptr__5937(_5937 ? _5937->raw() : nullptr,_5937 ? _5937->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5931,_5931,_5936,_5937,_5928)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5939) { return mosek::fusion::p_Matrix::antidiag(_5939); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5939){
  _checked_ptr_1<double> _ptr__5939(_5939 ? _5939->raw() : nullptr, _5939 ? _5939->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_5939,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5940,    int _5941) { return mosek::fusion::p_Matrix::diag(_5940,_5941); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5940,int _5941){
  _checked_ptr_1<double> _ptr__5940(_5940 ? _5940->raw() : nullptr, _5940 ? _5940->size(0) : 0);
  int _9686;
  bool _9687 = (_5941 > (int)0);
  if (_9687)
  {
    _9686 = _5941;
  }
  else
  {
    _9686 = (-_5941);
  }
  int _5942 = _9686;
  int _5943 = safe_add( (int)((_5940)->size(0)),_5942 );
  int _5944 = (int)((_5940)->size(0));
  if ((_5941 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5945 = ::mosek::fusion::Utils::Tools::range((int)0,_5944);
      _checked_ptr_1<int> _ptr__5945(_5945 ? _5945->raw() : nullptr,_5945 ? _5945->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5946 = ::mosek::fusion::Utils::Tools::range(_5942,safe_add( _5944,_5942 ));
      _checked_ptr_1<int> _ptr__5946(_5946 ? _5946->raw() : nullptr,_5946 ? _5946->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5943,_5943,_5945,_5946,_5940)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5947 = ::mosek::fusion::Utils::Tools::range(_5942,safe_add( _5944,_5942 ));
      _checked_ptr_1<int> _ptr__5947(_5947 ? _5947->raw() : nullptr,_5947 ? _5947->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5948 = ::mosek::fusion::Utils::Tools::range((int)0,_5944);
      _checked_ptr_1<int> _ptr__5948(_5948 ? _5948->raw() : nullptr,_5948 ? _5948->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5943,_5943,_5947,_5948,_5940)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5949) { return mosek::fusion::p_Matrix::diag(_5949); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5949){
  _checked_ptr_1<double> _ptr__5949(_5949 ? _5949->raw() : nullptr, _5949 ? _5949->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_5949,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _5950,    int _5951) { return mosek::fusion::p_Matrix::ones(_5950,_5951); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _5950,int _5951){
  return ::mosek::fusion::p_Matrix::dense(_5950,_5951,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _5952) { return mosek::fusion::p_Matrix::eye(_5952); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _5952){
  std::vector<double> _9688;
  for (int _5953 = (int)0, _9689 = _5952; _5953 < _9689 ; ++_5953)
  {
    _9688.push_back(1.0);
  }
  auto _9690 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9688.size()),_9688.begin(),_9688.end()));
  return ::mosek::fusion::p_Matrix::diag(_9690);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5954) { return mosek::fusion::p_Matrix::dense(_5954); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5954){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5954)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5955,    int _5956,    double _5957) { return mosek::fusion::p_Matrix::dense(_5955,_5956,_5957); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5955,int _5956,double _5957){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5955,_5956,_5957)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5958,    int _5959,    std::shared_ptr< monty::ndarray< double,1 > > _5960) { return mosek::fusion::p_Matrix::dense(_5958,_5959,_5960); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5958,int _5959,std::shared_ptr< monty::ndarray< double,1 > > _5960){
  _checked_ptr_1<double> _ptr__5960(_5960 ? _5960->raw() : nullptr, _5960 ? _5960->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5958,_5959,_5960)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _5961) { return mosek::fusion::p_Matrix::dense(_5961); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _5961){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5961)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5962) { return mosek::fusion::p_Matrix::sparse(_5962); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5962){
  std::shared_ptr< monty::ndarray< int,1 > > _5963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5962->numNonzeros())));
  _checked_ptr_1<int> _ptr__5963(_5963 ? _5963->raw() : nullptr,_5963 ? _5963->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5962->numNonzeros())));
  _checked_ptr_1<int> _ptr__5964(_5964 ? _5964->raw() : nullptr,_5964 ? _5964->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5965 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5962->numNonzeros())));
  _checked_ptr_1<double> _ptr__5965(_5965 ? _5965->raw() : nullptr,_5965 ? _5965->size(0) : 0);
  _5962->getDataAsTriplets(_5963,_5964,_5965);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5962->numRows(),_5962->numColumns(),_5963,_5964,_5965)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5966) { return mosek::fusion::p_Matrix::sparse(_5966); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5966){
  int _5967 = (int)((_5966)->size(0));
  int _5968 = (int)((((*_5966)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5969 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5967)));
  _checked_ptr_1<int> _ptr__5969(_5969 ? _5969->raw() : nullptr,_5969 ? _5969->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5970 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5968)));
  _checked_ptr_1<int> _ptr__5970(_5970 ? _5970->raw() : nullptr,_5970 ? _5970->size(0) : 0);
  long long _5971 = (long long)0;
  int _5972 = (int)0;
  {
    int _5973 = (int)0;
    for(;(_5973 < _5967);++ _5973)
    {
      {
        {
          int _5974 = (int)0;
          for(;(_5974 < _5968);++ _5974)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _5975 = ((*((*_5966)(_5973)))(_5974));
              if ((NULL != _5975.get()))
              {
                {
                  if ((_ptr__5970[_5974] == (int)0))
                  {
                    {
                      _ptr__5970[_5974] = mosek::fusion::p_Matrix::_get_impl(_5975)->dimj;
                    }
                  }
                  else if((_ptr__5970[_5974] != mosek::fusion::p_Matrix::_get_impl(_5975)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__5969[_5973] == (int)0))
                  {
                    {
                      _ptr__5969[_5973] = mosek::fusion::p_Matrix::_get_impl(_5975)->dimi;
                    }
                  }
                  else if((_ptr__5969[_5973] != mosek::fusion::p_Matrix::_get_impl(_5975)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _5971 = safe_add( _5971,_5975->numNonzeros() );
                }
              }
              {}
              ++ _5972;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5976 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5971)));
  _checked_ptr_1<double> _ptr__5976(_5976 ? _5976->raw() : nullptr,_5976 ? _5976->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5977 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5971)));
  _checked_ptr_1<int> _ptr__5977(_5977 ? _5977->raw() : nullptr,_5977 ? _5977->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5978 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5971)));
  _checked_ptr_1<int> _ptr__5978(_5978 ? _5978->raw() : nullptr,_5978 ? _5978->size(0) : 0);
  int _5979 = (int)0;
  int _5980 = (int)0;
  {
    int _5981 = (int)0;
    for(;(_5981 < _5967);++ _5981)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _5982 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5968)));
        _checked_ptr_1<int> _ptr__5982(_5982 ? _5982->raw() : nullptr,_5982 ? _5982->size(0) : 0);
        {
          int _5983 = (int)0;
          for(;(_5983 < _ptr__5969[_5981]);++ _5983)
          {
            {
              int _5984 = (int)0;
              {
                int _5985 = (int)0;
                for(;(_5985 < _5968);++ _5985)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _5986 = ((*((*_5966)(_5981)))(_5985));
                    if ((NULL != _5986.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _9691 = _5986;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9691.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _5987 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9691.get()));
                          {
                            int _5990 = _ptr__5982[_5985];
                            {
                              int _5991 = (int)0;
                              for(;(_5991 < mosek::fusion::p_Matrix::_get_impl(_5987)->dimj);++ _5991)
                              {
                                {
                                  _ptr__5976[_5979] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_5987)->data)(_5990));
                                  _ptr__5977[_5979] = safe_add( _5980,_5983 );
                                  _ptr__5978[_5979] = safe_add( _5984,_5991 );
                                  ++ _5990;
                                  ++ _5979;
                                }
                              }
                            }
                            _ptr__5982[_5985] = _5990;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9691.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _5988 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9691.get()));
                          {
                            int _5992;
                            {
                              _5992 = _ptr__5982[_5985];
                              for(;((_5992 < mosek::fusion::p_SparseMatrix::_get_impl(_5988)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_5988)->subi)(_5992)) == _5983));++ _5992)
                              {
                                {
                                  _ptr__5976[_5979] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5988)->val)(_5992));
                                  _ptr__5978[_5979] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5988)->subj)(_5992)),_5984 );
                                  _ptr__5977[_5979] = safe_add( _5980,_5983 );
                                  ++ _5979;
                                }
                              }
                            }
                            _ptr__5982[_5985] = _5992;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _5989 = _9691;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _5984 = safe_add( _5984,_ptr__5970[_5985] );
                  }
                }
              }
            }
          }
        }
        _5980 = safe_add( _5980,_ptr__5969[_5981] );
      }
    }
  }
  int _5993 = (int)0;
  int _5994 = (int)0;
  {
    int _5995 = (int)0;
    for(;(_5995 < _5967);++ _5995)
    {
      {
        _5993 = safe_add( _5993,_ptr__5969[_5995] );
      }
    }
  }
  {
    int _5996 = (int)0;
    for(;(_5996 < _5968);++ _5996)
    {
      {
        _5994 = safe_add( _5994,_ptr__5970[_5996] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5993,_5994,_5977,_5978,_5976)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _5997) { return mosek::fusion::p_Matrix::sparse(_5997); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _5997){
  int _5998 = (int)((_5997)->size(0));
  int _5999 = (int)((_5997)->size(1));
  long long _6000 = (long long)safe_mul( _5998,_5999 );
  int _6001 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _6002 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6000)));
  _checked_ptr_1<int> _ptr__6002(_6002 ? _6002->raw() : nullptr,_6002 ? _6002->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6003 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6000)));
  _checked_ptr_1<int> _ptr__6003(_6003 ? _6003->raw() : nullptr,_6003 ? _6003->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6004 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6000)));
  _checked_ptr_1<double> _ptr__6004(_6004 ? _6004->raw() : nullptr,_6004 ? _6004->size(0) : 0);
  {
    int _6005 = (int)0;
    for(;(_6005 < _5998);++ _6005)
    {
      {
        {
          int _6006 = (int)0;
          for(;(_6006 < _5999);++ _6006)
          {
            {
              _ptr__6002[_6001] = _6005;
              _ptr__6003[_6001] = _6006;
              _ptr__6004[_6001] = ((*_5997)(_6005,_6006));
              ++ _6001;
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5998,_5999,_6002,_6003,_6004)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _6007,    int _6008) { return mosek::fusion::p_Matrix::sparse(_6007,_6008); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _6007,int _6008){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_6007,_6008,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _6009,    int _6010,    std::shared_ptr< monty::ndarray< int,1 > > _6011,    std::shared_ptr< monty::ndarray< int,1 > > _6012,    double _6013) { return mosek::fusion::p_Matrix::sparse(_6009,_6010,_6011,_6012,_6013); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _6009,int _6010,std::shared_ptr< monty::ndarray< int,1 > > _6011,std::shared_ptr< monty::ndarray< int,1 > > _6012,double _6013){
  _checked_ptr_1<int> _ptr__6011(_6011 ? _6011->raw() : nullptr, _6011 ? _6011->size(0) : 0);
  _checked_ptr_1<int> _ptr__6012(_6012 ? _6012->raw() : nullptr, _6012 ? _6012->size(0) : 0);
  int _6014 = (int)0;
  if ((NULL != _6011.get()))
  {
    {
      _6014 = (int)((_6011)->size(0));
    }
  }
  else if((NULL != _6012.get()))
  {
    {
      _6014 = (int)((_6012)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_6009,_6010,_6011,_6012,::mosek::fusion::Utils::Tools::makevector(_6013,_6014));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _6015,    std::shared_ptr< monty::ndarray< int,1 > > _6016,    double _6017) { return mosek::fusion::p_Matrix::sparse(_6015,_6016,_6017); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _6015,std::shared_ptr< monty::ndarray< int,1 > > _6016,double _6017){
  _checked_ptr_1<int> _ptr__6015(_6015 ? _6015->raw() : nullptr, _6015 ? _6015->size(0) : 0);
  _checked_ptr_1<int> _ptr__6016(_6016 ? _6016->raw() : nullptr, _6016 ? _6016->size(0) : 0);
  int _6018 = (int)0;
  int _6019 = (int)0;
  int _6020 = (int)((_6015)->size(0));
  if ((_6020 > (int)((_6016)->size(0))))
  {
    {
      _6020 = (int)((_6016)->size(0));
    }
  }
  {}
  int _9692 = (int)0;
  int _9693 = _6020;
  for (int _6021 = _9692; _6021 < _9693; ++_6021)
  {
    {
      if ((_6019 < _ptr__6015[_6021]))
      {
        {
          _6019 = _ptr__6015[_6021];
        }
      }
      {}
      if ((_6018 < _ptr__6016[_6021]))
      {
        {
          _6018 = _ptr__6016[_6021];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _6019,(int)1 ),safe_add( _6018,(int)1 ),_6015,_6016,_6017);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _6022,    std::shared_ptr< monty::ndarray< int,1 > > _6023,    std::shared_ptr< monty::ndarray< double,1 > > _6024) { return mosek::fusion::p_Matrix::sparse(_6022,_6023,_6024); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _6022,std::shared_ptr< monty::ndarray< int,1 > > _6023,std::shared_ptr< monty::ndarray< double,1 > > _6024){
  _checked_ptr_1<int> _ptr__6022(_6022 ? _6022->raw() : nullptr, _6022 ? _6022->size(0) : 0);
  _checked_ptr_1<int> _ptr__6023(_6023 ? _6023->raw() : nullptr, _6023 ? _6023->size(0) : 0);
  _checked_ptr_1<double> _ptr__6024(_6024 ? _6024->raw() : nullptr, _6024 ? _6024->size(0) : 0);
  int _6025 = (int)0;
  int _6026 = (int)0;
  int _6027 = (int)((_6022)->size(0));
  if ((_6027 > (int)((_6023)->size(0))))
  {
    {
      _6027 = (int)((_6023)->size(0));
    }
  }
  {}
  if ((_6027 > (int)((_6024)->size(0))))
  {
    {
      _6027 = (int)((_6024)->size(0));
    }
  }
  {}
  int _9694 = (int)0;
  int _9695 = _6027;
  for (int _6028 = _9694; _6028 < _9695; ++_6028)
  {
    {
      if ((_6026 < _ptr__6022[_6028]))
      {
        {
          _6026 = _ptr__6022[_6028];
        }
      }
      {}
      if ((_6025 < _ptr__6023[_6028]))
      {
        {
          _6025 = _ptr__6023[_6028];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _6026,(int)1 ),safe_add( _6025,(int)1 ),_6022,_6023,_6024);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _6029,    int _6030,    std::shared_ptr< monty::ndarray< int,1 > > _6031,    std::shared_ptr< monty::ndarray< int,1 > > _6032,    std::shared_ptr< monty::ndarray< double,1 > > _6033) { return mosek::fusion::p_Matrix::sparse(_6029,_6030,_6031,_6032,_6033); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _6029,int _6030,std::shared_ptr< monty::ndarray< int,1 > > _6031,std::shared_ptr< monty::ndarray< int,1 > > _6032,std::shared_ptr< monty::ndarray< double,1 > > _6033){
  _checked_ptr_1<int> _ptr__6031(_6031 ? _6031->raw() : nullptr, _6031 ? _6031->size(0) : 0);
  _checked_ptr_1<int> _ptr__6032(_6032 ? _6032->raw() : nullptr, _6032 ? _6032->size(0) : 0);
  _checked_ptr_1<double> _ptr__6033(_6033 ? _6033->raw() : nullptr, _6033 ? _6033->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9696;
  bool _9697 = (NULL != _6033.get());
  if (_9697)
  {
    _9696 = _6033;
  }
  else
  {
    _9696 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _6034 = _9696;
  _checked_ptr_1<double> _ptr__6034(_6034 ? _6034->raw() : nullptr,_6034 ? _6034->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9698;
  bool _9699 = (NULL != _6032.get());
  if (_9699)
  {
    _9698 = _6032;
  }
  else
  {
    _9698 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _6035 = _9698;
  _checked_ptr_1<int> _ptr__6035(_6035 ? _6035->raw() : nullptr,_6035 ? _6035->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9700;
  bool _9701 = (NULL != _6031.get());
  if (_9701)
  {
    _9700 = _6031;
  }
  else
  {
    _9700 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _6036 = _9700;
  _checked_ptr_1<int> _ptr__6036(_6036 ? _6036->raw() : nullptr,_6036 ? _6036->size(0) : 0);
  long long _6037 = (long long)((_6036)->size(0));
  if ((((long long)((_6035)->size(0)) != _6037) || ((long long)((_6034)->size(0)) != _6037)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_6029,_6030,_6036,_6035,_6034,_6037)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _6043) : RuntimeException(_6043)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _6044) : RuntimeException(_6044)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _6045) : RuntimeException(_6045.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _6046) : RuntimeException(_6046)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _6047) : mosek::fusion::FusionRuntimeException(_6047)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _6048) : mosek::fusion::FusionException(_6048)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _6049) : mosek::fusion::FusionRuntimeException(_6049)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _6050) : mosek::fusion::FusionRuntimeException(_6050)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _6051) : mosek::fusion::FusionRuntimeException(_6051)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _6052) : mosek::fusion::FusionRuntimeException(_6052)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _6053) : mosek::fusion::FusionRuntimeException(_6053)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _6054) : mosek::fusion::FusionRuntimeException(_6054)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _6055) : mosek::fusion::FusionRuntimeException(_6055)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _6056) : mosek::fusion::FusionRuntimeException(_6056)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _6057) : mosek::fusion::FusionRuntimeException(_6057)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _6058) : mosek::fusion::FusionRuntimeException(_6058)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _6059) : mosek::fusion::FusionRuntimeException(_6059)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _6060) : mosek::fusion::FusionRuntimeException(_6060)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _6061) : mosek::fusion::FusionRuntimeException(_6061)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _6062) : mosek::fusion::FusionRuntimeException(_6062)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _6063) : mosek::fusion::FusionRuntimeException(_6063)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _6064) : RuntimeException(_6064)  {
    msg = _6064;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _6065) : Exception(_6065)  {
    msg = _6065;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _6066){ return new mosek::fusion::LinkedBlocks(_6066); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _6066) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_6066); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _6066){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_6066);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6067){ return new mosek::fusion::LinkedBlocks(_6067); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6067) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_6067); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _6067){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_6067)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_6067)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_6067)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_6067)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _6068) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_6068); }void mosek::fusion::p_LinkedBlocks::free(int _6068){
  int _6069 = ((*bfirst)(_6068));
  ints->free(_6068,((*bsize)(_6068)));
  ((*bsize)(_6068)) = (-(int)1);
  ((*bfirst)(_6068)) = (-(int)1);
  blocks->free(_6069,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _6070) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_6070); }int mosek::fusion::p_LinkedBlocks::alloc(int _6070){
  int _9702;
  bool _9703 = (_6070 > (int)0);
  if (_9703)
  {
    _9702 = ints->alloc(_6070);
  }
  else
  {
    _9702 = (-(int)1);
  }
  int _6071 = _9702;
  int _6072 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _6073 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__6073(_6073 ? _6073->raw() : nullptr,_6073 ? _6073->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _6074 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__6074(_6074 ? _6074->raw() : nullptr,_6074 ? _6074->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_6073,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_6074,(int)0,(int)((bfirst)->size(0)));
      bsize = _6073;
      bfirst = _6074;
    }
  }
  {}
  ((*bfirst)(_6072)) = _6071;
  ((*bsize)(_6072)) = _6070;
  return _6072;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _6075) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_6075); }int mosek::fusion::p_LinkedBlocks::maxidx(int _6075){
  return ints->maxidx(((*bfirst)(_6075)),((*bsize)(_6075)));
}
void mosek::fusion::LinkedBlocks :: get(int _6076,std::shared_ptr< monty::ndarray< int,1 > > _6077,int _6078) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_6076,_6077,_6078); }void mosek::fusion::p_LinkedBlocks::get(int _6076,std::shared_ptr< monty::ndarray< int,1 > > _6077,int _6078){
  _checked_ptr_1<int> _ptr__6077(_6077 ? _6077->raw() : nullptr, _6077 ? _6077->size(0) : 0);
  ints->get(((*bfirst)(_6076)),((*bsize)(_6076)),_6077,_6078);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _6079) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_6079); }int mosek::fusion::p_LinkedBlocks::blocksize(int _6079){
  return ((*bsize)(_6079));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _6080){ return new mosek::fusion::LinkedInts(_6080); }mosek::fusion::LinkedInts::LinkedInts  (int _6080) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_6080); }void mosek::fusion::p_LinkedInts::_initialize  (int _6080){monty::rc_reserve __reserve_this(_pubthis);   {
    int _9704;
    bool _9705 = (_6080 > (int)0);
    if (_9705)
    {
      _9704 = _6080;
    }
    else
    {
      _9704 = (int)128;
    }
    int _6081 = _9704;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6081)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6081)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_6081 - (int)1);
    int _9706 = (int)1;
    int _9707 = _6081;
    for (int _6082 = _9706; _6082 < _9707; ++_6082)
    {
      {
        ((*prev)(_6082)) = (_6082 - (int)1);
        ((*next)((_6082 - (int)1))) = _6082;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_6081 - (int)1))) = (-(int)1);
    nfree = _6081;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _6083){ return new mosek::fusion::LinkedInts(_6083); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _6083) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_6083); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _6083){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_6083)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_6083)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_6083)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_6083)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_6083)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_6083)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _6084,int _6085) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_6084,_6085); }void mosek::fusion::p_LinkedInts::free(int _6084,int _6085){
  int _6086 = _6084;
  int _6087 = _6086;
  int _9708 = (int)0;
  int _9709 = (_6085 - (int)1);
  for (int _6088 = _9708; _6088 < _9709; ++_6088)
  {
    {
      _6087 = ((*next)(_6087));
    }
  }
  int _6089 = ((*prev)(_6086));
  int _6090 = ((*next)(_6087));
  if ((_6089 >= (int)0))
  {
    {
      ((*next)(_6089)) = _6090;
    }
  }
  {}
  if ((_6090 >= (int)0))
  {
    {
      ((*prev)(_6090)) = _6089;
    }
  }
  {}
  ((*prev)(_6086)) = (-(int)1);
  ((*next)(_6087)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _6087;
    }
  }
  {}
  first_free = _6086;
  nfree += _6085;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _6091) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6091); }int mosek::fusion::p_LinkedInts::alloc(int _6091){
  return allocblock(_6091);
}
void mosek::fusion::LinkedInts :: alloc(int _6092,std::shared_ptr< monty::ndarray< int,1 > > _6093,int _6094) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6092,_6093,_6094); }void mosek::fusion::p_LinkedInts::alloc(int _6092,std::shared_ptr< monty::ndarray< int,1 > > _6093,int _6094){
  _checked_ptr_1<int> _ptr__6093(_6093 ? _6093->raw() : nullptr, _6093 ? _6093->size(0) : 0);
  int _6095 = allocblock(_6092);
  int _9710 = (int)0;
  int _9711 = _6092;
  for (int _6096 = _9710; _6096 < _9711; ++_6096)
  {
    {
      _ptr__6093[safe_add( _6096,_6094 )] = _6095;
      _6095 = ((*next)(_6095));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _6097,int _6098,std::shared_ptr< monty::ndarray< int,1 > > _6099,int _6100) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_6097,_6098,_6099,_6100); }void mosek::fusion::p_LinkedInts::get(int _6097,int _6098,std::shared_ptr< monty::ndarray< int,1 > > _6099,int _6100){
  _checked_ptr_1<int> _ptr__6099(_6099 ? _6099->raw() : nullptr, _6099 ? _6099->size(0) : 0);
  int _6101 = _6097;
  int _9712 = (int)0;
  int _9713 = _6098;
  for (int _6102 = _9712; _6102 < _9713; ++_6102)
  {
    {
      _ptr__6099[safe_add( _6102,_6100 )] = _6101;
      _6101 = ((*next)(_6101));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _6103,int _6104) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_6103,_6104); }int mosek::fusion::p_LinkedInts::maxidx(int _6103,int _6104){
  int _6105 = _6103;
  int _6106 = _6103;
  int _9714 = (int)1;
  int _9715 = _6104;
  for (int _6107 = _9714; _6107 < _9715; ++_6107)
  {
    {
      _6106 = ((*next)(_6106));
      if ((_6105 < _6106))
      {
        {
          _6105 = _6106;
        }
      }
      {}
    }
  }
  return _6105;
}
int mosek::fusion::p_LinkedInts::allocblock(int _6108){
  int _6109 = (int)((next)->size(0));
  if ((nfree < _6108))
  {
    {
      int _6110 = (_6108 - nfree);
      if ((_6110 < _6109))
      {
        {
          _6110 = _6109;
        }
      }
      {}
      recap(safe_add( _6110,_6109 ));
    }
  }
  {}
  int _6111 = first_free;
  int _6112 = _6111;
  int _9716 = (int)0;
  int _9717 = (_6108 - (int)1);
  for (int _6113 = _9716; _6113 < _9717; ++_6113)
  {
    {
      _6112 = ((*next)(_6112));
    }
  }
  first_free = ((*next)(_6112));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_6112)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _6112;
    }
  }
  {}
  first_used = _6111;
  nfree -= _6108;
  return _6111;
}
void mosek::fusion::p_LinkedInts::recap(int _6114){
  int _6115 = (int)((next)->size(0));
  if ((_6114 > _6115))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_6114);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_6114);
      int _9718 = _6115;
      int _9719 = (_6114 - (int)1);
      for (int _6116 = _9718; _6116 < _9719; ++_6116)
      {
        {
          ((*next)(_6116)) = safe_add( _6116,(int)1 );
          ((*prev)(safe_add( _6116,(int)1 ))) = _6116;
        }
      }
      ((*next)((_6114 - (int)1))) = (-(int)1);
      ((*prev)(_6115)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _6115;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _6115;
        }
      }
      last_free = (_6114 - (int)1);
      nfree += (_6114 - _6115);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _6117 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _6118 = first_used;
  while ( (_6118 >= (int)0) )
  {
    {
      ((*_6117)(_6118)) = true;
      _6118 = ((*next)(_6118));
      if (((_6118 >= (int)0) && ((*_6117)(_6118))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _6118 = first_free;
  int _6119 = (int)0;
  while ( (_6118 >= (int)0) )
  {
    {
      ++ _6119;
      ((*_6117)(_6118)) = true;
      _6118 = ((*next)(_6118));
      if (((_6118 >= (int)0) && ((*_6117)(_6118))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6119 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _9720 = (int)0;
  int _9721 = (int)((_6117)->size(0));
  for (int _6120 = _9720; _6120 < _9721; ++_6120)
  {
    {
      if ((!((*_6117)(_6118))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _9722 = (int)0;
  int _9723 = (int)((_6117)->size(0));
  for (int _6121 = _9722; _6121 < _9723; ++_6121)
  {
    {
      ((*_6117)(_6121)) = false;
    }
  }
  _6118 = last_free;
  int _6122 = (int)0;
  while ( (_6118 >= (int)0) )
  {
    {
      ++ _6122;
      ((*_6117)(_6118)) = true;
      _6118 = ((*prev)(_6118));
      if (((_6118 >= (int)0) && ((*_6117)(_6118))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6122 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6123,    const std::string & _6124,    double _6125) { mosek::fusion::p_Parameters::setParameter(_6123,_6124,_6125); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6123,const std::string & _6124,double _6125){
  if (false)
  {
    {
    }
  }
  else if((_6124 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6124 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6124 == std::string ("numThreads")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6126 = _6125;
          if (((int)0 <= _6126))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6126);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6124 == std::string ("mtSpincount")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6127 = _6125;
          if ((((int)0 <= _6127) && (_6127 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6127);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6124 == std::string ("biMaxIterations")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6128 = _6125;
          if (((int)0 <= _6128))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6128);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6129 = _6125;
          if (((int)0 <= _6129))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6129);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6130 = _6125;
          if (((int)0 <= _6130))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6130);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logResponse")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6131 = _6125;
          if (((int)0 <= _6131))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6131);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6124 == std::string ("logBi")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6132 = _6125;
          if (((int)0 <= _6132))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6132);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logBiFreq")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6133 = _6125;
          if (((int)0 <= _6133))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6133);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6124 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6124 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6124 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6124 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6124 == std::string ("logIntpnt")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6134 = _6125;
          if (((int)0 <= _6134))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6134);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6135 = _6125;
          if (((int)0 <= _6135))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6135);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6136 = _6125;
          if (((int)0 <= _6136))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6136);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_6124 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6137 = _6125;
          if (((int)0 <= _6137))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6137);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6124 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6124 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6124 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6138 = _6125;
          if (((-(int)1) <= _6138))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6138);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6124 == std::string ("presolveLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6139 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6139);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logPresolve")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6140 = _6125;
          if (((int)0 <= _6140))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6140);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6124 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6141 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6141);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6142 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6142);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6143 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6143);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simPrimalCrash")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6144 = _6125;
          if (((int)0 <= _6144))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6144);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logSim")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6145 = _6125;
          if (((int)0 <= _6145))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6145);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logSimMinor")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6146 = _6125;
          if (((int)0 <= _6146))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6146);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logSimFreq")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6147 = _6125;
          if (((int)0 <= _6147))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6147);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6148 = _6125;
          if ((((int)0 <= _6148) && (_6148 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6148);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6124 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6149 = _6125;
          if ((((int)0 <= _6149) && (_6149 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6149);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6124 == std::string ("simMaxIterations")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6150 = _6125;
          if (((int)0 <= _6150))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6150);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6124 == std::string ("simRefactorFreq")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6151 = _6125;
          if (((int)0 <= _6151))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6151);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simSeed")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6152 = _6125;
          if ((((int)0 <= _6152) && (_6152 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6152);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6124 == std::string ("logMio")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6153 = _6125;
          if (((int)0 <= _6153))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6153);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logMioFreq")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6154 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6154);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6155 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6155);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6156 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6156);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6157 = _6125;
          if (((int)0 <= _6157))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6157);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6158 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6158);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6124 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6159 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6159);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioProbingLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6160 = _6125;
          if ((((-(int)1) <= _6160) && (_6160 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6160);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6161 = _6125;
          if ((((-(int)1) <= _6161) && (_6161 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6161);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6162 = _6125;
          if ((((-(int)1) <= _6162) && (_6162 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6162);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6124 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6124 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6124 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6124 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6124 == std::string ("mioSeed")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6163 = _6125;
          if (((int)0 <= _6163))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6163);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6124 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6124 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6164 = _6125;
          if (((int)40 <= _6164))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6164);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6165 = _6125;
          if (((int)0 <= _6165))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6165);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6124 == std::string ("logInfeasAna")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6166 = _6125;
          if (((int)0 <= _6166))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6166);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6124 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6124 == std::string ("licensePauseTime")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6167 = _6125;
          if ((((int)0 <= _6167) && (_6167 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6167);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6124 == std::string ("log")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6168 = _6125;
          if (((int)0 <= _6168))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6168);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logExpand")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6169 = _6125;
          if (((int)0 <= _6169))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6169);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logFile")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6170 = _6125;
          if (((int)0 <= _6170))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6170);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("logOrder")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6171 = _6125;
          if (((int)0 <= _6171))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6171);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6124 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6124 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6172 = _6125;
          if ((((int)0 <= _6172) && (_6172 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6172);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6173 = _6125;
          if ((((int)0 <= _6173) && (_6173 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6173);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6174 = _6125;
          if (((int)0 <= _6174))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6174);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6124 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6124 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6124 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6124 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6124 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6124 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6124 == std::string ("simDualCrash")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6175 = _6125;
          if (((int)0 <= _6175))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6175);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6124 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6176 = _6125;
          if ((((-(int)1) <= _6176) && (_6176 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6176);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6124 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6124 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6124 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6124 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6124 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6177 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6177);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6178 = _6125;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6178);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6124 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6124 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6124 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6124 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6179 = _6125;
          if (((-(int)1) <= _6179))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6179);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioFeaspumpLevel")))
  {
    {
      if (((_6125 - (int)_6125) == 0.0))
      {
        {
          double _6180 = _6125;
          if ((((-(int)1) <= _6180) && (_6180 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6180);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("optimizerMaxTime")))
  {
    {
      double _6181 = _6125;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("lowerObjCut")))
  {
    {
      double _6182 = _6125;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("upperObjCut")))
  {
    {
      double _6183 = _6125;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6183);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6184 = _6125;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6184);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6185 = _6125;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6185);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolRelGap")))
  {
    {
      double _6186 = _6125;
      if ((1.000000e-14 <= _6186))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6186);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolStepSize")))
  {
    {
      double _6187 = _6125;
      if (((0.000000e+00 <= _6187) && (_6187 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6187);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6188 = _6125;
      if (((1.000000e-06 <= _6188) && (_6188 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6188);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolRelStep")))
  {
    {
      double _6189 = _6125;
      if (((1.000000e-04 <= _6189) && (_6189 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6189);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolPath")))
  {
    {
      double _6190 = _6125;
      if (((0.000000e+00 <= _6190) && (_6190 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6190);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolPfeas")))
  {
    {
      double _6191 = _6125;
      if (((0.000000e+00 <= _6191) && (_6191 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6191);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolDfeas")))
  {
    {
      double _6192 = _6125;
      if (((0.000000e+00 <= _6192) && (_6192 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6192);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolMuRed")))
  {
    {
      double _6193 = _6125;
      if (((0.000000e+00 <= _6193) && (_6193 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6193);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolInfeas")))
  {
    {
      double _6194 = _6125;
      if (((0.000000e+00 <= _6194) && (_6194 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6194);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6195 = _6125;
      if (((0.000000e+00 <= _6195) && (_6195 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6195);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6196 = _6125;
      if (((0.000000e+00 <= _6196) && (_6196 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6196);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6197 = _6125;
      if (((0.000000e+00 <= _6197) && (_6197 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6197);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6198 = _6125;
      if (((0.000000e+00 <= _6198) && (_6198 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6198);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6199 = _6125;
      if ((1.000000e+00 <= _6199))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6199);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6200 = _6125;
      if (((0.000000e+00 <= _6200) && (_6200 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6200);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolPsafe")))
  {
    {
      double _6201 = _6125;
      if ((1.000000e-04 <= _6201))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6201);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("intpntTolDsafe")))
  {
    {
      double _6202 = _6125;
      if ((1.000000e-04 <= _6202))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6202);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioMaxTime")))
  {
    {
      double _6203 = _6125;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6203);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioRelGapConst")))
  {
    {
      double _6204 = _6125;
      if ((1.000000e-15 <= _6204))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6204);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioTolRelGap")))
  {
    {
      double _6205 = _6125;
      if ((0.000000e+00 <= _6205))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6205);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioTolAbsGap")))
  {
    {
      double _6206 = _6125;
      if ((0.000000e+00 <= _6206))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6206);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6207 = _6125;
      if ((1.000000e-09 <= _6207))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6207);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("basisTolX")))
  {
    {
      double _6208 = _6125;
      if ((1.000000e-09 <= _6208))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6208);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("basisTolS")))
  {
    {
      double _6209 = _6125;
      if ((1.000000e-09 <= _6209))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6209);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("basisRelTolS")))
  {
    {
      double _6210 = _6125;
      if ((0.000000e+00 <= _6210))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6210);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveTolX")))
  {
    {
      double _6211 = _6125;
      if ((0.000000e+00 <= _6211))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6211);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveTolS")))
  {
    {
      double _6212 = _6125;
      if ((0.000000e+00 <= _6212))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6212);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveTolAij")))
  {
    {
      double _6213 = _6125;
      if ((1.000000e-15 <= _6213))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6213);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6214 = _6125;
      if ((0.000000e+00 <= _6214))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6214);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6215 = _6125;
      if ((0.000000e+00 <= _6215))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6215);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6216 = _6125;
      if ((1.000000e-12 <= _6216))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6216);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioTolFeas")))
  {
    {
      double _6217 = _6125;
      if (((1.000000e-09 <= _6217) && (_6217 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6217);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6124 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6218 = _6125;
      if (((0.000000e+00 <= _6218) && (_6218 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6123.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6218);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6124 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6124 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6124 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6124 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6124 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6124 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6219,    const std::string & _6220,    int _6221) { mosek::fusion::p_Parameters::setParameter(_6219,_6220,_6221); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6219,const std::string & _6220,int _6221){
  if (false)
  {
    {
    }
  }
  else if((_6220 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6220 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6220 == std::string ("numThreads")))
  {
    {
      int _6222 = _6221;
      if (((int)0 <= _6222))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6222);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6220 == std::string ("mtSpincount")))
  {
    {
      int _6223 = _6221;
      if ((((int)0 <= _6223) && (_6223 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6223);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6220 == std::string ("biMaxIterations")))
  {
    {
      int _6224 = _6221;
      if (((int)0 <= _6224))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6224);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _6225 = _6221;
      if (((int)0 <= _6225))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6225);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logCutSecondOpt")))
  {
    {
      int _6226 = _6221;
      if (((int)0 <= _6226))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6226);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logResponse")))
  {
    {
      int _6227 = _6221;
      if (((int)0 <= _6227))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6227);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6220 == std::string ("logBi")))
  {
    {
      int _6228 = _6221;
      if (((int)0 <= _6228))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6228);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logBiFreq")))
  {
    {
      int _6229 = _6221;
      if (((int)0 <= _6229))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6229);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6220 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6220 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6220 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6220 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6220 == std::string ("logIntpnt")))
  {
    {
      int _6230 = _6221;
      if (((int)0 <= _6230))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6230);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntMaxIterations")))
  {
    {
      int _6231 = _6221;
      if (((int)0 <= _6231))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6231);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntOffColTrh")))
  {
    {
      int _6232 = _6221;
      if (((int)0 <= _6232))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6232);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_6220 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      int _6233 = _6221;
      if (((int)0 <= _6233))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6233);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6220 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6220 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6220 == std::string ("intpntMaxNumCor")))
  {
    {
      int _6234 = _6221;
      if (((-(int)1) <= _6234))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6234);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6220 == std::string ("presolveLevel")))
  {
    {
      int _6235 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6235);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logPresolve")))
  {
    {
      int _6236 = _6221;
      if (((int)0 <= _6236))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6236);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6220 == std::string ("presolveMaxNumPass")))
  {
    {
      int _6237 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6237);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _6238 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6238);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _6239 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6239);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simPrimalCrash")))
  {
    {
      int _6240 = _6221;
      if (((int)0 <= _6240))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6240);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logSim")))
  {
    {
      int _6241 = _6221;
      if (((int)0 <= _6241))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6241);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logSimMinor")))
  {
    {
      int _6242 = _6221;
      if (((int)0 <= _6242))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6242);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logSimFreq")))
  {
    {
      int _6243 = _6221;
      if (((int)0 <= _6243))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6243);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _6244 = _6221;
      if ((((int)0 <= _6244) && (_6244 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6244);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6220 == std::string ("simDualRestrictSelection")))
  {
    {
      int _6245 = _6221;
      if ((((int)0 <= _6245) && (_6245 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6245);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6220 == std::string ("simMaxIterations")))
  {
    {
      int _6246 = _6221;
      if (((int)0 <= _6246))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6246);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6220 == std::string ("simRefactorFreq")))
  {
    {
      int _6247 = _6221;
      if (((int)0 <= _6247))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6247);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simSeed")))
  {
    {
      int _6248 = _6221;
      if ((((int)0 <= _6248) && (_6248 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6248);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6220 == std::string ("logMio")))
  {
    {
      int _6249 = _6221;
      if (((int)0 <= _6249))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6249);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logMioFreq")))
  {
    {
      int _6250 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6250);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _6251 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6251);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioMaxNumBranches")))
  {
    {
      int _6252 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6252);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      int _6253 = _6221;
      if (((int)0 <= _6253))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6253);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _6254 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6254);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6220 == std::string ("mioHeuristicLevel")))
  {
    {
      int _6255 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6255);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioProbingLevel")))
  {
    {
      int _6256 = _6221;
      if ((((-(int)1) <= _6256) && (_6256 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6256);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _6257 = _6221;
      if ((((-(int)1) <= _6257) && (_6257 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6257);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _6258 = _6221;
      if ((((-(int)1) <= _6258) && (_6258 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6258);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6220 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6220 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6220 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6220 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6220 == std::string ("mioSeed")))
  {
    {
      int _6259 = _6221;
      if (((int)0 <= _6259))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6259);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6220 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6220 == std::string ("writeLpLineWidth")))
  {
    {
      int _6260 = _6221;
      if (((int)40 <= _6260))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6260);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _6261 = _6221;
      if (((int)0 <= _6261))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6261);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6220 == std::string ("logInfeasAna")))
  {
    {
      int _6262 = _6221;
      if (((int)0 <= _6262))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6262);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6220 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6220 == std::string ("licensePauseTime")))
  {
    {
      int _6263 = _6221;
      if ((((int)0 <= _6263) && (_6263 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6263);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6220 == std::string ("log")))
  {
    {
      int _6264 = _6221;
      if (((int)0 <= _6264))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6264);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logExpand")))
  {
    {
      int _6265 = _6221;
      if (((int)0 <= _6265))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6265);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logFile")))
  {
    {
      int _6266 = _6221;
      if (((int)0 <= _6266))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6266);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("logOrder")))
  {
    {
      int _6267 = _6221;
      if (((int)0 <= _6267))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6267);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6220 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6220 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _6268 = _6221;
      if ((((int)0 <= _6268) && (_6268 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6268);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _6269 = _6221;
      if ((((int)0 <= _6269) && (_6269 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6269);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _6270 = _6221;
      if (((int)0 <= _6270))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6270);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6220 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6220 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6220 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6220 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6220 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6220 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6220 == std::string ("simDualCrash")))
  {
    {
      int _6271 = _6221;
      if (((int)0 <= _6271))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6271);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6220 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _6272 = _6221;
      if ((((-(int)1) <= _6272) && (_6272 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6272);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6220 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6220 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6220 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6220 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6220 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _6273 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6273);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _6274 = _6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6274);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6220 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6220 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6220 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6220 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _6275 = _6221;
      if (((-(int)1) <= _6275))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6275);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioFeaspumpLevel")))
  {
    {
      int _6276 = _6221;
      if ((((-(int)1) <= _6276) && (_6276 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6276);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("optimizerMaxTime")))
  {
    {
      double _6277 = (double)_6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6277);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("lowerObjCut")))
  {
    {
      double _6278 = (double)_6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6278);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("upperObjCut")))
  {
    {
      double _6279 = (double)_6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6279);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6280 = (double)_6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6280);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6281 = (double)_6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6281);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolRelGap")))
  {
    {
      double _6282 = (double)_6221;
      if ((1.000000e-14 <= _6282))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6282);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolStepSize")))
  {
    {
      double _6283 = (double)_6221;
      if (((0.000000e+00 <= _6283) && (_6283 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6283);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6284 = (double)_6221;
      if (((1.000000e-06 <= _6284) && (_6284 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6284);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolRelStep")))
  {
    {
      double _6285 = (double)_6221;
      if (((1.000000e-04 <= _6285) && (_6285 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6285);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolPath")))
  {
    {
      double _6286 = (double)_6221;
      if (((0.000000e+00 <= _6286) && (_6286 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6286);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolPfeas")))
  {
    {
      double _6287 = (double)_6221;
      if (((0.000000e+00 <= _6287) && (_6287 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6287);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolDfeas")))
  {
    {
      double _6288 = (double)_6221;
      if (((0.000000e+00 <= _6288) && (_6288 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6288);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolMuRed")))
  {
    {
      double _6289 = (double)_6221;
      if (((0.000000e+00 <= _6289) && (_6289 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6289);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolInfeas")))
  {
    {
      double _6290 = (double)_6221;
      if (((0.000000e+00 <= _6290) && (_6290 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6290);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6291 = (double)_6221;
      if (((0.000000e+00 <= _6291) && (_6291 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6291);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6292 = (double)_6221;
      if (((0.000000e+00 <= _6292) && (_6292 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6292);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6293 = (double)_6221;
      if (((0.000000e+00 <= _6293) && (_6293 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6293);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6294 = (double)_6221;
      if (((0.000000e+00 <= _6294) && (_6294 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6294);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6295 = (double)_6221;
      if ((1.000000e+00 <= _6295))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6295);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6296 = (double)_6221;
      if (((0.000000e+00 <= _6296) && (_6296 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6296);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolPsafe")))
  {
    {
      double _6297 = (double)_6221;
      if ((1.000000e-04 <= _6297))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6297);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("intpntTolDsafe")))
  {
    {
      double _6298 = (double)_6221;
      if ((1.000000e-04 <= _6298))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6298);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioMaxTime")))
  {
    {
      double _6299 = (double)_6221;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6299);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioRelGapConst")))
  {
    {
      double _6300 = (double)_6221;
      if ((1.000000e-15 <= _6300))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6300);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioTolRelGap")))
  {
    {
      double _6301 = (double)_6221;
      if ((0.000000e+00 <= _6301))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6301);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioTolAbsGap")))
  {
    {
      double _6302 = (double)_6221;
      if ((0.000000e+00 <= _6302))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6302);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6303 = (double)_6221;
      if ((1.000000e-09 <= _6303))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6303);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("basisTolX")))
  {
    {
      double _6304 = (double)_6221;
      if ((1.000000e-09 <= _6304))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6304);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("basisTolS")))
  {
    {
      double _6305 = (double)_6221;
      if ((1.000000e-09 <= _6305))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6305);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("basisRelTolS")))
  {
    {
      double _6306 = (double)_6221;
      if ((0.000000e+00 <= _6306))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6306);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveTolX")))
  {
    {
      double _6307 = (double)_6221;
      if ((0.000000e+00 <= _6307))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6307);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveTolS")))
  {
    {
      double _6308 = (double)_6221;
      if ((0.000000e+00 <= _6308))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6308);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveTolAij")))
  {
    {
      double _6309 = (double)_6221;
      if ((1.000000e-15 <= _6309))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6309);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6310 = (double)_6221;
      if ((0.000000e+00 <= _6310))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6310);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6311 = (double)_6221;
      if ((0.000000e+00 <= _6311))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6311);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6312 = (double)_6221;
      if ((1.000000e-12 <= _6312))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6312);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioTolFeas")))
  {
    {
      double _6313 = (double)_6221;
      if (((1.000000e-09 <= _6313) && (_6313 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6313);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6220 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6314 = (double)_6221;
      if (((0.000000e+00 <= _6314) && (_6314 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6219.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6314);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6220 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6220 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6220 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6220 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6220 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6220 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6315,    const std::string & _6316,    const std::string & _6317) { mosek::fusion::p_Parameters::setParameter(_6315,_6316,_6317); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6315,const std::string & _6316,const std::string & _6317){
  if (false)
  {
    {
    }
  }
  {}
  if ((_6316 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _6318 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6318 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_6318);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("removeUnusedSolutions")))
  {
    {
      int _6319 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6319 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_6319);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _6321 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6321))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6321);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6320)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntMultiThread")))
  {
    {
      int _6322 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6322 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_6322);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _6324 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6324) && (_6324 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6324);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6323)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("optimizer")))
  {
    {
      int _6325 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6317);
      if ((_6325 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_6325);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _6327 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6327))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6327);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6326)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _6329 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6329))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6329);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6328)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _6331 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6331))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6331);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6330)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _6333 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6333))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6333);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6332)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logLocalInfo")))
  {
    {
      int _6334 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6334 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_LOCAL_INFO"),_6334);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _6336 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6336))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6336);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6335)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _6338 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6338))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6338);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6337)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("biCleanOptimizer")))
  {
    {
      int _6339 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6317);
      if ((_6339 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_6339);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntStartingPoint")))
  {
    {
      int _6340 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_6317);
      if ((_6340 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_6340);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntDiffStep")))
  {
    {
      int _6341 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6341 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_6341);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntScaling")))
  {
    {
      int _6342 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6317);
      if ((_6342 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_6342);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntSolveForm")))
  {
    {
      int _6343 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6317);
      if ((_6343 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_6343);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _6345 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6345))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6345);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6344)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _6347 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6347))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6347);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6346)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _6349 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6349))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6349);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6348)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntOrderMethod")))
  {
    {
      int _6350 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_6317);
      if ((_6350 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_6350);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      try
      {
        {
          int _6352 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6352))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_6352);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6351)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntBasis")))
  {
    {
      int _6353 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_6317);
      if ((_6353 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_6353);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _6354 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6354 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_6354);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("biIgnoreNumError")))
  {
    {
      int _6355 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6355 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_6355);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _6357 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((-(int)1) <= _6357))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6357);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6356)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveUse")))
  {
    {
      int _6358 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_6317);
      if ((_6358 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_6358);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _6360 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6360);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6359)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _6362 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6362))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6362);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6361)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveLindepUse")))
  {
    {
      int _6363 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6363 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_6363);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _6365 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6365);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6364)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _6367 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6367);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6366)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _6369 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6369);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6368)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _6371 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6371))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6371);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6370)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _6373 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6373))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6373);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6372)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _6375 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6375))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6375);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6374)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _6377 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6377))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6377);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6376)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _6379 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6379) && (_6379 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6379);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6378)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simPrimalSelection")))
  {
    {
      int _6380 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6317);
      if ((_6380 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_6380);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _6382 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6382) && (_6382 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6382);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6381)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simDualSelection")))
  {
    {
      int _6383 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6317);
      if ((_6383 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_6383);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _6385 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6385))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6385);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6384)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simHotstartLu")))
  {
    {
      int _6386 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6386 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_6386);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _6388 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6388))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6388);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6387)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _6390 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6390) && (_6390 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6390);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6389)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioMode")))
  {
    {
      int _6391 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_6317);
      if ((_6391 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_6391);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _6393 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6393))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _6395 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _6397 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6397);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6396)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _6399 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      try
      {
        {
          int _6401 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6401))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _6403 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioNodeSelection")))
  {
    {
      int _6404 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_6317);
      if ((_6404 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_6404);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _6406 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6406);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6405)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _6408 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((-(int)1) <= _6408) && (_6408 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6408);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6407)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _6410 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((-(int)1) <= _6410) && (_6410 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6410);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6409)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _6412 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((-(int)1) <= _6412) && (_6412 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6412);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6411)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioBranchDir")))
  {
    {
      int _6413 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_6317);
      if ((_6413 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_6413);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioRootOptimizer")))
  {
    {
      int _6414 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6317);
      if ((_6414 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_6414);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioNodeOptimizer")))
  {
    {
      int _6415 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6317);
      if ((_6415 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_6415);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _6416 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6416 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_6416);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _6417 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6417 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_6417);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _6419 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6419))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6419);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6418)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _6420 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6420 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_6420);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("writeLpQuotedNames")))
  {
    {
      int _6421 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6421 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_6421);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _6423 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)40 <= _6423))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6423);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6422)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _6425 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6425))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6425);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6424)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("writeLpFullObj")))
  {
    {
      int _6426 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6426 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_6426);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _6428 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6428))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6428);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6427)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("licenseWait")))
  {
    {
      int _6429 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6429 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_6429);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _6430 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6430 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_6430);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _6432 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6432) && (_6432 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6432);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6431)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("licenseDebug")))
  {
    {
      int _6433 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6433 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_6433);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("log")))
  {
    {
      try
      {
        {
          int _6435 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6435))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6435);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6434)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _6437 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6437))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6437);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6436)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _6439 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6439))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6439);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6438)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _6441 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6441))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6441);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6440)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simScaling")))
  {
    {
      int _6442 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6317);
      if ((_6442 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_6442);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simScalingMethod")))
  {
    {
      int _6443 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_6317);
      if ((_6443 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_6443);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6445 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6445) && (_6445 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6445);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6444)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6447 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((int)0 <= _6447) && (_6447 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6447);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6446)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _6449 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6449))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6449);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6448)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simHotstart")))
  {
    {
      int _6450 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_6317);
      if ((_6450 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_6450);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simBasisFactorUse")))
  {
    {
      int _6451 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6451 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_6451);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simDegen")))
  {
    {
      int _6452 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_6317);
      if ((_6452 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_6452);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simReformulation")))
  {
    {
      int _6453 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_6317);
      if ((_6453 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_6453);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simExploitDupvec")))
  {
    {
      int _6454 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_6317);
      if ((_6454 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_6454);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simSaveLu")))
  {
    {
      int _6455 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6455 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_6455);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simNonSingular")))
  {
    {
      int _6456 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6456 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_6456);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _6458 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((int)0 <= _6458))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6458);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6457)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("infeasPreferPrimal")))
  {
    {
      int _6459 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6459 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_6459);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _6461 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((-(int)1) <= _6461) && (_6461 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6461);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6460)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioCutCmir")))
  {
    {
      int _6462 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6462 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_6462);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioCutClique")))
  {
    {
      int _6463 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6463 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_6463);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioCutImpliedBound")))
  {
    {
      int _6464 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6464 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_6464);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _6465 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6465 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_6465);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioCutGmi")))
  {
    {
      int _6466 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6466 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_6466);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _6468 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6468);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6467)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _6470 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6470);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6469)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("cacheLicense")))
  {
    {
      int _6471 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6471 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_6471);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intpntRegularizationUse")))
  {
    {
      int _6472 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6472 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_6472);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simSolveForm")))
  {
    {
      int _6473 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6317);
      if ((_6473 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_6473);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("simSwitchOptimizer")))
  {
    {
      int _6474 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6317);
      if ((_6474 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_6474);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _6476 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if (((-(int)1) <= _6476))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6476);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6475)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioFeaspumpLevel")))
  {
    {
      try
      {
        {
          int _6478 = ::mosek::fusion::Utils::Tools::toInt(_6317);
          if ((((-(int)1) <= _6478) && (_6478 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6478);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6477)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _6480 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6480);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6479)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _6482 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6482);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6481)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _6484 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6484);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6483)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6486 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6486);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6485)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6488 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6488);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6487)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _6490 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-14 <= _6490))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6490);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6489)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _6492 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6492) && (_6492 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6492);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6491)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _6494 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((1.000000e-06 <= _6494) && (_6494 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6494);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6493)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _6496 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((1.000000e-04 <= _6496) && (_6496 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6496);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6495)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _6498 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6498) && (_6498 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6498);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6497)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _6500 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6500) && (_6500 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6500);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6499)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _6502 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6502) && (_6502 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6502);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6501)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _6504 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6504) && (_6504 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6504);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6503)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _6506 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6506) && (_6506 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6506);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6505)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _6508 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6508) && (_6508 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6508);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6507)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _6510 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6510) && (_6510 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6510);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6509)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _6512 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6512) && (_6512 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6512);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6511)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _6514 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6514) && (_6514 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6514);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6513)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _6516 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e+00 <= _6516))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6516);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6515)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _6518 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6518) && (_6518 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6518);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6517)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _6520 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-04 <= _6520))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6520);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6519)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _6522 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-04 <= _6522))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6522);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6521)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _6524 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6524);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6523)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _6526 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-15 <= _6526))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6526);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6525)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _6528 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6528))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6528);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6527)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _6530 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6530))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6530);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6529)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _6532 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-09 <= _6532))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6532);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6531)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _6534 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-09 <= _6534))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6534);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6533)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _6536 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-09 <= _6536))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6536);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6535)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _6538 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6538))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6538);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6537)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _6540 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6540))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6540);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6539)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _6542 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6542))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6542);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6541)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _6544 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-15 <= _6544))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6544);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6543)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _6546 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6546))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6546);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6545)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _6548 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((0.000000e+00 <= _6548))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6548);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6547)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _6550 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if ((1.000000e-12 <= _6550))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6550);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6549)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _6552 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((1.000000e-09 <= _6552) && (_6552 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6552);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6551)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _6554 = ::mosek::fusion::Utils::Tools::toDouble(_6317);
          if (((0.000000e+00 <= _6554) && (_6554 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6554);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6553)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_6316 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_6317);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_6317);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_6317);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_6317);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_6317);
      return;
    }
  }
  {}
  if ((_6316 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6315.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_6317);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _6555){
  if ((_6555 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6555 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6555 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _6556){
  if ((_6556 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6556 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6556 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6556 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6556 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6556 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6556 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6556 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6556 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6556 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6556 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6556 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6556 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6556 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6556 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6556 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6556 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6556 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6556 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6556 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6556 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6556 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6556 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6556 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6556 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6556 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6556 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6556 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6556 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6556 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6556 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6556 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6556 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6556 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6556 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6556 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6556 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6556 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6556 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6556 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6556 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6556 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6556 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6556 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6556 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _6557){
  if ((_6557 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6557 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6557 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6557 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6557 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6557 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6557 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6557 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _6558){
  if ((_6558 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _6559){
  if ((_6559 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6559 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6559 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6559 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _6560){
  if ((_6560 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6560 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6560 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6560 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _6561){
  if ((_6561 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6561 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _6562){
  if ((_6562 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6562 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6562 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6562 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6562 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6562 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6562 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6562 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6562 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6562 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6562 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6562 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6562 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _6563){
  if ((_6563 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6563 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6563 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _6564){
  if ((_6564 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6564 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6564 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6564 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6564 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6564 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6564 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6564 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6564 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _6565){
  if ((_6565 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6565 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6565 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _6566){
  if ((_6566 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6566 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6566 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6566 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _6567){
  if ((_6567 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6567 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6567 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _6568){
  if ((_6568 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6568 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6568 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6568 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _6569){
  if ((_6569 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6569 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _6570){
  if ((_6570 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6570 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _6571){
  if ((_6571 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6571 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6571 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _6572){
  if ((_6572 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6572 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6572 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6572 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _6573){
  if ((_6573 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6573 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6573 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6573 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6573 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _6574){
  if ((_6574 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6574 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6574 == std::string ("intpntFactorNumNzAfter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6574 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6574 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6574 == std::string ("presolveStackSize")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6574 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6574 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _6575){
  if ((_6575 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6575 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6575 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _6576){
  if ((_6576 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6576 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6576 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _6577){
  if ((_6577 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6577 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _6578){
  if ((_6578 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6578 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6578 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6578 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6578 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6578 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6578 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6578 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6578 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _6579){
  if ((_6579 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6579 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6579 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6579 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _6580){
  if ((_6580 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6580 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _6581){
  if ((_6581 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6581 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6581 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6581 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6581 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _6582){
  if ((_6582 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6582 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6582 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6582 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _6583){
  if ((_6583 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6583 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6583 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6583 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6583 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _6584){
  if ((_6584 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6584 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6584 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6584 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6584 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6584 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6584 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6584 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6584 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6584 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _6585){
  if ((_6585 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6585 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6585 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6585 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6585 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6585 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6585 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _6586){
  if ((_6586 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6586 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6586 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6586 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6586 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _6587){
  if ((_6587 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _6588){
  if ((_6588 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6588 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _6589){
  if ((_6589 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6589 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6589 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6589 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _6590){
  if ((_6590 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6590 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6590 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6590 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6590 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6590 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6590 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6590 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6590 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6590 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6590 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6590 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6590 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6590 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6590 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6590 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6590 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6590 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6590 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6590 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6590 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6590 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6590 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6590 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6590 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6590 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6590 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6590 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6590 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6590 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6590 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6590 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6590 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6590 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6590 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6590 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6590 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6590 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6590 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6590 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6590 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6590 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6590 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6590 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _6591){
  if ((_6591 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6591 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _6592){
  if ((_6592 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6592 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_6592 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6592 == std::string ("intpntPurify")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6592 == std::string ("numThreads")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6592 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6592 == std::string ("timingLevel")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_6592 == std::string ("mtSpincount")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6592 == std::string ("maxNumWarnings")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6592 == std::string ("optimizer")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6592 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6592 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6592 == std::string ("logIncludeSummary")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6592 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6592 == std::string ("logAnaPro")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6592 == std::string ("logResponse")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6592 == std::string ("logLocalInfo")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6592 == std::string ("logBi")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6592 == std::string ("logBiFreq")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6592 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6592 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6592 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6592 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6592 == std::string ("intpntScaling")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6592 == std::string ("intpntSolveForm")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6592 == std::string ("logIntpnt")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6592 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6592 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6592 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6592 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6592 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6592 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6592 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6592 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6592 == std::string ("presolveUse")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_6592 == std::string ("presolveLevel")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_6592 == std::string ("logPresolve")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6592 == std::string ("presolveLindepUse")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_6592 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_6592 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_6592 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6592 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_6592 == std::string ("simStabilityPriority")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_6592 == std::string ("simPrimalCrash")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_6592 == std::string ("logSim")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6592 == std::string ("logSimMinor")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6592 == std::string ("logSimFreq")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6592 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_6592 == std::string ("simPrimalSelection")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_6592 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_6592 == std::string ("simDualSelection")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_6592 == std::string ("simMaxIterations")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_6592 == std::string ("simHotstartLu")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_6592 == std::string ("simRefactorFreq")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_6592 == std::string ("simSeed")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_6592 == std::string ("mioMode")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6592 == std::string ("logMio")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6592 == std::string ("logMioFreq")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6592 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6592 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6592 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6592 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6592 == std::string ("mioNodeSelection")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6592 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6592 == std::string ("mioProbingLevel")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6592 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6592 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6592 == std::string ("mioBranchDir")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6592 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6592 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6592 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6592 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6592 == std::string ("mioSeed")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6592 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6592 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_6592 == std::string ("readMpsFormat")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_6592 == std::string ("writeMpsFormat")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_6592 == std::string ("readMpsWidth")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_6592 == std::string ("readDebug")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_6592 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_6592 == std::string ("writeDataParam")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_6592 == std::string ("writeFreeCon")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_6592 == std::string ("writeGenericNames")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_6592 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_6592 == std::string ("writeCompression")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_6592 == std::string ("writeMpsInt")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_6592 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_6592 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_6592 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_6592 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_6592 == std::string ("writeLpFullObj")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_6592 == std::string ("writePrecision")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_6592 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)176;
    }
  }
  {}
  if ((_6592 == std::string ("writeSolHead")))
  {
    {
      return (int)175;
    }
  }
  {}
  if ((_6592 == std::string ("writeSolConstraints")))
  {
    {
      return (int)174;
    }
  }
  {}
  if ((_6592 == std::string ("writeSolVariables")))
  {
    {
      return (int)177;
    }
  }
  {}
  if ((_6592 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_6592 == std::string ("writeBasHead")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_6592 == std::string ("writeBasConstraints")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_6592 == std::string ("writeBasVariables")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_6592 == std::string ("writeIntHead")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_6592 == std::string ("writeIntConstraints")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_6592 == std::string ("writeIntVariables")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_6592 == std::string ("solReadNameWidth")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_6592 == std::string ("solReadWidth")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_6592 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6592 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6592 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6592 == std::string ("logInfeasAna")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6592 == std::string ("licenseWait")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6592 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6592 == std::string ("licensePauseTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6592 == std::string ("licenseDebug")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6592 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_6592 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_6592 == std::string ("log")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6592 == std::string ("logExpand")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6592 == std::string ("logFile")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6592 == std::string ("logOrder")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6592 == std::string ("logSensitivity")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6592 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6592 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_6592 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)178;
    }
  }
  {}
  if ((_6592 == std::string ("paramReadCaseName")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6592 == std::string ("paramReadIgnError")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6592 == std::string ("solutionCallback")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_6592 == std::string ("simScaling")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_6592 == std::string ("simScalingMethod")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_6592 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_6592 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_6592 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_6592 == std::string ("simHotstart")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_6592 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_6592 == std::string ("simDegen")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_6592 == std::string ("simReformulation")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_6592 == std::string ("simExploitDupvec")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_6592 == std::string ("simSaveLu")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_6592 == std::string ("simNonSingular")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_6592 == std::string ("simDualCrash")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_6592 == std::string ("logStorage")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6592 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6592 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteHints")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteParameters")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteProblem")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteHeader")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6592 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6592 == std::string ("ptfWriteTransform")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_6592 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_6592 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6592 == std::string ("mioCutCmir")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6592 == std::string ("mioCutClique")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6592 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6592 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6592 == std::string ("mioCutGmi")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6592 == std::string ("sensitivityType")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_6592 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_6592 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_6592 == std::string ("sensitivityAll")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_6592 == std::string ("logFeasRepair")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6592 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6592 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6592 == std::string ("simSolveForm")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_6592 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_6592 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_6592 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6592 == std::string ("logCheckConvexity")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6592 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6592 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_6592 == std::string ("writeXmlMode")))
  {
    {
      return (int)179;
    }
  }
  {}
  if ((_6592 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6592 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6592 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6592 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6592 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6592 == std::string ("mioFeaspumpLevel")))
  {
    {
      return (int)69;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _6593){
  if ((_6593 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_6593 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _6594){
  if ((_6594 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6594 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6594 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6594 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6594 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6594 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6594 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6594 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6594 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6594 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6594 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6594 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6594 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6594 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6594 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6594 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6594 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6594 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6594 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6594 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6594 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6594 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6594 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6594 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6594 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6594 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6594 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6594 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6594 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6594 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6594 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6594 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6594 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6594 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6594 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6594 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6594 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6594 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6594 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6594 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6594 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6594 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6594 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6594 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6594 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6594 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6594 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6594 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6594 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6594 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6594 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6594 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6594 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6594 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6594 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6594 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6594 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6594 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6594 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6594 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6594 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6594 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6594 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6594 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6594 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6594 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6594 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6594 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6594 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6594 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6594 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6594 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6594 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6594 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6594 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6594 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6594 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6594 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6594 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6594 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6594 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6594 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6594 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6594 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6594 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6594 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6594 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6594 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6594 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6594 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6594 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6594 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6594 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _6595){
  if ((_6595 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6595 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6595 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6595 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6595 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6595 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6595 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6595 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6595 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6595 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6595 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6595 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6595 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6595 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6595 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6595 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6595 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6595 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6595 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6595 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6595 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6595 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6595 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6595 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6595 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6595 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6595 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6595 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6595 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6595 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6595 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6595 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6595 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6595 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6595 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6595 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6595 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6595 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6595 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6595 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _6596){
  if ((_6596 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6596 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6596 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _6597){
  if ((_6597 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6597 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6597 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6597 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6597 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6597 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6597 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _6598){
  if ((_6598 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6598 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6598 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6598 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6598 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6598 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6598 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6598 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _6599){
  if ((_6599 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6599 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6599 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6599 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6599 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6599 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6599 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6599 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6599 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6599 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6599 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6599 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6599 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6599 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6599 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6599 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6599 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6599 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6599 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6599 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6599 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6599 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6599 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6599 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _6600){
  if ((_6600 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6600 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _6601){
  if ((_6601 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6601 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6601 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6601 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _6602){
  if ((_6602 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6602 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _6603){
  if ((_6603 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6603 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6603 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6603 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6603 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6603 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _6604){
  if ((_6604 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6604 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _6605){
  if ((_6605 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6605 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6605 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _6606){
  if ((_6606 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6606 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6606 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6606 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _6607){
  if ((_6607 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6607 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6607 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _6608){
  if ((_6608 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6608 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6608 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6608 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6608 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _6609){
  if ((_6609 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6609 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6609 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6609 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6609 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6609 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6609 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _6610){
  if ((_6610 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6610 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6610 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6610 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6610 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6610 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6610 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6610 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6610 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6610 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6610 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6610 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6610 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6610 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6610 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6610 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6610 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6610 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6610 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6610 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6610 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6610 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6610 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6610 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6610 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6610 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6610 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6610 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6610 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6610 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6610 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6610 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6610 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6610 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6610 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6610 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6610 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6610 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6610 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6610 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6610 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6610 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6610 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6610 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6610 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6610 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6610 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6610 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6610 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6610 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6610 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6610 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6610 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6610 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6610 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6610 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6610 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6610 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6610 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6610 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6610 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6610 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6610 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6610 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6610 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6610 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6610 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6610 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6610 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6610 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6610 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6610 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6610 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6610 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _6611){
  if ((_6611 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6611 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _6612){
  if ((_6612 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6612 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6612 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6612 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6612 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6612 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6612 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6612 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6612 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_6612 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_6612 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_6612 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_6612 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_6612 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_6612 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_6612 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_6612 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_6612 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_6612 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_6612 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_6612 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_6612 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_6612 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_6612 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_6612 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_6612 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_6612 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_6612 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_6612 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_6612 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_6612 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_6612 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_6612 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_6612 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_6612 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_6612 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_6612 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_6612 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_6612 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_6612 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_6612 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_6612 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_6612 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_6612 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_6612 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_6612 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_6612 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_6612 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_6612 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_6612 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_6612 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_6612 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_6612 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_6612 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_6612 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_6612 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_6612 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_6612 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_6612 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_6612 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_6612 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_6612 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_6612 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_6612 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_6612 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_6612 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_6612 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_6612 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_6612 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_6612 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_6612 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_6612 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_6612 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_6612 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_6612 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_6612 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_6612 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_6612 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_6612 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_6612 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_6612 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_6612 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_6612 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_6612 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_6612 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_6612 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_6612 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_6612 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_6612 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_6612 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_6612 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_6612 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_6612 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_6612 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_6612 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_6612 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_6612 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_6612 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_6612 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_6612 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_6612 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_6612 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_6612 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_6612 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_6612 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_6612 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_6612 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_6612 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_6612 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_6612 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_6612 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_6612 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_6612 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_6612 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_6612 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_6612 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_6612 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_6612 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_6612 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_6612 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_6612 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_6612 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_6612 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_6612 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_6612 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_6612 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_6612 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_6612 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_6612 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_6612 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_6612 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_6612 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_6612 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_6612 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_6612 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_6612 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_6612 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_6612 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_6612 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_6612 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_6612 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_6612 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_6612 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_6612 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_6612 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_6612 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_6612 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_6612 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_6612 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_6612 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_6612 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_6612 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_6612 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_6612 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_6612 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_6612 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_6612 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_6612 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_6612 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_6612 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_6612 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_6612 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_6612 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_6612 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_6612 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_6612 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_6612 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_6612 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_6612 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_6612 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_6612 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_6612 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_6612 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_6612 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_6612 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_6612 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_6612 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_6612 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_6612 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_6612 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_6612 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_6612 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_6612 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_6612 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_6612 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_6612 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_6612 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_6612 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_6612 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_6612 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_6612 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_6612 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_6612 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_6612 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_6612 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_6612 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_6612 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_6612 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_6612 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_6612 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_6612 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_6612 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_6612 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_6612 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_6612 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_6612 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_6612 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_6612 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_6612 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_6612 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_6612 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_6612 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_6612 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_6612 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_6612 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_6612 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_6612 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_6612 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_6612 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_6612 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_6612 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_6612 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_6612 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_6612 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_6612 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_6612 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_6612 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_6612 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_6612 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_6612 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_6612 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_6612 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_6612 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_6612 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_6612 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_6612 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_6612 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_6612 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_6612 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_6612 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_6612 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_6612 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_6612 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_6612 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_6612 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_6612 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_6612 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_6612 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_6612 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_6612 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_6612 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_6612 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_6612 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_6612 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_6612 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_6612 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_6612 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_6612 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_6612 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_6612 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_6612 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_6612 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_6612 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_6612 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_6612 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_6612 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_6612 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_6612 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_6612 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_6612 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_6612 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_6612 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_6612 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_6612 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_6612 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_6612 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_6612 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_6612 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_6612 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_6612 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_6612 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_6612 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_6612 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_6612 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_6612 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_6612 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_6612 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_6612 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_6612 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_6612 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_6612 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_6612 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_6612 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_6612 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_6612 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_6612 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_6612 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_6612 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_6612 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_6612 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_6612 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_6612 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_6612 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_6612 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_6612 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_6612 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_6612 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_6612 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_6612 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_6612 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_6612 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_6612 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_6612 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_6612 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_6612 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_6612 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_6612 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_6612 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_6612 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_6612 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_6612 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_6612 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_6612 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_6612 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_6612 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _6613){
  if ((_6613 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6613 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6613 == std::string ("optimizeResponse")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6613 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6613 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6613 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6613 == std::string ("mioNodeDepth")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumbin")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumcont")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumcon")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumcone")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumrqcones")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumdexpcones")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumppowcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumdpowcones")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumconevar")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumdexpcones")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumppowcones")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumdpowcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6613 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6613 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6613 == std::string ("mioConstructSolution")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6613 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumRelax")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumBranch")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6613 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6613 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6613 == std::string ("mioUserObjCut")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6613 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6613 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6613 == std::string ("rdProtype")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6613 == std::string ("rdNumcon")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6613 == std::string ("rdNumvar")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6613 == std::string ("rdNumbarvar")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6613 == std::string ("rdNumintvar")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6613 == std::string ("rdNumq")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6613 == std::string ("simDualDegIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6613 == std::string ("simDualInfIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6613 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6613 == std::string ("simPrimalIter")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6613 == std::string ("simDualIter")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6613 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6613 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6613 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6613 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6613 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6613 == std::string ("simDualHotstart")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6613 == std::string ("solItrProsta")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6613 == std::string ("solItrSolsta")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6613 == std::string ("solBasProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6613 == std::string ("solBasSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6613 == std::string ("solItgProsta")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6613 == std::string ("solItgSolsta")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6613 == std::string ("simNumcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6613 == std::string ("simNumvar")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6613 == std::string ("optNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6613 == std::string ("optNumvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6613 == std::string ("stoNumARealloc")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6613 == std::string ("rdNumcone")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6613 == std::string ("simSolveDual")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6613 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6613 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)72;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _6614){
  if ((_6614 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6614 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6614 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6614 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6614 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _6615){
  if ((_6615 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6615 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6615 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6615 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6615 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6615 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _6616){
  if ((_6616 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6616 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6616 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6616 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6616 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }